import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface YandexProviderConfig {
    /**
    * ID of Yandex.Cloud tenant.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#cloud_id YandexProvider#cloud_id}
    */
    readonly cloudId?: string;
    /**
    * The API endpoint for Yandex.Cloud SDK client.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#endpoint YandexProvider#endpoint}
    */
    readonly endpoint?: string;
    /**
    * The default folder ID where resources will be placed.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#folder_id YandexProvider#folder_id}
    */
    readonly folderId?: string;
    /**
    * Explicitly allow the provider to perform "insecure" SSL requests. If omitted,default value is `false`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#insecure YandexProvider#insecure}
    */
    readonly insecure?: boolean | cdktf.IResolvable;
    /**
    * The maximum number of times an API request is being executed.
  If the API request still fails, an error is thrown.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#max_retries YandexProvider#max_retries}
    */
    readonly maxRetries?: number;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#organization_id YandexProvider#organization_id}
    */
    readonly organizationId?: string;
    /**
    * Disable use of TLS. Default value is `false`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#plaintext YandexProvider#plaintext}
    */
    readonly plaintext?: boolean | cdktf.IResolvable;
    /**
    * Either the path to or the contents of a Service Account key file in JSON format.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#service_account_key_file YandexProvider#service_account_key_file}
    */
    readonly serviceAccountKeyFile?: string;
    /**
    * Yandex.Cloud storage service access key.
  Used when a storage data/resource doesn't have an access key explicitly specified.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#storage_access_key YandexProvider#storage_access_key}
    */
    readonly storageAccessKey?: string;
    /**
    * Yandex.Cloud storage service endpoint. Default is
  storage.yandexcloud.net
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#storage_endpoint YandexProvider#storage_endpoint}
    */
    readonly storageEndpoint?: string;
    /**
    * Yandex.Cloud storage service secret key.
  Used when a storage data/resource doesn't have a secret key explicitly specified.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#storage_secret_key YandexProvider#storage_secret_key}
    */
    readonly storageSecretKey?: string;
    /**
    * The access token for API operations.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#token YandexProvider#token}
    */
    readonly token?: string;
    /**
    * Yandex.Cloud Message Queue service access key.
  Used when a message queue resource doesn't have an access key explicitly specified.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#ymq_access_key YandexProvider#ymq_access_key}
    */
    readonly ymqAccessKey?: string;
    /**
    * Yandex.Cloud Message Queue service endpoint. Default is
  message-queue.api.cloud.yandex.net
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#ymq_endpoint YandexProvider#ymq_endpoint}
    */
    readonly ymqEndpoint?: string;
    /**
    * Yandex.Cloud Message Queue service secret key.
  Used when a message queue resource doesn't have a secret key explicitly specified.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#ymq_secret_key YandexProvider#ymq_secret_key}
    */
    readonly ymqSecretKey?: string;
    /**
    * The zone where operations will take place. Examples
  are ru-central1-a, ru-central2-c, etc.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#zone YandexProvider#zone}
    */
    readonly zone?: string;
    /**
    * Alias name
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#alias YandexProvider#alias}
    */
    readonly alias?: string;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/yandex yandex}
*/
export declare class YandexProvider extends cdktf.TerraformProvider {
    static readonly tfResourceType = "yandex";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/yandex yandex} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options YandexProviderConfig = {}
    */
    constructor(scope: Construct, id: string, config?: YandexProviderConfig);
    private _cloudId?;
    get cloudId(): string | undefined;
    set cloudId(value: string | undefined);
    resetCloudId(): void;
    get cloudIdInput(): string | undefined;
    private _endpoint?;
    get endpoint(): string | undefined;
    set endpoint(value: string | undefined);
    resetEndpoint(): void;
    get endpointInput(): string | undefined;
    private _folderId?;
    get folderId(): string | undefined;
    set folderId(value: string | undefined);
    resetFolderId(): void;
    get folderIdInput(): string | undefined;
    private _insecure?;
    get insecure(): boolean | cdktf.IResolvable | undefined;
    set insecure(value: boolean | cdktf.IResolvable | undefined);
    resetInsecure(): void;
    get insecureInput(): boolean | cdktf.IResolvable | undefined;
    private _maxRetries?;
    get maxRetries(): number | undefined;
    set maxRetries(value: number | undefined);
    resetMaxRetries(): void;
    get maxRetriesInput(): number | undefined;
    private _organizationId?;
    get organizationId(): string | undefined;
    set organizationId(value: string | undefined);
    resetOrganizationId(): void;
    get organizationIdInput(): string | undefined;
    private _plaintext?;
    get plaintext(): boolean | cdktf.IResolvable | undefined;
    set plaintext(value: boolean | cdktf.IResolvable | undefined);
    resetPlaintext(): void;
    get plaintextInput(): boolean | cdktf.IResolvable | undefined;
    private _serviceAccountKeyFile?;
    get serviceAccountKeyFile(): string | undefined;
    set serviceAccountKeyFile(value: string | undefined);
    resetServiceAccountKeyFile(): void;
    get serviceAccountKeyFileInput(): string | undefined;
    private _storageAccessKey?;
    get storageAccessKey(): string | undefined;
    set storageAccessKey(value: string | undefined);
    resetStorageAccessKey(): void;
    get storageAccessKeyInput(): string | undefined;
    private _storageEndpoint?;
    get storageEndpoint(): string | undefined;
    set storageEndpoint(value: string | undefined);
    resetStorageEndpoint(): void;
    get storageEndpointInput(): string | undefined;
    private _storageSecretKey?;
    get storageSecretKey(): string | undefined;
    set storageSecretKey(value: string | undefined);
    resetStorageSecretKey(): void;
    get storageSecretKeyInput(): string | undefined;
    private _token?;
    get token(): string | undefined;
    set token(value: string | undefined);
    resetToken(): void;
    get tokenInput(): string | undefined;
    private _ymqAccessKey?;
    get ymqAccessKey(): string | undefined;
    set ymqAccessKey(value: string | undefined);
    resetYmqAccessKey(): void;
    get ymqAccessKeyInput(): string | undefined;
    private _ymqEndpoint?;
    get ymqEndpoint(): string | undefined;
    set ymqEndpoint(value: string | undefined);
    resetYmqEndpoint(): void;
    get ymqEndpointInput(): string | undefined;
    private _ymqSecretKey?;
    get ymqSecretKey(): string | undefined;
    set ymqSecretKey(value: string | undefined);
    resetYmqSecretKey(): void;
    get ymqSecretKeyInput(): string | undefined;
    private _zone?;
    get zone(): string | undefined;
    set zone(value: string | undefined);
    resetZone(): void;
    get zoneInput(): string | undefined;
    private _alias?;
    get alias(): string | undefined;
    set alias(value: string | undefined);
    resetAlias(): void;
    get aliasInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
//# sourceMappingURL=yandex-provider.d.ts.map