'''
# Terraform CDK yandex Provider ~> 0.73.0

This repo builds and publishes the Terraform yandex Provider bindings for [cdktf](https://cdk.tf).

## Available Packages

### NPM

The npm package is available at [https://www.npmjs.com/package/@cdktf/provider-yandex](https://www.npmjs.com/package/@cdktf/provider-yandex).

`npm install @cdktf/provider-yandex`

### PyPI

The PyPI package is available at [https://pypi.org/project/cdktf-cdktf-provider-yandex](https://pypi.org/project/cdktf-cdktf-provider-yandex).

`pipenv install cdktf-cdktf-provider-yandex`

### Nuget

The Nuget package is available at [https://www.nuget.org/packages/HashiCorp.Cdktf.Providers.Yandex](https://www.nuget.org/packages/HashiCorp.Cdktf.Providers.Yandex).

`dotnet add package HashiCorp.Cdktf.Providers.Yandex`

### Maven

The Maven package is available at [https://mvnrepository.com/artifact/com.hashicorp/cdktf-provider-yandex](https://mvnrepository.com/artifact/com.hashicorp/cdktf-provider-yandex).

```
<dependency>
    <groupId>com.hashicorp</groupId>
    <artifactId>cdktf-provider-yandex</artifactId>
    <version>[REPLACE WITH DESIRED VERSION]</version>
</dependency>
```

## Docs

Find auto-generated docs for this provider here: [./API.md](./API.md)

## Versioning

This project is explicitly not tracking the Terraform yandex Provider version 1:1. In fact, it always tracks `latest` of `~> 0.73.0` with every release. If there are scenarios where you explicitly have to pin your provider version, you can do so by generating the [provider constructs manually](https://cdk.tf/imports).

These are the upstream dependencies:

* [Terraform CDK](https://cdk.tf)
* [Terraform yandex Provider](https://github.com/terraform-providers/terraform-provider-yandex)
* [Terraform Engine](https://terraform.io)

If there are breaking changes (backward incompatible) in any of the above, the major version of this project will be bumped. While the Terraform Engine and the Terraform yandex Provider are relatively stable, the Terraform CDK is in an early stage. Therefore, it's likely that there will be breaking changes.

## Features / Issues / Bugs

Please report bugs and issues to the [terraform cdk](https://cdk.tf) project:

* [Create bug report](https://cdk.tf/bug)
* [Create feature request](https://cdk.tf/feature)

## Contributing

### projen

This is mostly based on [projen](https://github.com/eladb/projen), which takes care of generating the entire repository.

### cdktf-provider-project based on projen

There's a custom [project builder](https://github.com/hashicorp/cdktf-provider-project) which encapsulate the common settings for all `cdktf` providers.

### Provider Version

The provider version can be adjusted in [./.projenrc.js](./.projenrc.js).

### Repository Management

The repository is managed by [Repository Manager](https://github.com/hashicorp/cdktf-repository-manager/)
'''
import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

from ._jsii import *

import cdktf
import constructs


class AlbBackendGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbBackendGroup",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group yandex_alb_backend_group}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        grpc_backend: typing.Optional[typing.Union[typing.Sequence["AlbBackendGroupGrpcBackend"], cdktf.IResolvable]] = None,
        http_backend: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["AlbBackendGroupHttpBackend"]]] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        stream_backend: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["AlbBackendGroupStreamBackend"]]] = None,
        timeouts: typing.Optional["AlbBackendGroupTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group yandex_alb_backend_group} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#description AlbBackendGroup#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#folder_id AlbBackendGroup#folder_id}.
        :param grpc_backend: grpc_backend block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#grpc_backend AlbBackendGroup#grpc_backend}
        :param http_backend: http_backend block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#http_backend AlbBackendGroup#http_backend}
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#id AlbBackendGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#labels AlbBackendGroup#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#name AlbBackendGroup#name}.
        :param stream_backend: stream_backend block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#stream_backend AlbBackendGroup#stream_backend}
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#timeouts AlbBackendGroup#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = AlbBackendGroupConfig(
            description=description,
            folder_id=folder_id,
            grpc_backend=grpc_backend,
            http_backend=http_backend,
            id=id,
            labels=labels,
            name=name,
            stream_backend=stream_backend,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putGrpcBackend")
    def put_grpc_backend(
        self,
        value: typing.Union[typing.Sequence["AlbBackendGroupGrpcBackend"], cdktf.IResolvable],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putGrpcBackend", [value]))

    @jsii.member(jsii_name="putHttpBackend")
    def put_http_backend(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["AlbBackendGroupHttpBackend"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putHttpBackend", [value]))

    @jsii.member(jsii_name="putStreamBackend")
    def put_stream_backend(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["AlbBackendGroupStreamBackend"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putStreamBackend", [value]))

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#create AlbBackendGroup#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#delete AlbBackendGroup#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#update AlbBackendGroup#update}.
        '''
        value = AlbBackendGroupTimeouts(create=create, delete=delete, update=update)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetGrpcBackend")
    def reset_grpc_backend(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGrpcBackend", []))

    @jsii.member(jsii_name="resetHttpBackend")
    def reset_http_backend(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttpBackend", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetStreamBackend")
    def reset_stream_backend(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStreamBackend", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="grpcBackend")
    def grpc_backend(self) -> "AlbBackendGroupGrpcBackendList":
        return typing.cast("AlbBackendGroupGrpcBackendList", jsii.get(self, "grpcBackend"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpBackend")
    def http_backend(self) -> "AlbBackendGroupHttpBackendList":
        return typing.cast("AlbBackendGroupHttpBackendList", jsii.get(self, "httpBackend"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="streamBackend")
    def stream_backend(self) -> "AlbBackendGroupStreamBackendList":
        return typing.cast("AlbBackendGroupStreamBackendList", jsii.get(self, "streamBackend"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "AlbBackendGroupTimeoutsOutputReference":
        return typing.cast("AlbBackendGroupTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="grpcBackendInput")
    def grpc_backend_input(
        self,
    ) -> typing.Optional[typing.Union[typing.List["AlbBackendGroupGrpcBackend"], cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[typing.List["AlbBackendGroupGrpcBackend"], cdktf.IResolvable]], jsii.get(self, "grpcBackendInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpBackendInput")
    def http_backend_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbBackendGroupHttpBackend"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbBackendGroupHttpBackend"]]], jsii.get(self, "httpBackendInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="streamBackendInput")
    def stream_backend_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbBackendGroupStreamBackend"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbBackendGroupStreamBackend"]]], jsii.get(self, "streamBackendInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "AlbBackendGroupTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "AlbBackendGroupTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "description": "description",
        "folder_id": "folderId",
        "grpc_backend": "grpcBackend",
        "http_backend": "httpBackend",
        "id": "id",
        "labels": "labels",
        "name": "name",
        "stream_backend": "streamBackend",
        "timeouts": "timeouts",
    },
)
class AlbBackendGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        grpc_backend: typing.Optional[typing.Union[typing.Sequence["AlbBackendGroupGrpcBackend"], cdktf.IResolvable]] = None,
        http_backend: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["AlbBackendGroupHttpBackend"]]] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        stream_backend: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["AlbBackendGroupStreamBackend"]]] = None,
        timeouts: typing.Optional["AlbBackendGroupTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#description AlbBackendGroup#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#folder_id AlbBackendGroup#folder_id}.
        :param grpc_backend: grpc_backend block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#grpc_backend AlbBackendGroup#grpc_backend}
        :param http_backend: http_backend block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#http_backend AlbBackendGroup#http_backend}
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#id AlbBackendGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#labels AlbBackendGroup#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#name AlbBackendGroup#name}.
        :param stream_backend: stream_backend block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#stream_backend AlbBackendGroup#stream_backend}
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#timeouts AlbBackendGroup#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AlbBackendGroupTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if grpc_backend is not None:
            self._values["grpc_backend"] = grpc_backend
        if http_backend is not None:
            self._values["http_backend"] = http_backend
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if name is not None:
            self._values["name"] = name
        if stream_backend is not None:
            self._values["stream_backend"] = stream_backend
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#description AlbBackendGroup#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#folder_id AlbBackendGroup#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def grpc_backend(
        self,
    ) -> typing.Optional[typing.Union[typing.List["AlbBackendGroupGrpcBackend"], cdktf.IResolvable]]:
        '''grpc_backend block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#grpc_backend AlbBackendGroup#grpc_backend}
        '''
        result = self._values.get("grpc_backend")
        return typing.cast(typing.Optional[typing.Union[typing.List["AlbBackendGroupGrpcBackend"], cdktf.IResolvable]], result)

    @builtins.property
    def http_backend(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbBackendGroupHttpBackend"]]]:
        '''http_backend block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#http_backend AlbBackendGroup#http_backend}
        '''
        result = self._values.get("http_backend")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbBackendGroupHttpBackend"]]], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#id AlbBackendGroup#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#labels AlbBackendGroup#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#name AlbBackendGroup#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def stream_backend(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbBackendGroupStreamBackend"]]]:
        '''stream_backend block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#stream_backend AlbBackendGroup#stream_backend}
        '''
        result = self._values.get("stream_backend")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbBackendGroupStreamBackend"]]], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["AlbBackendGroupTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#timeouts AlbBackendGroup#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["AlbBackendGroupTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbBackendGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupGrpcBackend",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "target_group_ids": "targetGroupIds",
        "healthcheck": "healthcheck",
        "load_balancing_config": "loadBalancingConfig",
        "port": "port",
        "tls": "tls",
        "weight": "weight",
    },
)
class AlbBackendGroupGrpcBackend:
    def __init__(
        self,
        *,
        name: builtins.str,
        target_group_ids: typing.Sequence[builtins.str],
        healthcheck: typing.Optional["AlbBackendGroupGrpcBackendHealthcheck"] = None,
        load_balancing_config: typing.Optional["AlbBackendGroupGrpcBackendLoadBalancingConfig"] = None,
        port: typing.Optional[jsii.Number] = None,
        tls: typing.Optional["AlbBackendGroupGrpcBackendTls"] = None,
        weight: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#name AlbBackendGroup#name}.
        :param target_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#target_group_ids AlbBackendGroup#target_group_ids}.
        :param healthcheck: healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#healthcheck AlbBackendGroup#healthcheck}
        :param load_balancing_config: load_balancing_config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#load_balancing_config AlbBackendGroup#load_balancing_config}
        :param port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#port AlbBackendGroup#port}.
        :param tls: tls block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#tls AlbBackendGroup#tls}
        :param weight: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#weight AlbBackendGroup#weight}.
        '''
        if isinstance(healthcheck, dict):
            healthcheck = AlbBackendGroupGrpcBackendHealthcheck(**healthcheck)
        if isinstance(load_balancing_config, dict):
            load_balancing_config = AlbBackendGroupGrpcBackendLoadBalancingConfig(**load_balancing_config)
        if isinstance(tls, dict):
            tls = AlbBackendGroupGrpcBackendTls(**tls)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "target_group_ids": target_group_ids,
        }
        if healthcheck is not None:
            self._values["healthcheck"] = healthcheck
        if load_balancing_config is not None:
            self._values["load_balancing_config"] = load_balancing_config
        if port is not None:
            self._values["port"] = port
        if tls is not None:
            self._values["tls"] = tls
        if weight is not None:
            self._values["weight"] = weight

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#name AlbBackendGroup#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def target_group_ids(self) -> typing.List[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#target_group_ids AlbBackendGroup#target_group_ids}.'''
        result = self._values.get("target_group_ids")
        assert result is not None, "Required property 'target_group_ids' is missing"
        return typing.cast(typing.List[builtins.str], result)

    @builtins.property
    def healthcheck(self) -> typing.Optional["AlbBackendGroupGrpcBackendHealthcheck"]:
        '''healthcheck block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#healthcheck AlbBackendGroup#healthcheck}
        '''
        result = self._values.get("healthcheck")
        return typing.cast(typing.Optional["AlbBackendGroupGrpcBackendHealthcheck"], result)

    @builtins.property
    def load_balancing_config(
        self,
    ) -> typing.Optional["AlbBackendGroupGrpcBackendLoadBalancingConfig"]:
        '''load_balancing_config block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#load_balancing_config AlbBackendGroup#load_balancing_config}
        '''
        result = self._values.get("load_balancing_config")
        return typing.cast(typing.Optional["AlbBackendGroupGrpcBackendLoadBalancingConfig"], result)

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#port AlbBackendGroup#port}.'''
        result = self._values.get("port")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def tls(self) -> typing.Optional["AlbBackendGroupGrpcBackendTls"]:
        '''tls block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#tls AlbBackendGroup#tls}
        '''
        result = self._values.get("tls")
        return typing.cast(typing.Optional["AlbBackendGroupGrpcBackendTls"], result)

    @builtins.property
    def weight(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#weight AlbBackendGroup#weight}.'''
        result = self._values.get("weight")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbBackendGroupGrpcBackend(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupGrpcBackendHealthcheck",
    jsii_struct_bases=[],
    name_mapping={
        "interval": "interval",
        "timeout": "timeout",
        "grpc_healthcheck": "grpcHealthcheck",
        "healthcheck_port": "healthcheckPort",
        "healthy_threshold": "healthyThreshold",
        "http_healthcheck": "httpHealthcheck",
        "interval_jitter_percent": "intervalJitterPercent",
        "stream_healthcheck": "streamHealthcheck",
        "unhealthy_threshold": "unhealthyThreshold",
    },
)
class AlbBackendGroupGrpcBackendHealthcheck:
    def __init__(
        self,
        *,
        interval: builtins.str,
        timeout: builtins.str,
        grpc_healthcheck: typing.Optional["AlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheck"] = None,
        healthcheck_port: typing.Optional[jsii.Number] = None,
        healthy_threshold: typing.Optional[jsii.Number] = None,
        http_healthcheck: typing.Optional["AlbBackendGroupGrpcBackendHealthcheckHttpHealthcheck"] = None,
        interval_jitter_percent: typing.Optional[jsii.Number] = None,
        stream_healthcheck: typing.Optional["AlbBackendGroupGrpcBackendHealthcheckStreamHealthcheck"] = None,
        unhealthy_threshold: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param interval: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#interval AlbBackendGroup#interval}.
        :param timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#timeout AlbBackendGroup#timeout}.
        :param grpc_healthcheck: grpc_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#grpc_healthcheck AlbBackendGroup#grpc_healthcheck}
        :param healthcheck_port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#healthcheck_port AlbBackendGroup#healthcheck_port}.
        :param healthy_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#healthy_threshold AlbBackendGroup#healthy_threshold}.
        :param http_healthcheck: http_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#http_healthcheck AlbBackendGroup#http_healthcheck}
        :param interval_jitter_percent: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#interval_jitter_percent AlbBackendGroup#interval_jitter_percent}.
        :param stream_healthcheck: stream_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#stream_healthcheck AlbBackendGroup#stream_healthcheck}
        :param unhealthy_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#unhealthy_threshold AlbBackendGroup#unhealthy_threshold}.
        '''
        if isinstance(grpc_healthcheck, dict):
            grpc_healthcheck = AlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheck(**grpc_healthcheck)
        if isinstance(http_healthcheck, dict):
            http_healthcheck = AlbBackendGroupGrpcBackendHealthcheckHttpHealthcheck(**http_healthcheck)
        if isinstance(stream_healthcheck, dict):
            stream_healthcheck = AlbBackendGroupGrpcBackendHealthcheckStreamHealthcheck(**stream_healthcheck)
        self._values: typing.Dict[str, typing.Any] = {
            "interval": interval,
            "timeout": timeout,
        }
        if grpc_healthcheck is not None:
            self._values["grpc_healthcheck"] = grpc_healthcheck
        if healthcheck_port is not None:
            self._values["healthcheck_port"] = healthcheck_port
        if healthy_threshold is not None:
            self._values["healthy_threshold"] = healthy_threshold
        if http_healthcheck is not None:
            self._values["http_healthcheck"] = http_healthcheck
        if interval_jitter_percent is not None:
            self._values["interval_jitter_percent"] = interval_jitter_percent
        if stream_healthcheck is not None:
            self._values["stream_healthcheck"] = stream_healthcheck
        if unhealthy_threshold is not None:
            self._values["unhealthy_threshold"] = unhealthy_threshold

    @builtins.property
    def interval(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#interval AlbBackendGroup#interval}.'''
        result = self._values.get("interval")
        assert result is not None, "Required property 'interval' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def timeout(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#timeout AlbBackendGroup#timeout}.'''
        result = self._values.get("timeout")
        assert result is not None, "Required property 'timeout' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def grpc_healthcheck(
        self,
    ) -> typing.Optional["AlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheck"]:
        '''grpc_healthcheck block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#grpc_healthcheck AlbBackendGroup#grpc_healthcheck}
        '''
        result = self._values.get("grpc_healthcheck")
        return typing.cast(typing.Optional["AlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheck"], result)

    @builtins.property
    def healthcheck_port(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#healthcheck_port AlbBackendGroup#healthcheck_port}.'''
        result = self._values.get("healthcheck_port")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def healthy_threshold(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#healthy_threshold AlbBackendGroup#healthy_threshold}.'''
        result = self._values.get("healthy_threshold")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def http_healthcheck(
        self,
    ) -> typing.Optional["AlbBackendGroupGrpcBackendHealthcheckHttpHealthcheck"]:
        '''http_healthcheck block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#http_healthcheck AlbBackendGroup#http_healthcheck}
        '''
        result = self._values.get("http_healthcheck")
        return typing.cast(typing.Optional["AlbBackendGroupGrpcBackendHealthcheckHttpHealthcheck"], result)

    @builtins.property
    def interval_jitter_percent(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#interval_jitter_percent AlbBackendGroup#interval_jitter_percent}.'''
        result = self._values.get("interval_jitter_percent")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def stream_healthcheck(
        self,
    ) -> typing.Optional["AlbBackendGroupGrpcBackendHealthcheckStreamHealthcheck"]:
        '''stream_healthcheck block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#stream_healthcheck AlbBackendGroup#stream_healthcheck}
        '''
        result = self._values.get("stream_healthcheck")
        return typing.cast(typing.Optional["AlbBackendGroupGrpcBackendHealthcheckStreamHealthcheck"], result)

    @builtins.property
    def unhealthy_threshold(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#unhealthy_threshold AlbBackendGroup#unhealthy_threshold}.'''
        result = self._values.get("unhealthy_threshold")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbBackendGroupGrpcBackendHealthcheck(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheck",
    jsii_struct_bases=[],
    name_mapping={"service_name": "serviceName"},
)
class AlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheck:
    def __init__(self, *, service_name: typing.Optional[builtins.str] = None) -> None:
        '''
        :param service_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#service_name AlbBackendGroup#service_name}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if service_name is not None:
            self._values["service_name"] = service_name

    @builtins.property
    def service_name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#service_name AlbBackendGroup#service_name}.'''
        result = self._values.get("service_name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheck(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheckOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheckOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetServiceName")
    def reset_service_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetServiceName", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceNameInput")
    def service_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceName")
    def service_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceName"))

    @service_name.setter
    def service_name(self, value: builtins.str) -> None:
        jsii.set(self, "serviceName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheck]:
        return typing.cast(typing.Optional[AlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheck], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheck],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupGrpcBackendHealthcheckHttpHealthcheck",
    jsii_struct_bases=[],
    name_mapping={"path": "path", "host": "host", "http2": "http2"},
)
class AlbBackendGroupGrpcBackendHealthcheckHttpHealthcheck:
    def __init__(
        self,
        *,
        path: builtins.str,
        host: typing.Optional[builtins.str] = None,
        http2: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param path: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#path AlbBackendGroup#path}.
        :param host: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#host AlbBackendGroup#host}.
        :param http2: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#http2 AlbBackendGroup#http2}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "path": path,
        }
        if host is not None:
            self._values["host"] = host
        if http2 is not None:
            self._values["http2"] = http2

    @builtins.property
    def path(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#path AlbBackendGroup#path}.'''
        result = self._values.get("path")
        assert result is not None, "Required property 'path' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def host(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#host AlbBackendGroup#host}.'''
        result = self._values.get("host")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def http2(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#http2 AlbBackendGroup#http2}.'''
        result = self._values.get("http2")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbBackendGroupGrpcBackendHealthcheckHttpHealthcheck(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbBackendGroupGrpcBackendHealthcheckHttpHealthcheckOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupGrpcBackendHealthcheckHttpHealthcheckOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetHost")
    def reset_host(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHost", []))

    @jsii.member(jsii_name="resetHttp2")
    def reset_http2(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttp2", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostInput")
    def host_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "hostInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="http2Input")
    def http2_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "http2Input"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="pathInput")
    def path_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "pathInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="host")
    def host(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "host"))

    @host.setter
    def host(self, value: builtins.str) -> None:
        jsii.set(self, "host", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="http2")
    def http2(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "http2"))

    @http2.setter
    def http2(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "http2", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="path")
    def path(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "path"))

    @path.setter
    def path(self, value: builtins.str) -> None:
        jsii.set(self, "path", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbBackendGroupGrpcBackendHealthcheckHttpHealthcheck]:
        return typing.cast(typing.Optional[AlbBackendGroupGrpcBackendHealthcheckHttpHealthcheck], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbBackendGroupGrpcBackendHealthcheckHttpHealthcheck],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbBackendGroupGrpcBackendHealthcheckOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupGrpcBackendHealthcheckOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putGrpcHealthcheck")
    def put_grpc_healthcheck(
        self,
        *,
        service_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param service_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#service_name AlbBackendGroup#service_name}.
        '''
        value = AlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheck(
            service_name=service_name
        )

        return typing.cast(None, jsii.invoke(self, "putGrpcHealthcheck", [value]))

    @jsii.member(jsii_name="putHttpHealthcheck")
    def put_http_healthcheck(
        self,
        *,
        path: builtins.str,
        host: typing.Optional[builtins.str] = None,
        http2: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param path: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#path AlbBackendGroup#path}.
        :param host: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#host AlbBackendGroup#host}.
        :param http2: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#http2 AlbBackendGroup#http2}.
        '''
        value = AlbBackendGroupGrpcBackendHealthcheckHttpHealthcheck(
            path=path, host=host, http2=http2
        )

        return typing.cast(None, jsii.invoke(self, "putHttpHealthcheck", [value]))

    @jsii.member(jsii_name="putStreamHealthcheck")
    def put_stream_healthcheck(
        self,
        *,
        receive: typing.Optional[builtins.str] = None,
        send: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param receive: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#receive AlbBackendGroup#receive}.
        :param send: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#send AlbBackendGroup#send}.
        '''
        value = AlbBackendGroupGrpcBackendHealthcheckStreamHealthcheck(
            receive=receive, send=send
        )

        return typing.cast(None, jsii.invoke(self, "putStreamHealthcheck", [value]))

    @jsii.member(jsii_name="resetGrpcHealthcheck")
    def reset_grpc_healthcheck(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGrpcHealthcheck", []))

    @jsii.member(jsii_name="resetHealthcheckPort")
    def reset_healthcheck_port(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHealthcheckPort", []))

    @jsii.member(jsii_name="resetHealthyThreshold")
    def reset_healthy_threshold(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHealthyThreshold", []))

    @jsii.member(jsii_name="resetHttpHealthcheck")
    def reset_http_healthcheck(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttpHealthcheck", []))

    @jsii.member(jsii_name="resetIntervalJitterPercent")
    def reset_interval_jitter_percent(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIntervalJitterPercent", []))

    @jsii.member(jsii_name="resetStreamHealthcheck")
    def reset_stream_healthcheck(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStreamHealthcheck", []))

    @jsii.member(jsii_name="resetUnhealthyThreshold")
    def reset_unhealthy_threshold(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUnhealthyThreshold", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="grpcHealthcheck")
    def grpc_healthcheck(
        self,
    ) -> AlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheckOutputReference:
        return typing.cast(AlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheckOutputReference, jsii.get(self, "grpcHealthcheck"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpHealthcheck")
    def http_healthcheck(
        self,
    ) -> AlbBackendGroupGrpcBackendHealthcheckHttpHealthcheckOutputReference:
        return typing.cast(AlbBackendGroupGrpcBackendHealthcheckHttpHealthcheckOutputReference, jsii.get(self, "httpHealthcheck"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="streamHealthcheck")
    def stream_healthcheck(
        self,
    ) -> "AlbBackendGroupGrpcBackendHealthcheckStreamHealthcheckOutputReference":
        return typing.cast("AlbBackendGroupGrpcBackendHealthcheckStreamHealthcheckOutputReference", jsii.get(self, "streamHealthcheck"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="grpcHealthcheckInput")
    def grpc_healthcheck_input(
        self,
    ) -> typing.Optional[AlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheck]:
        return typing.cast(typing.Optional[AlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheck], jsii.get(self, "grpcHealthcheckInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthcheckPortInput")
    def healthcheck_port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "healthcheckPortInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthyThresholdInput")
    def healthy_threshold_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "healthyThresholdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpHealthcheckInput")
    def http_healthcheck_input(
        self,
    ) -> typing.Optional[AlbBackendGroupGrpcBackendHealthcheckHttpHealthcheck]:
        return typing.cast(typing.Optional[AlbBackendGroupGrpcBackendHealthcheckHttpHealthcheck], jsii.get(self, "httpHealthcheckInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "intervalInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="intervalJitterPercentInput")
    def interval_jitter_percent_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalJitterPercentInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="streamHealthcheckInput")
    def stream_healthcheck_input(
        self,
    ) -> typing.Optional["AlbBackendGroupGrpcBackendHealthcheckStreamHealthcheck"]:
        return typing.cast(typing.Optional["AlbBackendGroupGrpcBackendHealthcheckStreamHealthcheck"], jsii.get(self, "streamHealthcheckInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutInput")
    def timeout_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "timeoutInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="unhealthyThresholdInput")
    def unhealthy_threshold_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "unhealthyThresholdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthcheckPort")
    def healthcheck_port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "healthcheckPort"))

    @healthcheck_port.setter
    def healthcheck_port(self, value: jsii.Number) -> None:
        jsii.set(self, "healthcheckPort", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthyThreshold")
    def healthy_threshold(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "healthyThreshold"))

    @healthy_threshold.setter
    def healthy_threshold(self, value: jsii.Number) -> None:
        jsii.set(self, "healthyThreshold", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="interval")
    def interval(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: builtins.str) -> None:
        jsii.set(self, "interval", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="intervalJitterPercent")
    def interval_jitter_percent(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "intervalJitterPercent"))

    @interval_jitter_percent.setter
    def interval_jitter_percent(self, value: jsii.Number) -> None:
        jsii.set(self, "intervalJitterPercent", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeout")
    def timeout(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "timeout"))

    @timeout.setter
    def timeout(self, value: builtins.str) -> None:
        jsii.set(self, "timeout", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="unhealthyThreshold")
    def unhealthy_threshold(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "unhealthyThreshold"))

    @unhealthy_threshold.setter
    def unhealthy_threshold(self, value: jsii.Number) -> None:
        jsii.set(self, "unhealthyThreshold", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[AlbBackendGroupGrpcBackendHealthcheck]:
        return typing.cast(typing.Optional[AlbBackendGroupGrpcBackendHealthcheck], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbBackendGroupGrpcBackendHealthcheck],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupGrpcBackendHealthcheckStreamHealthcheck",
    jsii_struct_bases=[],
    name_mapping={"receive": "receive", "send": "send"},
)
class AlbBackendGroupGrpcBackendHealthcheckStreamHealthcheck:
    def __init__(
        self,
        *,
        receive: typing.Optional[builtins.str] = None,
        send: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param receive: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#receive AlbBackendGroup#receive}.
        :param send: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#send AlbBackendGroup#send}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if receive is not None:
            self._values["receive"] = receive
        if send is not None:
            self._values["send"] = send

    @builtins.property
    def receive(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#receive AlbBackendGroup#receive}.'''
        result = self._values.get("receive")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def send(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#send AlbBackendGroup#send}.'''
        result = self._values.get("send")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbBackendGroupGrpcBackendHealthcheckStreamHealthcheck(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbBackendGroupGrpcBackendHealthcheckStreamHealthcheckOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupGrpcBackendHealthcheckStreamHealthcheckOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetReceive")
    def reset_receive(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetReceive", []))

    @jsii.member(jsii_name="resetSend")
    def reset_send(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSend", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="receiveInput")
    def receive_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "receiveInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sendInput")
    def send_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sendInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="receive")
    def receive(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "receive"))

    @receive.setter
    def receive(self, value: builtins.str) -> None:
        jsii.set(self, "receive", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="send")
    def send(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "send"))

    @send.setter
    def send(self, value: builtins.str) -> None:
        jsii.set(self, "send", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbBackendGroupGrpcBackendHealthcheckStreamHealthcheck]:
        return typing.cast(typing.Optional[AlbBackendGroupGrpcBackendHealthcheckStreamHealthcheck], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbBackendGroupGrpcBackendHealthcheckStreamHealthcheck],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbBackendGroupGrpcBackendList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupGrpcBackendList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "AlbBackendGroupGrpcBackendOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("AlbBackendGroupGrpcBackendOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[typing.List[AlbBackendGroupGrpcBackend], cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[typing.List[AlbBackendGroupGrpcBackend], cdktf.IResolvable]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[typing.List[AlbBackendGroupGrpcBackend], cdktf.IResolvable]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupGrpcBackendLoadBalancingConfig",
    jsii_struct_bases=[],
    name_mapping={
        "locality_aware_routing_percent": "localityAwareRoutingPercent",
        "panic_threshold": "panicThreshold",
        "strict_locality": "strictLocality",
    },
)
class AlbBackendGroupGrpcBackendLoadBalancingConfig:
    def __init__(
        self,
        *,
        locality_aware_routing_percent: typing.Optional[jsii.Number] = None,
        panic_threshold: typing.Optional[jsii.Number] = None,
        strict_locality: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param locality_aware_routing_percent: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#locality_aware_routing_percent AlbBackendGroup#locality_aware_routing_percent}.
        :param panic_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#panic_threshold AlbBackendGroup#panic_threshold}.
        :param strict_locality: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#strict_locality AlbBackendGroup#strict_locality}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if locality_aware_routing_percent is not None:
            self._values["locality_aware_routing_percent"] = locality_aware_routing_percent
        if panic_threshold is not None:
            self._values["panic_threshold"] = panic_threshold
        if strict_locality is not None:
            self._values["strict_locality"] = strict_locality

    @builtins.property
    def locality_aware_routing_percent(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#locality_aware_routing_percent AlbBackendGroup#locality_aware_routing_percent}.'''
        result = self._values.get("locality_aware_routing_percent")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def panic_threshold(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#panic_threshold AlbBackendGroup#panic_threshold}.'''
        result = self._values.get("panic_threshold")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def strict_locality(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#strict_locality AlbBackendGroup#strict_locality}.'''
        result = self._values.get("strict_locality")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbBackendGroupGrpcBackendLoadBalancingConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbBackendGroupGrpcBackendLoadBalancingConfigOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupGrpcBackendLoadBalancingConfigOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetLocalityAwareRoutingPercent")
    def reset_locality_aware_routing_percent(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLocalityAwareRoutingPercent", []))

    @jsii.member(jsii_name="resetPanicThreshold")
    def reset_panic_threshold(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPanicThreshold", []))

    @jsii.member(jsii_name="resetStrictLocality")
    def reset_strict_locality(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStrictLocality", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="localityAwareRoutingPercentInput")
    def locality_aware_routing_percent_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "localityAwareRoutingPercentInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="panicThresholdInput")
    def panic_threshold_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "panicThresholdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="strictLocalityInput")
    def strict_locality_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "strictLocalityInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="localityAwareRoutingPercent")
    def locality_aware_routing_percent(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "localityAwareRoutingPercent"))

    @locality_aware_routing_percent.setter
    def locality_aware_routing_percent(self, value: jsii.Number) -> None:
        jsii.set(self, "localityAwareRoutingPercent", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="panicThreshold")
    def panic_threshold(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "panicThreshold"))

    @panic_threshold.setter
    def panic_threshold(self, value: jsii.Number) -> None:
        jsii.set(self, "panicThreshold", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="strictLocality")
    def strict_locality(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "strictLocality"))

    @strict_locality.setter
    def strict_locality(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "strictLocality", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbBackendGroupGrpcBackendLoadBalancingConfig]:
        return typing.cast(typing.Optional[AlbBackendGroupGrpcBackendLoadBalancingConfig], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbBackendGroupGrpcBackendLoadBalancingConfig],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbBackendGroupGrpcBackendOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupGrpcBackendOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putHealthcheck")
    def put_healthcheck(
        self,
        *,
        interval: builtins.str,
        timeout: builtins.str,
        grpc_healthcheck: typing.Optional[AlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheck] = None,
        healthcheck_port: typing.Optional[jsii.Number] = None,
        healthy_threshold: typing.Optional[jsii.Number] = None,
        http_healthcheck: typing.Optional[AlbBackendGroupGrpcBackendHealthcheckHttpHealthcheck] = None,
        interval_jitter_percent: typing.Optional[jsii.Number] = None,
        stream_healthcheck: typing.Optional[AlbBackendGroupGrpcBackendHealthcheckStreamHealthcheck] = None,
        unhealthy_threshold: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param interval: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#interval AlbBackendGroup#interval}.
        :param timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#timeout AlbBackendGroup#timeout}.
        :param grpc_healthcheck: grpc_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#grpc_healthcheck AlbBackendGroup#grpc_healthcheck}
        :param healthcheck_port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#healthcheck_port AlbBackendGroup#healthcheck_port}.
        :param healthy_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#healthy_threshold AlbBackendGroup#healthy_threshold}.
        :param http_healthcheck: http_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#http_healthcheck AlbBackendGroup#http_healthcheck}
        :param interval_jitter_percent: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#interval_jitter_percent AlbBackendGroup#interval_jitter_percent}.
        :param stream_healthcheck: stream_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#stream_healthcheck AlbBackendGroup#stream_healthcheck}
        :param unhealthy_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#unhealthy_threshold AlbBackendGroup#unhealthy_threshold}.
        '''
        value = AlbBackendGroupGrpcBackendHealthcheck(
            interval=interval,
            timeout=timeout,
            grpc_healthcheck=grpc_healthcheck,
            healthcheck_port=healthcheck_port,
            healthy_threshold=healthy_threshold,
            http_healthcheck=http_healthcheck,
            interval_jitter_percent=interval_jitter_percent,
            stream_healthcheck=stream_healthcheck,
            unhealthy_threshold=unhealthy_threshold,
        )

        return typing.cast(None, jsii.invoke(self, "putHealthcheck", [value]))

    @jsii.member(jsii_name="putLoadBalancingConfig")
    def put_load_balancing_config(
        self,
        *,
        locality_aware_routing_percent: typing.Optional[jsii.Number] = None,
        panic_threshold: typing.Optional[jsii.Number] = None,
        strict_locality: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param locality_aware_routing_percent: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#locality_aware_routing_percent AlbBackendGroup#locality_aware_routing_percent}.
        :param panic_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#panic_threshold AlbBackendGroup#panic_threshold}.
        :param strict_locality: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#strict_locality AlbBackendGroup#strict_locality}.
        '''
        value = AlbBackendGroupGrpcBackendLoadBalancingConfig(
            locality_aware_routing_percent=locality_aware_routing_percent,
            panic_threshold=panic_threshold,
            strict_locality=strict_locality,
        )

        return typing.cast(None, jsii.invoke(self, "putLoadBalancingConfig", [value]))

    @jsii.member(jsii_name="putTls")
    def put_tls(
        self,
        *,
        sni: typing.Optional[builtins.str] = None,
        validation_context: typing.Optional["AlbBackendGroupGrpcBackendTlsValidationContext"] = None,
    ) -> None:
        '''
        :param sni: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#sni AlbBackendGroup#sni}.
        :param validation_context: validation_context block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#validation_context AlbBackendGroup#validation_context}
        '''
        value = AlbBackendGroupGrpcBackendTls(
            sni=sni, validation_context=validation_context
        )

        return typing.cast(None, jsii.invoke(self, "putTls", [value]))

    @jsii.member(jsii_name="resetHealthcheck")
    def reset_healthcheck(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHealthcheck", []))

    @jsii.member(jsii_name="resetLoadBalancingConfig")
    def reset_load_balancing_config(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLoadBalancingConfig", []))

    @jsii.member(jsii_name="resetPort")
    def reset_port(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPort", []))

    @jsii.member(jsii_name="resetTls")
    def reset_tls(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTls", []))

    @jsii.member(jsii_name="resetWeight")
    def reset_weight(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetWeight", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthcheck")
    def healthcheck(self) -> AlbBackendGroupGrpcBackendHealthcheckOutputReference:
        return typing.cast(AlbBackendGroupGrpcBackendHealthcheckOutputReference, jsii.get(self, "healthcheck"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="loadBalancingConfig")
    def load_balancing_config(
        self,
    ) -> AlbBackendGroupGrpcBackendLoadBalancingConfigOutputReference:
        return typing.cast(AlbBackendGroupGrpcBackendLoadBalancingConfigOutputReference, jsii.get(self, "loadBalancingConfig"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tls")
    def tls(self) -> "AlbBackendGroupGrpcBackendTlsOutputReference":
        return typing.cast("AlbBackendGroupGrpcBackendTlsOutputReference", jsii.get(self, "tls"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthcheckInput")
    def healthcheck_input(
        self,
    ) -> typing.Optional[AlbBackendGroupGrpcBackendHealthcheck]:
        return typing.cast(typing.Optional[AlbBackendGroupGrpcBackendHealthcheck], jsii.get(self, "healthcheckInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="loadBalancingConfigInput")
    def load_balancing_config_input(
        self,
    ) -> typing.Optional[AlbBackendGroupGrpcBackendLoadBalancingConfig]:
        return typing.cast(typing.Optional[AlbBackendGroupGrpcBackendLoadBalancingConfig], jsii.get(self, "loadBalancingConfigInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="portInput")
    def port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "portInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupIdsInput")
    def target_group_ids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "targetGroupIdsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tlsInput")
    def tls_input(self) -> typing.Optional["AlbBackendGroupGrpcBackendTls"]:
        return typing.cast(typing.Optional["AlbBackendGroupGrpcBackendTls"], jsii.get(self, "tlsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="weightInput")
    def weight_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "weightInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "port"))

    @port.setter
    def port(self, value: jsii.Number) -> None:
        jsii.set(self, "port", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupIds")
    def target_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "targetGroupIds"))

    @target_group_ids.setter
    def target_group_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "targetGroupIds", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="weight")
    def weight(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "weight"))

    @weight.setter
    def weight(self, value: jsii.Number) -> None:
        jsii.set(self, "weight", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[AlbBackendGroupGrpcBackend, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[AlbBackendGroupGrpcBackend, cdktf.IResolvable]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[AlbBackendGroupGrpcBackend, cdktf.IResolvable]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupGrpcBackendTls",
    jsii_struct_bases=[],
    name_mapping={"sni": "sni", "validation_context": "validationContext"},
)
class AlbBackendGroupGrpcBackendTls:
    def __init__(
        self,
        *,
        sni: typing.Optional[builtins.str] = None,
        validation_context: typing.Optional["AlbBackendGroupGrpcBackendTlsValidationContext"] = None,
    ) -> None:
        '''
        :param sni: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#sni AlbBackendGroup#sni}.
        :param validation_context: validation_context block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#validation_context AlbBackendGroup#validation_context}
        '''
        if isinstance(validation_context, dict):
            validation_context = AlbBackendGroupGrpcBackendTlsValidationContext(**validation_context)
        self._values: typing.Dict[str, typing.Any] = {}
        if sni is not None:
            self._values["sni"] = sni
        if validation_context is not None:
            self._values["validation_context"] = validation_context

    @builtins.property
    def sni(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#sni AlbBackendGroup#sni}.'''
        result = self._values.get("sni")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def validation_context(
        self,
    ) -> typing.Optional["AlbBackendGroupGrpcBackendTlsValidationContext"]:
        '''validation_context block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#validation_context AlbBackendGroup#validation_context}
        '''
        result = self._values.get("validation_context")
        return typing.cast(typing.Optional["AlbBackendGroupGrpcBackendTlsValidationContext"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbBackendGroupGrpcBackendTls(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbBackendGroupGrpcBackendTlsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupGrpcBackendTlsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putValidationContext")
    def put_validation_context(
        self,
        *,
        trusted_ca_bytes: typing.Optional[builtins.str] = None,
        trusted_ca_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param trusted_ca_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#trusted_ca_bytes AlbBackendGroup#trusted_ca_bytes}.
        :param trusted_ca_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#trusted_ca_id AlbBackendGroup#trusted_ca_id}.
        '''
        value = AlbBackendGroupGrpcBackendTlsValidationContext(
            trusted_ca_bytes=trusted_ca_bytes, trusted_ca_id=trusted_ca_id
        )

        return typing.cast(None, jsii.invoke(self, "putValidationContext", [value]))

    @jsii.member(jsii_name="resetSni")
    def reset_sni(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSni", []))

    @jsii.member(jsii_name="resetValidationContext")
    def reset_validation_context(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetValidationContext", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="validationContext")
    def validation_context(
        self,
    ) -> "AlbBackendGroupGrpcBackendTlsValidationContextOutputReference":
        return typing.cast("AlbBackendGroupGrpcBackendTlsValidationContextOutputReference", jsii.get(self, "validationContext"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sniInput")
    def sni_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sniInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="validationContextInput")
    def validation_context_input(
        self,
    ) -> typing.Optional["AlbBackendGroupGrpcBackendTlsValidationContext"]:
        return typing.cast(typing.Optional["AlbBackendGroupGrpcBackendTlsValidationContext"], jsii.get(self, "validationContextInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sni")
    def sni(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sni"))

    @sni.setter
    def sni(self, value: builtins.str) -> None:
        jsii.set(self, "sni", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[AlbBackendGroupGrpcBackendTls]:
        return typing.cast(typing.Optional[AlbBackendGroupGrpcBackendTls], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbBackendGroupGrpcBackendTls],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupGrpcBackendTlsValidationContext",
    jsii_struct_bases=[],
    name_mapping={
        "trusted_ca_bytes": "trustedCaBytes",
        "trusted_ca_id": "trustedCaId",
    },
)
class AlbBackendGroupGrpcBackendTlsValidationContext:
    def __init__(
        self,
        *,
        trusted_ca_bytes: typing.Optional[builtins.str] = None,
        trusted_ca_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param trusted_ca_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#trusted_ca_bytes AlbBackendGroup#trusted_ca_bytes}.
        :param trusted_ca_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#trusted_ca_id AlbBackendGroup#trusted_ca_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if trusted_ca_bytes is not None:
            self._values["trusted_ca_bytes"] = trusted_ca_bytes
        if trusted_ca_id is not None:
            self._values["trusted_ca_id"] = trusted_ca_id

    @builtins.property
    def trusted_ca_bytes(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#trusted_ca_bytes AlbBackendGroup#trusted_ca_bytes}.'''
        result = self._values.get("trusted_ca_bytes")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def trusted_ca_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#trusted_ca_id AlbBackendGroup#trusted_ca_id}.'''
        result = self._values.get("trusted_ca_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbBackendGroupGrpcBackendTlsValidationContext(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbBackendGroupGrpcBackendTlsValidationContextOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupGrpcBackendTlsValidationContextOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetTrustedCaBytes")
    def reset_trusted_ca_bytes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTrustedCaBytes", []))

    @jsii.member(jsii_name="resetTrustedCaId")
    def reset_trusted_ca_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTrustedCaId", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="trustedCaBytesInput")
    def trusted_ca_bytes_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "trustedCaBytesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="trustedCaIdInput")
    def trusted_ca_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "trustedCaIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="trustedCaBytes")
    def trusted_ca_bytes(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "trustedCaBytes"))

    @trusted_ca_bytes.setter
    def trusted_ca_bytes(self, value: builtins.str) -> None:
        jsii.set(self, "trustedCaBytes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="trustedCaId")
    def trusted_ca_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "trustedCaId"))

    @trusted_ca_id.setter
    def trusted_ca_id(self, value: builtins.str) -> None:
        jsii.set(self, "trustedCaId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbBackendGroupGrpcBackendTlsValidationContext]:
        return typing.cast(typing.Optional[AlbBackendGroupGrpcBackendTlsValidationContext], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbBackendGroupGrpcBackendTlsValidationContext],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupHttpBackend",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "healthcheck": "healthcheck",
        "http2": "http2",
        "load_balancing_config": "loadBalancingConfig",
        "port": "port",
        "storage_bucket": "storageBucket",
        "target_group_ids": "targetGroupIds",
        "tls": "tls",
        "weight": "weight",
    },
)
class AlbBackendGroupHttpBackend:
    def __init__(
        self,
        *,
        name: builtins.str,
        healthcheck: typing.Optional["AlbBackendGroupHttpBackendHealthcheck"] = None,
        http2: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        load_balancing_config: typing.Optional["AlbBackendGroupHttpBackendLoadBalancingConfig"] = None,
        port: typing.Optional[jsii.Number] = None,
        storage_bucket: typing.Optional[builtins.str] = None,
        target_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        tls: typing.Optional["AlbBackendGroupHttpBackendTls"] = None,
        weight: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#name AlbBackendGroup#name}.
        :param healthcheck: healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#healthcheck AlbBackendGroup#healthcheck}
        :param http2: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#http2 AlbBackendGroup#http2}.
        :param load_balancing_config: load_balancing_config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#load_balancing_config AlbBackendGroup#load_balancing_config}
        :param port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#port AlbBackendGroup#port}.
        :param storage_bucket: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#storage_bucket AlbBackendGroup#storage_bucket}.
        :param target_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#target_group_ids AlbBackendGroup#target_group_ids}.
        :param tls: tls block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#tls AlbBackendGroup#tls}
        :param weight: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#weight AlbBackendGroup#weight}.
        '''
        if isinstance(healthcheck, dict):
            healthcheck = AlbBackendGroupHttpBackendHealthcheck(**healthcheck)
        if isinstance(load_balancing_config, dict):
            load_balancing_config = AlbBackendGroupHttpBackendLoadBalancingConfig(**load_balancing_config)
        if isinstance(tls, dict):
            tls = AlbBackendGroupHttpBackendTls(**tls)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }
        if healthcheck is not None:
            self._values["healthcheck"] = healthcheck
        if http2 is not None:
            self._values["http2"] = http2
        if load_balancing_config is not None:
            self._values["load_balancing_config"] = load_balancing_config
        if port is not None:
            self._values["port"] = port
        if storage_bucket is not None:
            self._values["storage_bucket"] = storage_bucket
        if target_group_ids is not None:
            self._values["target_group_ids"] = target_group_ids
        if tls is not None:
            self._values["tls"] = tls
        if weight is not None:
            self._values["weight"] = weight

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#name AlbBackendGroup#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def healthcheck(self) -> typing.Optional["AlbBackendGroupHttpBackendHealthcheck"]:
        '''healthcheck block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#healthcheck AlbBackendGroup#healthcheck}
        '''
        result = self._values.get("healthcheck")
        return typing.cast(typing.Optional["AlbBackendGroupHttpBackendHealthcheck"], result)

    @builtins.property
    def http2(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#http2 AlbBackendGroup#http2}.'''
        result = self._values.get("http2")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def load_balancing_config(
        self,
    ) -> typing.Optional["AlbBackendGroupHttpBackendLoadBalancingConfig"]:
        '''load_balancing_config block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#load_balancing_config AlbBackendGroup#load_balancing_config}
        '''
        result = self._values.get("load_balancing_config")
        return typing.cast(typing.Optional["AlbBackendGroupHttpBackendLoadBalancingConfig"], result)

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#port AlbBackendGroup#port}.'''
        result = self._values.get("port")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def storage_bucket(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#storage_bucket AlbBackendGroup#storage_bucket}.'''
        result = self._values.get("storage_bucket")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def target_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#target_group_ids AlbBackendGroup#target_group_ids}.'''
        result = self._values.get("target_group_ids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def tls(self) -> typing.Optional["AlbBackendGroupHttpBackendTls"]:
        '''tls block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#tls AlbBackendGroup#tls}
        '''
        result = self._values.get("tls")
        return typing.cast(typing.Optional["AlbBackendGroupHttpBackendTls"], result)

    @builtins.property
    def weight(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#weight AlbBackendGroup#weight}.'''
        result = self._values.get("weight")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbBackendGroupHttpBackend(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupHttpBackendHealthcheck",
    jsii_struct_bases=[],
    name_mapping={
        "interval": "interval",
        "timeout": "timeout",
        "grpc_healthcheck": "grpcHealthcheck",
        "healthcheck_port": "healthcheckPort",
        "healthy_threshold": "healthyThreshold",
        "http_healthcheck": "httpHealthcheck",
        "interval_jitter_percent": "intervalJitterPercent",
        "stream_healthcheck": "streamHealthcheck",
        "unhealthy_threshold": "unhealthyThreshold",
    },
)
class AlbBackendGroupHttpBackendHealthcheck:
    def __init__(
        self,
        *,
        interval: builtins.str,
        timeout: builtins.str,
        grpc_healthcheck: typing.Optional["AlbBackendGroupHttpBackendHealthcheckGrpcHealthcheck"] = None,
        healthcheck_port: typing.Optional[jsii.Number] = None,
        healthy_threshold: typing.Optional[jsii.Number] = None,
        http_healthcheck: typing.Optional["AlbBackendGroupHttpBackendHealthcheckHttpHealthcheck"] = None,
        interval_jitter_percent: typing.Optional[jsii.Number] = None,
        stream_healthcheck: typing.Optional["AlbBackendGroupHttpBackendHealthcheckStreamHealthcheck"] = None,
        unhealthy_threshold: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param interval: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#interval AlbBackendGroup#interval}.
        :param timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#timeout AlbBackendGroup#timeout}.
        :param grpc_healthcheck: grpc_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#grpc_healthcheck AlbBackendGroup#grpc_healthcheck}
        :param healthcheck_port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#healthcheck_port AlbBackendGroup#healthcheck_port}.
        :param healthy_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#healthy_threshold AlbBackendGroup#healthy_threshold}.
        :param http_healthcheck: http_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#http_healthcheck AlbBackendGroup#http_healthcheck}
        :param interval_jitter_percent: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#interval_jitter_percent AlbBackendGroup#interval_jitter_percent}.
        :param stream_healthcheck: stream_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#stream_healthcheck AlbBackendGroup#stream_healthcheck}
        :param unhealthy_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#unhealthy_threshold AlbBackendGroup#unhealthy_threshold}.
        '''
        if isinstance(grpc_healthcheck, dict):
            grpc_healthcheck = AlbBackendGroupHttpBackendHealthcheckGrpcHealthcheck(**grpc_healthcheck)
        if isinstance(http_healthcheck, dict):
            http_healthcheck = AlbBackendGroupHttpBackendHealthcheckHttpHealthcheck(**http_healthcheck)
        if isinstance(stream_healthcheck, dict):
            stream_healthcheck = AlbBackendGroupHttpBackendHealthcheckStreamHealthcheck(**stream_healthcheck)
        self._values: typing.Dict[str, typing.Any] = {
            "interval": interval,
            "timeout": timeout,
        }
        if grpc_healthcheck is not None:
            self._values["grpc_healthcheck"] = grpc_healthcheck
        if healthcheck_port is not None:
            self._values["healthcheck_port"] = healthcheck_port
        if healthy_threshold is not None:
            self._values["healthy_threshold"] = healthy_threshold
        if http_healthcheck is not None:
            self._values["http_healthcheck"] = http_healthcheck
        if interval_jitter_percent is not None:
            self._values["interval_jitter_percent"] = interval_jitter_percent
        if stream_healthcheck is not None:
            self._values["stream_healthcheck"] = stream_healthcheck
        if unhealthy_threshold is not None:
            self._values["unhealthy_threshold"] = unhealthy_threshold

    @builtins.property
    def interval(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#interval AlbBackendGroup#interval}.'''
        result = self._values.get("interval")
        assert result is not None, "Required property 'interval' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def timeout(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#timeout AlbBackendGroup#timeout}.'''
        result = self._values.get("timeout")
        assert result is not None, "Required property 'timeout' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def grpc_healthcheck(
        self,
    ) -> typing.Optional["AlbBackendGroupHttpBackendHealthcheckGrpcHealthcheck"]:
        '''grpc_healthcheck block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#grpc_healthcheck AlbBackendGroup#grpc_healthcheck}
        '''
        result = self._values.get("grpc_healthcheck")
        return typing.cast(typing.Optional["AlbBackendGroupHttpBackendHealthcheckGrpcHealthcheck"], result)

    @builtins.property
    def healthcheck_port(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#healthcheck_port AlbBackendGroup#healthcheck_port}.'''
        result = self._values.get("healthcheck_port")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def healthy_threshold(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#healthy_threshold AlbBackendGroup#healthy_threshold}.'''
        result = self._values.get("healthy_threshold")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def http_healthcheck(
        self,
    ) -> typing.Optional["AlbBackendGroupHttpBackendHealthcheckHttpHealthcheck"]:
        '''http_healthcheck block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#http_healthcheck AlbBackendGroup#http_healthcheck}
        '''
        result = self._values.get("http_healthcheck")
        return typing.cast(typing.Optional["AlbBackendGroupHttpBackendHealthcheckHttpHealthcheck"], result)

    @builtins.property
    def interval_jitter_percent(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#interval_jitter_percent AlbBackendGroup#interval_jitter_percent}.'''
        result = self._values.get("interval_jitter_percent")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def stream_healthcheck(
        self,
    ) -> typing.Optional["AlbBackendGroupHttpBackendHealthcheckStreamHealthcheck"]:
        '''stream_healthcheck block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#stream_healthcheck AlbBackendGroup#stream_healthcheck}
        '''
        result = self._values.get("stream_healthcheck")
        return typing.cast(typing.Optional["AlbBackendGroupHttpBackendHealthcheckStreamHealthcheck"], result)

    @builtins.property
    def unhealthy_threshold(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#unhealthy_threshold AlbBackendGroup#unhealthy_threshold}.'''
        result = self._values.get("unhealthy_threshold")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbBackendGroupHttpBackendHealthcheck(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupHttpBackendHealthcheckGrpcHealthcheck",
    jsii_struct_bases=[],
    name_mapping={"service_name": "serviceName"},
)
class AlbBackendGroupHttpBackendHealthcheckGrpcHealthcheck:
    def __init__(self, *, service_name: typing.Optional[builtins.str] = None) -> None:
        '''
        :param service_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#service_name AlbBackendGroup#service_name}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if service_name is not None:
            self._values["service_name"] = service_name

    @builtins.property
    def service_name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#service_name AlbBackendGroup#service_name}.'''
        result = self._values.get("service_name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbBackendGroupHttpBackendHealthcheckGrpcHealthcheck(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbBackendGroupHttpBackendHealthcheckGrpcHealthcheckOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupHttpBackendHealthcheckGrpcHealthcheckOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetServiceName")
    def reset_service_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetServiceName", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceNameInput")
    def service_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceName")
    def service_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceName"))

    @service_name.setter
    def service_name(self, value: builtins.str) -> None:
        jsii.set(self, "serviceName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbBackendGroupHttpBackendHealthcheckGrpcHealthcheck]:
        return typing.cast(typing.Optional[AlbBackendGroupHttpBackendHealthcheckGrpcHealthcheck], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbBackendGroupHttpBackendHealthcheckGrpcHealthcheck],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupHttpBackendHealthcheckHttpHealthcheck",
    jsii_struct_bases=[],
    name_mapping={"path": "path", "host": "host", "http2": "http2"},
)
class AlbBackendGroupHttpBackendHealthcheckHttpHealthcheck:
    def __init__(
        self,
        *,
        path: builtins.str,
        host: typing.Optional[builtins.str] = None,
        http2: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param path: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#path AlbBackendGroup#path}.
        :param host: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#host AlbBackendGroup#host}.
        :param http2: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#http2 AlbBackendGroup#http2}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "path": path,
        }
        if host is not None:
            self._values["host"] = host
        if http2 is not None:
            self._values["http2"] = http2

    @builtins.property
    def path(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#path AlbBackendGroup#path}.'''
        result = self._values.get("path")
        assert result is not None, "Required property 'path' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def host(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#host AlbBackendGroup#host}.'''
        result = self._values.get("host")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def http2(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#http2 AlbBackendGroup#http2}.'''
        result = self._values.get("http2")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbBackendGroupHttpBackendHealthcheckHttpHealthcheck(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbBackendGroupHttpBackendHealthcheckHttpHealthcheckOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupHttpBackendHealthcheckHttpHealthcheckOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetHost")
    def reset_host(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHost", []))

    @jsii.member(jsii_name="resetHttp2")
    def reset_http2(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttp2", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostInput")
    def host_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "hostInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="http2Input")
    def http2_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "http2Input"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="pathInput")
    def path_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "pathInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="host")
    def host(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "host"))

    @host.setter
    def host(self, value: builtins.str) -> None:
        jsii.set(self, "host", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="http2")
    def http2(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "http2"))

    @http2.setter
    def http2(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "http2", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="path")
    def path(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "path"))

    @path.setter
    def path(self, value: builtins.str) -> None:
        jsii.set(self, "path", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbBackendGroupHttpBackendHealthcheckHttpHealthcheck]:
        return typing.cast(typing.Optional[AlbBackendGroupHttpBackendHealthcheckHttpHealthcheck], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbBackendGroupHttpBackendHealthcheckHttpHealthcheck],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbBackendGroupHttpBackendHealthcheckOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupHttpBackendHealthcheckOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putGrpcHealthcheck")
    def put_grpc_healthcheck(
        self,
        *,
        service_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param service_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#service_name AlbBackendGroup#service_name}.
        '''
        value = AlbBackendGroupHttpBackendHealthcheckGrpcHealthcheck(
            service_name=service_name
        )

        return typing.cast(None, jsii.invoke(self, "putGrpcHealthcheck", [value]))

    @jsii.member(jsii_name="putHttpHealthcheck")
    def put_http_healthcheck(
        self,
        *,
        path: builtins.str,
        host: typing.Optional[builtins.str] = None,
        http2: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param path: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#path AlbBackendGroup#path}.
        :param host: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#host AlbBackendGroup#host}.
        :param http2: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#http2 AlbBackendGroup#http2}.
        '''
        value = AlbBackendGroupHttpBackendHealthcheckHttpHealthcheck(
            path=path, host=host, http2=http2
        )

        return typing.cast(None, jsii.invoke(self, "putHttpHealthcheck", [value]))

    @jsii.member(jsii_name="putStreamHealthcheck")
    def put_stream_healthcheck(
        self,
        *,
        receive: typing.Optional[builtins.str] = None,
        send: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param receive: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#receive AlbBackendGroup#receive}.
        :param send: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#send AlbBackendGroup#send}.
        '''
        value = AlbBackendGroupHttpBackendHealthcheckStreamHealthcheck(
            receive=receive, send=send
        )

        return typing.cast(None, jsii.invoke(self, "putStreamHealthcheck", [value]))

    @jsii.member(jsii_name="resetGrpcHealthcheck")
    def reset_grpc_healthcheck(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGrpcHealthcheck", []))

    @jsii.member(jsii_name="resetHealthcheckPort")
    def reset_healthcheck_port(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHealthcheckPort", []))

    @jsii.member(jsii_name="resetHealthyThreshold")
    def reset_healthy_threshold(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHealthyThreshold", []))

    @jsii.member(jsii_name="resetHttpHealthcheck")
    def reset_http_healthcheck(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttpHealthcheck", []))

    @jsii.member(jsii_name="resetIntervalJitterPercent")
    def reset_interval_jitter_percent(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIntervalJitterPercent", []))

    @jsii.member(jsii_name="resetStreamHealthcheck")
    def reset_stream_healthcheck(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStreamHealthcheck", []))

    @jsii.member(jsii_name="resetUnhealthyThreshold")
    def reset_unhealthy_threshold(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUnhealthyThreshold", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="grpcHealthcheck")
    def grpc_healthcheck(
        self,
    ) -> AlbBackendGroupHttpBackendHealthcheckGrpcHealthcheckOutputReference:
        return typing.cast(AlbBackendGroupHttpBackendHealthcheckGrpcHealthcheckOutputReference, jsii.get(self, "grpcHealthcheck"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpHealthcheck")
    def http_healthcheck(
        self,
    ) -> AlbBackendGroupHttpBackendHealthcheckHttpHealthcheckOutputReference:
        return typing.cast(AlbBackendGroupHttpBackendHealthcheckHttpHealthcheckOutputReference, jsii.get(self, "httpHealthcheck"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="streamHealthcheck")
    def stream_healthcheck(
        self,
    ) -> "AlbBackendGroupHttpBackendHealthcheckStreamHealthcheckOutputReference":
        return typing.cast("AlbBackendGroupHttpBackendHealthcheckStreamHealthcheckOutputReference", jsii.get(self, "streamHealthcheck"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="grpcHealthcheckInput")
    def grpc_healthcheck_input(
        self,
    ) -> typing.Optional[AlbBackendGroupHttpBackendHealthcheckGrpcHealthcheck]:
        return typing.cast(typing.Optional[AlbBackendGroupHttpBackendHealthcheckGrpcHealthcheck], jsii.get(self, "grpcHealthcheckInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthcheckPortInput")
    def healthcheck_port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "healthcheckPortInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthyThresholdInput")
    def healthy_threshold_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "healthyThresholdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpHealthcheckInput")
    def http_healthcheck_input(
        self,
    ) -> typing.Optional[AlbBackendGroupHttpBackendHealthcheckHttpHealthcheck]:
        return typing.cast(typing.Optional[AlbBackendGroupHttpBackendHealthcheckHttpHealthcheck], jsii.get(self, "httpHealthcheckInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "intervalInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="intervalJitterPercentInput")
    def interval_jitter_percent_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalJitterPercentInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="streamHealthcheckInput")
    def stream_healthcheck_input(
        self,
    ) -> typing.Optional["AlbBackendGroupHttpBackendHealthcheckStreamHealthcheck"]:
        return typing.cast(typing.Optional["AlbBackendGroupHttpBackendHealthcheckStreamHealthcheck"], jsii.get(self, "streamHealthcheckInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutInput")
    def timeout_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "timeoutInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="unhealthyThresholdInput")
    def unhealthy_threshold_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "unhealthyThresholdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthcheckPort")
    def healthcheck_port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "healthcheckPort"))

    @healthcheck_port.setter
    def healthcheck_port(self, value: jsii.Number) -> None:
        jsii.set(self, "healthcheckPort", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthyThreshold")
    def healthy_threshold(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "healthyThreshold"))

    @healthy_threshold.setter
    def healthy_threshold(self, value: jsii.Number) -> None:
        jsii.set(self, "healthyThreshold", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="interval")
    def interval(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: builtins.str) -> None:
        jsii.set(self, "interval", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="intervalJitterPercent")
    def interval_jitter_percent(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "intervalJitterPercent"))

    @interval_jitter_percent.setter
    def interval_jitter_percent(self, value: jsii.Number) -> None:
        jsii.set(self, "intervalJitterPercent", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeout")
    def timeout(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "timeout"))

    @timeout.setter
    def timeout(self, value: builtins.str) -> None:
        jsii.set(self, "timeout", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="unhealthyThreshold")
    def unhealthy_threshold(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "unhealthyThreshold"))

    @unhealthy_threshold.setter
    def unhealthy_threshold(self, value: jsii.Number) -> None:
        jsii.set(self, "unhealthyThreshold", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[AlbBackendGroupHttpBackendHealthcheck]:
        return typing.cast(typing.Optional[AlbBackendGroupHttpBackendHealthcheck], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbBackendGroupHttpBackendHealthcheck],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupHttpBackendHealthcheckStreamHealthcheck",
    jsii_struct_bases=[],
    name_mapping={"receive": "receive", "send": "send"},
)
class AlbBackendGroupHttpBackendHealthcheckStreamHealthcheck:
    def __init__(
        self,
        *,
        receive: typing.Optional[builtins.str] = None,
        send: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param receive: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#receive AlbBackendGroup#receive}.
        :param send: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#send AlbBackendGroup#send}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if receive is not None:
            self._values["receive"] = receive
        if send is not None:
            self._values["send"] = send

    @builtins.property
    def receive(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#receive AlbBackendGroup#receive}.'''
        result = self._values.get("receive")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def send(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#send AlbBackendGroup#send}.'''
        result = self._values.get("send")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbBackendGroupHttpBackendHealthcheckStreamHealthcheck(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbBackendGroupHttpBackendHealthcheckStreamHealthcheckOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupHttpBackendHealthcheckStreamHealthcheckOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetReceive")
    def reset_receive(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetReceive", []))

    @jsii.member(jsii_name="resetSend")
    def reset_send(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSend", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="receiveInput")
    def receive_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "receiveInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sendInput")
    def send_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sendInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="receive")
    def receive(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "receive"))

    @receive.setter
    def receive(self, value: builtins.str) -> None:
        jsii.set(self, "receive", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="send")
    def send(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "send"))

    @send.setter
    def send(self, value: builtins.str) -> None:
        jsii.set(self, "send", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbBackendGroupHttpBackendHealthcheckStreamHealthcheck]:
        return typing.cast(typing.Optional[AlbBackendGroupHttpBackendHealthcheckStreamHealthcheck], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbBackendGroupHttpBackendHealthcheckStreamHealthcheck],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbBackendGroupHttpBackendList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupHttpBackendList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "AlbBackendGroupHttpBackendOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("AlbBackendGroupHttpBackendOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbBackendGroupHttpBackend]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbBackendGroupHttpBackend]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbBackendGroupHttpBackend]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupHttpBackendLoadBalancingConfig",
    jsii_struct_bases=[],
    name_mapping={
        "locality_aware_routing_percent": "localityAwareRoutingPercent",
        "panic_threshold": "panicThreshold",
        "strict_locality": "strictLocality",
    },
)
class AlbBackendGroupHttpBackendLoadBalancingConfig:
    def __init__(
        self,
        *,
        locality_aware_routing_percent: typing.Optional[jsii.Number] = None,
        panic_threshold: typing.Optional[jsii.Number] = None,
        strict_locality: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param locality_aware_routing_percent: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#locality_aware_routing_percent AlbBackendGroup#locality_aware_routing_percent}.
        :param panic_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#panic_threshold AlbBackendGroup#panic_threshold}.
        :param strict_locality: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#strict_locality AlbBackendGroup#strict_locality}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if locality_aware_routing_percent is not None:
            self._values["locality_aware_routing_percent"] = locality_aware_routing_percent
        if panic_threshold is not None:
            self._values["panic_threshold"] = panic_threshold
        if strict_locality is not None:
            self._values["strict_locality"] = strict_locality

    @builtins.property
    def locality_aware_routing_percent(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#locality_aware_routing_percent AlbBackendGroup#locality_aware_routing_percent}.'''
        result = self._values.get("locality_aware_routing_percent")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def panic_threshold(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#panic_threshold AlbBackendGroup#panic_threshold}.'''
        result = self._values.get("panic_threshold")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def strict_locality(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#strict_locality AlbBackendGroup#strict_locality}.'''
        result = self._values.get("strict_locality")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbBackendGroupHttpBackendLoadBalancingConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbBackendGroupHttpBackendLoadBalancingConfigOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupHttpBackendLoadBalancingConfigOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetLocalityAwareRoutingPercent")
    def reset_locality_aware_routing_percent(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLocalityAwareRoutingPercent", []))

    @jsii.member(jsii_name="resetPanicThreshold")
    def reset_panic_threshold(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPanicThreshold", []))

    @jsii.member(jsii_name="resetStrictLocality")
    def reset_strict_locality(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStrictLocality", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="localityAwareRoutingPercentInput")
    def locality_aware_routing_percent_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "localityAwareRoutingPercentInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="panicThresholdInput")
    def panic_threshold_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "panicThresholdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="strictLocalityInput")
    def strict_locality_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "strictLocalityInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="localityAwareRoutingPercent")
    def locality_aware_routing_percent(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "localityAwareRoutingPercent"))

    @locality_aware_routing_percent.setter
    def locality_aware_routing_percent(self, value: jsii.Number) -> None:
        jsii.set(self, "localityAwareRoutingPercent", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="panicThreshold")
    def panic_threshold(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "panicThreshold"))

    @panic_threshold.setter
    def panic_threshold(self, value: jsii.Number) -> None:
        jsii.set(self, "panicThreshold", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="strictLocality")
    def strict_locality(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "strictLocality"))

    @strict_locality.setter
    def strict_locality(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "strictLocality", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbBackendGroupHttpBackendLoadBalancingConfig]:
        return typing.cast(typing.Optional[AlbBackendGroupHttpBackendLoadBalancingConfig], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbBackendGroupHttpBackendLoadBalancingConfig],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbBackendGroupHttpBackendOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupHttpBackendOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putHealthcheck")
    def put_healthcheck(
        self,
        *,
        interval: builtins.str,
        timeout: builtins.str,
        grpc_healthcheck: typing.Optional[AlbBackendGroupHttpBackendHealthcheckGrpcHealthcheck] = None,
        healthcheck_port: typing.Optional[jsii.Number] = None,
        healthy_threshold: typing.Optional[jsii.Number] = None,
        http_healthcheck: typing.Optional[AlbBackendGroupHttpBackendHealthcheckHttpHealthcheck] = None,
        interval_jitter_percent: typing.Optional[jsii.Number] = None,
        stream_healthcheck: typing.Optional[AlbBackendGroupHttpBackendHealthcheckStreamHealthcheck] = None,
        unhealthy_threshold: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param interval: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#interval AlbBackendGroup#interval}.
        :param timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#timeout AlbBackendGroup#timeout}.
        :param grpc_healthcheck: grpc_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#grpc_healthcheck AlbBackendGroup#grpc_healthcheck}
        :param healthcheck_port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#healthcheck_port AlbBackendGroup#healthcheck_port}.
        :param healthy_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#healthy_threshold AlbBackendGroup#healthy_threshold}.
        :param http_healthcheck: http_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#http_healthcheck AlbBackendGroup#http_healthcheck}
        :param interval_jitter_percent: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#interval_jitter_percent AlbBackendGroup#interval_jitter_percent}.
        :param stream_healthcheck: stream_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#stream_healthcheck AlbBackendGroup#stream_healthcheck}
        :param unhealthy_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#unhealthy_threshold AlbBackendGroup#unhealthy_threshold}.
        '''
        value = AlbBackendGroupHttpBackendHealthcheck(
            interval=interval,
            timeout=timeout,
            grpc_healthcheck=grpc_healthcheck,
            healthcheck_port=healthcheck_port,
            healthy_threshold=healthy_threshold,
            http_healthcheck=http_healthcheck,
            interval_jitter_percent=interval_jitter_percent,
            stream_healthcheck=stream_healthcheck,
            unhealthy_threshold=unhealthy_threshold,
        )

        return typing.cast(None, jsii.invoke(self, "putHealthcheck", [value]))

    @jsii.member(jsii_name="putLoadBalancingConfig")
    def put_load_balancing_config(
        self,
        *,
        locality_aware_routing_percent: typing.Optional[jsii.Number] = None,
        panic_threshold: typing.Optional[jsii.Number] = None,
        strict_locality: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param locality_aware_routing_percent: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#locality_aware_routing_percent AlbBackendGroup#locality_aware_routing_percent}.
        :param panic_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#panic_threshold AlbBackendGroup#panic_threshold}.
        :param strict_locality: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#strict_locality AlbBackendGroup#strict_locality}.
        '''
        value = AlbBackendGroupHttpBackendLoadBalancingConfig(
            locality_aware_routing_percent=locality_aware_routing_percent,
            panic_threshold=panic_threshold,
            strict_locality=strict_locality,
        )

        return typing.cast(None, jsii.invoke(self, "putLoadBalancingConfig", [value]))

    @jsii.member(jsii_name="putTls")
    def put_tls(
        self,
        *,
        sni: typing.Optional[builtins.str] = None,
        validation_context: typing.Optional["AlbBackendGroupHttpBackendTlsValidationContext"] = None,
    ) -> None:
        '''
        :param sni: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#sni AlbBackendGroup#sni}.
        :param validation_context: validation_context block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#validation_context AlbBackendGroup#validation_context}
        '''
        value = AlbBackendGroupHttpBackendTls(
            sni=sni, validation_context=validation_context
        )

        return typing.cast(None, jsii.invoke(self, "putTls", [value]))

    @jsii.member(jsii_name="resetHealthcheck")
    def reset_healthcheck(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHealthcheck", []))

    @jsii.member(jsii_name="resetHttp2")
    def reset_http2(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttp2", []))

    @jsii.member(jsii_name="resetLoadBalancingConfig")
    def reset_load_balancing_config(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLoadBalancingConfig", []))

    @jsii.member(jsii_name="resetPort")
    def reset_port(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPort", []))

    @jsii.member(jsii_name="resetStorageBucket")
    def reset_storage_bucket(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStorageBucket", []))

    @jsii.member(jsii_name="resetTargetGroupIds")
    def reset_target_group_ids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTargetGroupIds", []))

    @jsii.member(jsii_name="resetTls")
    def reset_tls(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTls", []))

    @jsii.member(jsii_name="resetWeight")
    def reset_weight(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetWeight", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthcheck")
    def healthcheck(self) -> AlbBackendGroupHttpBackendHealthcheckOutputReference:
        return typing.cast(AlbBackendGroupHttpBackendHealthcheckOutputReference, jsii.get(self, "healthcheck"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="loadBalancingConfig")
    def load_balancing_config(
        self,
    ) -> AlbBackendGroupHttpBackendLoadBalancingConfigOutputReference:
        return typing.cast(AlbBackendGroupHttpBackendLoadBalancingConfigOutputReference, jsii.get(self, "loadBalancingConfig"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tls")
    def tls(self) -> "AlbBackendGroupHttpBackendTlsOutputReference":
        return typing.cast("AlbBackendGroupHttpBackendTlsOutputReference", jsii.get(self, "tls"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthcheckInput")
    def healthcheck_input(
        self,
    ) -> typing.Optional[AlbBackendGroupHttpBackendHealthcheck]:
        return typing.cast(typing.Optional[AlbBackendGroupHttpBackendHealthcheck], jsii.get(self, "healthcheckInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="http2Input")
    def http2_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "http2Input"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="loadBalancingConfigInput")
    def load_balancing_config_input(
        self,
    ) -> typing.Optional[AlbBackendGroupHttpBackendLoadBalancingConfig]:
        return typing.cast(typing.Optional[AlbBackendGroupHttpBackendLoadBalancingConfig], jsii.get(self, "loadBalancingConfigInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="portInput")
    def port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "portInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="storageBucketInput")
    def storage_bucket_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "storageBucketInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupIdsInput")
    def target_group_ids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "targetGroupIdsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tlsInput")
    def tls_input(self) -> typing.Optional["AlbBackendGroupHttpBackendTls"]:
        return typing.cast(typing.Optional["AlbBackendGroupHttpBackendTls"], jsii.get(self, "tlsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="weightInput")
    def weight_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "weightInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="http2")
    def http2(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "http2"))

    @http2.setter
    def http2(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "http2", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "port"))

    @port.setter
    def port(self, value: jsii.Number) -> None:
        jsii.set(self, "port", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="storageBucket")
    def storage_bucket(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "storageBucket"))

    @storage_bucket.setter
    def storage_bucket(self, value: builtins.str) -> None:
        jsii.set(self, "storageBucket", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupIds")
    def target_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "targetGroupIds"))

    @target_group_ids.setter
    def target_group_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "targetGroupIds", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="weight")
    def weight(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "weight"))

    @weight.setter
    def weight(self, value: jsii.Number) -> None:
        jsii.set(self, "weight", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, AlbBackendGroupHttpBackend]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, AlbBackendGroupHttpBackend]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, AlbBackendGroupHttpBackend]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupHttpBackendTls",
    jsii_struct_bases=[],
    name_mapping={"sni": "sni", "validation_context": "validationContext"},
)
class AlbBackendGroupHttpBackendTls:
    def __init__(
        self,
        *,
        sni: typing.Optional[builtins.str] = None,
        validation_context: typing.Optional["AlbBackendGroupHttpBackendTlsValidationContext"] = None,
    ) -> None:
        '''
        :param sni: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#sni AlbBackendGroup#sni}.
        :param validation_context: validation_context block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#validation_context AlbBackendGroup#validation_context}
        '''
        if isinstance(validation_context, dict):
            validation_context = AlbBackendGroupHttpBackendTlsValidationContext(**validation_context)
        self._values: typing.Dict[str, typing.Any] = {}
        if sni is not None:
            self._values["sni"] = sni
        if validation_context is not None:
            self._values["validation_context"] = validation_context

    @builtins.property
    def sni(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#sni AlbBackendGroup#sni}.'''
        result = self._values.get("sni")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def validation_context(
        self,
    ) -> typing.Optional["AlbBackendGroupHttpBackendTlsValidationContext"]:
        '''validation_context block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#validation_context AlbBackendGroup#validation_context}
        '''
        result = self._values.get("validation_context")
        return typing.cast(typing.Optional["AlbBackendGroupHttpBackendTlsValidationContext"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbBackendGroupHttpBackendTls(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbBackendGroupHttpBackendTlsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupHttpBackendTlsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putValidationContext")
    def put_validation_context(
        self,
        *,
        trusted_ca_bytes: typing.Optional[builtins.str] = None,
        trusted_ca_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param trusted_ca_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#trusted_ca_bytes AlbBackendGroup#trusted_ca_bytes}.
        :param trusted_ca_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#trusted_ca_id AlbBackendGroup#trusted_ca_id}.
        '''
        value = AlbBackendGroupHttpBackendTlsValidationContext(
            trusted_ca_bytes=trusted_ca_bytes, trusted_ca_id=trusted_ca_id
        )

        return typing.cast(None, jsii.invoke(self, "putValidationContext", [value]))

    @jsii.member(jsii_name="resetSni")
    def reset_sni(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSni", []))

    @jsii.member(jsii_name="resetValidationContext")
    def reset_validation_context(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetValidationContext", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="validationContext")
    def validation_context(
        self,
    ) -> "AlbBackendGroupHttpBackendTlsValidationContextOutputReference":
        return typing.cast("AlbBackendGroupHttpBackendTlsValidationContextOutputReference", jsii.get(self, "validationContext"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sniInput")
    def sni_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sniInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="validationContextInput")
    def validation_context_input(
        self,
    ) -> typing.Optional["AlbBackendGroupHttpBackendTlsValidationContext"]:
        return typing.cast(typing.Optional["AlbBackendGroupHttpBackendTlsValidationContext"], jsii.get(self, "validationContextInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sni")
    def sni(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sni"))

    @sni.setter
    def sni(self, value: builtins.str) -> None:
        jsii.set(self, "sni", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[AlbBackendGroupHttpBackendTls]:
        return typing.cast(typing.Optional[AlbBackendGroupHttpBackendTls], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbBackendGroupHttpBackendTls],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupHttpBackendTlsValidationContext",
    jsii_struct_bases=[],
    name_mapping={
        "trusted_ca_bytes": "trustedCaBytes",
        "trusted_ca_id": "trustedCaId",
    },
)
class AlbBackendGroupHttpBackendTlsValidationContext:
    def __init__(
        self,
        *,
        trusted_ca_bytes: typing.Optional[builtins.str] = None,
        trusted_ca_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param trusted_ca_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#trusted_ca_bytes AlbBackendGroup#trusted_ca_bytes}.
        :param trusted_ca_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#trusted_ca_id AlbBackendGroup#trusted_ca_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if trusted_ca_bytes is not None:
            self._values["trusted_ca_bytes"] = trusted_ca_bytes
        if trusted_ca_id is not None:
            self._values["trusted_ca_id"] = trusted_ca_id

    @builtins.property
    def trusted_ca_bytes(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#trusted_ca_bytes AlbBackendGroup#trusted_ca_bytes}.'''
        result = self._values.get("trusted_ca_bytes")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def trusted_ca_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#trusted_ca_id AlbBackendGroup#trusted_ca_id}.'''
        result = self._values.get("trusted_ca_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbBackendGroupHttpBackendTlsValidationContext(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbBackendGroupHttpBackendTlsValidationContextOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupHttpBackendTlsValidationContextOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetTrustedCaBytes")
    def reset_trusted_ca_bytes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTrustedCaBytes", []))

    @jsii.member(jsii_name="resetTrustedCaId")
    def reset_trusted_ca_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTrustedCaId", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="trustedCaBytesInput")
    def trusted_ca_bytes_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "trustedCaBytesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="trustedCaIdInput")
    def trusted_ca_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "trustedCaIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="trustedCaBytes")
    def trusted_ca_bytes(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "trustedCaBytes"))

    @trusted_ca_bytes.setter
    def trusted_ca_bytes(self, value: builtins.str) -> None:
        jsii.set(self, "trustedCaBytes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="trustedCaId")
    def trusted_ca_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "trustedCaId"))

    @trusted_ca_id.setter
    def trusted_ca_id(self, value: builtins.str) -> None:
        jsii.set(self, "trustedCaId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbBackendGroupHttpBackendTlsValidationContext]:
        return typing.cast(typing.Optional[AlbBackendGroupHttpBackendTlsValidationContext], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbBackendGroupHttpBackendTlsValidationContext],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupStreamBackend",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "target_group_ids": "targetGroupIds",
        "healthcheck": "healthcheck",
        "load_balancing_config": "loadBalancingConfig",
        "port": "port",
        "tls": "tls",
        "weight": "weight",
    },
)
class AlbBackendGroupStreamBackend:
    def __init__(
        self,
        *,
        name: builtins.str,
        target_group_ids: typing.Sequence[builtins.str],
        healthcheck: typing.Optional["AlbBackendGroupStreamBackendHealthcheck"] = None,
        load_balancing_config: typing.Optional["AlbBackendGroupStreamBackendLoadBalancingConfig"] = None,
        port: typing.Optional[jsii.Number] = None,
        tls: typing.Optional["AlbBackendGroupStreamBackendTls"] = None,
        weight: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#name AlbBackendGroup#name}.
        :param target_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#target_group_ids AlbBackendGroup#target_group_ids}.
        :param healthcheck: healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#healthcheck AlbBackendGroup#healthcheck}
        :param load_balancing_config: load_balancing_config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#load_balancing_config AlbBackendGroup#load_balancing_config}
        :param port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#port AlbBackendGroup#port}.
        :param tls: tls block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#tls AlbBackendGroup#tls}
        :param weight: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#weight AlbBackendGroup#weight}.
        '''
        if isinstance(healthcheck, dict):
            healthcheck = AlbBackendGroupStreamBackendHealthcheck(**healthcheck)
        if isinstance(load_balancing_config, dict):
            load_balancing_config = AlbBackendGroupStreamBackendLoadBalancingConfig(**load_balancing_config)
        if isinstance(tls, dict):
            tls = AlbBackendGroupStreamBackendTls(**tls)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "target_group_ids": target_group_ids,
        }
        if healthcheck is not None:
            self._values["healthcheck"] = healthcheck
        if load_balancing_config is not None:
            self._values["load_balancing_config"] = load_balancing_config
        if port is not None:
            self._values["port"] = port
        if tls is not None:
            self._values["tls"] = tls
        if weight is not None:
            self._values["weight"] = weight

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#name AlbBackendGroup#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def target_group_ids(self) -> typing.List[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#target_group_ids AlbBackendGroup#target_group_ids}.'''
        result = self._values.get("target_group_ids")
        assert result is not None, "Required property 'target_group_ids' is missing"
        return typing.cast(typing.List[builtins.str], result)

    @builtins.property
    def healthcheck(self) -> typing.Optional["AlbBackendGroupStreamBackendHealthcheck"]:
        '''healthcheck block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#healthcheck AlbBackendGroup#healthcheck}
        '''
        result = self._values.get("healthcheck")
        return typing.cast(typing.Optional["AlbBackendGroupStreamBackendHealthcheck"], result)

    @builtins.property
    def load_balancing_config(
        self,
    ) -> typing.Optional["AlbBackendGroupStreamBackendLoadBalancingConfig"]:
        '''load_balancing_config block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#load_balancing_config AlbBackendGroup#load_balancing_config}
        '''
        result = self._values.get("load_balancing_config")
        return typing.cast(typing.Optional["AlbBackendGroupStreamBackendLoadBalancingConfig"], result)

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#port AlbBackendGroup#port}.'''
        result = self._values.get("port")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def tls(self) -> typing.Optional["AlbBackendGroupStreamBackendTls"]:
        '''tls block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#tls AlbBackendGroup#tls}
        '''
        result = self._values.get("tls")
        return typing.cast(typing.Optional["AlbBackendGroupStreamBackendTls"], result)

    @builtins.property
    def weight(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#weight AlbBackendGroup#weight}.'''
        result = self._values.get("weight")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbBackendGroupStreamBackend(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupStreamBackendHealthcheck",
    jsii_struct_bases=[],
    name_mapping={
        "interval": "interval",
        "timeout": "timeout",
        "grpc_healthcheck": "grpcHealthcheck",
        "healthcheck_port": "healthcheckPort",
        "healthy_threshold": "healthyThreshold",
        "http_healthcheck": "httpHealthcheck",
        "interval_jitter_percent": "intervalJitterPercent",
        "stream_healthcheck": "streamHealthcheck",
        "unhealthy_threshold": "unhealthyThreshold",
    },
)
class AlbBackendGroupStreamBackendHealthcheck:
    def __init__(
        self,
        *,
        interval: builtins.str,
        timeout: builtins.str,
        grpc_healthcheck: typing.Optional["AlbBackendGroupStreamBackendHealthcheckGrpcHealthcheck"] = None,
        healthcheck_port: typing.Optional[jsii.Number] = None,
        healthy_threshold: typing.Optional[jsii.Number] = None,
        http_healthcheck: typing.Optional["AlbBackendGroupStreamBackendHealthcheckHttpHealthcheck"] = None,
        interval_jitter_percent: typing.Optional[jsii.Number] = None,
        stream_healthcheck: typing.Optional["AlbBackendGroupStreamBackendHealthcheckStreamHealthcheck"] = None,
        unhealthy_threshold: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param interval: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#interval AlbBackendGroup#interval}.
        :param timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#timeout AlbBackendGroup#timeout}.
        :param grpc_healthcheck: grpc_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#grpc_healthcheck AlbBackendGroup#grpc_healthcheck}
        :param healthcheck_port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#healthcheck_port AlbBackendGroup#healthcheck_port}.
        :param healthy_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#healthy_threshold AlbBackendGroup#healthy_threshold}.
        :param http_healthcheck: http_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#http_healthcheck AlbBackendGroup#http_healthcheck}
        :param interval_jitter_percent: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#interval_jitter_percent AlbBackendGroup#interval_jitter_percent}.
        :param stream_healthcheck: stream_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#stream_healthcheck AlbBackendGroup#stream_healthcheck}
        :param unhealthy_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#unhealthy_threshold AlbBackendGroup#unhealthy_threshold}.
        '''
        if isinstance(grpc_healthcheck, dict):
            grpc_healthcheck = AlbBackendGroupStreamBackendHealthcheckGrpcHealthcheck(**grpc_healthcheck)
        if isinstance(http_healthcheck, dict):
            http_healthcheck = AlbBackendGroupStreamBackendHealthcheckHttpHealthcheck(**http_healthcheck)
        if isinstance(stream_healthcheck, dict):
            stream_healthcheck = AlbBackendGroupStreamBackendHealthcheckStreamHealthcheck(**stream_healthcheck)
        self._values: typing.Dict[str, typing.Any] = {
            "interval": interval,
            "timeout": timeout,
        }
        if grpc_healthcheck is not None:
            self._values["grpc_healthcheck"] = grpc_healthcheck
        if healthcheck_port is not None:
            self._values["healthcheck_port"] = healthcheck_port
        if healthy_threshold is not None:
            self._values["healthy_threshold"] = healthy_threshold
        if http_healthcheck is not None:
            self._values["http_healthcheck"] = http_healthcheck
        if interval_jitter_percent is not None:
            self._values["interval_jitter_percent"] = interval_jitter_percent
        if stream_healthcheck is not None:
            self._values["stream_healthcheck"] = stream_healthcheck
        if unhealthy_threshold is not None:
            self._values["unhealthy_threshold"] = unhealthy_threshold

    @builtins.property
    def interval(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#interval AlbBackendGroup#interval}.'''
        result = self._values.get("interval")
        assert result is not None, "Required property 'interval' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def timeout(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#timeout AlbBackendGroup#timeout}.'''
        result = self._values.get("timeout")
        assert result is not None, "Required property 'timeout' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def grpc_healthcheck(
        self,
    ) -> typing.Optional["AlbBackendGroupStreamBackendHealthcheckGrpcHealthcheck"]:
        '''grpc_healthcheck block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#grpc_healthcheck AlbBackendGroup#grpc_healthcheck}
        '''
        result = self._values.get("grpc_healthcheck")
        return typing.cast(typing.Optional["AlbBackendGroupStreamBackendHealthcheckGrpcHealthcheck"], result)

    @builtins.property
    def healthcheck_port(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#healthcheck_port AlbBackendGroup#healthcheck_port}.'''
        result = self._values.get("healthcheck_port")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def healthy_threshold(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#healthy_threshold AlbBackendGroup#healthy_threshold}.'''
        result = self._values.get("healthy_threshold")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def http_healthcheck(
        self,
    ) -> typing.Optional["AlbBackendGroupStreamBackendHealthcheckHttpHealthcheck"]:
        '''http_healthcheck block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#http_healthcheck AlbBackendGroup#http_healthcheck}
        '''
        result = self._values.get("http_healthcheck")
        return typing.cast(typing.Optional["AlbBackendGroupStreamBackendHealthcheckHttpHealthcheck"], result)

    @builtins.property
    def interval_jitter_percent(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#interval_jitter_percent AlbBackendGroup#interval_jitter_percent}.'''
        result = self._values.get("interval_jitter_percent")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def stream_healthcheck(
        self,
    ) -> typing.Optional["AlbBackendGroupStreamBackendHealthcheckStreamHealthcheck"]:
        '''stream_healthcheck block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#stream_healthcheck AlbBackendGroup#stream_healthcheck}
        '''
        result = self._values.get("stream_healthcheck")
        return typing.cast(typing.Optional["AlbBackendGroupStreamBackendHealthcheckStreamHealthcheck"], result)

    @builtins.property
    def unhealthy_threshold(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#unhealthy_threshold AlbBackendGroup#unhealthy_threshold}.'''
        result = self._values.get("unhealthy_threshold")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbBackendGroupStreamBackendHealthcheck(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupStreamBackendHealthcheckGrpcHealthcheck",
    jsii_struct_bases=[],
    name_mapping={"service_name": "serviceName"},
)
class AlbBackendGroupStreamBackendHealthcheckGrpcHealthcheck:
    def __init__(self, *, service_name: typing.Optional[builtins.str] = None) -> None:
        '''
        :param service_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#service_name AlbBackendGroup#service_name}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if service_name is not None:
            self._values["service_name"] = service_name

    @builtins.property
    def service_name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#service_name AlbBackendGroup#service_name}.'''
        result = self._values.get("service_name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbBackendGroupStreamBackendHealthcheckGrpcHealthcheck(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbBackendGroupStreamBackendHealthcheckGrpcHealthcheckOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupStreamBackendHealthcheckGrpcHealthcheckOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetServiceName")
    def reset_service_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetServiceName", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceNameInput")
    def service_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceName")
    def service_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceName"))

    @service_name.setter
    def service_name(self, value: builtins.str) -> None:
        jsii.set(self, "serviceName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbBackendGroupStreamBackendHealthcheckGrpcHealthcheck]:
        return typing.cast(typing.Optional[AlbBackendGroupStreamBackendHealthcheckGrpcHealthcheck], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbBackendGroupStreamBackendHealthcheckGrpcHealthcheck],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupStreamBackendHealthcheckHttpHealthcheck",
    jsii_struct_bases=[],
    name_mapping={"path": "path", "host": "host", "http2": "http2"},
)
class AlbBackendGroupStreamBackendHealthcheckHttpHealthcheck:
    def __init__(
        self,
        *,
        path: builtins.str,
        host: typing.Optional[builtins.str] = None,
        http2: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param path: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#path AlbBackendGroup#path}.
        :param host: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#host AlbBackendGroup#host}.
        :param http2: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#http2 AlbBackendGroup#http2}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "path": path,
        }
        if host is not None:
            self._values["host"] = host
        if http2 is not None:
            self._values["http2"] = http2

    @builtins.property
    def path(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#path AlbBackendGroup#path}.'''
        result = self._values.get("path")
        assert result is not None, "Required property 'path' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def host(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#host AlbBackendGroup#host}.'''
        result = self._values.get("host")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def http2(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#http2 AlbBackendGroup#http2}.'''
        result = self._values.get("http2")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbBackendGroupStreamBackendHealthcheckHttpHealthcheck(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbBackendGroupStreamBackendHealthcheckHttpHealthcheckOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupStreamBackendHealthcheckHttpHealthcheckOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetHost")
    def reset_host(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHost", []))

    @jsii.member(jsii_name="resetHttp2")
    def reset_http2(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttp2", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostInput")
    def host_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "hostInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="http2Input")
    def http2_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "http2Input"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="pathInput")
    def path_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "pathInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="host")
    def host(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "host"))

    @host.setter
    def host(self, value: builtins.str) -> None:
        jsii.set(self, "host", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="http2")
    def http2(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "http2"))

    @http2.setter
    def http2(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "http2", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="path")
    def path(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "path"))

    @path.setter
    def path(self, value: builtins.str) -> None:
        jsii.set(self, "path", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbBackendGroupStreamBackendHealthcheckHttpHealthcheck]:
        return typing.cast(typing.Optional[AlbBackendGroupStreamBackendHealthcheckHttpHealthcheck], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbBackendGroupStreamBackendHealthcheckHttpHealthcheck],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbBackendGroupStreamBackendHealthcheckOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupStreamBackendHealthcheckOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putGrpcHealthcheck")
    def put_grpc_healthcheck(
        self,
        *,
        service_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param service_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#service_name AlbBackendGroup#service_name}.
        '''
        value = AlbBackendGroupStreamBackendHealthcheckGrpcHealthcheck(
            service_name=service_name
        )

        return typing.cast(None, jsii.invoke(self, "putGrpcHealthcheck", [value]))

    @jsii.member(jsii_name="putHttpHealthcheck")
    def put_http_healthcheck(
        self,
        *,
        path: builtins.str,
        host: typing.Optional[builtins.str] = None,
        http2: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param path: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#path AlbBackendGroup#path}.
        :param host: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#host AlbBackendGroup#host}.
        :param http2: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#http2 AlbBackendGroup#http2}.
        '''
        value = AlbBackendGroupStreamBackendHealthcheckHttpHealthcheck(
            path=path, host=host, http2=http2
        )

        return typing.cast(None, jsii.invoke(self, "putHttpHealthcheck", [value]))

    @jsii.member(jsii_name="putStreamHealthcheck")
    def put_stream_healthcheck(
        self,
        *,
        receive: typing.Optional[builtins.str] = None,
        send: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param receive: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#receive AlbBackendGroup#receive}.
        :param send: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#send AlbBackendGroup#send}.
        '''
        value = AlbBackendGroupStreamBackendHealthcheckStreamHealthcheck(
            receive=receive, send=send
        )

        return typing.cast(None, jsii.invoke(self, "putStreamHealthcheck", [value]))

    @jsii.member(jsii_name="resetGrpcHealthcheck")
    def reset_grpc_healthcheck(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGrpcHealthcheck", []))

    @jsii.member(jsii_name="resetHealthcheckPort")
    def reset_healthcheck_port(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHealthcheckPort", []))

    @jsii.member(jsii_name="resetHealthyThreshold")
    def reset_healthy_threshold(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHealthyThreshold", []))

    @jsii.member(jsii_name="resetHttpHealthcheck")
    def reset_http_healthcheck(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttpHealthcheck", []))

    @jsii.member(jsii_name="resetIntervalJitterPercent")
    def reset_interval_jitter_percent(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIntervalJitterPercent", []))

    @jsii.member(jsii_name="resetStreamHealthcheck")
    def reset_stream_healthcheck(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStreamHealthcheck", []))

    @jsii.member(jsii_name="resetUnhealthyThreshold")
    def reset_unhealthy_threshold(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUnhealthyThreshold", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="grpcHealthcheck")
    def grpc_healthcheck(
        self,
    ) -> AlbBackendGroupStreamBackendHealthcheckGrpcHealthcheckOutputReference:
        return typing.cast(AlbBackendGroupStreamBackendHealthcheckGrpcHealthcheckOutputReference, jsii.get(self, "grpcHealthcheck"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpHealthcheck")
    def http_healthcheck(
        self,
    ) -> AlbBackendGroupStreamBackendHealthcheckHttpHealthcheckOutputReference:
        return typing.cast(AlbBackendGroupStreamBackendHealthcheckHttpHealthcheckOutputReference, jsii.get(self, "httpHealthcheck"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="streamHealthcheck")
    def stream_healthcheck(
        self,
    ) -> "AlbBackendGroupStreamBackendHealthcheckStreamHealthcheckOutputReference":
        return typing.cast("AlbBackendGroupStreamBackendHealthcheckStreamHealthcheckOutputReference", jsii.get(self, "streamHealthcheck"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="grpcHealthcheckInput")
    def grpc_healthcheck_input(
        self,
    ) -> typing.Optional[AlbBackendGroupStreamBackendHealthcheckGrpcHealthcheck]:
        return typing.cast(typing.Optional[AlbBackendGroupStreamBackendHealthcheckGrpcHealthcheck], jsii.get(self, "grpcHealthcheckInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthcheckPortInput")
    def healthcheck_port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "healthcheckPortInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthyThresholdInput")
    def healthy_threshold_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "healthyThresholdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpHealthcheckInput")
    def http_healthcheck_input(
        self,
    ) -> typing.Optional[AlbBackendGroupStreamBackendHealthcheckHttpHealthcheck]:
        return typing.cast(typing.Optional[AlbBackendGroupStreamBackendHealthcheckHttpHealthcheck], jsii.get(self, "httpHealthcheckInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "intervalInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="intervalJitterPercentInput")
    def interval_jitter_percent_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalJitterPercentInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="streamHealthcheckInput")
    def stream_healthcheck_input(
        self,
    ) -> typing.Optional["AlbBackendGroupStreamBackendHealthcheckStreamHealthcheck"]:
        return typing.cast(typing.Optional["AlbBackendGroupStreamBackendHealthcheckStreamHealthcheck"], jsii.get(self, "streamHealthcheckInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutInput")
    def timeout_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "timeoutInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="unhealthyThresholdInput")
    def unhealthy_threshold_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "unhealthyThresholdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthcheckPort")
    def healthcheck_port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "healthcheckPort"))

    @healthcheck_port.setter
    def healthcheck_port(self, value: jsii.Number) -> None:
        jsii.set(self, "healthcheckPort", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthyThreshold")
    def healthy_threshold(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "healthyThreshold"))

    @healthy_threshold.setter
    def healthy_threshold(self, value: jsii.Number) -> None:
        jsii.set(self, "healthyThreshold", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="interval")
    def interval(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: builtins.str) -> None:
        jsii.set(self, "interval", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="intervalJitterPercent")
    def interval_jitter_percent(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "intervalJitterPercent"))

    @interval_jitter_percent.setter
    def interval_jitter_percent(self, value: jsii.Number) -> None:
        jsii.set(self, "intervalJitterPercent", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeout")
    def timeout(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "timeout"))

    @timeout.setter
    def timeout(self, value: builtins.str) -> None:
        jsii.set(self, "timeout", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="unhealthyThreshold")
    def unhealthy_threshold(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "unhealthyThreshold"))

    @unhealthy_threshold.setter
    def unhealthy_threshold(self, value: jsii.Number) -> None:
        jsii.set(self, "unhealthyThreshold", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbBackendGroupStreamBackendHealthcheck]:
        return typing.cast(typing.Optional[AlbBackendGroupStreamBackendHealthcheck], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbBackendGroupStreamBackendHealthcheck],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupStreamBackendHealthcheckStreamHealthcheck",
    jsii_struct_bases=[],
    name_mapping={"receive": "receive", "send": "send"},
)
class AlbBackendGroupStreamBackendHealthcheckStreamHealthcheck:
    def __init__(
        self,
        *,
        receive: typing.Optional[builtins.str] = None,
        send: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param receive: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#receive AlbBackendGroup#receive}.
        :param send: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#send AlbBackendGroup#send}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if receive is not None:
            self._values["receive"] = receive
        if send is not None:
            self._values["send"] = send

    @builtins.property
    def receive(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#receive AlbBackendGroup#receive}.'''
        result = self._values.get("receive")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def send(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#send AlbBackendGroup#send}.'''
        result = self._values.get("send")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbBackendGroupStreamBackendHealthcheckStreamHealthcheck(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbBackendGroupStreamBackendHealthcheckStreamHealthcheckOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupStreamBackendHealthcheckStreamHealthcheckOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetReceive")
    def reset_receive(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetReceive", []))

    @jsii.member(jsii_name="resetSend")
    def reset_send(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSend", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="receiveInput")
    def receive_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "receiveInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sendInput")
    def send_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sendInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="receive")
    def receive(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "receive"))

    @receive.setter
    def receive(self, value: builtins.str) -> None:
        jsii.set(self, "receive", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="send")
    def send(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "send"))

    @send.setter
    def send(self, value: builtins.str) -> None:
        jsii.set(self, "send", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbBackendGroupStreamBackendHealthcheckStreamHealthcheck]:
        return typing.cast(typing.Optional[AlbBackendGroupStreamBackendHealthcheckStreamHealthcheck], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbBackendGroupStreamBackendHealthcheckStreamHealthcheck],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbBackendGroupStreamBackendList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupStreamBackendList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "AlbBackendGroupStreamBackendOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("AlbBackendGroupStreamBackendOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbBackendGroupStreamBackend]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbBackendGroupStreamBackend]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbBackendGroupStreamBackend]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupStreamBackendLoadBalancingConfig",
    jsii_struct_bases=[],
    name_mapping={
        "locality_aware_routing_percent": "localityAwareRoutingPercent",
        "panic_threshold": "panicThreshold",
        "strict_locality": "strictLocality",
    },
)
class AlbBackendGroupStreamBackendLoadBalancingConfig:
    def __init__(
        self,
        *,
        locality_aware_routing_percent: typing.Optional[jsii.Number] = None,
        panic_threshold: typing.Optional[jsii.Number] = None,
        strict_locality: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param locality_aware_routing_percent: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#locality_aware_routing_percent AlbBackendGroup#locality_aware_routing_percent}.
        :param panic_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#panic_threshold AlbBackendGroup#panic_threshold}.
        :param strict_locality: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#strict_locality AlbBackendGroup#strict_locality}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if locality_aware_routing_percent is not None:
            self._values["locality_aware_routing_percent"] = locality_aware_routing_percent
        if panic_threshold is not None:
            self._values["panic_threshold"] = panic_threshold
        if strict_locality is not None:
            self._values["strict_locality"] = strict_locality

    @builtins.property
    def locality_aware_routing_percent(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#locality_aware_routing_percent AlbBackendGroup#locality_aware_routing_percent}.'''
        result = self._values.get("locality_aware_routing_percent")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def panic_threshold(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#panic_threshold AlbBackendGroup#panic_threshold}.'''
        result = self._values.get("panic_threshold")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def strict_locality(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#strict_locality AlbBackendGroup#strict_locality}.'''
        result = self._values.get("strict_locality")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbBackendGroupStreamBackendLoadBalancingConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbBackendGroupStreamBackendLoadBalancingConfigOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupStreamBackendLoadBalancingConfigOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetLocalityAwareRoutingPercent")
    def reset_locality_aware_routing_percent(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLocalityAwareRoutingPercent", []))

    @jsii.member(jsii_name="resetPanicThreshold")
    def reset_panic_threshold(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPanicThreshold", []))

    @jsii.member(jsii_name="resetStrictLocality")
    def reset_strict_locality(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStrictLocality", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="localityAwareRoutingPercentInput")
    def locality_aware_routing_percent_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "localityAwareRoutingPercentInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="panicThresholdInput")
    def panic_threshold_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "panicThresholdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="strictLocalityInput")
    def strict_locality_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "strictLocalityInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="localityAwareRoutingPercent")
    def locality_aware_routing_percent(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "localityAwareRoutingPercent"))

    @locality_aware_routing_percent.setter
    def locality_aware_routing_percent(self, value: jsii.Number) -> None:
        jsii.set(self, "localityAwareRoutingPercent", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="panicThreshold")
    def panic_threshold(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "panicThreshold"))

    @panic_threshold.setter
    def panic_threshold(self, value: jsii.Number) -> None:
        jsii.set(self, "panicThreshold", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="strictLocality")
    def strict_locality(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "strictLocality"))

    @strict_locality.setter
    def strict_locality(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "strictLocality", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbBackendGroupStreamBackendLoadBalancingConfig]:
        return typing.cast(typing.Optional[AlbBackendGroupStreamBackendLoadBalancingConfig], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbBackendGroupStreamBackendLoadBalancingConfig],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbBackendGroupStreamBackendOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupStreamBackendOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putHealthcheck")
    def put_healthcheck(
        self,
        *,
        interval: builtins.str,
        timeout: builtins.str,
        grpc_healthcheck: typing.Optional[AlbBackendGroupStreamBackendHealthcheckGrpcHealthcheck] = None,
        healthcheck_port: typing.Optional[jsii.Number] = None,
        healthy_threshold: typing.Optional[jsii.Number] = None,
        http_healthcheck: typing.Optional[AlbBackendGroupStreamBackendHealthcheckHttpHealthcheck] = None,
        interval_jitter_percent: typing.Optional[jsii.Number] = None,
        stream_healthcheck: typing.Optional[AlbBackendGroupStreamBackendHealthcheckStreamHealthcheck] = None,
        unhealthy_threshold: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param interval: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#interval AlbBackendGroup#interval}.
        :param timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#timeout AlbBackendGroup#timeout}.
        :param grpc_healthcheck: grpc_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#grpc_healthcheck AlbBackendGroup#grpc_healthcheck}
        :param healthcheck_port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#healthcheck_port AlbBackendGroup#healthcheck_port}.
        :param healthy_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#healthy_threshold AlbBackendGroup#healthy_threshold}.
        :param http_healthcheck: http_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#http_healthcheck AlbBackendGroup#http_healthcheck}
        :param interval_jitter_percent: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#interval_jitter_percent AlbBackendGroup#interval_jitter_percent}.
        :param stream_healthcheck: stream_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#stream_healthcheck AlbBackendGroup#stream_healthcheck}
        :param unhealthy_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#unhealthy_threshold AlbBackendGroup#unhealthy_threshold}.
        '''
        value = AlbBackendGroupStreamBackendHealthcheck(
            interval=interval,
            timeout=timeout,
            grpc_healthcheck=grpc_healthcheck,
            healthcheck_port=healthcheck_port,
            healthy_threshold=healthy_threshold,
            http_healthcheck=http_healthcheck,
            interval_jitter_percent=interval_jitter_percent,
            stream_healthcheck=stream_healthcheck,
            unhealthy_threshold=unhealthy_threshold,
        )

        return typing.cast(None, jsii.invoke(self, "putHealthcheck", [value]))

    @jsii.member(jsii_name="putLoadBalancingConfig")
    def put_load_balancing_config(
        self,
        *,
        locality_aware_routing_percent: typing.Optional[jsii.Number] = None,
        panic_threshold: typing.Optional[jsii.Number] = None,
        strict_locality: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param locality_aware_routing_percent: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#locality_aware_routing_percent AlbBackendGroup#locality_aware_routing_percent}.
        :param panic_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#panic_threshold AlbBackendGroup#panic_threshold}.
        :param strict_locality: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#strict_locality AlbBackendGroup#strict_locality}.
        '''
        value = AlbBackendGroupStreamBackendLoadBalancingConfig(
            locality_aware_routing_percent=locality_aware_routing_percent,
            panic_threshold=panic_threshold,
            strict_locality=strict_locality,
        )

        return typing.cast(None, jsii.invoke(self, "putLoadBalancingConfig", [value]))

    @jsii.member(jsii_name="putTls")
    def put_tls(
        self,
        *,
        sni: typing.Optional[builtins.str] = None,
        validation_context: typing.Optional["AlbBackendGroupStreamBackendTlsValidationContext"] = None,
    ) -> None:
        '''
        :param sni: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#sni AlbBackendGroup#sni}.
        :param validation_context: validation_context block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#validation_context AlbBackendGroup#validation_context}
        '''
        value = AlbBackendGroupStreamBackendTls(
            sni=sni, validation_context=validation_context
        )

        return typing.cast(None, jsii.invoke(self, "putTls", [value]))

    @jsii.member(jsii_name="resetHealthcheck")
    def reset_healthcheck(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHealthcheck", []))

    @jsii.member(jsii_name="resetLoadBalancingConfig")
    def reset_load_balancing_config(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLoadBalancingConfig", []))

    @jsii.member(jsii_name="resetPort")
    def reset_port(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPort", []))

    @jsii.member(jsii_name="resetTls")
    def reset_tls(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTls", []))

    @jsii.member(jsii_name="resetWeight")
    def reset_weight(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetWeight", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthcheck")
    def healthcheck(self) -> AlbBackendGroupStreamBackendHealthcheckOutputReference:
        return typing.cast(AlbBackendGroupStreamBackendHealthcheckOutputReference, jsii.get(self, "healthcheck"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="loadBalancingConfig")
    def load_balancing_config(
        self,
    ) -> AlbBackendGroupStreamBackendLoadBalancingConfigOutputReference:
        return typing.cast(AlbBackendGroupStreamBackendLoadBalancingConfigOutputReference, jsii.get(self, "loadBalancingConfig"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tls")
    def tls(self) -> "AlbBackendGroupStreamBackendTlsOutputReference":
        return typing.cast("AlbBackendGroupStreamBackendTlsOutputReference", jsii.get(self, "tls"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthcheckInput")
    def healthcheck_input(
        self,
    ) -> typing.Optional[AlbBackendGroupStreamBackendHealthcheck]:
        return typing.cast(typing.Optional[AlbBackendGroupStreamBackendHealthcheck], jsii.get(self, "healthcheckInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="loadBalancingConfigInput")
    def load_balancing_config_input(
        self,
    ) -> typing.Optional[AlbBackendGroupStreamBackendLoadBalancingConfig]:
        return typing.cast(typing.Optional[AlbBackendGroupStreamBackendLoadBalancingConfig], jsii.get(self, "loadBalancingConfigInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="portInput")
    def port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "portInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupIdsInput")
    def target_group_ids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "targetGroupIdsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tlsInput")
    def tls_input(self) -> typing.Optional["AlbBackendGroupStreamBackendTls"]:
        return typing.cast(typing.Optional["AlbBackendGroupStreamBackendTls"], jsii.get(self, "tlsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="weightInput")
    def weight_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "weightInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "port"))

    @port.setter
    def port(self, value: jsii.Number) -> None:
        jsii.set(self, "port", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupIds")
    def target_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "targetGroupIds"))

    @target_group_ids.setter
    def target_group_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "targetGroupIds", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="weight")
    def weight(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "weight"))

    @weight.setter
    def weight(self, value: jsii.Number) -> None:
        jsii.set(self, "weight", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, AlbBackendGroupStreamBackend]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, AlbBackendGroupStreamBackend]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, AlbBackendGroupStreamBackend]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupStreamBackendTls",
    jsii_struct_bases=[],
    name_mapping={"sni": "sni", "validation_context": "validationContext"},
)
class AlbBackendGroupStreamBackendTls:
    def __init__(
        self,
        *,
        sni: typing.Optional[builtins.str] = None,
        validation_context: typing.Optional["AlbBackendGroupStreamBackendTlsValidationContext"] = None,
    ) -> None:
        '''
        :param sni: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#sni AlbBackendGroup#sni}.
        :param validation_context: validation_context block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#validation_context AlbBackendGroup#validation_context}
        '''
        if isinstance(validation_context, dict):
            validation_context = AlbBackendGroupStreamBackendTlsValidationContext(**validation_context)
        self._values: typing.Dict[str, typing.Any] = {}
        if sni is not None:
            self._values["sni"] = sni
        if validation_context is not None:
            self._values["validation_context"] = validation_context

    @builtins.property
    def sni(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#sni AlbBackendGroup#sni}.'''
        result = self._values.get("sni")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def validation_context(
        self,
    ) -> typing.Optional["AlbBackendGroupStreamBackendTlsValidationContext"]:
        '''validation_context block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#validation_context AlbBackendGroup#validation_context}
        '''
        result = self._values.get("validation_context")
        return typing.cast(typing.Optional["AlbBackendGroupStreamBackendTlsValidationContext"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbBackendGroupStreamBackendTls(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbBackendGroupStreamBackendTlsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupStreamBackendTlsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putValidationContext")
    def put_validation_context(
        self,
        *,
        trusted_ca_bytes: typing.Optional[builtins.str] = None,
        trusted_ca_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param trusted_ca_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#trusted_ca_bytes AlbBackendGroup#trusted_ca_bytes}.
        :param trusted_ca_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#trusted_ca_id AlbBackendGroup#trusted_ca_id}.
        '''
        value = AlbBackendGroupStreamBackendTlsValidationContext(
            trusted_ca_bytes=trusted_ca_bytes, trusted_ca_id=trusted_ca_id
        )

        return typing.cast(None, jsii.invoke(self, "putValidationContext", [value]))

    @jsii.member(jsii_name="resetSni")
    def reset_sni(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSni", []))

    @jsii.member(jsii_name="resetValidationContext")
    def reset_validation_context(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetValidationContext", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="validationContext")
    def validation_context(
        self,
    ) -> "AlbBackendGroupStreamBackendTlsValidationContextOutputReference":
        return typing.cast("AlbBackendGroupStreamBackendTlsValidationContextOutputReference", jsii.get(self, "validationContext"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sniInput")
    def sni_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sniInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="validationContextInput")
    def validation_context_input(
        self,
    ) -> typing.Optional["AlbBackendGroupStreamBackendTlsValidationContext"]:
        return typing.cast(typing.Optional["AlbBackendGroupStreamBackendTlsValidationContext"], jsii.get(self, "validationContextInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sni")
    def sni(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sni"))

    @sni.setter
    def sni(self, value: builtins.str) -> None:
        jsii.set(self, "sni", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[AlbBackendGroupStreamBackendTls]:
        return typing.cast(typing.Optional[AlbBackendGroupStreamBackendTls], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbBackendGroupStreamBackendTls],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupStreamBackendTlsValidationContext",
    jsii_struct_bases=[],
    name_mapping={
        "trusted_ca_bytes": "trustedCaBytes",
        "trusted_ca_id": "trustedCaId",
    },
)
class AlbBackendGroupStreamBackendTlsValidationContext:
    def __init__(
        self,
        *,
        trusted_ca_bytes: typing.Optional[builtins.str] = None,
        trusted_ca_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param trusted_ca_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#trusted_ca_bytes AlbBackendGroup#trusted_ca_bytes}.
        :param trusted_ca_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#trusted_ca_id AlbBackendGroup#trusted_ca_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if trusted_ca_bytes is not None:
            self._values["trusted_ca_bytes"] = trusted_ca_bytes
        if trusted_ca_id is not None:
            self._values["trusted_ca_id"] = trusted_ca_id

    @builtins.property
    def trusted_ca_bytes(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#trusted_ca_bytes AlbBackendGroup#trusted_ca_bytes}.'''
        result = self._values.get("trusted_ca_bytes")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def trusted_ca_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#trusted_ca_id AlbBackendGroup#trusted_ca_id}.'''
        result = self._values.get("trusted_ca_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbBackendGroupStreamBackendTlsValidationContext(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbBackendGroupStreamBackendTlsValidationContextOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupStreamBackendTlsValidationContextOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetTrustedCaBytes")
    def reset_trusted_ca_bytes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTrustedCaBytes", []))

    @jsii.member(jsii_name="resetTrustedCaId")
    def reset_trusted_ca_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTrustedCaId", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="trustedCaBytesInput")
    def trusted_ca_bytes_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "trustedCaBytesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="trustedCaIdInput")
    def trusted_ca_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "trustedCaIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="trustedCaBytes")
    def trusted_ca_bytes(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "trustedCaBytes"))

    @trusted_ca_bytes.setter
    def trusted_ca_bytes(self, value: builtins.str) -> None:
        jsii.set(self, "trustedCaBytes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="trustedCaId")
    def trusted_ca_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "trustedCaId"))

    @trusted_ca_id.setter
    def trusted_ca_id(self, value: builtins.str) -> None:
        jsii.set(self, "trustedCaId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbBackendGroupStreamBackendTlsValidationContext]:
        return typing.cast(typing.Optional[AlbBackendGroupStreamBackendTlsValidationContext], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbBackendGroupStreamBackendTlsValidationContext],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class AlbBackendGroupTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#create AlbBackendGroup#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#delete AlbBackendGroup#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#update AlbBackendGroup#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#create AlbBackendGroup#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#delete AlbBackendGroup#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_backend_group#update AlbBackendGroup#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbBackendGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbBackendGroupTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbBackendGroupTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, AlbBackendGroupTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, AlbBackendGroupTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, AlbBackendGroupTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbHttpRouter(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbHttpRouter",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/alb_http_router yandex_alb_http_router}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["AlbHttpRouterTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/alb_http_router yandex_alb_http_router} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_http_router#description AlbHttpRouter#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_http_router#folder_id AlbHttpRouter#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_http_router#id AlbHttpRouter#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_http_router#labels AlbHttpRouter#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_http_router#name AlbHttpRouter#name}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_http_router#timeouts AlbHttpRouter#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = AlbHttpRouterConfig(
            description=description,
            folder_id=folder_id,
            id=id,
            labels=labels,
            name=name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_http_router#create AlbHttpRouter#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_http_router#delete AlbHttpRouter#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_http_router#update AlbHttpRouter#update}.
        '''
        value = AlbHttpRouterTimeouts(create=create, delete=delete, update=update)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "AlbHttpRouterTimeoutsOutputReference":
        return typing.cast("AlbHttpRouterTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "AlbHttpRouterTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "AlbHttpRouterTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbHttpRouterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "description": "description",
        "folder_id": "folderId",
        "id": "id",
        "labels": "labels",
        "name": "name",
        "timeouts": "timeouts",
    },
)
class AlbHttpRouterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["AlbHttpRouterTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_http_router#description AlbHttpRouter#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_http_router#folder_id AlbHttpRouter#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_http_router#id AlbHttpRouter#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_http_router#labels AlbHttpRouter#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_http_router#name AlbHttpRouter#name}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_http_router#timeouts AlbHttpRouter#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AlbHttpRouterTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if name is not None:
            self._values["name"] = name
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_http_router#description AlbHttpRouter#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_http_router#folder_id AlbHttpRouter#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_http_router#id AlbHttpRouter#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_http_router#labels AlbHttpRouter#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_http_router#name AlbHttpRouter#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["AlbHttpRouterTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_http_router#timeouts AlbHttpRouter#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["AlbHttpRouterTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbHttpRouterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbHttpRouterTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class AlbHttpRouterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_http_router#create AlbHttpRouter#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_http_router#delete AlbHttpRouter#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_http_router#update AlbHttpRouter#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_http_router#create AlbHttpRouter#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_http_router#delete AlbHttpRouter#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_http_router#update AlbHttpRouter#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbHttpRouterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbHttpRouterTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbHttpRouterTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, AlbHttpRouterTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, AlbHttpRouterTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, AlbHttpRouterTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbLoadBalancer(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancer",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer yandex_alb_load_balancer}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        allocation_policy: "AlbLoadBalancerAllocationPolicy",
        network_id: builtins.str,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        listener: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["AlbLoadBalancerListener"]]] = None,
        name: typing.Optional[builtins.str] = None,
        region_id: typing.Optional[builtins.str] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        timeouts: typing.Optional["AlbLoadBalancerTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer yandex_alb_load_balancer} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param allocation_policy: allocation_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#allocation_policy AlbLoadBalancer#allocation_policy}
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#network_id AlbLoadBalancer#network_id}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#description AlbLoadBalancer#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#folder_id AlbLoadBalancer#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#id AlbLoadBalancer#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#labels AlbLoadBalancer#labels}.
        :param listener: listener block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#listener AlbLoadBalancer#listener}
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#name AlbLoadBalancer#name}.
        :param region_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#region_id AlbLoadBalancer#region_id}.
        :param security_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#security_group_ids AlbLoadBalancer#security_group_ids}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#timeouts AlbLoadBalancer#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = AlbLoadBalancerConfig(
            allocation_policy=allocation_policy,
            network_id=network_id,
            description=description,
            folder_id=folder_id,
            id=id,
            labels=labels,
            listener=listener,
            name=name,
            region_id=region_id,
            security_group_ids=security_group_ids,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putAllocationPolicy")
    def put_allocation_policy(
        self,
        *,
        location: typing.Union[cdktf.IResolvable, typing.Sequence["AlbLoadBalancerAllocationPolicyLocation"]],
    ) -> None:
        '''
        :param location: location block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#location AlbLoadBalancer#location}
        '''
        value = AlbLoadBalancerAllocationPolicy(location=location)

        return typing.cast(None, jsii.invoke(self, "putAllocationPolicy", [value]))

    @jsii.member(jsii_name="putListener")
    def put_listener(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["AlbLoadBalancerListener"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putListener", [value]))

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#create AlbLoadBalancer#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#delete AlbLoadBalancer#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#update AlbLoadBalancer#update}.
        '''
        value = AlbLoadBalancerTimeouts(create=create, delete=delete, update=update)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetListener")
    def reset_listener(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetListener", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetRegionId")
    def reset_region_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRegionId", []))

    @jsii.member(jsii_name="resetSecurityGroupIds")
    def reset_security_group_ids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityGroupIds", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allocationPolicy")
    def allocation_policy(self) -> "AlbLoadBalancerAllocationPolicyOutputReference":
        return typing.cast("AlbLoadBalancerAllocationPolicyOutputReference", jsii.get(self, "allocationPolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="listener")
    def listener(self) -> "AlbLoadBalancerListenerList":
        return typing.cast("AlbLoadBalancerListenerList", jsii.get(self, "listener"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logGroupId")
    def log_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "logGroupId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "AlbLoadBalancerTimeoutsOutputReference":
        return typing.cast("AlbLoadBalancerTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allocationPolicyInput")
    def allocation_policy_input(
        self,
    ) -> typing.Optional["AlbLoadBalancerAllocationPolicy"]:
        return typing.cast(typing.Optional["AlbLoadBalancerAllocationPolicy"], jsii.get(self, "allocationPolicyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="listenerInput")
    def listener_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbLoadBalancerListener"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbLoadBalancerListener"]]], jsii.get(self, "listenerInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkIdInput")
    def network_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "networkIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="regionIdInput")
    def region_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "regionIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIdsInput")
    def security_group_ids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "securityGroupIdsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "AlbLoadBalancerTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "AlbLoadBalancerTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @network_id.setter
    def network_id(self, value: builtins.str) -> None:
        jsii.set(self, "networkId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="regionId")
    def region_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "regionId"))

    @region_id.setter
    def region_id(self, value: builtins.str) -> None:
        jsii.set(self, "regionId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "securityGroupIds"))

    @security_group_ids.setter
    def security_group_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "securityGroupIds", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerAllocationPolicy",
    jsii_struct_bases=[],
    name_mapping={"location": "location"},
)
class AlbLoadBalancerAllocationPolicy:
    def __init__(
        self,
        *,
        location: typing.Union[cdktf.IResolvable, typing.Sequence["AlbLoadBalancerAllocationPolicyLocation"]],
    ) -> None:
        '''
        :param location: location block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#location AlbLoadBalancer#location}
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "location": location,
        }

    @builtins.property
    def location(
        self,
    ) -> typing.Union[cdktf.IResolvable, typing.List["AlbLoadBalancerAllocationPolicyLocation"]]:
        '''location block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#location AlbLoadBalancer#location}
        '''
        result = self._values.get("location")
        assert result is not None, "Required property 'location' is missing"
        return typing.cast(typing.Union[cdktf.IResolvable, typing.List["AlbLoadBalancerAllocationPolicyLocation"]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbLoadBalancerAllocationPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerAllocationPolicyLocation",
    jsii_struct_bases=[],
    name_mapping={
        "subnet_id": "subnetId",
        "zone_id": "zoneId",
        "disable_traffic": "disableTraffic",
    },
)
class AlbLoadBalancerAllocationPolicyLocation:
    def __init__(
        self,
        *,
        subnet_id: builtins.str,
        zone_id: builtins.str,
        disable_traffic: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param subnet_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#subnet_id AlbLoadBalancer#subnet_id}.
        :param zone_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#zone_id AlbLoadBalancer#zone_id}.
        :param disable_traffic: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#disable_traffic AlbLoadBalancer#disable_traffic}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "subnet_id": subnet_id,
            "zone_id": zone_id,
        }
        if disable_traffic is not None:
            self._values["disable_traffic"] = disable_traffic

    @builtins.property
    def subnet_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#subnet_id AlbLoadBalancer#subnet_id}.'''
        result = self._values.get("subnet_id")
        assert result is not None, "Required property 'subnet_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def zone_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#zone_id AlbLoadBalancer#zone_id}.'''
        result = self._values.get("zone_id")
        assert result is not None, "Required property 'zone_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def disable_traffic(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#disable_traffic AlbLoadBalancer#disable_traffic}.'''
        result = self._values.get("disable_traffic")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbLoadBalancerAllocationPolicyLocation(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbLoadBalancerAllocationPolicyLocationList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerAllocationPolicyLocationList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "AlbLoadBalancerAllocationPolicyLocationOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("AlbLoadBalancerAllocationPolicyLocationOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbLoadBalancerAllocationPolicyLocation]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbLoadBalancerAllocationPolicyLocation]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbLoadBalancerAllocationPolicyLocation]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbLoadBalancerAllocationPolicyLocationOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerAllocationPolicyLocationOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetDisableTraffic")
    def reset_disable_traffic(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDisableTraffic", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="disableTrafficInput")
    def disable_traffic_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "disableTrafficInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIdInput")
    def subnet_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "subnetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneIdInput")
    def zone_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "zoneIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="disableTraffic")
    def disable_traffic(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "disableTraffic"))

    @disable_traffic.setter
    def disable_traffic(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "disableTraffic", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @subnet_id.setter
    def subnet_id(self, value: builtins.str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneId")
    def zone_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zoneId"))

    @zone_id.setter
    def zone_id(self, value: builtins.str) -> None:
        jsii.set(self, "zoneId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, AlbLoadBalancerAllocationPolicyLocation]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, AlbLoadBalancerAllocationPolicyLocation]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, AlbLoadBalancerAllocationPolicyLocation]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbLoadBalancerAllocationPolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerAllocationPolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putLocation")
    def put_location(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence[AlbLoadBalancerAllocationPolicyLocation]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putLocation", [value]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="location")
    def location(self) -> AlbLoadBalancerAllocationPolicyLocationList:
        return typing.cast(AlbLoadBalancerAllocationPolicyLocationList, jsii.get(self, "location"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="locationInput")
    def location_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbLoadBalancerAllocationPolicyLocation]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbLoadBalancerAllocationPolicyLocation]]], jsii.get(self, "locationInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[AlbLoadBalancerAllocationPolicy]:
        return typing.cast(typing.Optional[AlbLoadBalancerAllocationPolicy], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbLoadBalancerAllocationPolicy],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "allocation_policy": "allocationPolicy",
        "network_id": "networkId",
        "description": "description",
        "folder_id": "folderId",
        "id": "id",
        "labels": "labels",
        "listener": "listener",
        "name": "name",
        "region_id": "regionId",
        "security_group_ids": "securityGroupIds",
        "timeouts": "timeouts",
    },
)
class AlbLoadBalancerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        allocation_policy: AlbLoadBalancerAllocationPolicy,
        network_id: builtins.str,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        listener: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["AlbLoadBalancerListener"]]] = None,
        name: typing.Optional[builtins.str] = None,
        region_id: typing.Optional[builtins.str] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        timeouts: typing.Optional["AlbLoadBalancerTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param allocation_policy: allocation_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#allocation_policy AlbLoadBalancer#allocation_policy}
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#network_id AlbLoadBalancer#network_id}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#description AlbLoadBalancer#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#folder_id AlbLoadBalancer#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#id AlbLoadBalancer#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#labels AlbLoadBalancer#labels}.
        :param listener: listener block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#listener AlbLoadBalancer#listener}
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#name AlbLoadBalancer#name}.
        :param region_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#region_id AlbLoadBalancer#region_id}.
        :param security_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#security_group_ids AlbLoadBalancer#security_group_ids}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#timeouts AlbLoadBalancer#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(allocation_policy, dict):
            allocation_policy = AlbLoadBalancerAllocationPolicy(**allocation_policy)
        if isinstance(timeouts, dict):
            timeouts = AlbLoadBalancerTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "allocation_policy": allocation_policy,
            "network_id": network_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if listener is not None:
            self._values["listener"] = listener
        if name is not None:
            self._values["name"] = name
        if region_id is not None:
            self._values["region_id"] = region_id
        if security_group_ids is not None:
            self._values["security_group_ids"] = security_group_ids
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def allocation_policy(self) -> AlbLoadBalancerAllocationPolicy:
        '''allocation_policy block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#allocation_policy AlbLoadBalancer#allocation_policy}
        '''
        result = self._values.get("allocation_policy")
        assert result is not None, "Required property 'allocation_policy' is missing"
        return typing.cast(AlbLoadBalancerAllocationPolicy, result)

    @builtins.property
    def network_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#network_id AlbLoadBalancer#network_id}.'''
        result = self._values.get("network_id")
        assert result is not None, "Required property 'network_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#description AlbLoadBalancer#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#folder_id AlbLoadBalancer#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#id AlbLoadBalancer#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#labels AlbLoadBalancer#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def listener(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbLoadBalancerListener"]]]:
        '''listener block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#listener AlbLoadBalancer#listener}
        '''
        result = self._values.get("listener")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbLoadBalancerListener"]]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#name AlbLoadBalancer#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def region_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#region_id AlbLoadBalancer#region_id}.'''
        result = self._values.get("region_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def security_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#security_group_ids AlbLoadBalancer#security_group_ids}.'''
        result = self._values.get("security_group_ids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["AlbLoadBalancerTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#timeouts AlbLoadBalancer#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["AlbLoadBalancerTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbLoadBalancerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListener",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "endpoint": "endpoint",
        "http": "http",
        "stream": "stream",
        "tls": "tls",
    },
)
class AlbLoadBalancerListener:
    def __init__(
        self,
        *,
        name: builtins.str,
        endpoint: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["AlbLoadBalancerListenerEndpoint"]]] = None,
        http: typing.Optional["AlbLoadBalancerListenerHttp"] = None,
        stream: typing.Optional["AlbLoadBalancerListenerStream"] = None,
        tls: typing.Optional["AlbLoadBalancerListenerTls"] = None,
    ) -> None:
        '''
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#name AlbLoadBalancer#name}.
        :param endpoint: endpoint block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#endpoint AlbLoadBalancer#endpoint}
        :param http: http block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#http AlbLoadBalancer#http}
        :param stream: stream block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#stream AlbLoadBalancer#stream}
        :param tls: tls block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#tls AlbLoadBalancer#tls}
        '''
        if isinstance(http, dict):
            http = AlbLoadBalancerListenerHttp(**http)
        if isinstance(stream, dict):
            stream = AlbLoadBalancerListenerStream(**stream)
        if isinstance(tls, dict):
            tls = AlbLoadBalancerListenerTls(**tls)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }
        if endpoint is not None:
            self._values["endpoint"] = endpoint
        if http is not None:
            self._values["http"] = http
        if stream is not None:
            self._values["stream"] = stream
        if tls is not None:
            self._values["tls"] = tls

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#name AlbLoadBalancer#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def endpoint(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbLoadBalancerListenerEndpoint"]]]:
        '''endpoint block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#endpoint AlbLoadBalancer#endpoint}
        '''
        result = self._values.get("endpoint")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbLoadBalancerListenerEndpoint"]]], result)

    @builtins.property
    def http(self) -> typing.Optional["AlbLoadBalancerListenerHttp"]:
        '''http block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#http AlbLoadBalancer#http}
        '''
        result = self._values.get("http")
        return typing.cast(typing.Optional["AlbLoadBalancerListenerHttp"], result)

    @builtins.property
    def stream(self) -> typing.Optional["AlbLoadBalancerListenerStream"]:
        '''stream block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#stream AlbLoadBalancer#stream}
        '''
        result = self._values.get("stream")
        return typing.cast(typing.Optional["AlbLoadBalancerListenerStream"], result)

    @builtins.property
    def tls(self) -> typing.Optional["AlbLoadBalancerListenerTls"]:
        '''tls block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#tls AlbLoadBalancer#tls}
        '''
        result = self._values.get("tls")
        return typing.cast(typing.Optional["AlbLoadBalancerListenerTls"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbLoadBalancerListener(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerEndpoint",
    jsii_struct_bases=[],
    name_mapping={"address": "address", "ports": "ports"},
)
class AlbLoadBalancerListenerEndpoint:
    def __init__(
        self,
        *,
        address: typing.Union[cdktf.IResolvable, typing.Sequence["AlbLoadBalancerListenerEndpointAddress"]],
        ports: typing.Sequence[jsii.Number],
    ) -> None:
        '''
        :param address: address block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#address AlbLoadBalancer#address}
        :param ports: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#ports AlbLoadBalancer#ports}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "address": address,
            "ports": ports,
        }

    @builtins.property
    def address(
        self,
    ) -> typing.Union[cdktf.IResolvable, typing.List["AlbLoadBalancerListenerEndpointAddress"]]:
        '''address block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#address AlbLoadBalancer#address}
        '''
        result = self._values.get("address")
        assert result is not None, "Required property 'address' is missing"
        return typing.cast(typing.Union[cdktf.IResolvable, typing.List["AlbLoadBalancerListenerEndpointAddress"]], result)

    @builtins.property
    def ports(self) -> typing.List[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#ports AlbLoadBalancer#ports}.'''
        result = self._values.get("ports")
        assert result is not None, "Required property 'ports' is missing"
        return typing.cast(typing.List[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbLoadBalancerListenerEndpoint(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerEndpointAddress",
    jsii_struct_bases=[],
    name_mapping={
        "external_ipv4_address": "externalIpv4Address",
        "external_ipv6_address": "externalIpv6Address",
        "internal_ipv4_address": "internalIpv4Address",
    },
)
class AlbLoadBalancerListenerEndpointAddress:
    def __init__(
        self,
        *,
        external_ipv4_address: typing.Optional["AlbLoadBalancerListenerEndpointAddressExternalIpv4Address"] = None,
        external_ipv6_address: typing.Optional["AlbLoadBalancerListenerEndpointAddressExternalIpv6Address"] = None,
        internal_ipv4_address: typing.Optional["AlbLoadBalancerListenerEndpointAddressInternalIpv4Address"] = None,
    ) -> None:
        '''
        :param external_ipv4_address: external_ipv4_address block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#external_ipv4_address AlbLoadBalancer#external_ipv4_address}
        :param external_ipv6_address: external_ipv6_address block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#external_ipv6_address AlbLoadBalancer#external_ipv6_address}
        :param internal_ipv4_address: internal_ipv4_address block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#internal_ipv4_address AlbLoadBalancer#internal_ipv4_address}
        '''
        if isinstance(external_ipv4_address, dict):
            external_ipv4_address = AlbLoadBalancerListenerEndpointAddressExternalIpv4Address(**external_ipv4_address)
        if isinstance(external_ipv6_address, dict):
            external_ipv6_address = AlbLoadBalancerListenerEndpointAddressExternalIpv6Address(**external_ipv6_address)
        if isinstance(internal_ipv4_address, dict):
            internal_ipv4_address = AlbLoadBalancerListenerEndpointAddressInternalIpv4Address(**internal_ipv4_address)
        self._values: typing.Dict[str, typing.Any] = {}
        if external_ipv4_address is not None:
            self._values["external_ipv4_address"] = external_ipv4_address
        if external_ipv6_address is not None:
            self._values["external_ipv6_address"] = external_ipv6_address
        if internal_ipv4_address is not None:
            self._values["internal_ipv4_address"] = internal_ipv4_address

    @builtins.property
    def external_ipv4_address(
        self,
    ) -> typing.Optional["AlbLoadBalancerListenerEndpointAddressExternalIpv4Address"]:
        '''external_ipv4_address block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#external_ipv4_address AlbLoadBalancer#external_ipv4_address}
        '''
        result = self._values.get("external_ipv4_address")
        return typing.cast(typing.Optional["AlbLoadBalancerListenerEndpointAddressExternalIpv4Address"], result)

    @builtins.property
    def external_ipv6_address(
        self,
    ) -> typing.Optional["AlbLoadBalancerListenerEndpointAddressExternalIpv6Address"]:
        '''external_ipv6_address block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#external_ipv6_address AlbLoadBalancer#external_ipv6_address}
        '''
        result = self._values.get("external_ipv6_address")
        return typing.cast(typing.Optional["AlbLoadBalancerListenerEndpointAddressExternalIpv6Address"], result)

    @builtins.property
    def internal_ipv4_address(
        self,
    ) -> typing.Optional["AlbLoadBalancerListenerEndpointAddressInternalIpv4Address"]:
        '''internal_ipv4_address block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#internal_ipv4_address AlbLoadBalancer#internal_ipv4_address}
        '''
        result = self._values.get("internal_ipv4_address")
        return typing.cast(typing.Optional["AlbLoadBalancerListenerEndpointAddressInternalIpv4Address"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbLoadBalancerListenerEndpointAddress(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerEndpointAddressExternalIpv4Address",
    jsii_struct_bases=[],
    name_mapping={"address": "address"},
)
class AlbLoadBalancerListenerEndpointAddressExternalIpv4Address:
    def __init__(self, *, address: typing.Optional[builtins.str] = None) -> None:
        '''
        :param address: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#address AlbLoadBalancer#address}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if address is not None:
            self._values["address"] = address

    @builtins.property
    def address(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#address AlbLoadBalancer#address}.'''
        result = self._values.get("address")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbLoadBalancerListenerEndpointAddressExternalIpv4Address(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbLoadBalancerListenerEndpointAddressExternalIpv4AddressOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerEndpointAddressExternalIpv4AddressOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAddress")
    def reset_address(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAddress", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="addressInput")
    def address_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "addressInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="address")
    def address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "address"))

    @address.setter
    def address(self, value: builtins.str) -> None:
        jsii.set(self, "address", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbLoadBalancerListenerEndpointAddressExternalIpv4Address]:
        return typing.cast(typing.Optional[AlbLoadBalancerListenerEndpointAddressExternalIpv4Address], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbLoadBalancerListenerEndpointAddressExternalIpv4Address],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerEndpointAddressExternalIpv6Address",
    jsii_struct_bases=[],
    name_mapping={"address": "address"},
)
class AlbLoadBalancerListenerEndpointAddressExternalIpv6Address:
    def __init__(self, *, address: typing.Optional[builtins.str] = None) -> None:
        '''
        :param address: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#address AlbLoadBalancer#address}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if address is not None:
            self._values["address"] = address

    @builtins.property
    def address(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#address AlbLoadBalancer#address}.'''
        result = self._values.get("address")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbLoadBalancerListenerEndpointAddressExternalIpv6Address(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbLoadBalancerListenerEndpointAddressExternalIpv6AddressOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerEndpointAddressExternalIpv6AddressOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAddress")
    def reset_address(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAddress", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="addressInput")
    def address_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "addressInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="address")
    def address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "address"))

    @address.setter
    def address(self, value: builtins.str) -> None:
        jsii.set(self, "address", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbLoadBalancerListenerEndpointAddressExternalIpv6Address]:
        return typing.cast(typing.Optional[AlbLoadBalancerListenerEndpointAddressExternalIpv6Address], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbLoadBalancerListenerEndpointAddressExternalIpv6Address],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerEndpointAddressInternalIpv4Address",
    jsii_struct_bases=[],
    name_mapping={"address": "address", "subnet_id": "subnetId"},
)
class AlbLoadBalancerListenerEndpointAddressInternalIpv4Address:
    def __init__(
        self,
        *,
        address: typing.Optional[builtins.str] = None,
        subnet_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param address: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#address AlbLoadBalancer#address}.
        :param subnet_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#subnet_id AlbLoadBalancer#subnet_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if address is not None:
            self._values["address"] = address
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id

    @builtins.property
    def address(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#address AlbLoadBalancer#address}.'''
        result = self._values.get("address")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#subnet_id AlbLoadBalancer#subnet_id}.'''
        result = self._values.get("subnet_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbLoadBalancerListenerEndpointAddressInternalIpv4Address(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbLoadBalancerListenerEndpointAddressInternalIpv4AddressOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerEndpointAddressInternalIpv4AddressOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAddress")
    def reset_address(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAddress", []))

    @jsii.member(jsii_name="resetSubnetId")
    def reset_subnet_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSubnetId", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="addressInput")
    def address_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "addressInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIdInput")
    def subnet_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "subnetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="address")
    def address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "address"))

    @address.setter
    def address(self, value: builtins.str) -> None:
        jsii.set(self, "address", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @subnet_id.setter
    def subnet_id(self, value: builtins.str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbLoadBalancerListenerEndpointAddressInternalIpv4Address]:
        return typing.cast(typing.Optional[AlbLoadBalancerListenerEndpointAddressInternalIpv4Address], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbLoadBalancerListenerEndpointAddressInternalIpv4Address],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbLoadBalancerListenerEndpointAddressList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerEndpointAddressList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "AlbLoadBalancerListenerEndpointAddressOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("AlbLoadBalancerListenerEndpointAddressOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbLoadBalancerListenerEndpointAddress]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbLoadBalancerListenerEndpointAddress]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbLoadBalancerListenerEndpointAddress]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbLoadBalancerListenerEndpointAddressOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerEndpointAddressOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putExternalIpv4Address")
    def put_external_ipv4_address(
        self,
        *,
        address: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param address: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#address AlbLoadBalancer#address}.
        '''
        value = AlbLoadBalancerListenerEndpointAddressExternalIpv4Address(
            address=address
        )

        return typing.cast(None, jsii.invoke(self, "putExternalIpv4Address", [value]))

    @jsii.member(jsii_name="putExternalIpv6Address")
    def put_external_ipv6_address(
        self,
        *,
        address: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param address: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#address AlbLoadBalancer#address}.
        '''
        value = AlbLoadBalancerListenerEndpointAddressExternalIpv6Address(
            address=address
        )

        return typing.cast(None, jsii.invoke(self, "putExternalIpv6Address", [value]))

    @jsii.member(jsii_name="putInternalIpv4Address")
    def put_internal_ipv4_address(
        self,
        *,
        address: typing.Optional[builtins.str] = None,
        subnet_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param address: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#address AlbLoadBalancer#address}.
        :param subnet_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#subnet_id AlbLoadBalancer#subnet_id}.
        '''
        value = AlbLoadBalancerListenerEndpointAddressInternalIpv4Address(
            address=address, subnet_id=subnet_id
        )

        return typing.cast(None, jsii.invoke(self, "putInternalIpv4Address", [value]))

    @jsii.member(jsii_name="resetExternalIpv4Address")
    def reset_external_ipv4_address(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetExternalIpv4Address", []))

    @jsii.member(jsii_name="resetExternalIpv6Address")
    def reset_external_ipv6_address(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetExternalIpv6Address", []))

    @jsii.member(jsii_name="resetInternalIpv4Address")
    def reset_internal_ipv4_address(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInternalIpv4Address", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="externalIpv4Address")
    def external_ipv4_address(
        self,
    ) -> AlbLoadBalancerListenerEndpointAddressExternalIpv4AddressOutputReference:
        return typing.cast(AlbLoadBalancerListenerEndpointAddressExternalIpv4AddressOutputReference, jsii.get(self, "externalIpv4Address"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="externalIpv6Address")
    def external_ipv6_address(
        self,
    ) -> AlbLoadBalancerListenerEndpointAddressExternalIpv6AddressOutputReference:
        return typing.cast(AlbLoadBalancerListenerEndpointAddressExternalIpv6AddressOutputReference, jsii.get(self, "externalIpv6Address"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalIpv4Address")
    def internal_ipv4_address(
        self,
    ) -> AlbLoadBalancerListenerEndpointAddressInternalIpv4AddressOutputReference:
        return typing.cast(AlbLoadBalancerListenerEndpointAddressInternalIpv4AddressOutputReference, jsii.get(self, "internalIpv4Address"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="externalIpv4AddressInput")
    def external_ipv4_address_input(
        self,
    ) -> typing.Optional[AlbLoadBalancerListenerEndpointAddressExternalIpv4Address]:
        return typing.cast(typing.Optional[AlbLoadBalancerListenerEndpointAddressExternalIpv4Address], jsii.get(self, "externalIpv4AddressInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="externalIpv6AddressInput")
    def external_ipv6_address_input(
        self,
    ) -> typing.Optional[AlbLoadBalancerListenerEndpointAddressExternalIpv6Address]:
        return typing.cast(typing.Optional[AlbLoadBalancerListenerEndpointAddressExternalIpv6Address], jsii.get(self, "externalIpv6AddressInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalIpv4AddressInput")
    def internal_ipv4_address_input(
        self,
    ) -> typing.Optional[AlbLoadBalancerListenerEndpointAddressInternalIpv4Address]:
        return typing.cast(typing.Optional[AlbLoadBalancerListenerEndpointAddressInternalIpv4Address], jsii.get(self, "internalIpv4AddressInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, AlbLoadBalancerListenerEndpointAddress]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, AlbLoadBalancerListenerEndpointAddress]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, AlbLoadBalancerListenerEndpointAddress]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbLoadBalancerListenerEndpointList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerEndpointList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "AlbLoadBalancerListenerEndpointOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("AlbLoadBalancerListenerEndpointOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbLoadBalancerListenerEndpoint]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbLoadBalancerListenerEndpoint]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbLoadBalancerListenerEndpoint]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbLoadBalancerListenerEndpointOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerEndpointOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putAddress")
    def put_address(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence[AlbLoadBalancerListenerEndpointAddress]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putAddress", [value]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="address")
    def address(self) -> AlbLoadBalancerListenerEndpointAddressList:
        return typing.cast(AlbLoadBalancerListenerEndpointAddressList, jsii.get(self, "address"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="addressInput")
    def address_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbLoadBalancerListenerEndpointAddress]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbLoadBalancerListenerEndpointAddress]]], jsii.get(self, "addressInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="portsInput")
    def ports_input(self) -> typing.Optional[typing.List[jsii.Number]]:
        return typing.cast(typing.Optional[typing.List[jsii.Number]], jsii.get(self, "portsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ports")
    def ports(self) -> typing.List[jsii.Number]:
        return typing.cast(typing.List[jsii.Number], jsii.get(self, "ports"))

    @ports.setter
    def ports(self, value: typing.List[jsii.Number]) -> None:
        jsii.set(self, "ports", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, AlbLoadBalancerListenerEndpoint]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, AlbLoadBalancerListenerEndpoint]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, AlbLoadBalancerListenerEndpoint]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerHttp",
    jsii_struct_bases=[],
    name_mapping={"handler": "handler", "redirects": "redirects"},
)
class AlbLoadBalancerListenerHttp:
    def __init__(
        self,
        *,
        handler: typing.Optional["AlbLoadBalancerListenerHttpHandler"] = None,
        redirects: typing.Optional["AlbLoadBalancerListenerHttpRedirects"] = None,
    ) -> None:
        '''
        :param handler: handler block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#handler AlbLoadBalancer#handler}
        :param redirects: redirects block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#redirects AlbLoadBalancer#redirects}
        '''
        if isinstance(handler, dict):
            handler = AlbLoadBalancerListenerHttpHandler(**handler)
        if isinstance(redirects, dict):
            redirects = AlbLoadBalancerListenerHttpRedirects(**redirects)
        self._values: typing.Dict[str, typing.Any] = {}
        if handler is not None:
            self._values["handler"] = handler
        if redirects is not None:
            self._values["redirects"] = redirects

    @builtins.property
    def handler(self) -> typing.Optional["AlbLoadBalancerListenerHttpHandler"]:
        '''handler block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#handler AlbLoadBalancer#handler}
        '''
        result = self._values.get("handler")
        return typing.cast(typing.Optional["AlbLoadBalancerListenerHttpHandler"], result)

    @builtins.property
    def redirects(self) -> typing.Optional["AlbLoadBalancerListenerHttpRedirects"]:
        '''redirects block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#redirects AlbLoadBalancer#redirects}
        '''
        result = self._values.get("redirects")
        return typing.cast(typing.Optional["AlbLoadBalancerListenerHttpRedirects"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbLoadBalancerListenerHttp(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerHttpHandler",
    jsii_struct_bases=[],
    name_mapping={
        "allow_http10": "allowHttp10",
        "http2_options": "http2Options",
        "http_router_id": "httpRouterId",
    },
)
class AlbLoadBalancerListenerHttpHandler:
    def __init__(
        self,
        *,
        allow_http10: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        http2_options: typing.Optional["AlbLoadBalancerListenerHttpHandlerHttp2Options"] = None,
        http_router_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param allow_http10: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#allow_http10 AlbLoadBalancer#allow_http10}.
        :param http2_options: http2_options block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#http2_options AlbLoadBalancer#http2_options}
        :param http_router_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#http_router_id AlbLoadBalancer#http_router_id}.
        '''
        if isinstance(http2_options, dict):
            http2_options = AlbLoadBalancerListenerHttpHandlerHttp2Options(**http2_options)
        self._values: typing.Dict[str, typing.Any] = {}
        if allow_http10 is not None:
            self._values["allow_http10"] = allow_http10
        if http2_options is not None:
            self._values["http2_options"] = http2_options
        if http_router_id is not None:
            self._values["http_router_id"] = http_router_id

    @builtins.property
    def allow_http10(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#allow_http10 AlbLoadBalancer#allow_http10}.'''
        result = self._values.get("allow_http10")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def http2_options(
        self,
    ) -> typing.Optional["AlbLoadBalancerListenerHttpHandlerHttp2Options"]:
        '''http2_options block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#http2_options AlbLoadBalancer#http2_options}
        '''
        result = self._values.get("http2_options")
        return typing.cast(typing.Optional["AlbLoadBalancerListenerHttpHandlerHttp2Options"], result)

    @builtins.property
    def http_router_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#http_router_id AlbLoadBalancer#http_router_id}.'''
        result = self._values.get("http_router_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbLoadBalancerListenerHttpHandler(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerHttpHandlerHttp2Options",
    jsii_struct_bases=[],
    name_mapping={"max_concurrent_streams": "maxConcurrentStreams"},
)
class AlbLoadBalancerListenerHttpHandlerHttp2Options:
    def __init__(
        self,
        *,
        max_concurrent_streams: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param max_concurrent_streams: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#max_concurrent_streams AlbLoadBalancer#max_concurrent_streams}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if max_concurrent_streams is not None:
            self._values["max_concurrent_streams"] = max_concurrent_streams

    @builtins.property
    def max_concurrent_streams(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#max_concurrent_streams AlbLoadBalancer#max_concurrent_streams}.'''
        result = self._values.get("max_concurrent_streams")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbLoadBalancerListenerHttpHandlerHttp2Options(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbLoadBalancerListenerHttpHandlerHttp2OptionsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerHttpHandlerHttp2OptionsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetMaxConcurrentStreams")
    def reset_max_concurrent_streams(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxConcurrentStreams", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxConcurrentStreamsInput")
    def max_concurrent_streams_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxConcurrentStreamsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxConcurrentStreams")
    def max_concurrent_streams(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxConcurrentStreams"))

    @max_concurrent_streams.setter
    def max_concurrent_streams(self, value: jsii.Number) -> None:
        jsii.set(self, "maxConcurrentStreams", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbLoadBalancerListenerHttpHandlerHttp2Options]:
        return typing.cast(typing.Optional[AlbLoadBalancerListenerHttpHandlerHttp2Options], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbLoadBalancerListenerHttpHandlerHttp2Options],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbLoadBalancerListenerHttpHandlerOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerHttpHandlerOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putHttp2Options")
    def put_http2_options(
        self,
        *,
        max_concurrent_streams: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param max_concurrent_streams: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#max_concurrent_streams AlbLoadBalancer#max_concurrent_streams}.
        '''
        value = AlbLoadBalancerListenerHttpHandlerHttp2Options(
            max_concurrent_streams=max_concurrent_streams
        )

        return typing.cast(None, jsii.invoke(self, "putHttp2Options", [value]))

    @jsii.member(jsii_name="resetAllowHttp10")
    def reset_allow_http10(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAllowHttp10", []))

    @jsii.member(jsii_name="resetHttp2Options")
    def reset_http2_options(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttp2Options", []))

    @jsii.member(jsii_name="resetHttpRouterId")
    def reset_http_router_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttpRouterId", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="http2Options")
    def http2_options(
        self,
    ) -> AlbLoadBalancerListenerHttpHandlerHttp2OptionsOutputReference:
        return typing.cast(AlbLoadBalancerListenerHttpHandlerHttp2OptionsOutputReference, jsii.get(self, "http2Options"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allowHttp10Input")
    def allow_http10_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "allowHttp10Input"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="http2OptionsInput")
    def http2_options_input(
        self,
    ) -> typing.Optional[AlbLoadBalancerListenerHttpHandlerHttp2Options]:
        return typing.cast(typing.Optional[AlbLoadBalancerListenerHttpHandlerHttp2Options], jsii.get(self, "http2OptionsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpRouterIdInput")
    def http_router_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "httpRouterIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allowHttp10")
    def allow_http10(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "allowHttp10"))

    @allow_http10.setter
    def allow_http10(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "allowHttp10", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpRouterId")
    def http_router_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "httpRouterId"))

    @http_router_id.setter
    def http_router_id(self, value: builtins.str) -> None:
        jsii.set(self, "httpRouterId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[AlbLoadBalancerListenerHttpHandler]:
        return typing.cast(typing.Optional[AlbLoadBalancerListenerHttpHandler], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbLoadBalancerListenerHttpHandler],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbLoadBalancerListenerHttpOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerHttpOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putHandler")
    def put_handler(
        self,
        *,
        allow_http10: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        http2_options: typing.Optional[AlbLoadBalancerListenerHttpHandlerHttp2Options] = None,
        http_router_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param allow_http10: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#allow_http10 AlbLoadBalancer#allow_http10}.
        :param http2_options: http2_options block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#http2_options AlbLoadBalancer#http2_options}
        :param http_router_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#http_router_id AlbLoadBalancer#http_router_id}.
        '''
        value = AlbLoadBalancerListenerHttpHandler(
            allow_http10=allow_http10,
            http2_options=http2_options,
            http_router_id=http_router_id,
        )

        return typing.cast(None, jsii.invoke(self, "putHandler", [value]))

    @jsii.member(jsii_name="putRedirects")
    def put_redirects(
        self,
        *,
        http_to_https: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param http_to_https: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#http_to_https AlbLoadBalancer#http_to_https}.
        '''
        value = AlbLoadBalancerListenerHttpRedirects(http_to_https=http_to_https)

        return typing.cast(None, jsii.invoke(self, "putRedirects", [value]))

    @jsii.member(jsii_name="resetHandler")
    def reset_handler(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHandler", []))

    @jsii.member(jsii_name="resetRedirects")
    def reset_redirects(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRedirects", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="handler")
    def handler(self) -> AlbLoadBalancerListenerHttpHandlerOutputReference:
        return typing.cast(AlbLoadBalancerListenerHttpHandlerOutputReference, jsii.get(self, "handler"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="redirects")
    def redirects(self) -> "AlbLoadBalancerListenerHttpRedirectsOutputReference":
        return typing.cast("AlbLoadBalancerListenerHttpRedirectsOutputReference", jsii.get(self, "redirects"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="handlerInput")
    def handler_input(self) -> typing.Optional[AlbLoadBalancerListenerHttpHandler]:
        return typing.cast(typing.Optional[AlbLoadBalancerListenerHttpHandler], jsii.get(self, "handlerInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="redirectsInput")
    def redirects_input(
        self,
    ) -> typing.Optional["AlbLoadBalancerListenerHttpRedirects"]:
        return typing.cast(typing.Optional["AlbLoadBalancerListenerHttpRedirects"], jsii.get(self, "redirectsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[AlbLoadBalancerListenerHttp]:
        return typing.cast(typing.Optional[AlbLoadBalancerListenerHttp], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbLoadBalancerListenerHttp],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerHttpRedirects",
    jsii_struct_bases=[],
    name_mapping={"http_to_https": "httpToHttps"},
)
class AlbLoadBalancerListenerHttpRedirects:
    def __init__(
        self,
        *,
        http_to_https: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param http_to_https: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#http_to_https AlbLoadBalancer#http_to_https}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if http_to_https is not None:
            self._values["http_to_https"] = http_to_https

    @builtins.property
    def http_to_https(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#http_to_https AlbLoadBalancer#http_to_https}.'''
        result = self._values.get("http_to_https")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbLoadBalancerListenerHttpRedirects(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbLoadBalancerListenerHttpRedirectsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerHttpRedirectsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetHttpToHttps")
    def reset_http_to_https(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttpToHttps", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpToHttpsInput")
    def http_to_https_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "httpToHttpsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpToHttps")
    def http_to_https(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "httpToHttps"))

    @http_to_https.setter
    def http_to_https(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "httpToHttps", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[AlbLoadBalancerListenerHttpRedirects]:
        return typing.cast(typing.Optional[AlbLoadBalancerListenerHttpRedirects], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbLoadBalancerListenerHttpRedirects],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbLoadBalancerListenerList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "AlbLoadBalancerListenerOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("AlbLoadBalancerListenerOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbLoadBalancerListener]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbLoadBalancerListener]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbLoadBalancerListener]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbLoadBalancerListenerOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putEndpoint")
    def put_endpoint(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence[AlbLoadBalancerListenerEndpoint]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putEndpoint", [value]))

    @jsii.member(jsii_name="putHttp")
    def put_http(
        self,
        *,
        handler: typing.Optional[AlbLoadBalancerListenerHttpHandler] = None,
        redirects: typing.Optional[AlbLoadBalancerListenerHttpRedirects] = None,
    ) -> None:
        '''
        :param handler: handler block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#handler AlbLoadBalancer#handler}
        :param redirects: redirects block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#redirects AlbLoadBalancer#redirects}
        '''
        value = AlbLoadBalancerListenerHttp(handler=handler, redirects=redirects)

        return typing.cast(None, jsii.invoke(self, "putHttp", [value]))

    @jsii.member(jsii_name="putStream")
    def put_stream(
        self,
        *,
        handler: typing.Optional["AlbLoadBalancerListenerStreamHandler"] = None,
    ) -> None:
        '''
        :param handler: handler block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#handler AlbLoadBalancer#handler}
        '''
        value = AlbLoadBalancerListenerStream(handler=handler)

        return typing.cast(None, jsii.invoke(self, "putStream", [value]))

    @jsii.member(jsii_name="putTls")
    def put_tls(
        self,
        *,
        default_handler: "AlbLoadBalancerListenerTlsDefaultHandler",
        sni_handler: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["AlbLoadBalancerListenerTlsSniHandler"]]] = None,
    ) -> None:
        '''
        :param default_handler: default_handler block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#default_handler AlbLoadBalancer#default_handler}
        :param sni_handler: sni_handler block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#sni_handler AlbLoadBalancer#sni_handler}
        '''
        value = AlbLoadBalancerListenerTls(
            default_handler=default_handler, sni_handler=sni_handler
        )

        return typing.cast(None, jsii.invoke(self, "putTls", [value]))

    @jsii.member(jsii_name="resetEndpoint")
    def reset_endpoint(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEndpoint", []))

    @jsii.member(jsii_name="resetHttp")
    def reset_http(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttp", []))

    @jsii.member(jsii_name="resetStream")
    def reset_stream(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStream", []))

    @jsii.member(jsii_name="resetTls")
    def reset_tls(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTls", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> AlbLoadBalancerListenerEndpointList:
        return typing.cast(AlbLoadBalancerListenerEndpointList, jsii.get(self, "endpoint"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="http")
    def http(self) -> AlbLoadBalancerListenerHttpOutputReference:
        return typing.cast(AlbLoadBalancerListenerHttpOutputReference, jsii.get(self, "http"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="stream")
    def stream(self) -> "AlbLoadBalancerListenerStreamOutputReference":
        return typing.cast("AlbLoadBalancerListenerStreamOutputReference", jsii.get(self, "stream"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tls")
    def tls(self) -> "AlbLoadBalancerListenerTlsOutputReference":
        return typing.cast("AlbLoadBalancerListenerTlsOutputReference", jsii.get(self, "tls"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="endpointInput")
    def endpoint_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbLoadBalancerListenerEndpoint]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbLoadBalancerListenerEndpoint]]], jsii.get(self, "endpointInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpInput")
    def http_input(self) -> typing.Optional[AlbLoadBalancerListenerHttp]:
        return typing.cast(typing.Optional[AlbLoadBalancerListenerHttp], jsii.get(self, "httpInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="streamInput")
    def stream_input(self) -> typing.Optional["AlbLoadBalancerListenerStream"]:
        return typing.cast(typing.Optional["AlbLoadBalancerListenerStream"], jsii.get(self, "streamInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tlsInput")
    def tls_input(self) -> typing.Optional["AlbLoadBalancerListenerTls"]:
        return typing.cast(typing.Optional["AlbLoadBalancerListenerTls"], jsii.get(self, "tlsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, AlbLoadBalancerListener]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, AlbLoadBalancerListener]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, AlbLoadBalancerListener]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerStream",
    jsii_struct_bases=[],
    name_mapping={"handler": "handler"},
)
class AlbLoadBalancerListenerStream:
    def __init__(
        self,
        *,
        handler: typing.Optional["AlbLoadBalancerListenerStreamHandler"] = None,
    ) -> None:
        '''
        :param handler: handler block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#handler AlbLoadBalancer#handler}
        '''
        if isinstance(handler, dict):
            handler = AlbLoadBalancerListenerStreamHandler(**handler)
        self._values: typing.Dict[str, typing.Any] = {}
        if handler is not None:
            self._values["handler"] = handler

    @builtins.property
    def handler(self) -> typing.Optional["AlbLoadBalancerListenerStreamHandler"]:
        '''handler block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#handler AlbLoadBalancer#handler}
        '''
        result = self._values.get("handler")
        return typing.cast(typing.Optional["AlbLoadBalancerListenerStreamHandler"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbLoadBalancerListenerStream(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerStreamHandler",
    jsii_struct_bases=[],
    name_mapping={"backend_group_id": "backendGroupId"},
)
class AlbLoadBalancerListenerStreamHandler:
    def __init__(
        self,
        *,
        backend_group_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param backend_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#backend_group_id AlbLoadBalancer#backend_group_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if backend_group_id is not None:
            self._values["backend_group_id"] = backend_group_id

    @builtins.property
    def backend_group_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#backend_group_id AlbLoadBalancer#backend_group_id}.'''
        result = self._values.get("backend_group_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbLoadBalancerListenerStreamHandler(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbLoadBalancerListenerStreamHandlerOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerStreamHandlerOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetBackendGroupId")
    def reset_backend_group_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetBackendGroupId", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backendGroupIdInput")
    def backend_group_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "backendGroupIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backendGroupId")
    def backend_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "backendGroupId"))

    @backend_group_id.setter
    def backend_group_id(self, value: builtins.str) -> None:
        jsii.set(self, "backendGroupId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[AlbLoadBalancerListenerStreamHandler]:
        return typing.cast(typing.Optional[AlbLoadBalancerListenerStreamHandler], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbLoadBalancerListenerStreamHandler],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbLoadBalancerListenerStreamOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerStreamOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putHandler")
    def put_handler(
        self,
        *,
        backend_group_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param backend_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#backend_group_id AlbLoadBalancer#backend_group_id}.
        '''
        value = AlbLoadBalancerListenerStreamHandler(backend_group_id=backend_group_id)

        return typing.cast(None, jsii.invoke(self, "putHandler", [value]))

    @jsii.member(jsii_name="resetHandler")
    def reset_handler(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHandler", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="handler")
    def handler(self) -> AlbLoadBalancerListenerStreamHandlerOutputReference:
        return typing.cast(AlbLoadBalancerListenerStreamHandlerOutputReference, jsii.get(self, "handler"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="handlerInput")
    def handler_input(self) -> typing.Optional[AlbLoadBalancerListenerStreamHandler]:
        return typing.cast(typing.Optional[AlbLoadBalancerListenerStreamHandler], jsii.get(self, "handlerInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[AlbLoadBalancerListenerStream]:
        return typing.cast(typing.Optional[AlbLoadBalancerListenerStream], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbLoadBalancerListenerStream],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerTls",
    jsii_struct_bases=[],
    name_mapping={"default_handler": "defaultHandler", "sni_handler": "sniHandler"},
)
class AlbLoadBalancerListenerTls:
    def __init__(
        self,
        *,
        default_handler: "AlbLoadBalancerListenerTlsDefaultHandler",
        sni_handler: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["AlbLoadBalancerListenerTlsSniHandler"]]] = None,
    ) -> None:
        '''
        :param default_handler: default_handler block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#default_handler AlbLoadBalancer#default_handler}
        :param sni_handler: sni_handler block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#sni_handler AlbLoadBalancer#sni_handler}
        '''
        if isinstance(default_handler, dict):
            default_handler = AlbLoadBalancerListenerTlsDefaultHandler(**default_handler)
        self._values: typing.Dict[str, typing.Any] = {
            "default_handler": default_handler,
        }
        if sni_handler is not None:
            self._values["sni_handler"] = sni_handler

    @builtins.property
    def default_handler(self) -> "AlbLoadBalancerListenerTlsDefaultHandler":
        '''default_handler block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#default_handler AlbLoadBalancer#default_handler}
        '''
        result = self._values.get("default_handler")
        assert result is not None, "Required property 'default_handler' is missing"
        return typing.cast("AlbLoadBalancerListenerTlsDefaultHandler", result)

    @builtins.property
    def sni_handler(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbLoadBalancerListenerTlsSniHandler"]]]:
        '''sni_handler block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#sni_handler AlbLoadBalancer#sni_handler}
        '''
        result = self._values.get("sni_handler")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbLoadBalancerListenerTlsSniHandler"]]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbLoadBalancerListenerTls(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerTlsDefaultHandler",
    jsii_struct_bases=[],
    name_mapping={
        "certificate_ids": "certificateIds",
        "http_handler": "httpHandler",
        "stream_handler": "streamHandler",
    },
)
class AlbLoadBalancerListenerTlsDefaultHandler:
    def __init__(
        self,
        *,
        certificate_ids: typing.Sequence[builtins.str],
        http_handler: typing.Optional["AlbLoadBalancerListenerTlsDefaultHandlerHttpHandler"] = None,
        stream_handler: typing.Optional["AlbLoadBalancerListenerTlsDefaultHandlerStreamHandler"] = None,
    ) -> None:
        '''
        :param certificate_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#certificate_ids AlbLoadBalancer#certificate_ids}.
        :param http_handler: http_handler block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#http_handler AlbLoadBalancer#http_handler}
        :param stream_handler: stream_handler block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#stream_handler AlbLoadBalancer#stream_handler}
        '''
        if isinstance(http_handler, dict):
            http_handler = AlbLoadBalancerListenerTlsDefaultHandlerHttpHandler(**http_handler)
        if isinstance(stream_handler, dict):
            stream_handler = AlbLoadBalancerListenerTlsDefaultHandlerStreamHandler(**stream_handler)
        self._values: typing.Dict[str, typing.Any] = {
            "certificate_ids": certificate_ids,
        }
        if http_handler is not None:
            self._values["http_handler"] = http_handler
        if stream_handler is not None:
            self._values["stream_handler"] = stream_handler

    @builtins.property
    def certificate_ids(self) -> typing.List[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#certificate_ids AlbLoadBalancer#certificate_ids}.'''
        result = self._values.get("certificate_ids")
        assert result is not None, "Required property 'certificate_ids' is missing"
        return typing.cast(typing.List[builtins.str], result)

    @builtins.property
    def http_handler(
        self,
    ) -> typing.Optional["AlbLoadBalancerListenerTlsDefaultHandlerHttpHandler"]:
        '''http_handler block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#http_handler AlbLoadBalancer#http_handler}
        '''
        result = self._values.get("http_handler")
        return typing.cast(typing.Optional["AlbLoadBalancerListenerTlsDefaultHandlerHttpHandler"], result)

    @builtins.property
    def stream_handler(
        self,
    ) -> typing.Optional["AlbLoadBalancerListenerTlsDefaultHandlerStreamHandler"]:
        '''stream_handler block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#stream_handler AlbLoadBalancer#stream_handler}
        '''
        result = self._values.get("stream_handler")
        return typing.cast(typing.Optional["AlbLoadBalancerListenerTlsDefaultHandlerStreamHandler"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbLoadBalancerListenerTlsDefaultHandler(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerTlsDefaultHandlerHttpHandler",
    jsii_struct_bases=[],
    name_mapping={
        "allow_http10": "allowHttp10",
        "http2_options": "http2Options",
        "http_router_id": "httpRouterId",
    },
)
class AlbLoadBalancerListenerTlsDefaultHandlerHttpHandler:
    def __init__(
        self,
        *,
        allow_http10: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        http2_options: typing.Optional["AlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2Options"] = None,
        http_router_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param allow_http10: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#allow_http10 AlbLoadBalancer#allow_http10}.
        :param http2_options: http2_options block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#http2_options AlbLoadBalancer#http2_options}
        :param http_router_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#http_router_id AlbLoadBalancer#http_router_id}.
        '''
        if isinstance(http2_options, dict):
            http2_options = AlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2Options(**http2_options)
        self._values: typing.Dict[str, typing.Any] = {}
        if allow_http10 is not None:
            self._values["allow_http10"] = allow_http10
        if http2_options is not None:
            self._values["http2_options"] = http2_options
        if http_router_id is not None:
            self._values["http_router_id"] = http_router_id

    @builtins.property
    def allow_http10(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#allow_http10 AlbLoadBalancer#allow_http10}.'''
        result = self._values.get("allow_http10")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def http2_options(
        self,
    ) -> typing.Optional["AlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2Options"]:
        '''http2_options block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#http2_options AlbLoadBalancer#http2_options}
        '''
        result = self._values.get("http2_options")
        return typing.cast(typing.Optional["AlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2Options"], result)

    @builtins.property
    def http_router_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#http_router_id AlbLoadBalancer#http_router_id}.'''
        result = self._values.get("http_router_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbLoadBalancerListenerTlsDefaultHandlerHttpHandler(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2Options",
    jsii_struct_bases=[],
    name_mapping={"max_concurrent_streams": "maxConcurrentStreams"},
)
class AlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2Options:
    def __init__(
        self,
        *,
        max_concurrent_streams: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param max_concurrent_streams: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#max_concurrent_streams AlbLoadBalancer#max_concurrent_streams}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if max_concurrent_streams is not None:
            self._values["max_concurrent_streams"] = max_concurrent_streams

    @builtins.property
    def max_concurrent_streams(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#max_concurrent_streams AlbLoadBalancer#max_concurrent_streams}.'''
        result = self._values.get("max_concurrent_streams")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2Options(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2OptionsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2OptionsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetMaxConcurrentStreams")
    def reset_max_concurrent_streams(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxConcurrentStreams", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxConcurrentStreamsInput")
    def max_concurrent_streams_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxConcurrentStreamsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxConcurrentStreams")
    def max_concurrent_streams(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxConcurrentStreams"))

    @max_concurrent_streams.setter
    def max_concurrent_streams(self, value: jsii.Number) -> None:
        jsii.set(self, "maxConcurrentStreams", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2Options]:
        return typing.cast(typing.Optional[AlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2Options], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2Options],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putHttp2Options")
    def put_http2_options(
        self,
        *,
        max_concurrent_streams: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param max_concurrent_streams: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#max_concurrent_streams AlbLoadBalancer#max_concurrent_streams}.
        '''
        value = AlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2Options(
            max_concurrent_streams=max_concurrent_streams
        )

        return typing.cast(None, jsii.invoke(self, "putHttp2Options", [value]))

    @jsii.member(jsii_name="resetAllowHttp10")
    def reset_allow_http10(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAllowHttp10", []))

    @jsii.member(jsii_name="resetHttp2Options")
    def reset_http2_options(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttp2Options", []))

    @jsii.member(jsii_name="resetHttpRouterId")
    def reset_http_router_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttpRouterId", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="http2Options")
    def http2_options(
        self,
    ) -> AlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2OptionsOutputReference:
        return typing.cast(AlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2OptionsOutputReference, jsii.get(self, "http2Options"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allowHttp10Input")
    def allow_http10_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "allowHttp10Input"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="http2OptionsInput")
    def http2_options_input(
        self,
    ) -> typing.Optional[AlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2Options]:
        return typing.cast(typing.Optional[AlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2Options], jsii.get(self, "http2OptionsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpRouterIdInput")
    def http_router_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "httpRouterIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allowHttp10")
    def allow_http10(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "allowHttp10"))

    @allow_http10.setter
    def allow_http10(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "allowHttp10", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpRouterId")
    def http_router_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "httpRouterId"))

    @http_router_id.setter
    def http_router_id(self, value: builtins.str) -> None:
        jsii.set(self, "httpRouterId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbLoadBalancerListenerTlsDefaultHandlerHttpHandler]:
        return typing.cast(typing.Optional[AlbLoadBalancerListenerTlsDefaultHandlerHttpHandler], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbLoadBalancerListenerTlsDefaultHandlerHttpHandler],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbLoadBalancerListenerTlsDefaultHandlerOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerTlsDefaultHandlerOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putHttpHandler")
    def put_http_handler(
        self,
        *,
        allow_http10: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        http2_options: typing.Optional[AlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2Options] = None,
        http_router_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param allow_http10: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#allow_http10 AlbLoadBalancer#allow_http10}.
        :param http2_options: http2_options block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#http2_options AlbLoadBalancer#http2_options}
        :param http_router_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#http_router_id AlbLoadBalancer#http_router_id}.
        '''
        value = AlbLoadBalancerListenerTlsDefaultHandlerHttpHandler(
            allow_http10=allow_http10,
            http2_options=http2_options,
            http_router_id=http_router_id,
        )

        return typing.cast(None, jsii.invoke(self, "putHttpHandler", [value]))

    @jsii.member(jsii_name="putStreamHandler")
    def put_stream_handler(
        self,
        *,
        backend_group_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param backend_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#backend_group_id AlbLoadBalancer#backend_group_id}.
        '''
        value = AlbLoadBalancerListenerTlsDefaultHandlerStreamHandler(
            backend_group_id=backend_group_id
        )

        return typing.cast(None, jsii.invoke(self, "putStreamHandler", [value]))

    @jsii.member(jsii_name="resetHttpHandler")
    def reset_http_handler(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttpHandler", []))

    @jsii.member(jsii_name="resetStreamHandler")
    def reset_stream_handler(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStreamHandler", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpHandler")
    def http_handler(
        self,
    ) -> AlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerOutputReference:
        return typing.cast(AlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerOutputReference, jsii.get(self, "httpHandler"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="streamHandler")
    def stream_handler(
        self,
    ) -> "AlbLoadBalancerListenerTlsDefaultHandlerStreamHandlerOutputReference":
        return typing.cast("AlbLoadBalancerListenerTlsDefaultHandlerStreamHandlerOutputReference", jsii.get(self, "streamHandler"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="certificateIdsInput")
    def certificate_ids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "certificateIdsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpHandlerInput")
    def http_handler_input(
        self,
    ) -> typing.Optional[AlbLoadBalancerListenerTlsDefaultHandlerHttpHandler]:
        return typing.cast(typing.Optional[AlbLoadBalancerListenerTlsDefaultHandlerHttpHandler], jsii.get(self, "httpHandlerInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="streamHandlerInput")
    def stream_handler_input(
        self,
    ) -> typing.Optional["AlbLoadBalancerListenerTlsDefaultHandlerStreamHandler"]:
        return typing.cast(typing.Optional["AlbLoadBalancerListenerTlsDefaultHandlerStreamHandler"], jsii.get(self, "streamHandlerInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="certificateIds")
    def certificate_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "certificateIds"))

    @certificate_ids.setter
    def certificate_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "certificateIds", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbLoadBalancerListenerTlsDefaultHandler]:
        return typing.cast(typing.Optional[AlbLoadBalancerListenerTlsDefaultHandler], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbLoadBalancerListenerTlsDefaultHandler],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerTlsDefaultHandlerStreamHandler",
    jsii_struct_bases=[],
    name_mapping={"backend_group_id": "backendGroupId"},
)
class AlbLoadBalancerListenerTlsDefaultHandlerStreamHandler:
    def __init__(
        self,
        *,
        backend_group_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param backend_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#backend_group_id AlbLoadBalancer#backend_group_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if backend_group_id is not None:
            self._values["backend_group_id"] = backend_group_id

    @builtins.property
    def backend_group_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#backend_group_id AlbLoadBalancer#backend_group_id}.'''
        result = self._values.get("backend_group_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbLoadBalancerListenerTlsDefaultHandlerStreamHandler(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbLoadBalancerListenerTlsDefaultHandlerStreamHandlerOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerTlsDefaultHandlerStreamHandlerOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetBackendGroupId")
    def reset_backend_group_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetBackendGroupId", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backendGroupIdInput")
    def backend_group_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "backendGroupIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backendGroupId")
    def backend_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "backendGroupId"))

    @backend_group_id.setter
    def backend_group_id(self, value: builtins.str) -> None:
        jsii.set(self, "backendGroupId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbLoadBalancerListenerTlsDefaultHandlerStreamHandler]:
        return typing.cast(typing.Optional[AlbLoadBalancerListenerTlsDefaultHandlerStreamHandler], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbLoadBalancerListenerTlsDefaultHandlerStreamHandler],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbLoadBalancerListenerTlsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerTlsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putDefaultHandler")
    def put_default_handler(
        self,
        *,
        certificate_ids: typing.Sequence[builtins.str],
        http_handler: typing.Optional[AlbLoadBalancerListenerTlsDefaultHandlerHttpHandler] = None,
        stream_handler: typing.Optional[AlbLoadBalancerListenerTlsDefaultHandlerStreamHandler] = None,
    ) -> None:
        '''
        :param certificate_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#certificate_ids AlbLoadBalancer#certificate_ids}.
        :param http_handler: http_handler block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#http_handler AlbLoadBalancer#http_handler}
        :param stream_handler: stream_handler block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#stream_handler AlbLoadBalancer#stream_handler}
        '''
        value = AlbLoadBalancerListenerTlsDefaultHandler(
            certificate_ids=certificate_ids,
            http_handler=http_handler,
            stream_handler=stream_handler,
        )

        return typing.cast(None, jsii.invoke(self, "putDefaultHandler", [value]))

    @jsii.member(jsii_name="putSniHandler")
    def put_sni_handler(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["AlbLoadBalancerListenerTlsSniHandler"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putSniHandler", [value]))

    @jsii.member(jsii_name="resetSniHandler")
    def reset_sni_handler(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSniHandler", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="defaultHandler")
    def default_handler(
        self,
    ) -> AlbLoadBalancerListenerTlsDefaultHandlerOutputReference:
        return typing.cast(AlbLoadBalancerListenerTlsDefaultHandlerOutputReference, jsii.get(self, "defaultHandler"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sniHandler")
    def sni_handler(self) -> "AlbLoadBalancerListenerTlsSniHandlerList":
        return typing.cast("AlbLoadBalancerListenerTlsSniHandlerList", jsii.get(self, "sniHandler"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="defaultHandlerInput")
    def default_handler_input(
        self,
    ) -> typing.Optional[AlbLoadBalancerListenerTlsDefaultHandler]:
        return typing.cast(typing.Optional[AlbLoadBalancerListenerTlsDefaultHandler], jsii.get(self, "defaultHandlerInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sniHandlerInput")
    def sni_handler_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbLoadBalancerListenerTlsSniHandler"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbLoadBalancerListenerTlsSniHandler"]]], jsii.get(self, "sniHandlerInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[AlbLoadBalancerListenerTls]:
        return typing.cast(typing.Optional[AlbLoadBalancerListenerTls], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbLoadBalancerListenerTls],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerTlsSniHandler",
    jsii_struct_bases=[],
    name_mapping={"handler": "handler", "name": "name", "server_names": "serverNames"},
)
class AlbLoadBalancerListenerTlsSniHandler:
    def __init__(
        self,
        *,
        handler: "AlbLoadBalancerListenerTlsSniHandlerHandler",
        name: builtins.str,
        server_names: typing.Sequence[builtins.str],
    ) -> None:
        '''
        :param handler: handler block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#handler AlbLoadBalancer#handler}
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#name AlbLoadBalancer#name}.
        :param server_names: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#server_names AlbLoadBalancer#server_names}.
        '''
        if isinstance(handler, dict):
            handler = AlbLoadBalancerListenerTlsSniHandlerHandler(**handler)
        self._values: typing.Dict[str, typing.Any] = {
            "handler": handler,
            "name": name,
            "server_names": server_names,
        }

    @builtins.property
    def handler(self) -> "AlbLoadBalancerListenerTlsSniHandlerHandler":
        '''handler block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#handler AlbLoadBalancer#handler}
        '''
        result = self._values.get("handler")
        assert result is not None, "Required property 'handler' is missing"
        return typing.cast("AlbLoadBalancerListenerTlsSniHandlerHandler", result)

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#name AlbLoadBalancer#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def server_names(self) -> typing.List[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#server_names AlbLoadBalancer#server_names}.'''
        result = self._values.get("server_names")
        assert result is not None, "Required property 'server_names' is missing"
        return typing.cast(typing.List[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbLoadBalancerListenerTlsSniHandler(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerTlsSniHandlerHandler",
    jsii_struct_bases=[],
    name_mapping={
        "certificate_ids": "certificateIds",
        "http_handler": "httpHandler",
        "stream_handler": "streamHandler",
    },
)
class AlbLoadBalancerListenerTlsSniHandlerHandler:
    def __init__(
        self,
        *,
        certificate_ids: typing.Sequence[builtins.str],
        http_handler: typing.Optional["AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandler"] = None,
        stream_handler: typing.Optional["AlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandler"] = None,
    ) -> None:
        '''
        :param certificate_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#certificate_ids AlbLoadBalancer#certificate_ids}.
        :param http_handler: http_handler block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#http_handler AlbLoadBalancer#http_handler}
        :param stream_handler: stream_handler block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#stream_handler AlbLoadBalancer#stream_handler}
        '''
        if isinstance(http_handler, dict):
            http_handler = AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandler(**http_handler)
        if isinstance(stream_handler, dict):
            stream_handler = AlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandler(**stream_handler)
        self._values: typing.Dict[str, typing.Any] = {
            "certificate_ids": certificate_ids,
        }
        if http_handler is not None:
            self._values["http_handler"] = http_handler
        if stream_handler is not None:
            self._values["stream_handler"] = stream_handler

    @builtins.property
    def certificate_ids(self) -> typing.List[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#certificate_ids AlbLoadBalancer#certificate_ids}.'''
        result = self._values.get("certificate_ids")
        assert result is not None, "Required property 'certificate_ids' is missing"
        return typing.cast(typing.List[builtins.str], result)

    @builtins.property
    def http_handler(
        self,
    ) -> typing.Optional["AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandler"]:
        '''http_handler block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#http_handler AlbLoadBalancer#http_handler}
        '''
        result = self._values.get("http_handler")
        return typing.cast(typing.Optional["AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandler"], result)

    @builtins.property
    def stream_handler(
        self,
    ) -> typing.Optional["AlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandler"]:
        '''stream_handler block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#stream_handler AlbLoadBalancer#stream_handler}
        '''
        result = self._values.get("stream_handler")
        return typing.cast(typing.Optional["AlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandler"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbLoadBalancerListenerTlsSniHandlerHandler(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandler",
    jsii_struct_bases=[],
    name_mapping={
        "allow_http10": "allowHttp10",
        "http2_options": "http2Options",
        "http_router_id": "httpRouterId",
    },
)
class AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandler:
    def __init__(
        self,
        *,
        allow_http10: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        http2_options: typing.Optional["AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2Options"] = None,
        http_router_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param allow_http10: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#allow_http10 AlbLoadBalancer#allow_http10}.
        :param http2_options: http2_options block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#http2_options AlbLoadBalancer#http2_options}
        :param http_router_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#http_router_id AlbLoadBalancer#http_router_id}.
        '''
        if isinstance(http2_options, dict):
            http2_options = AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2Options(**http2_options)
        self._values: typing.Dict[str, typing.Any] = {}
        if allow_http10 is not None:
            self._values["allow_http10"] = allow_http10
        if http2_options is not None:
            self._values["http2_options"] = http2_options
        if http_router_id is not None:
            self._values["http_router_id"] = http_router_id

    @builtins.property
    def allow_http10(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#allow_http10 AlbLoadBalancer#allow_http10}.'''
        result = self._values.get("allow_http10")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def http2_options(
        self,
    ) -> typing.Optional["AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2Options"]:
        '''http2_options block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#http2_options AlbLoadBalancer#http2_options}
        '''
        result = self._values.get("http2_options")
        return typing.cast(typing.Optional["AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2Options"], result)

    @builtins.property
    def http_router_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#http_router_id AlbLoadBalancer#http_router_id}.'''
        result = self._values.get("http_router_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandler(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2Options",
    jsii_struct_bases=[],
    name_mapping={"max_concurrent_streams": "maxConcurrentStreams"},
)
class AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2Options:
    def __init__(
        self,
        *,
        max_concurrent_streams: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param max_concurrent_streams: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#max_concurrent_streams AlbLoadBalancer#max_concurrent_streams}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if max_concurrent_streams is not None:
            self._values["max_concurrent_streams"] = max_concurrent_streams

    @builtins.property
    def max_concurrent_streams(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#max_concurrent_streams AlbLoadBalancer#max_concurrent_streams}.'''
        result = self._values.get("max_concurrent_streams")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2Options(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2OptionsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2OptionsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetMaxConcurrentStreams")
    def reset_max_concurrent_streams(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxConcurrentStreams", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxConcurrentStreamsInput")
    def max_concurrent_streams_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxConcurrentStreamsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxConcurrentStreams")
    def max_concurrent_streams(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxConcurrentStreams"))

    @max_concurrent_streams.setter
    def max_concurrent_streams(self, value: jsii.Number) -> None:
        jsii.set(self, "maxConcurrentStreams", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2Options]:
        return typing.cast(typing.Optional[AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2Options], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2Options],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putHttp2Options")
    def put_http2_options(
        self,
        *,
        max_concurrent_streams: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param max_concurrent_streams: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#max_concurrent_streams AlbLoadBalancer#max_concurrent_streams}.
        '''
        value = AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2Options(
            max_concurrent_streams=max_concurrent_streams
        )

        return typing.cast(None, jsii.invoke(self, "putHttp2Options", [value]))

    @jsii.member(jsii_name="resetAllowHttp10")
    def reset_allow_http10(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAllowHttp10", []))

    @jsii.member(jsii_name="resetHttp2Options")
    def reset_http2_options(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttp2Options", []))

    @jsii.member(jsii_name="resetHttpRouterId")
    def reset_http_router_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttpRouterId", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="http2Options")
    def http2_options(
        self,
    ) -> AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2OptionsOutputReference:
        return typing.cast(AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2OptionsOutputReference, jsii.get(self, "http2Options"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allowHttp10Input")
    def allow_http10_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "allowHttp10Input"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="http2OptionsInput")
    def http2_options_input(
        self,
    ) -> typing.Optional[AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2Options]:
        return typing.cast(typing.Optional[AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2Options], jsii.get(self, "http2OptionsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpRouterIdInput")
    def http_router_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "httpRouterIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allowHttp10")
    def allow_http10(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "allowHttp10"))

    @allow_http10.setter
    def allow_http10(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "allowHttp10", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpRouterId")
    def http_router_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "httpRouterId"))

    @http_router_id.setter
    def http_router_id(self, value: builtins.str) -> None:
        jsii.set(self, "httpRouterId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandler]:
        return typing.cast(typing.Optional[AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandler], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandler],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbLoadBalancerListenerTlsSniHandlerHandlerOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerTlsSniHandlerHandlerOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putHttpHandler")
    def put_http_handler(
        self,
        *,
        allow_http10: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        http2_options: typing.Optional[AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2Options] = None,
        http_router_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param allow_http10: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#allow_http10 AlbLoadBalancer#allow_http10}.
        :param http2_options: http2_options block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#http2_options AlbLoadBalancer#http2_options}
        :param http_router_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#http_router_id AlbLoadBalancer#http_router_id}.
        '''
        value = AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandler(
            allow_http10=allow_http10,
            http2_options=http2_options,
            http_router_id=http_router_id,
        )

        return typing.cast(None, jsii.invoke(self, "putHttpHandler", [value]))

    @jsii.member(jsii_name="putStreamHandler")
    def put_stream_handler(
        self,
        *,
        backend_group_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param backend_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#backend_group_id AlbLoadBalancer#backend_group_id}.
        '''
        value = AlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandler(
            backend_group_id=backend_group_id
        )

        return typing.cast(None, jsii.invoke(self, "putStreamHandler", [value]))

    @jsii.member(jsii_name="resetHttpHandler")
    def reset_http_handler(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttpHandler", []))

    @jsii.member(jsii_name="resetStreamHandler")
    def reset_stream_handler(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStreamHandler", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpHandler")
    def http_handler(
        self,
    ) -> AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerOutputReference:
        return typing.cast(AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerOutputReference, jsii.get(self, "httpHandler"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="streamHandler")
    def stream_handler(
        self,
    ) -> "AlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandlerOutputReference":
        return typing.cast("AlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandlerOutputReference", jsii.get(self, "streamHandler"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="certificateIdsInput")
    def certificate_ids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "certificateIdsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpHandlerInput")
    def http_handler_input(
        self,
    ) -> typing.Optional[AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandler]:
        return typing.cast(typing.Optional[AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandler], jsii.get(self, "httpHandlerInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="streamHandlerInput")
    def stream_handler_input(
        self,
    ) -> typing.Optional["AlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandler"]:
        return typing.cast(typing.Optional["AlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandler"], jsii.get(self, "streamHandlerInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="certificateIds")
    def certificate_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "certificateIds"))

    @certificate_ids.setter
    def certificate_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "certificateIds", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbLoadBalancerListenerTlsSniHandlerHandler]:
        return typing.cast(typing.Optional[AlbLoadBalancerListenerTlsSniHandlerHandler], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbLoadBalancerListenerTlsSniHandlerHandler],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandler",
    jsii_struct_bases=[],
    name_mapping={"backend_group_id": "backendGroupId"},
)
class AlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandler:
    def __init__(
        self,
        *,
        backend_group_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param backend_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#backend_group_id AlbLoadBalancer#backend_group_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if backend_group_id is not None:
            self._values["backend_group_id"] = backend_group_id

    @builtins.property
    def backend_group_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#backend_group_id AlbLoadBalancer#backend_group_id}.'''
        result = self._values.get("backend_group_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandler(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandlerOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandlerOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetBackendGroupId")
    def reset_backend_group_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetBackendGroupId", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backendGroupIdInput")
    def backend_group_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "backendGroupIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backendGroupId")
    def backend_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "backendGroupId"))

    @backend_group_id.setter
    def backend_group_id(self, value: builtins.str) -> None:
        jsii.set(self, "backendGroupId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandler]:
        return typing.cast(typing.Optional[AlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandler], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandler],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbLoadBalancerListenerTlsSniHandlerList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerTlsSniHandlerList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "AlbLoadBalancerListenerTlsSniHandlerOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("AlbLoadBalancerListenerTlsSniHandlerOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbLoadBalancerListenerTlsSniHandler]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbLoadBalancerListenerTlsSniHandler]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbLoadBalancerListenerTlsSniHandler]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbLoadBalancerListenerTlsSniHandlerOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerListenerTlsSniHandlerOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putHandler")
    def put_handler(
        self,
        *,
        certificate_ids: typing.Sequence[builtins.str],
        http_handler: typing.Optional[AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandler] = None,
        stream_handler: typing.Optional[AlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandler] = None,
    ) -> None:
        '''
        :param certificate_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#certificate_ids AlbLoadBalancer#certificate_ids}.
        :param http_handler: http_handler block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#http_handler AlbLoadBalancer#http_handler}
        :param stream_handler: stream_handler block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#stream_handler AlbLoadBalancer#stream_handler}
        '''
        value = AlbLoadBalancerListenerTlsSniHandlerHandler(
            certificate_ids=certificate_ids,
            http_handler=http_handler,
            stream_handler=stream_handler,
        )

        return typing.cast(None, jsii.invoke(self, "putHandler", [value]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="handler")
    def handler(self) -> AlbLoadBalancerListenerTlsSniHandlerHandlerOutputReference:
        return typing.cast(AlbLoadBalancerListenerTlsSniHandlerHandlerOutputReference, jsii.get(self, "handler"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="handlerInput")
    def handler_input(
        self,
    ) -> typing.Optional[AlbLoadBalancerListenerTlsSniHandlerHandler]:
        return typing.cast(typing.Optional[AlbLoadBalancerListenerTlsSniHandlerHandler], jsii.get(self, "handlerInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serverNamesInput")
    def server_names_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "serverNamesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serverNames")
    def server_names(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "serverNames"))

    @server_names.setter
    def server_names(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "serverNames", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, AlbLoadBalancerListenerTlsSniHandler]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, AlbLoadBalancerListenerTlsSniHandler]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, AlbLoadBalancerListenerTlsSniHandler]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class AlbLoadBalancerTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#create AlbLoadBalancer#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#delete AlbLoadBalancer#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#update AlbLoadBalancer#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#create AlbLoadBalancer#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#delete AlbLoadBalancer#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_load_balancer#update AlbLoadBalancer#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbLoadBalancerTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbLoadBalancerTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbLoadBalancerTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, AlbLoadBalancerTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, AlbLoadBalancerTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, AlbLoadBalancerTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbTargetGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbTargetGroup",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group yandex_alb_target_group}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        target: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["AlbTargetGroupTarget"]]] = None,
        timeouts: typing.Optional["AlbTargetGroupTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group yandex_alb_target_group} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#description AlbTargetGroup#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#folder_id AlbTargetGroup#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#id AlbTargetGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#labels AlbTargetGroup#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#name AlbTargetGroup#name}.
        :param target: target block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#target AlbTargetGroup#target}
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#timeouts AlbTargetGroup#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = AlbTargetGroupConfig(
            description=description,
            folder_id=folder_id,
            id=id,
            labels=labels,
            name=name,
            target=target,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putTarget")
    def put_target(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["AlbTargetGroupTarget"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putTarget", [value]))

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#create AlbTargetGroup#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#delete AlbTargetGroup#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#update AlbTargetGroup#update}.
        '''
        value = AlbTargetGroupTimeouts(create=create, delete=delete, update=update)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetTarget")
    def reset_target(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTarget", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="target")
    def target(self) -> "AlbTargetGroupTargetList":
        return typing.cast("AlbTargetGroupTargetList", jsii.get(self, "target"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "AlbTargetGroupTimeoutsOutputReference":
        return typing.cast("AlbTargetGroupTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetInput")
    def target_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbTargetGroupTarget"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbTargetGroupTarget"]]], jsii.get(self, "targetInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "AlbTargetGroupTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "AlbTargetGroupTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbTargetGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "description": "description",
        "folder_id": "folderId",
        "id": "id",
        "labels": "labels",
        "name": "name",
        "target": "target",
        "timeouts": "timeouts",
    },
)
class AlbTargetGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        target: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["AlbTargetGroupTarget"]]] = None,
        timeouts: typing.Optional["AlbTargetGroupTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#description AlbTargetGroup#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#folder_id AlbTargetGroup#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#id AlbTargetGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#labels AlbTargetGroup#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#name AlbTargetGroup#name}.
        :param target: target block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#target AlbTargetGroup#target}
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#timeouts AlbTargetGroup#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AlbTargetGroupTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if name is not None:
            self._values["name"] = name
        if target is not None:
            self._values["target"] = target
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#description AlbTargetGroup#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#folder_id AlbTargetGroup#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#id AlbTargetGroup#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#labels AlbTargetGroup#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#name AlbTargetGroup#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def target(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbTargetGroupTarget"]]]:
        '''target block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#target AlbTargetGroup#target}
        '''
        result = self._values.get("target")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbTargetGroupTarget"]]], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["AlbTargetGroupTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#timeouts AlbTargetGroup#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["AlbTargetGroupTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbTargetGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbTargetGroupTarget",
    jsii_struct_bases=[],
    name_mapping={
        "ip_address": "ipAddress",
        "private_ipv4_address": "privateIpv4Address",
        "subnet_id": "subnetId",
    },
)
class AlbTargetGroupTarget:
    def __init__(
        self,
        *,
        ip_address: builtins.str,
        private_ipv4_address: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        subnet_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param ip_address: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#ip_address AlbTargetGroup#ip_address}.
        :param private_ipv4_address: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#private_ipv4_address AlbTargetGroup#private_ipv4_address}.
        :param subnet_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#subnet_id AlbTargetGroup#subnet_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "ip_address": ip_address,
        }
        if private_ipv4_address is not None:
            self._values["private_ipv4_address"] = private_ipv4_address
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id

    @builtins.property
    def ip_address(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#ip_address AlbTargetGroup#ip_address}.'''
        result = self._values.get("ip_address")
        assert result is not None, "Required property 'ip_address' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def private_ipv4_address(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#private_ipv4_address AlbTargetGroup#private_ipv4_address}.'''
        result = self._values.get("private_ipv4_address")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#subnet_id AlbTargetGroup#subnet_id}.'''
        result = self._values.get("subnet_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbTargetGroupTarget(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbTargetGroupTargetList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbTargetGroupTargetList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "AlbTargetGroupTargetOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("AlbTargetGroupTargetOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbTargetGroupTarget]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbTargetGroupTarget]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbTargetGroupTarget]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbTargetGroupTargetOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbTargetGroupTargetOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetPrivateIpv4Address")
    def reset_private_ipv4_address(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrivateIpv4Address", []))

    @jsii.member(jsii_name="resetSubnetId")
    def reset_subnet_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSubnetId", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipAddressInput")
    def ip_address_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "ipAddressInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="privateIpv4AddressInput")
    def private_ipv4_address_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "privateIpv4AddressInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIdInput")
    def subnet_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "subnetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipAddress")
    def ip_address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ipAddress"))

    @ip_address.setter
    def ip_address(self, value: builtins.str) -> None:
        jsii.set(self, "ipAddress", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="privateIpv4Address")
    def private_ipv4_address(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "privateIpv4Address"))

    @private_ipv4_address.setter
    def private_ipv4_address(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "privateIpv4Address", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @subnet_id.setter
    def subnet_id(self, value: builtins.str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, AlbTargetGroupTarget]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, AlbTargetGroupTarget]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, AlbTargetGroupTarget]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbTargetGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class AlbTargetGroupTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#create AlbTargetGroup#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#delete AlbTargetGroup#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#update AlbTargetGroup#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#create AlbTargetGroup#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#delete AlbTargetGroup#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_target_group#update AlbTargetGroup#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbTargetGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbTargetGroupTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbTargetGroupTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, AlbTargetGroupTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, AlbTargetGroupTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, AlbTargetGroupTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbVirtualHost(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbVirtualHost",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host yandex_alb_virtual_host}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        http_router_id: builtins.str,
        name: builtins.str,
        authority: typing.Optional[typing.Sequence[builtins.str]] = None,
        id: typing.Optional[builtins.str] = None,
        modify_request_headers: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["AlbVirtualHostModifyRequestHeaders"]]] = None,
        modify_response_headers: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["AlbVirtualHostModifyResponseHeaders"]]] = None,
        route: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["AlbVirtualHostRoute"]]] = None,
        timeouts: typing.Optional["AlbVirtualHostTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host yandex_alb_virtual_host} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param http_router_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#http_router_id AlbVirtualHost#http_router_id}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#name AlbVirtualHost#name}.
        :param authority: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#authority AlbVirtualHost#authority}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#id AlbVirtualHost#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param modify_request_headers: modify_request_headers block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#modify_request_headers AlbVirtualHost#modify_request_headers}
        :param modify_response_headers: modify_response_headers block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#modify_response_headers AlbVirtualHost#modify_response_headers}
        :param route: route block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#route AlbVirtualHost#route}
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#timeouts AlbVirtualHost#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = AlbVirtualHostConfig(
            http_router_id=http_router_id,
            name=name,
            authority=authority,
            id=id,
            modify_request_headers=modify_request_headers,
            modify_response_headers=modify_response_headers,
            route=route,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putModifyRequestHeaders")
    def put_modify_request_headers(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["AlbVirtualHostModifyRequestHeaders"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putModifyRequestHeaders", [value]))

    @jsii.member(jsii_name="putModifyResponseHeaders")
    def put_modify_response_headers(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["AlbVirtualHostModifyResponseHeaders"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putModifyResponseHeaders", [value]))

    @jsii.member(jsii_name="putRoute")
    def put_route(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["AlbVirtualHostRoute"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putRoute", [value]))

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#create AlbVirtualHost#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#delete AlbVirtualHost#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#update AlbVirtualHost#update}.
        '''
        value = AlbVirtualHostTimeouts(create=create, delete=delete, update=update)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetAuthority")
    def reset_authority(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAuthority", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetModifyRequestHeaders")
    def reset_modify_request_headers(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetModifyRequestHeaders", []))

    @jsii.member(jsii_name="resetModifyResponseHeaders")
    def reset_modify_response_headers(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetModifyResponseHeaders", []))

    @jsii.member(jsii_name="resetRoute")
    def reset_route(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRoute", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="modifyRequestHeaders")
    def modify_request_headers(self) -> "AlbVirtualHostModifyRequestHeadersList":
        return typing.cast("AlbVirtualHostModifyRequestHeadersList", jsii.get(self, "modifyRequestHeaders"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="modifyResponseHeaders")
    def modify_response_headers(self) -> "AlbVirtualHostModifyResponseHeadersList":
        return typing.cast("AlbVirtualHostModifyResponseHeadersList", jsii.get(self, "modifyResponseHeaders"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="route")
    def route(self) -> "AlbVirtualHostRouteList":
        return typing.cast("AlbVirtualHostRouteList", jsii.get(self, "route"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "AlbVirtualHostTimeoutsOutputReference":
        return typing.cast("AlbVirtualHostTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="authorityInput")
    def authority_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "authorityInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpRouterIdInput")
    def http_router_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "httpRouterIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="modifyRequestHeadersInput")
    def modify_request_headers_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbVirtualHostModifyRequestHeaders"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbVirtualHostModifyRequestHeaders"]]], jsii.get(self, "modifyRequestHeadersInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="modifyResponseHeadersInput")
    def modify_response_headers_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbVirtualHostModifyResponseHeaders"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbVirtualHostModifyResponseHeaders"]]], jsii.get(self, "modifyResponseHeadersInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="routeInput")
    def route_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbVirtualHostRoute"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbVirtualHostRoute"]]], jsii.get(self, "routeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "AlbVirtualHostTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "AlbVirtualHostTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="authority")
    def authority(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "authority"))

    @authority.setter
    def authority(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "authority", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpRouterId")
    def http_router_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "httpRouterId"))

    @http_router_id.setter
    def http_router_id(self, value: builtins.str) -> None:
        jsii.set(self, "httpRouterId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "http_router_id": "httpRouterId",
        "name": "name",
        "authority": "authority",
        "id": "id",
        "modify_request_headers": "modifyRequestHeaders",
        "modify_response_headers": "modifyResponseHeaders",
        "route": "route",
        "timeouts": "timeouts",
    },
)
class AlbVirtualHostConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        http_router_id: builtins.str,
        name: builtins.str,
        authority: typing.Optional[typing.Sequence[builtins.str]] = None,
        id: typing.Optional[builtins.str] = None,
        modify_request_headers: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["AlbVirtualHostModifyRequestHeaders"]]] = None,
        modify_response_headers: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["AlbVirtualHostModifyResponseHeaders"]]] = None,
        route: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["AlbVirtualHostRoute"]]] = None,
        timeouts: typing.Optional["AlbVirtualHostTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param http_router_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#http_router_id AlbVirtualHost#http_router_id}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#name AlbVirtualHost#name}.
        :param authority: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#authority AlbVirtualHost#authority}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#id AlbVirtualHost#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param modify_request_headers: modify_request_headers block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#modify_request_headers AlbVirtualHost#modify_request_headers}
        :param modify_response_headers: modify_response_headers block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#modify_response_headers AlbVirtualHost#modify_response_headers}
        :param route: route block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#route AlbVirtualHost#route}
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#timeouts AlbVirtualHost#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AlbVirtualHostTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "http_router_id": http_router_id,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if authority is not None:
            self._values["authority"] = authority
        if id is not None:
            self._values["id"] = id
        if modify_request_headers is not None:
            self._values["modify_request_headers"] = modify_request_headers
        if modify_response_headers is not None:
            self._values["modify_response_headers"] = modify_response_headers
        if route is not None:
            self._values["route"] = route
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def http_router_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#http_router_id AlbVirtualHost#http_router_id}.'''
        result = self._values.get("http_router_id")
        assert result is not None, "Required property 'http_router_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#name AlbVirtualHost#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def authority(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#authority AlbVirtualHost#authority}.'''
        result = self._values.get("authority")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#id AlbVirtualHost#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def modify_request_headers(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbVirtualHostModifyRequestHeaders"]]]:
        '''modify_request_headers block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#modify_request_headers AlbVirtualHost#modify_request_headers}
        '''
        result = self._values.get("modify_request_headers")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbVirtualHostModifyRequestHeaders"]]], result)

    @builtins.property
    def modify_response_headers(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbVirtualHostModifyResponseHeaders"]]]:
        '''modify_response_headers block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#modify_response_headers AlbVirtualHost#modify_response_headers}
        '''
        result = self._values.get("modify_response_headers")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbVirtualHostModifyResponseHeaders"]]], result)

    @builtins.property
    def route(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbVirtualHostRoute"]]]:
        '''route block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#route AlbVirtualHost#route}
        '''
        result = self._values.get("route")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbVirtualHostRoute"]]], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["AlbVirtualHostTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#timeouts AlbVirtualHost#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["AlbVirtualHostTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbVirtualHostConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostModifyRequestHeaders",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "append": "append",
        "remove": "remove",
        "replace": "replace",
    },
)
class AlbVirtualHostModifyRequestHeaders:
    def __init__(
        self,
        *,
        name: builtins.str,
        append: typing.Optional[builtins.str] = None,
        remove: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        replace: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#name AlbVirtualHost#name}.
        :param append: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#append AlbVirtualHost#append}.
        :param remove: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#remove AlbVirtualHost#remove}.
        :param replace: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#replace AlbVirtualHost#replace}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }
        if append is not None:
            self._values["append"] = append
        if remove is not None:
            self._values["remove"] = remove
        if replace is not None:
            self._values["replace"] = replace

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#name AlbVirtualHost#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def append(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#append AlbVirtualHost#append}.'''
        result = self._values.get("append")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def remove(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#remove AlbVirtualHost#remove}.'''
        result = self._values.get("remove")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def replace(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#replace AlbVirtualHost#replace}.'''
        result = self._values.get("replace")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbVirtualHostModifyRequestHeaders(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbVirtualHostModifyRequestHeadersList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostModifyRequestHeadersList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "AlbVirtualHostModifyRequestHeadersOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("AlbVirtualHostModifyRequestHeadersOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbVirtualHostModifyRequestHeaders]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbVirtualHostModifyRequestHeaders]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbVirtualHostModifyRequestHeaders]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbVirtualHostModifyRequestHeadersOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostModifyRequestHeadersOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetAppend")
    def reset_append(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAppend", []))

    @jsii.member(jsii_name="resetRemove")
    def reset_remove(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRemove", []))

    @jsii.member(jsii_name="resetReplace")
    def reset_replace(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetReplace", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="appendInput")
    def append_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "appendInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="removeInput")
    def remove_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "removeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replaceInput")
    def replace_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "replaceInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="append")
    def append(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "append"))

    @append.setter
    def append(self, value: builtins.str) -> None:
        jsii.set(self, "append", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="remove")
    def remove(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "remove"))

    @remove.setter
    def remove(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "remove", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replace")
    def replace(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "replace"))

    @replace.setter
    def replace(self, value: builtins.str) -> None:
        jsii.set(self, "replace", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, AlbVirtualHostModifyRequestHeaders]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, AlbVirtualHostModifyRequestHeaders]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, AlbVirtualHostModifyRequestHeaders]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostModifyResponseHeaders",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "append": "append",
        "remove": "remove",
        "replace": "replace",
    },
)
class AlbVirtualHostModifyResponseHeaders:
    def __init__(
        self,
        *,
        name: builtins.str,
        append: typing.Optional[builtins.str] = None,
        remove: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        replace: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#name AlbVirtualHost#name}.
        :param append: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#append AlbVirtualHost#append}.
        :param remove: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#remove AlbVirtualHost#remove}.
        :param replace: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#replace AlbVirtualHost#replace}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }
        if append is not None:
            self._values["append"] = append
        if remove is not None:
            self._values["remove"] = remove
        if replace is not None:
            self._values["replace"] = replace

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#name AlbVirtualHost#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def append(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#append AlbVirtualHost#append}.'''
        result = self._values.get("append")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def remove(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#remove AlbVirtualHost#remove}.'''
        result = self._values.get("remove")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def replace(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#replace AlbVirtualHost#replace}.'''
        result = self._values.get("replace")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbVirtualHostModifyResponseHeaders(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbVirtualHostModifyResponseHeadersList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostModifyResponseHeadersList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "AlbVirtualHostModifyResponseHeadersOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("AlbVirtualHostModifyResponseHeadersOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbVirtualHostModifyResponseHeaders]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbVirtualHostModifyResponseHeaders]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbVirtualHostModifyResponseHeaders]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbVirtualHostModifyResponseHeadersOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostModifyResponseHeadersOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetAppend")
    def reset_append(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAppend", []))

    @jsii.member(jsii_name="resetRemove")
    def reset_remove(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRemove", []))

    @jsii.member(jsii_name="resetReplace")
    def reset_replace(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetReplace", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="appendInput")
    def append_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "appendInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="removeInput")
    def remove_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "removeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replaceInput")
    def replace_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "replaceInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="append")
    def append(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "append"))

    @append.setter
    def append(self, value: builtins.str) -> None:
        jsii.set(self, "append", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="remove")
    def remove(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "remove"))

    @remove.setter
    def remove(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "remove", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replace")
    def replace(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "replace"))

    @replace.setter
    def replace(self, value: builtins.str) -> None:
        jsii.set(self, "replace", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, AlbVirtualHostModifyResponseHeaders]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, AlbVirtualHostModifyResponseHeaders]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, AlbVirtualHostModifyResponseHeaders]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostRoute",
    jsii_struct_bases=[],
    name_mapping={
        "grpc_route": "grpcRoute",
        "http_route": "httpRoute",
        "name": "name",
    },
)
class AlbVirtualHostRoute:
    def __init__(
        self,
        *,
        grpc_route: typing.Optional["AlbVirtualHostRouteGrpcRoute"] = None,
        http_route: typing.Optional["AlbVirtualHostRouteHttpRoute"] = None,
        name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param grpc_route: grpc_route block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#grpc_route AlbVirtualHost#grpc_route}
        :param http_route: http_route block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#http_route AlbVirtualHost#http_route}
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#name AlbVirtualHost#name}.
        '''
        if isinstance(grpc_route, dict):
            grpc_route = AlbVirtualHostRouteGrpcRoute(**grpc_route)
        if isinstance(http_route, dict):
            http_route = AlbVirtualHostRouteHttpRoute(**http_route)
        self._values: typing.Dict[str, typing.Any] = {}
        if grpc_route is not None:
            self._values["grpc_route"] = grpc_route
        if http_route is not None:
            self._values["http_route"] = http_route
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def grpc_route(self) -> typing.Optional["AlbVirtualHostRouteGrpcRoute"]:
        '''grpc_route block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#grpc_route AlbVirtualHost#grpc_route}
        '''
        result = self._values.get("grpc_route")
        return typing.cast(typing.Optional["AlbVirtualHostRouteGrpcRoute"], result)

    @builtins.property
    def http_route(self) -> typing.Optional["AlbVirtualHostRouteHttpRoute"]:
        '''http_route block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#http_route AlbVirtualHost#http_route}
        '''
        result = self._values.get("http_route")
        return typing.cast(typing.Optional["AlbVirtualHostRouteHttpRoute"], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#name AlbVirtualHost#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbVirtualHostRoute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostRouteGrpcRoute",
    jsii_struct_bases=[],
    name_mapping={
        "grpc_match": "grpcMatch",
        "grpc_route_action": "grpcRouteAction",
        "grpc_status_response_action": "grpcStatusResponseAction",
    },
)
class AlbVirtualHostRouteGrpcRoute:
    def __init__(
        self,
        *,
        grpc_match: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["AlbVirtualHostRouteGrpcRouteGrpcMatch"]]] = None,
        grpc_route_action: typing.Optional["AlbVirtualHostRouteGrpcRouteGrpcRouteAction"] = None,
        grpc_status_response_action: typing.Optional["AlbVirtualHostRouteGrpcRouteGrpcStatusResponseAction"] = None,
    ) -> None:
        '''
        :param grpc_match: grpc_match block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#grpc_match AlbVirtualHost#grpc_match}
        :param grpc_route_action: grpc_route_action block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#grpc_route_action AlbVirtualHost#grpc_route_action}
        :param grpc_status_response_action: grpc_status_response_action block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#grpc_status_response_action AlbVirtualHost#grpc_status_response_action}
        '''
        if isinstance(grpc_route_action, dict):
            grpc_route_action = AlbVirtualHostRouteGrpcRouteGrpcRouteAction(**grpc_route_action)
        if isinstance(grpc_status_response_action, dict):
            grpc_status_response_action = AlbVirtualHostRouteGrpcRouteGrpcStatusResponseAction(**grpc_status_response_action)
        self._values: typing.Dict[str, typing.Any] = {}
        if grpc_match is not None:
            self._values["grpc_match"] = grpc_match
        if grpc_route_action is not None:
            self._values["grpc_route_action"] = grpc_route_action
        if grpc_status_response_action is not None:
            self._values["grpc_status_response_action"] = grpc_status_response_action

    @builtins.property
    def grpc_match(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbVirtualHostRouteGrpcRouteGrpcMatch"]]]:
        '''grpc_match block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#grpc_match AlbVirtualHost#grpc_match}
        '''
        result = self._values.get("grpc_match")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbVirtualHostRouteGrpcRouteGrpcMatch"]]], result)

    @builtins.property
    def grpc_route_action(
        self,
    ) -> typing.Optional["AlbVirtualHostRouteGrpcRouteGrpcRouteAction"]:
        '''grpc_route_action block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#grpc_route_action AlbVirtualHost#grpc_route_action}
        '''
        result = self._values.get("grpc_route_action")
        return typing.cast(typing.Optional["AlbVirtualHostRouteGrpcRouteGrpcRouteAction"], result)

    @builtins.property
    def grpc_status_response_action(
        self,
    ) -> typing.Optional["AlbVirtualHostRouteGrpcRouteGrpcStatusResponseAction"]:
        '''grpc_status_response_action block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#grpc_status_response_action AlbVirtualHost#grpc_status_response_action}
        '''
        result = self._values.get("grpc_status_response_action")
        return typing.cast(typing.Optional["AlbVirtualHostRouteGrpcRouteGrpcStatusResponseAction"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbVirtualHostRouteGrpcRoute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostRouteGrpcRouteGrpcMatch",
    jsii_struct_bases=[],
    name_mapping={"fqmn": "fqmn"},
)
class AlbVirtualHostRouteGrpcRouteGrpcMatch:
    def __init__(
        self,
        *,
        fqmn: typing.Optional["AlbVirtualHostRouteGrpcRouteGrpcMatchFqmn"] = None,
    ) -> None:
        '''
        :param fqmn: fqmn block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#fqmn AlbVirtualHost#fqmn}
        '''
        if isinstance(fqmn, dict):
            fqmn = AlbVirtualHostRouteGrpcRouteGrpcMatchFqmn(**fqmn)
        self._values: typing.Dict[str, typing.Any] = {}
        if fqmn is not None:
            self._values["fqmn"] = fqmn

    @builtins.property
    def fqmn(self) -> typing.Optional["AlbVirtualHostRouteGrpcRouteGrpcMatchFqmn"]:
        '''fqmn block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#fqmn AlbVirtualHost#fqmn}
        '''
        result = self._values.get("fqmn")
        return typing.cast(typing.Optional["AlbVirtualHostRouteGrpcRouteGrpcMatchFqmn"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbVirtualHostRouteGrpcRouteGrpcMatch(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostRouteGrpcRouteGrpcMatchFqmn",
    jsii_struct_bases=[],
    name_mapping={"exact": "exact", "prefix": "prefix"},
)
class AlbVirtualHostRouteGrpcRouteGrpcMatchFqmn:
    def __init__(
        self,
        *,
        exact: typing.Optional[builtins.str] = None,
        prefix: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param exact: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#exact AlbVirtualHost#exact}.
        :param prefix: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#prefix AlbVirtualHost#prefix}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if exact is not None:
            self._values["exact"] = exact
        if prefix is not None:
            self._values["prefix"] = prefix

    @builtins.property
    def exact(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#exact AlbVirtualHost#exact}.'''
        result = self._values.get("exact")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def prefix(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#prefix AlbVirtualHost#prefix}.'''
        result = self._values.get("prefix")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbVirtualHostRouteGrpcRouteGrpcMatchFqmn(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbVirtualHostRouteGrpcRouteGrpcMatchFqmnOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostRouteGrpcRouteGrpcMatchFqmnOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetExact")
    def reset_exact(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetExact", []))

    @jsii.member(jsii_name="resetPrefix")
    def reset_prefix(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrefix", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="exactInput")
    def exact_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "exactInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="prefixInput")
    def prefix_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "prefixInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="exact")
    def exact(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "exact"))

    @exact.setter
    def exact(self, value: builtins.str) -> None:
        jsii.set(self, "exact", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="prefix")
    def prefix(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "prefix"))

    @prefix.setter
    def prefix(self, value: builtins.str) -> None:
        jsii.set(self, "prefix", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbVirtualHostRouteGrpcRouteGrpcMatchFqmn]:
        return typing.cast(typing.Optional[AlbVirtualHostRouteGrpcRouteGrpcMatchFqmn], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbVirtualHostRouteGrpcRouteGrpcMatchFqmn],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbVirtualHostRouteGrpcRouteGrpcMatchList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostRouteGrpcRouteGrpcMatchList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "AlbVirtualHostRouteGrpcRouteGrpcMatchOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("AlbVirtualHostRouteGrpcRouteGrpcMatchOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbVirtualHostRouteGrpcRouteGrpcMatch]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbVirtualHostRouteGrpcRouteGrpcMatch]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbVirtualHostRouteGrpcRouteGrpcMatch]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbVirtualHostRouteGrpcRouteGrpcMatchOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostRouteGrpcRouteGrpcMatchOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putFqmn")
    def put_fqmn(
        self,
        *,
        exact: typing.Optional[builtins.str] = None,
        prefix: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param exact: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#exact AlbVirtualHost#exact}.
        :param prefix: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#prefix AlbVirtualHost#prefix}.
        '''
        value = AlbVirtualHostRouteGrpcRouteGrpcMatchFqmn(exact=exact, prefix=prefix)

        return typing.cast(None, jsii.invoke(self, "putFqmn", [value]))

    @jsii.member(jsii_name="resetFqmn")
    def reset_fqmn(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFqmn", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqmn")
    def fqmn(self) -> AlbVirtualHostRouteGrpcRouteGrpcMatchFqmnOutputReference:
        return typing.cast(AlbVirtualHostRouteGrpcRouteGrpcMatchFqmnOutputReference, jsii.get(self, "fqmn"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqmnInput")
    def fqmn_input(self) -> typing.Optional[AlbVirtualHostRouteGrpcRouteGrpcMatchFqmn]:
        return typing.cast(typing.Optional[AlbVirtualHostRouteGrpcRouteGrpcMatchFqmn], jsii.get(self, "fqmnInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, AlbVirtualHostRouteGrpcRouteGrpcMatch]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, AlbVirtualHostRouteGrpcRouteGrpcMatch]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, AlbVirtualHostRouteGrpcRouteGrpcMatch]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostRouteGrpcRouteGrpcRouteAction",
    jsii_struct_bases=[],
    name_mapping={
        "backend_group_id": "backendGroupId",
        "auto_host_rewrite": "autoHostRewrite",
        "host_rewrite": "hostRewrite",
        "idle_timeout": "idleTimeout",
        "max_timeout": "maxTimeout",
    },
)
class AlbVirtualHostRouteGrpcRouteGrpcRouteAction:
    def __init__(
        self,
        *,
        backend_group_id: builtins.str,
        auto_host_rewrite: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        host_rewrite: typing.Optional[builtins.str] = None,
        idle_timeout: typing.Optional[builtins.str] = None,
        max_timeout: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param backend_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#backend_group_id AlbVirtualHost#backend_group_id}.
        :param auto_host_rewrite: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#auto_host_rewrite AlbVirtualHost#auto_host_rewrite}.
        :param host_rewrite: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#host_rewrite AlbVirtualHost#host_rewrite}.
        :param idle_timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#idle_timeout AlbVirtualHost#idle_timeout}.
        :param max_timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#max_timeout AlbVirtualHost#max_timeout}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "backend_group_id": backend_group_id,
        }
        if auto_host_rewrite is not None:
            self._values["auto_host_rewrite"] = auto_host_rewrite
        if host_rewrite is not None:
            self._values["host_rewrite"] = host_rewrite
        if idle_timeout is not None:
            self._values["idle_timeout"] = idle_timeout
        if max_timeout is not None:
            self._values["max_timeout"] = max_timeout

    @builtins.property
    def backend_group_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#backend_group_id AlbVirtualHost#backend_group_id}.'''
        result = self._values.get("backend_group_id")
        assert result is not None, "Required property 'backend_group_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def auto_host_rewrite(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#auto_host_rewrite AlbVirtualHost#auto_host_rewrite}.'''
        result = self._values.get("auto_host_rewrite")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def host_rewrite(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#host_rewrite AlbVirtualHost#host_rewrite}.'''
        result = self._values.get("host_rewrite")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def idle_timeout(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#idle_timeout AlbVirtualHost#idle_timeout}.'''
        result = self._values.get("idle_timeout")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def max_timeout(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#max_timeout AlbVirtualHost#max_timeout}.'''
        result = self._values.get("max_timeout")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbVirtualHostRouteGrpcRouteGrpcRouteAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbVirtualHostRouteGrpcRouteGrpcRouteActionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostRouteGrpcRouteGrpcRouteActionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAutoHostRewrite")
    def reset_auto_host_rewrite(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAutoHostRewrite", []))

    @jsii.member(jsii_name="resetHostRewrite")
    def reset_host_rewrite(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHostRewrite", []))

    @jsii.member(jsii_name="resetIdleTimeout")
    def reset_idle_timeout(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIdleTimeout", []))

    @jsii.member(jsii_name="resetMaxTimeout")
    def reset_max_timeout(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxTimeout", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoHostRewriteInput")
    def auto_host_rewrite_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "autoHostRewriteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backendGroupIdInput")
    def backend_group_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "backendGroupIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostRewriteInput")
    def host_rewrite_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "hostRewriteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idleTimeoutInput")
    def idle_timeout_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idleTimeoutInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxTimeoutInput")
    def max_timeout_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "maxTimeoutInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoHostRewrite")
    def auto_host_rewrite(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "autoHostRewrite"))

    @auto_host_rewrite.setter
    def auto_host_rewrite(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "autoHostRewrite", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backendGroupId")
    def backend_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "backendGroupId"))

    @backend_group_id.setter
    def backend_group_id(self, value: builtins.str) -> None:
        jsii.set(self, "backendGroupId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostRewrite")
    def host_rewrite(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "hostRewrite"))

    @host_rewrite.setter
    def host_rewrite(self, value: builtins.str) -> None:
        jsii.set(self, "hostRewrite", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idleTimeout")
    def idle_timeout(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "idleTimeout"))

    @idle_timeout.setter
    def idle_timeout(self, value: builtins.str) -> None:
        jsii.set(self, "idleTimeout", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxTimeout")
    def max_timeout(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "maxTimeout"))

    @max_timeout.setter
    def max_timeout(self, value: builtins.str) -> None:
        jsii.set(self, "maxTimeout", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbVirtualHostRouteGrpcRouteGrpcRouteAction]:
        return typing.cast(typing.Optional[AlbVirtualHostRouteGrpcRouteGrpcRouteAction], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbVirtualHostRouteGrpcRouteGrpcRouteAction],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostRouteGrpcRouteGrpcStatusResponseAction",
    jsii_struct_bases=[],
    name_mapping={"status": "status"},
)
class AlbVirtualHostRouteGrpcRouteGrpcStatusResponseAction:
    def __init__(self, *, status: typing.Optional[builtins.str] = None) -> None:
        '''
        :param status: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#status AlbVirtualHost#status}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if status is not None:
            self._values["status"] = status

    @builtins.property
    def status(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#status AlbVirtualHost#status}.'''
        result = self._values.get("status")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbVirtualHostRouteGrpcRouteGrpcStatusResponseAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbVirtualHostRouteGrpcRouteGrpcStatusResponseActionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostRouteGrpcRouteGrpcStatusResponseActionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetStatus")
    def reset_status(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStatus", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="statusInput")
    def status_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "statusInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @status.setter
    def status(self, value: builtins.str) -> None:
        jsii.set(self, "status", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbVirtualHostRouteGrpcRouteGrpcStatusResponseAction]:
        return typing.cast(typing.Optional[AlbVirtualHostRouteGrpcRouteGrpcStatusResponseAction], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbVirtualHostRouteGrpcRouteGrpcStatusResponseAction],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbVirtualHostRouteGrpcRouteOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostRouteGrpcRouteOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putGrpcMatch")
    def put_grpc_match(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence[AlbVirtualHostRouteGrpcRouteGrpcMatch]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putGrpcMatch", [value]))

    @jsii.member(jsii_name="putGrpcRouteAction")
    def put_grpc_route_action(
        self,
        *,
        backend_group_id: builtins.str,
        auto_host_rewrite: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        host_rewrite: typing.Optional[builtins.str] = None,
        idle_timeout: typing.Optional[builtins.str] = None,
        max_timeout: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param backend_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#backend_group_id AlbVirtualHost#backend_group_id}.
        :param auto_host_rewrite: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#auto_host_rewrite AlbVirtualHost#auto_host_rewrite}.
        :param host_rewrite: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#host_rewrite AlbVirtualHost#host_rewrite}.
        :param idle_timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#idle_timeout AlbVirtualHost#idle_timeout}.
        :param max_timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#max_timeout AlbVirtualHost#max_timeout}.
        '''
        value = AlbVirtualHostRouteGrpcRouteGrpcRouteAction(
            backend_group_id=backend_group_id,
            auto_host_rewrite=auto_host_rewrite,
            host_rewrite=host_rewrite,
            idle_timeout=idle_timeout,
            max_timeout=max_timeout,
        )

        return typing.cast(None, jsii.invoke(self, "putGrpcRouteAction", [value]))

    @jsii.member(jsii_name="putGrpcStatusResponseAction")
    def put_grpc_status_response_action(
        self,
        *,
        status: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param status: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#status AlbVirtualHost#status}.
        '''
        value = AlbVirtualHostRouteGrpcRouteGrpcStatusResponseAction(status=status)

        return typing.cast(None, jsii.invoke(self, "putGrpcStatusResponseAction", [value]))

    @jsii.member(jsii_name="resetGrpcMatch")
    def reset_grpc_match(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGrpcMatch", []))

    @jsii.member(jsii_name="resetGrpcRouteAction")
    def reset_grpc_route_action(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGrpcRouteAction", []))

    @jsii.member(jsii_name="resetGrpcStatusResponseAction")
    def reset_grpc_status_response_action(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGrpcStatusResponseAction", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="grpcMatch")
    def grpc_match(self) -> AlbVirtualHostRouteGrpcRouteGrpcMatchList:
        return typing.cast(AlbVirtualHostRouteGrpcRouteGrpcMatchList, jsii.get(self, "grpcMatch"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="grpcRouteAction")
    def grpc_route_action(
        self,
    ) -> AlbVirtualHostRouteGrpcRouteGrpcRouteActionOutputReference:
        return typing.cast(AlbVirtualHostRouteGrpcRouteGrpcRouteActionOutputReference, jsii.get(self, "grpcRouteAction"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="grpcStatusResponseAction")
    def grpc_status_response_action(
        self,
    ) -> AlbVirtualHostRouteGrpcRouteGrpcStatusResponseActionOutputReference:
        return typing.cast(AlbVirtualHostRouteGrpcRouteGrpcStatusResponseActionOutputReference, jsii.get(self, "grpcStatusResponseAction"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="grpcMatchInput")
    def grpc_match_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbVirtualHostRouteGrpcRouteGrpcMatch]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbVirtualHostRouteGrpcRouteGrpcMatch]]], jsii.get(self, "grpcMatchInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="grpcRouteActionInput")
    def grpc_route_action_input(
        self,
    ) -> typing.Optional[AlbVirtualHostRouteGrpcRouteGrpcRouteAction]:
        return typing.cast(typing.Optional[AlbVirtualHostRouteGrpcRouteGrpcRouteAction], jsii.get(self, "grpcRouteActionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="grpcStatusResponseActionInput")
    def grpc_status_response_action_input(
        self,
    ) -> typing.Optional[AlbVirtualHostRouteGrpcRouteGrpcStatusResponseAction]:
        return typing.cast(typing.Optional[AlbVirtualHostRouteGrpcRouteGrpcStatusResponseAction], jsii.get(self, "grpcStatusResponseActionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[AlbVirtualHostRouteGrpcRoute]:
        return typing.cast(typing.Optional[AlbVirtualHostRouteGrpcRoute], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbVirtualHostRouteGrpcRoute],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostRouteHttpRoute",
    jsii_struct_bases=[],
    name_mapping={
        "direct_response_action": "directResponseAction",
        "http_match": "httpMatch",
        "http_route_action": "httpRouteAction",
        "redirect_action": "redirectAction",
    },
)
class AlbVirtualHostRouteHttpRoute:
    def __init__(
        self,
        *,
        direct_response_action: typing.Optional["AlbVirtualHostRouteHttpRouteDirectResponseAction"] = None,
        http_match: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["AlbVirtualHostRouteHttpRouteHttpMatch"]]] = None,
        http_route_action: typing.Optional["AlbVirtualHostRouteHttpRouteHttpRouteAction"] = None,
        redirect_action: typing.Optional["AlbVirtualHostRouteHttpRouteRedirectAction"] = None,
    ) -> None:
        '''
        :param direct_response_action: direct_response_action block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#direct_response_action AlbVirtualHost#direct_response_action}
        :param http_match: http_match block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#http_match AlbVirtualHost#http_match}
        :param http_route_action: http_route_action block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#http_route_action AlbVirtualHost#http_route_action}
        :param redirect_action: redirect_action block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#redirect_action AlbVirtualHost#redirect_action}
        '''
        if isinstance(direct_response_action, dict):
            direct_response_action = AlbVirtualHostRouteHttpRouteDirectResponseAction(**direct_response_action)
        if isinstance(http_route_action, dict):
            http_route_action = AlbVirtualHostRouteHttpRouteHttpRouteAction(**http_route_action)
        if isinstance(redirect_action, dict):
            redirect_action = AlbVirtualHostRouteHttpRouteRedirectAction(**redirect_action)
        self._values: typing.Dict[str, typing.Any] = {}
        if direct_response_action is not None:
            self._values["direct_response_action"] = direct_response_action
        if http_match is not None:
            self._values["http_match"] = http_match
        if http_route_action is not None:
            self._values["http_route_action"] = http_route_action
        if redirect_action is not None:
            self._values["redirect_action"] = redirect_action

    @builtins.property
    def direct_response_action(
        self,
    ) -> typing.Optional["AlbVirtualHostRouteHttpRouteDirectResponseAction"]:
        '''direct_response_action block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#direct_response_action AlbVirtualHost#direct_response_action}
        '''
        result = self._values.get("direct_response_action")
        return typing.cast(typing.Optional["AlbVirtualHostRouteHttpRouteDirectResponseAction"], result)

    @builtins.property
    def http_match(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbVirtualHostRouteHttpRouteHttpMatch"]]]:
        '''http_match block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#http_match AlbVirtualHost#http_match}
        '''
        result = self._values.get("http_match")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["AlbVirtualHostRouteHttpRouteHttpMatch"]]], result)

    @builtins.property
    def http_route_action(
        self,
    ) -> typing.Optional["AlbVirtualHostRouteHttpRouteHttpRouteAction"]:
        '''http_route_action block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#http_route_action AlbVirtualHost#http_route_action}
        '''
        result = self._values.get("http_route_action")
        return typing.cast(typing.Optional["AlbVirtualHostRouteHttpRouteHttpRouteAction"], result)

    @builtins.property
    def redirect_action(
        self,
    ) -> typing.Optional["AlbVirtualHostRouteHttpRouteRedirectAction"]:
        '''redirect_action block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#redirect_action AlbVirtualHost#redirect_action}
        '''
        result = self._values.get("redirect_action")
        return typing.cast(typing.Optional["AlbVirtualHostRouteHttpRouteRedirectAction"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbVirtualHostRouteHttpRoute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostRouteHttpRouteDirectResponseAction",
    jsii_struct_bases=[],
    name_mapping={"body": "body", "status": "status"},
)
class AlbVirtualHostRouteHttpRouteDirectResponseAction:
    def __init__(
        self,
        *,
        body: typing.Optional[builtins.str] = None,
        status: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param body: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#body AlbVirtualHost#body}.
        :param status: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#status AlbVirtualHost#status}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if body is not None:
            self._values["body"] = body
        if status is not None:
            self._values["status"] = status

    @builtins.property
    def body(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#body AlbVirtualHost#body}.'''
        result = self._values.get("body")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def status(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#status AlbVirtualHost#status}.'''
        result = self._values.get("status")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbVirtualHostRouteHttpRouteDirectResponseAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbVirtualHostRouteHttpRouteDirectResponseActionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostRouteHttpRouteDirectResponseActionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetBody")
    def reset_body(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetBody", []))

    @jsii.member(jsii_name="resetStatus")
    def reset_status(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStatus", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bodyInput")
    def body_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "bodyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="statusInput")
    def status_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "statusInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="body")
    def body(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "body"))

    @body.setter
    def body(self, value: builtins.str) -> None:
        jsii.set(self, "body", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "status"))

    @status.setter
    def status(self, value: jsii.Number) -> None:
        jsii.set(self, "status", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbVirtualHostRouteHttpRouteDirectResponseAction]:
        return typing.cast(typing.Optional[AlbVirtualHostRouteHttpRouteDirectResponseAction], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbVirtualHostRouteHttpRouteDirectResponseAction],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostRouteHttpRouteHttpMatch",
    jsii_struct_bases=[],
    name_mapping={"http_method": "httpMethod", "path": "path"},
)
class AlbVirtualHostRouteHttpRouteHttpMatch:
    def __init__(
        self,
        *,
        http_method: typing.Optional[typing.Sequence[builtins.str]] = None,
        path: typing.Optional["AlbVirtualHostRouteHttpRouteHttpMatchPath"] = None,
    ) -> None:
        '''
        :param http_method: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#http_method AlbVirtualHost#http_method}.
        :param path: path block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#path AlbVirtualHost#path}
        '''
        if isinstance(path, dict):
            path = AlbVirtualHostRouteHttpRouteHttpMatchPath(**path)
        self._values: typing.Dict[str, typing.Any] = {}
        if http_method is not None:
            self._values["http_method"] = http_method
        if path is not None:
            self._values["path"] = path

    @builtins.property
    def http_method(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#http_method AlbVirtualHost#http_method}.'''
        result = self._values.get("http_method")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def path(self) -> typing.Optional["AlbVirtualHostRouteHttpRouteHttpMatchPath"]:
        '''path block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#path AlbVirtualHost#path}
        '''
        result = self._values.get("path")
        return typing.cast(typing.Optional["AlbVirtualHostRouteHttpRouteHttpMatchPath"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbVirtualHostRouteHttpRouteHttpMatch(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbVirtualHostRouteHttpRouteHttpMatchList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostRouteHttpRouteHttpMatchList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "AlbVirtualHostRouteHttpRouteHttpMatchOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("AlbVirtualHostRouteHttpRouteHttpMatchOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbVirtualHostRouteHttpRouteHttpMatch]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbVirtualHostRouteHttpRouteHttpMatch]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbVirtualHostRouteHttpRouteHttpMatch]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbVirtualHostRouteHttpRouteHttpMatchOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostRouteHttpRouteHttpMatchOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putPath")
    def put_path(
        self,
        *,
        exact: typing.Optional[builtins.str] = None,
        prefix: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param exact: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#exact AlbVirtualHost#exact}.
        :param prefix: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#prefix AlbVirtualHost#prefix}.
        '''
        value = AlbVirtualHostRouteHttpRouteHttpMatchPath(exact=exact, prefix=prefix)

        return typing.cast(None, jsii.invoke(self, "putPath", [value]))

    @jsii.member(jsii_name="resetHttpMethod")
    def reset_http_method(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttpMethod", []))

    @jsii.member(jsii_name="resetPath")
    def reset_path(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPath", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="path")
    def path(self) -> "AlbVirtualHostRouteHttpRouteHttpMatchPathOutputReference":
        return typing.cast("AlbVirtualHostRouteHttpRouteHttpMatchPathOutputReference", jsii.get(self, "path"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpMethodInput")
    def http_method_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "httpMethodInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="pathInput")
    def path_input(
        self,
    ) -> typing.Optional["AlbVirtualHostRouteHttpRouteHttpMatchPath"]:
        return typing.cast(typing.Optional["AlbVirtualHostRouteHttpRouteHttpMatchPath"], jsii.get(self, "pathInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpMethod")
    def http_method(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "httpMethod"))

    @http_method.setter
    def http_method(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "httpMethod", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, AlbVirtualHostRouteHttpRouteHttpMatch]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, AlbVirtualHostRouteHttpRouteHttpMatch]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, AlbVirtualHostRouteHttpRouteHttpMatch]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostRouteHttpRouteHttpMatchPath",
    jsii_struct_bases=[],
    name_mapping={"exact": "exact", "prefix": "prefix"},
)
class AlbVirtualHostRouteHttpRouteHttpMatchPath:
    def __init__(
        self,
        *,
        exact: typing.Optional[builtins.str] = None,
        prefix: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param exact: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#exact AlbVirtualHost#exact}.
        :param prefix: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#prefix AlbVirtualHost#prefix}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if exact is not None:
            self._values["exact"] = exact
        if prefix is not None:
            self._values["prefix"] = prefix

    @builtins.property
    def exact(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#exact AlbVirtualHost#exact}.'''
        result = self._values.get("exact")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def prefix(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#prefix AlbVirtualHost#prefix}.'''
        result = self._values.get("prefix")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbVirtualHostRouteHttpRouteHttpMatchPath(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbVirtualHostRouteHttpRouteHttpMatchPathOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostRouteHttpRouteHttpMatchPathOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetExact")
    def reset_exact(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetExact", []))

    @jsii.member(jsii_name="resetPrefix")
    def reset_prefix(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrefix", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="exactInput")
    def exact_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "exactInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="prefixInput")
    def prefix_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "prefixInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="exact")
    def exact(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "exact"))

    @exact.setter
    def exact(self, value: builtins.str) -> None:
        jsii.set(self, "exact", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="prefix")
    def prefix(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "prefix"))

    @prefix.setter
    def prefix(self, value: builtins.str) -> None:
        jsii.set(self, "prefix", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbVirtualHostRouteHttpRouteHttpMatchPath]:
        return typing.cast(typing.Optional[AlbVirtualHostRouteHttpRouteHttpMatchPath], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbVirtualHostRouteHttpRouteHttpMatchPath],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostRouteHttpRouteHttpRouteAction",
    jsii_struct_bases=[],
    name_mapping={
        "backend_group_id": "backendGroupId",
        "auto_host_rewrite": "autoHostRewrite",
        "host_rewrite": "hostRewrite",
        "idle_timeout": "idleTimeout",
        "prefix_rewrite": "prefixRewrite",
        "timeout": "timeout",
        "upgrade_types": "upgradeTypes",
    },
)
class AlbVirtualHostRouteHttpRouteHttpRouteAction:
    def __init__(
        self,
        *,
        backend_group_id: builtins.str,
        auto_host_rewrite: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        host_rewrite: typing.Optional[builtins.str] = None,
        idle_timeout: typing.Optional[builtins.str] = None,
        prefix_rewrite: typing.Optional[builtins.str] = None,
        timeout: typing.Optional[builtins.str] = None,
        upgrade_types: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param backend_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#backend_group_id AlbVirtualHost#backend_group_id}.
        :param auto_host_rewrite: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#auto_host_rewrite AlbVirtualHost#auto_host_rewrite}.
        :param host_rewrite: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#host_rewrite AlbVirtualHost#host_rewrite}.
        :param idle_timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#idle_timeout AlbVirtualHost#idle_timeout}.
        :param prefix_rewrite: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#prefix_rewrite AlbVirtualHost#prefix_rewrite}.
        :param timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#timeout AlbVirtualHost#timeout}.
        :param upgrade_types: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#upgrade_types AlbVirtualHost#upgrade_types}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "backend_group_id": backend_group_id,
        }
        if auto_host_rewrite is not None:
            self._values["auto_host_rewrite"] = auto_host_rewrite
        if host_rewrite is not None:
            self._values["host_rewrite"] = host_rewrite
        if idle_timeout is not None:
            self._values["idle_timeout"] = idle_timeout
        if prefix_rewrite is not None:
            self._values["prefix_rewrite"] = prefix_rewrite
        if timeout is not None:
            self._values["timeout"] = timeout
        if upgrade_types is not None:
            self._values["upgrade_types"] = upgrade_types

    @builtins.property
    def backend_group_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#backend_group_id AlbVirtualHost#backend_group_id}.'''
        result = self._values.get("backend_group_id")
        assert result is not None, "Required property 'backend_group_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def auto_host_rewrite(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#auto_host_rewrite AlbVirtualHost#auto_host_rewrite}.'''
        result = self._values.get("auto_host_rewrite")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def host_rewrite(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#host_rewrite AlbVirtualHost#host_rewrite}.'''
        result = self._values.get("host_rewrite")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def idle_timeout(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#idle_timeout AlbVirtualHost#idle_timeout}.'''
        result = self._values.get("idle_timeout")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def prefix_rewrite(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#prefix_rewrite AlbVirtualHost#prefix_rewrite}.'''
        result = self._values.get("prefix_rewrite")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeout(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#timeout AlbVirtualHost#timeout}.'''
        result = self._values.get("timeout")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def upgrade_types(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#upgrade_types AlbVirtualHost#upgrade_types}.'''
        result = self._values.get("upgrade_types")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbVirtualHostRouteHttpRouteHttpRouteAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbVirtualHostRouteHttpRouteHttpRouteActionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostRouteHttpRouteHttpRouteActionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAutoHostRewrite")
    def reset_auto_host_rewrite(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAutoHostRewrite", []))

    @jsii.member(jsii_name="resetHostRewrite")
    def reset_host_rewrite(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHostRewrite", []))

    @jsii.member(jsii_name="resetIdleTimeout")
    def reset_idle_timeout(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIdleTimeout", []))

    @jsii.member(jsii_name="resetPrefixRewrite")
    def reset_prefix_rewrite(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrefixRewrite", []))

    @jsii.member(jsii_name="resetTimeout")
    def reset_timeout(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeout", []))

    @jsii.member(jsii_name="resetUpgradeTypes")
    def reset_upgrade_types(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpgradeTypes", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoHostRewriteInput")
    def auto_host_rewrite_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "autoHostRewriteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backendGroupIdInput")
    def backend_group_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "backendGroupIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostRewriteInput")
    def host_rewrite_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "hostRewriteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idleTimeoutInput")
    def idle_timeout_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idleTimeoutInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="prefixRewriteInput")
    def prefix_rewrite_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "prefixRewriteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutInput")
    def timeout_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "timeoutInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="upgradeTypesInput")
    def upgrade_types_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "upgradeTypesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoHostRewrite")
    def auto_host_rewrite(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "autoHostRewrite"))

    @auto_host_rewrite.setter
    def auto_host_rewrite(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "autoHostRewrite", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backendGroupId")
    def backend_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "backendGroupId"))

    @backend_group_id.setter
    def backend_group_id(self, value: builtins.str) -> None:
        jsii.set(self, "backendGroupId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostRewrite")
    def host_rewrite(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "hostRewrite"))

    @host_rewrite.setter
    def host_rewrite(self, value: builtins.str) -> None:
        jsii.set(self, "hostRewrite", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idleTimeout")
    def idle_timeout(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "idleTimeout"))

    @idle_timeout.setter
    def idle_timeout(self, value: builtins.str) -> None:
        jsii.set(self, "idleTimeout", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="prefixRewrite")
    def prefix_rewrite(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "prefixRewrite"))

    @prefix_rewrite.setter
    def prefix_rewrite(self, value: builtins.str) -> None:
        jsii.set(self, "prefixRewrite", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeout")
    def timeout(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "timeout"))

    @timeout.setter
    def timeout(self, value: builtins.str) -> None:
        jsii.set(self, "timeout", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="upgradeTypes")
    def upgrade_types(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "upgradeTypes"))

    @upgrade_types.setter
    def upgrade_types(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "upgradeTypes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbVirtualHostRouteHttpRouteHttpRouteAction]:
        return typing.cast(typing.Optional[AlbVirtualHostRouteHttpRouteHttpRouteAction], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbVirtualHostRouteHttpRouteHttpRouteAction],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbVirtualHostRouteHttpRouteOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostRouteHttpRouteOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putDirectResponseAction")
    def put_direct_response_action(
        self,
        *,
        body: typing.Optional[builtins.str] = None,
        status: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param body: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#body AlbVirtualHost#body}.
        :param status: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#status AlbVirtualHost#status}.
        '''
        value = AlbVirtualHostRouteHttpRouteDirectResponseAction(
            body=body, status=status
        )

        return typing.cast(None, jsii.invoke(self, "putDirectResponseAction", [value]))

    @jsii.member(jsii_name="putHttpMatch")
    def put_http_match(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence[AlbVirtualHostRouteHttpRouteHttpMatch]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putHttpMatch", [value]))

    @jsii.member(jsii_name="putHttpRouteAction")
    def put_http_route_action(
        self,
        *,
        backend_group_id: builtins.str,
        auto_host_rewrite: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        host_rewrite: typing.Optional[builtins.str] = None,
        idle_timeout: typing.Optional[builtins.str] = None,
        prefix_rewrite: typing.Optional[builtins.str] = None,
        timeout: typing.Optional[builtins.str] = None,
        upgrade_types: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param backend_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#backend_group_id AlbVirtualHost#backend_group_id}.
        :param auto_host_rewrite: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#auto_host_rewrite AlbVirtualHost#auto_host_rewrite}.
        :param host_rewrite: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#host_rewrite AlbVirtualHost#host_rewrite}.
        :param idle_timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#idle_timeout AlbVirtualHost#idle_timeout}.
        :param prefix_rewrite: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#prefix_rewrite AlbVirtualHost#prefix_rewrite}.
        :param timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#timeout AlbVirtualHost#timeout}.
        :param upgrade_types: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#upgrade_types AlbVirtualHost#upgrade_types}.
        '''
        value = AlbVirtualHostRouteHttpRouteHttpRouteAction(
            backend_group_id=backend_group_id,
            auto_host_rewrite=auto_host_rewrite,
            host_rewrite=host_rewrite,
            idle_timeout=idle_timeout,
            prefix_rewrite=prefix_rewrite,
            timeout=timeout,
            upgrade_types=upgrade_types,
        )

        return typing.cast(None, jsii.invoke(self, "putHttpRouteAction", [value]))

    @jsii.member(jsii_name="putRedirectAction")
    def put_redirect_action(
        self,
        *,
        remove_query: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        replace_host: typing.Optional[builtins.str] = None,
        replace_path: typing.Optional[builtins.str] = None,
        replace_port: typing.Optional[jsii.Number] = None,
        replace_prefix: typing.Optional[builtins.str] = None,
        replace_scheme: typing.Optional[builtins.str] = None,
        response_code: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param remove_query: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#remove_query AlbVirtualHost#remove_query}.
        :param replace_host: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#replace_host AlbVirtualHost#replace_host}.
        :param replace_path: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#replace_path AlbVirtualHost#replace_path}.
        :param replace_port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#replace_port AlbVirtualHost#replace_port}.
        :param replace_prefix: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#replace_prefix AlbVirtualHost#replace_prefix}.
        :param replace_scheme: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#replace_scheme AlbVirtualHost#replace_scheme}.
        :param response_code: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#response_code AlbVirtualHost#response_code}.
        '''
        value = AlbVirtualHostRouteHttpRouteRedirectAction(
            remove_query=remove_query,
            replace_host=replace_host,
            replace_path=replace_path,
            replace_port=replace_port,
            replace_prefix=replace_prefix,
            replace_scheme=replace_scheme,
            response_code=response_code,
        )

        return typing.cast(None, jsii.invoke(self, "putRedirectAction", [value]))

    @jsii.member(jsii_name="resetDirectResponseAction")
    def reset_direct_response_action(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDirectResponseAction", []))

    @jsii.member(jsii_name="resetHttpMatch")
    def reset_http_match(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttpMatch", []))

    @jsii.member(jsii_name="resetHttpRouteAction")
    def reset_http_route_action(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttpRouteAction", []))

    @jsii.member(jsii_name="resetRedirectAction")
    def reset_redirect_action(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRedirectAction", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="directResponseAction")
    def direct_response_action(
        self,
    ) -> AlbVirtualHostRouteHttpRouteDirectResponseActionOutputReference:
        return typing.cast(AlbVirtualHostRouteHttpRouteDirectResponseActionOutputReference, jsii.get(self, "directResponseAction"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpMatch")
    def http_match(self) -> AlbVirtualHostRouteHttpRouteHttpMatchList:
        return typing.cast(AlbVirtualHostRouteHttpRouteHttpMatchList, jsii.get(self, "httpMatch"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpRouteAction")
    def http_route_action(
        self,
    ) -> AlbVirtualHostRouteHttpRouteHttpRouteActionOutputReference:
        return typing.cast(AlbVirtualHostRouteHttpRouteHttpRouteActionOutputReference, jsii.get(self, "httpRouteAction"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="redirectAction")
    def redirect_action(
        self,
    ) -> "AlbVirtualHostRouteHttpRouteRedirectActionOutputReference":
        return typing.cast("AlbVirtualHostRouteHttpRouteRedirectActionOutputReference", jsii.get(self, "redirectAction"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="directResponseActionInput")
    def direct_response_action_input(
        self,
    ) -> typing.Optional[AlbVirtualHostRouteHttpRouteDirectResponseAction]:
        return typing.cast(typing.Optional[AlbVirtualHostRouteHttpRouteDirectResponseAction], jsii.get(self, "directResponseActionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpMatchInput")
    def http_match_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbVirtualHostRouteHttpRouteHttpMatch]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbVirtualHostRouteHttpRouteHttpMatch]]], jsii.get(self, "httpMatchInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpRouteActionInput")
    def http_route_action_input(
        self,
    ) -> typing.Optional[AlbVirtualHostRouteHttpRouteHttpRouteAction]:
        return typing.cast(typing.Optional[AlbVirtualHostRouteHttpRouteHttpRouteAction], jsii.get(self, "httpRouteActionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="redirectActionInput")
    def redirect_action_input(
        self,
    ) -> typing.Optional["AlbVirtualHostRouteHttpRouteRedirectAction"]:
        return typing.cast(typing.Optional["AlbVirtualHostRouteHttpRouteRedirectAction"], jsii.get(self, "redirectActionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[AlbVirtualHostRouteHttpRoute]:
        return typing.cast(typing.Optional[AlbVirtualHostRouteHttpRoute], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbVirtualHostRouteHttpRoute],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostRouteHttpRouteRedirectAction",
    jsii_struct_bases=[],
    name_mapping={
        "remove_query": "removeQuery",
        "replace_host": "replaceHost",
        "replace_path": "replacePath",
        "replace_port": "replacePort",
        "replace_prefix": "replacePrefix",
        "replace_scheme": "replaceScheme",
        "response_code": "responseCode",
    },
)
class AlbVirtualHostRouteHttpRouteRedirectAction:
    def __init__(
        self,
        *,
        remove_query: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        replace_host: typing.Optional[builtins.str] = None,
        replace_path: typing.Optional[builtins.str] = None,
        replace_port: typing.Optional[jsii.Number] = None,
        replace_prefix: typing.Optional[builtins.str] = None,
        replace_scheme: typing.Optional[builtins.str] = None,
        response_code: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param remove_query: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#remove_query AlbVirtualHost#remove_query}.
        :param replace_host: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#replace_host AlbVirtualHost#replace_host}.
        :param replace_path: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#replace_path AlbVirtualHost#replace_path}.
        :param replace_port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#replace_port AlbVirtualHost#replace_port}.
        :param replace_prefix: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#replace_prefix AlbVirtualHost#replace_prefix}.
        :param replace_scheme: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#replace_scheme AlbVirtualHost#replace_scheme}.
        :param response_code: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#response_code AlbVirtualHost#response_code}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if remove_query is not None:
            self._values["remove_query"] = remove_query
        if replace_host is not None:
            self._values["replace_host"] = replace_host
        if replace_path is not None:
            self._values["replace_path"] = replace_path
        if replace_port is not None:
            self._values["replace_port"] = replace_port
        if replace_prefix is not None:
            self._values["replace_prefix"] = replace_prefix
        if replace_scheme is not None:
            self._values["replace_scheme"] = replace_scheme
        if response_code is not None:
            self._values["response_code"] = response_code

    @builtins.property
    def remove_query(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#remove_query AlbVirtualHost#remove_query}.'''
        result = self._values.get("remove_query")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def replace_host(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#replace_host AlbVirtualHost#replace_host}.'''
        result = self._values.get("replace_host")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def replace_path(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#replace_path AlbVirtualHost#replace_path}.'''
        result = self._values.get("replace_path")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def replace_port(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#replace_port AlbVirtualHost#replace_port}.'''
        result = self._values.get("replace_port")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def replace_prefix(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#replace_prefix AlbVirtualHost#replace_prefix}.'''
        result = self._values.get("replace_prefix")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def replace_scheme(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#replace_scheme AlbVirtualHost#replace_scheme}.'''
        result = self._values.get("replace_scheme")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def response_code(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#response_code AlbVirtualHost#response_code}.'''
        result = self._values.get("response_code")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbVirtualHostRouteHttpRouteRedirectAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbVirtualHostRouteHttpRouteRedirectActionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostRouteHttpRouteRedirectActionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetRemoveQuery")
    def reset_remove_query(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRemoveQuery", []))

    @jsii.member(jsii_name="resetReplaceHost")
    def reset_replace_host(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetReplaceHost", []))

    @jsii.member(jsii_name="resetReplacePath")
    def reset_replace_path(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetReplacePath", []))

    @jsii.member(jsii_name="resetReplacePort")
    def reset_replace_port(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetReplacePort", []))

    @jsii.member(jsii_name="resetReplacePrefix")
    def reset_replace_prefix(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetReplacePrefix", []))

    @jsii.member(jsii_name="resetReplaceScheme")
    def reset_replace_scheme(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetReplaceScheme", []))

    @jsii.member(jsii_name="resetResponseCode")
    def reset_response_code(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetResponseCode", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="removeQueryInput")
    def remove_query_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "removeQueryInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replaceHostInput")
    def replace_host_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "replaceHostInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replacePathInput")
    def replace_path_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "replacePathInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replacePortInput")
    def replace_port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "replacePortInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replacePrefixInput")
    def replace_prefix_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "replacePrefixInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replaceSchemeInput")
    def replace_scheme_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "replaceSchemeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="responseCodeInput")
    def response_code_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "responseCodeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="removeQuery")
    def remove_query(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "removeQuery"))

    @remove_query.setter
    def remove_query(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "removeQuery", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replaceHost")
    def replace_host(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "replaceHost"))

    @replace_host.setter
    def replace_host(self, value: builtins.str) -> None:
        jsii.set(self, "replaceHost", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replacePath")
    def replace_path(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "replacePath"))

    @replace_path.setter
    def replace_path(self, value: builtins.str) -> None:
        jsii.set(self, "replacePath", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replacePort")
    def replace_port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "replacePort"))

    @replace_port.setter
    def replace_port(self, value: jsii.Number) -> None:
        jsii.set(self, "replacePort", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replacePrefix")
    def replace_prefix(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "replacePrefix"))

    @replace_prefix.setter
    def replace_prefix(self, value: builtins.str) -> None:
        jsii.set(self, "replacePrefix", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replaceScheme")
    def replace_scheme(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "replaceScheme"))

    @replace_scheme.setter
    def replace_scheme(self, value: builtins.str) -> None:
        jsii.set(self, "replaceScheme", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="responseCode")
    def response_code(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "responseCode"))

    @response_code.setter
    def response_code(self, value: builtins.str) -> None:
        jsii.set(self, "responseCode", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[AlbVirtualHostRouteHttpRouteRedirectAction]:
        return typing.cast(typing.Optional[AlbVirtualHostRouteHttpRouteRedirectAction], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[AlbVirtualHostRouteHttpRouteRedirectAction],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbVirtualHostRouteList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostRouteList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "AlbVirtualHostRouteOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("AlbVirtualHostRouteOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbVirtualHostRoute]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbVirtualHostRoute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[AlbVirtualHostRoute]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class AlbVirtualHostRouteOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostRouteOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putGrpcRoute")
    def put_grpc_route(
        self,
        *,
        grpc_match: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence[AlbVirtualHostRouteGrpcRouteGrpcMatch]]] = None,
        grpc_route_action: typing.Optional[AlbVirtualHostRouteGrpcRouteGrpcRouteAction] = None,
        grpc_status_response_action: typing.Optional[AlbVirtualHostRouteGrpcRouteGrpcStatusResponseAction] = None,
    ) -> None:
        '''
        :param grpc_match: grpc_match block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#grpc_match AlbVirtualHost#grpc_match}
        :param grpc_route_action: grpc_route_action block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#grpc_route_action AlbVirtualHost#grpc_route_action}
        :param grpc_status_response_action: grpc_status_response_action block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#grpc_status_response_action AlbVirtualHost#grpc_status_response_action}
        '''
        value = AlbVirtualHostRouteGrpcRoute(
            grpc_match=grpc_match,
            grpc_route_action=grpc_route_action,
            grpc_status_response_action=grpc_status_response_action,
        )

        return typing.cast(None, jsii.invoke(self, "putGrpcRoute", [value]))

    @jsii.member(jsii_name="putHttpRoute")
    def put_http_route(
        self,
        *,
        direct_response_action: typing.Optional[AlbVirtualHostRouteHttpRouteDirectResponseAction] = None,
        http_match: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence[AlbVirtualHostRouteHttpRouteHttpMatch]]] = None,
        http_route_action: typing.Optional[AlbVirtualHostRouteHttpRouteHttpRouteAction] = None,
        redirect_action: typing.Optional[AlbVirtualHostRouteHttpRouteRedirectAction] = None,
    ) -> None:
        '''
        :param direct_response_action: direct_response_action block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#direct_response_action AlbVirtualHost#direct_response_action}
        :param http_match: http_match block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#http_match AlbVirtualHost#http_match}
        :param http_route_action: http_route_action block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#http_route_action AlbVirtualHost#http_route_action}
        :param redirect_action: redirect_action block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#redirect_action AlbVirtualHost#redirect_action}
        '''
        value = AlbVirtualHostRouteHttpRoute(
            direct_response_action=direct_response_action,
            http_match=http_match,
            http_route_action=http_route_action,
            redirect_action=redirect_action,
        )

        return typing.cast(None, jsii.invoke(self, "putHttpRoute", [value]))

    @jsii.member(jsii_name="resetGrpcRoute")
    def reset_grpc_route(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGrpcRoute", []))

    @jsii.member(jsii_name="resetHttpRoute")
    def reset_http_route(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttpRoute", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="grpcRoute")
    def grpc_route(self) -> AlbVirtualHostRouteGrpcRouteOutputReference:
        return typing.cast(AlbVirtualHostRouteGrpcRouteOutputReference, jsii.get(self, "grpcRoute"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpRoute")
    def http_route(self) -> AlbVirtualHostRouteHttpRouteOutputReference:
        return typing.cast(AlbVirtualHostRouteHttpRouteOutputReference, jsii.get(self, "httpRoute"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="grpcRouteInput")
    def grpc_route_input(self) -> typing.Optional[AlbVirtualHostRouteGrpcRoute]:
        return typing.cast(typing.Optional[AlbVirtualHostRouteGrpcRoute], jsii.get(self, "grpcRouteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpRouteInput")
    def http_route_input(self) -> typing.Optional[AlbVirtualHostRouteHttpRoute]:
        return typing.cast(typing.Optional[AlbVirtualHostRouteHttpRoute], jsii.get(self, "httpRouteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, AlbVirtualHostRoute]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, AlbVirtualHostRoute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, AlbVirtualHostRoute]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class AlbVirtualHostTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#create AlbVirtualHost#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#delete AlbVirtualHost#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#update AlbVirtualHost#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#create AlbVirtualHost#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#delete AlbVirtualHost#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/alb_virtual_host#update AlbVirtualHost#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbVirtualHostTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbVirtualHostTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.AlbVirtualHostTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, AlbVirtualHostTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, AlbVirtualHostTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, AlbVirtualHostTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ApiGateway(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ApiGateway",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/api_gateway yandex_api_gateway}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        name: builtins.str,
        spec: builtins.str,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["ApiGatewayTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/api_gateway yandex_api_gateway} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/api_gateway#name ApiGateway#name}.
        :param spec: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/api_gateway#spec ApiGateway#spec}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/api_gateway#description ApiGateway#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/api_gateway#folder_id ApiGateway#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/api_gateway#id ApiGateway#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/api_gateway#labels ApiGateway#labels}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/api_gateway#timeouts ApiGateway#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = ApiGatewayConfig(
            name=name,
            spec=spec,
            description=description,
            folder_id=folder_id,
            id=id,
            labels=labels,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/api_gateway#create ApiGateway#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/api_gateway#delete ApiGateway#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/api_gateway#update ApiGateway#update}.
        '''
        value = ApiGatewayTimeouts(create=create, delete=delete, update=update)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="domain")
    def domain(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "domain"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logGroupId")
    def log_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "logGroupId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "ApiGatewayTimeoutsOutputReference":
        return typing.cast("ApiGatewayTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="userDomains")
    def user_domains(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "userDomains"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="specInput")
    def spec_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "specInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "ApiGatewayTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "ApiGatewayTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="spec")
    def spec(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "spec"))

    @spec.setter
    def spec(self, value: builtins.str) -> None:
        jsii.set(self, "spec", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ApiGatewayConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "spec": "spec",
        "description": "description",
        "folder_id": "folderId",
        "id": "id",
        "labels": "labels",
        "timeouts": "timeouts",
    },
)
class ApiGatewayConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        spec: builtins.str,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["ApiGatewayTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/api_gateway#name ApiGateway#name}.
        :param spec: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/api_gateway#spec ApiGateway#spec}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/api_gateway#description ApiGateway#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/api_gateway#folder_id ApiGateway#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/api_gateway#id ApiGateway#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/api_gateway#labels ApiGateway#labels}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/api_gateway#timeouts ApiGateway#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ApiGatewayTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "spec": spec,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/api_gateway#name ApiGateway#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def spec(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/api_gateway#spec ApiGateway#spec}.'''
        result = self._values.get("spec")
        assert result is not None, "Required property 'spec' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/api_gateway#description ApiGateway#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/api_gateway#folder_id ApiGateway#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/api_gateway#id ApiGateway#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/api_gateway#labels ApiGateway#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["ApiGatewayTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/api_gateway#timeouts ApiGateway#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["ApiGatewayTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ApiGatewayTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class ApiGatewayTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/api_gateway#create ApiGateway#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/api_gateway#delete ApiGateway#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/api_gateway#update ApiGateway#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/api_gateway#create ApiGateway#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/api_gateway#delete ApiGateway#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/api_gateway#update ApiGateway#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiGatewayTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ApiGatewayTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, ApiGatewayTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, ApiGatewayTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, ApiGatewayTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class CdnOriginGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.CdnOriginGroup",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/cdn_origin_group yandex_cdn_origin_group}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        name: builtins.str,
        origin: typing.Union[cdktf.IResolvable, typing.Sequence["CdnOriginGroupOrigin"]],
        id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["CdnOriginGroupTimeouts"] = None,
        use_next: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/cdn_origin_group yandex_cdn_origin_group} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_origin_group#name CdnOriginGroup#name}.
        :param origin: origin block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_origin_group#origin CdnOriginGroup#origin}
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_origin_group#id CdnOriginGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_origin_group#timeouts CdnOriginGroup#timeouts}
        :param use_next: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_origin_group#use_next CdnOriginGroup#use_next}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = CdnOriginGroupConfig(
            name=name,
            origin=origin,
            id=id,
            timeouts=timeouts,
            use_next=use_next,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putOrigin")
    def put_origin(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["CdnOriginGroupOrigin"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putOrigin", [value]))

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_origin_group#create CdnOriginGroup#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_origin_group#delete CdnOriginGroup#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_origin_group#update CdnOriginGroup#update}.
        '''
        value = CdnOriginGroupTimeouts(create=create, delete=delete, update=update)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="resetUseNext")
    def reset_use_next(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUseNext", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="origin")
    def origin(self) -> "CdnOriginGroupOriginList":
        return typing.cast("CdnOriginGroupOriginList", jsii.get(self, "origin"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "CdnOriginGroupTimeoutsOutputReference":
        return typing.cast("CdnOriginGroupTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="originInput")
    def origin_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["CdnOriginGroupOrigin"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["CdnOriginGroupOrigin"]]], jsii.get(self, "originInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "CdnOriginGroupTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "CdnOriginGroupTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="useNextInput")
    def use_next_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "useNextInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="useNext")
    def use_next(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "useNext"))

    @use_next.setter
    def use_next(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "useNext", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.CdnOriginGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "origin": "origin",
        "id": "id",
        "timeouts": "timeouts",
        "use_next": "useNext",
    },
)
class CdnOriginGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        origin: typing.Union[cdktf.IResolvable, typing.Sequence["CdnOriginGroupOrigin"]],
        id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["CdnOriginGroupTimeouts"] = None,
        use_next: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_origin_group#name CdnOriginGroup#name}.
        :param origin: origin block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_origin_group#origin CdnOriginGroup#origin}
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_origin_group#id CdnOriginGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_origin_group#timeouts CdnOriginGroup#timeouts}
        :param use_next: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_origin_group#use_next CdnOriginGroup#use_next}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = CdnOriginGroupTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "origin": origin,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if id is not None:
            self._values["id"] = id
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if use_next is not None:
            self._values["use_next"] = use_next

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_origin_group#name CdnOriginGroup#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def origin(
        self,
    ) -> typing.Union[cdktf.IResolvable, typing.List["CdnOriginGroupOrigin"]]:
        '''origin block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_origin_group#origin CdnOriginGroup#origin}
        '''
        result = self._values.get("origin")
        assert result is not None, "Required property 'origin' is missing"
        return typing.cast(typing.Union[cdktf.IResolvable, typing.List["CdnOriginGroupOrigin"]], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_origin_group#id CdnOriginGroup#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["CdnOriginGroupTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_origin_group#timeouts CdnOriginGroup#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["CdnOriginGroupTimeouts"], result)

    @builtins.property
    def use_next(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_origin_group#use_next CdnOriginGroup#use_next}.'''
        result = self._values.get("use_next")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CdnOriginGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.CdnOriginGroupOrigin",
    jsii_struct_bases=[],
    name_mapping={"source": "source", "backup": "backup", "enabled": "enabled"},
)
class CdnOriginGroupOrigin:
    def __init__(
        self,
        *,
        source: builtins.str,
        backup: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param source: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_origin_group#source CdnOriginGroup#source}.
        :param backup: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_origin_group#backup CdnOriginGroup#backup}.
        :param enabled: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_origin_group#enabled CdnOriginGroup#enabled}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "source": source,
        }
        if backup is not None:
            self._values["backup"] = backup
        if enabled is not None:
            self._values["enabled"] = enabled

    @builtins.property
    def source(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_origin_group#source CdnOriginGroup#source}.'''
        result = self._values.get("source")
        assert result is not None, "Required property 'source' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def backup(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_origin_group#backup CdnOriginGroup#backup}.'''
        result = self._values.get("backup")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def enabled(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_origin_group#enabled CdnOriginGroup#enabled}.'''
        result = self._values.get("enabled")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CdnOriginGroupOrigin(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CdnOriginGroupOriginList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.CdnOriginGroupOriginList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "CdnOriginGroupOriginOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("CdnOriginGroupOriginOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[CdnOriginGroupOrigin]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[CdnOriginGroupOrigin]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[CdnOriginGroupOrigin]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class CdnOriginGroupOriginOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.CdnOriginGroupOriginOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetBackup")
    def reset_backup(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetBackup", []))

    @jsii.member(jsii_name="resetEnabled")
    def reset_enabled(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEnabled", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="originGroupId")
    def origin_group_id(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "originGroupId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backupInput")
    def backup_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "backupInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="enabledInput")
    def enabled_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "enabledInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sourceInput")
    def source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sourceInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backup")
    def backup(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "backup"))

    @backup.setter
    def backup(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "backup", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "enabled"))

    @enabled.setter
    def enabled(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="source")
    def source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "source"))

    @source.setter
    def source(self, value: builtins.str) -> None:
        jsii.set(self, "source", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, CdnOriginGroupOrigin]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, CdnOriginGroupOrigin]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, CdnOriginGroupOrigin]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.CdnOriginGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class CdnOriginGroupTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_origin_group#create CdnOriginGroup#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_origin_group#delete CdnOriginGroup#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_origin_group#update CdnOriginGroup#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_origin_group#create CdnOriginGroup#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_origin_group#delete CdnOriginGroup#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_origin_group#update CdnOriginGroup#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CdnOriginGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CdnOriginGroupTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.CdnOriginGroupTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, CdnOriginGroupTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, CdnOriginGroupTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, CdnOriginGroupTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class CdnResource(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.CdnResource",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource yandex_cdn_resource}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        active: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        cname: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        options: typing.Optional["CdnResourceOptions"] = None,
        origin_group_id: typing.Optional[jsii.Number] = None,
        origin_group_name: typing.Optional[builtins.str] = None,
        origin_protocol: typing.Optional[builtins.str] = None,
        secondary_hostnames: typing.Optional[typing.Sequence[builtins.str]] = None,
        ssl_certificate: typing.Optional["CdnResourceSslCertificate"] = None,
        timeouts: typing.Optional["CdnResourceTimeouts"] = None,
        updated_at: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource yandex_cdn_resource} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param active: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#active CdnResource#active}.
        :param cname: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#cname CdnResource#cname}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#id CdnResource#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param options: options block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#options CdnResource#options}
        :param origin_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#origin_group_id CdnResource#origin_group_id}.
        :param origin_group_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#origin_group_name CdnResource#origin_group_name}.
        :param origin_protocol: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#origin_protocol CdnResource#origin_protocol}.
        :param secondary_hostnames: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#secondary_hostnames CdnResource#secondary_hostnames}.
        :param ssl_certificate: ssl_certificate block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#ssl_certificate CdnResource#ssl_certificate}
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#timeouts CdnResource#timeouts}
        :param updated_at: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#updated_at CdnResource#updated_at}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = CdnResourceConfig(
            active=active,
            cname=cname,
            id=id,
            options=options,
            origin_group_id=origin_group_id,
            origin_group_name=origin_group_name,
            origin_protocol=origin_protocol,
            secondary_hostnames=secondary_hostnames,
            ssl_certificate=ssl_certificate,
            timeouts=timeouts,
            updated_at=updated_at,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putOptions")
    def put_options(
        self,
        *,
        allowed_http_methods: typing.Optional[typing.Sequence[builtins.str]] = None,
        browser_cache_settings: typing.Optional[jsii.Number] = None,
        cache_http_headers: typing.Optional[typing.Sequence[builtins.str]] = None,
        cors: typing.Optional[typing.Sequence[builtins.str]] = None,
        custom_host_header: typing.Optional[builtins.str] = None,
        custom_server_name: typing.Optional[builtins.str] = None,
        disable_cache: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        disable_proxy_force_ranges: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        edge_cache_settings: typing.Optional[jsii.Number] = None,
        fetched_compressed: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        forward_host_header: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        gzip_on: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        ignore_cookie: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        ignore_query_params: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        proxy_cache_methods_set: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        query_params_blacklist: typing.Optional[typing.Sequence[builtins.str]] = None,
        query_params_whitelist: typing.Optional[typing.Sequence[builtins.str]] = None,
        redirect_https_to_http: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        redirect_http_to_https: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        slice: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        static_request_headers: typing.Optional[typing.Sequence[builtins.str]] = None,
        static_response_headers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
    ) -> None:
        '''
        :param allowed_http_methods: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#allowed_http_methods CdnResource#allowed_http_methods}.
        :param browser_cache_settings: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#browser_cache_settings CdnResource#browser_cache_settings}.
        :param cache_http_headers: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#cache_http_headers CdnResource#cache_http_headers}.
        :param cors: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#cors CdnResource#cors}.
        :param custom_host_header: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#custom_host_header CdnResource#custom_host_header}.
        :param custom_server_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#custom_server_name CdnResource#custom_server_name}.
        :param disable_cache: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#disable_cache CdnResource#disable_cache}.
        :param disable_proxy_force_ranges: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#disable_proxy_force_ranges CdnResource#disable_proxy_force_ranges}.
        :param edge_cache_settings: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#edge_cache_settings CdnResource#edge_cache_settings}.
        :param fetched_compressed: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#fetched_compressed CdnResource#fetched_compressed}.
        :param forward_host_header: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#forward_host_header CdnResource#forward_host_header}.
        :param gzip_on: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#gzip_on CdnResource#gzip_on}.
        :param ignore_cookie: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#ignore_cookie CdnResource#ignore_cookie}.
        :param ignore_query_params: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#ignore_query_params CdnResource#ignore_query_params}.
        :param proxy_cache_methods_set: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#proxy_cache_methods_set CdnResource#proxy_cache_methods_set}.
        :param query_params_blacklist: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#query_params_blacklist CdnResource#query_params_blacklist}.
        :param query_params_whitelist: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#query_params_whitelist CdnResource#query_params_whitelist}.
        :param redirect_https_to_http: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#redirect_https_to_http CdnResource#redirect_https_to_http}.
        :param redirect_http_to_https: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#redirect_http_to_https CdnResource#redirect_http_to_https}.
        :param slice: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#slice CdnResource#slice}.
        :param static_request_headers: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#static_request_headers CdnResource#static_request_headers}.
        :param static_response_headers: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#static_response_headers CdnResource#static_response_headers}.
        '''
        value = CdnResourceOptions(
            allowed_http_methods=allowed_http_methods,
            browser_cache_settings=browser_cache_settings,
            cache_http_headers=cache_http_headers,
            cors=cors,
            custom_host_header=custom_host_header,
            custom_server_name=custom_server_name,
            disable_cache=disable_cache,
            disable_proxy_force_ranges=disable_proxy_force_ranges,
            edge_cache_settings=edge_cache_settings,
            fetched_compressed=fetched_compressed,
            forward_host_header=forward_host_header,
            gzip_on=gzip_on,
            ignore_cookie=ignore_cookie,
            ignore_query_params=ignore_query_params,
            proxy_cache_methods_set=proxy_cache_methods_set,
            query_params_blacklist=query_params_blacklist,
            query_params_whitelist=query_params_whitelist,
            redirect_https_to_http=redirect_https_to_http,
            redirect_http_to_https=redirect_http_to_https,
            slice=slice,
            static_request_headers=static_request_headers,
            static_response_headers=static_response_headers,
        )

        return typing.cast(None, jsii.invoke(self, "putOptions", [value]))

    @jsii.member(jsii_name="putSslCertificate")
    def put_ssl_certificate(
        self,
        *,
        type: builtins.str,
        certificate_manager_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#type CdnResource#type}.
        :param certificate_manager_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#certificate_manager_id CdnResource#certificate_manager_id}.
        '''
        value = CdnResourceSslCertificate(
            type=type, certificate_manager_id=certificate_manager_id
        )

        return typing.cast(None, jsii.invoke(self, "putSslCertificate", [value]))

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#create CdnResource#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#delete CdnResource#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#update CdnResource#update}.
        '''
        value = CdnResourceTimeouts(create=create, delete=delete, update=update)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetActive")
    def reset_active(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetActive", []))

    @jsii.member(jsii_name="resetCname")
    def reset_cname(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCname", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetOptions")
    def reset_options(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOptions", []))

    @jsii.member(jsii_name="resetOriginGroupId")
    def reset_origin_group_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOriginGroupId", []))

    @jsii.member(jsii_name="resetOriginGroupName")
    def reset_origin_group_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOriginGroupName", []))

    @jsii.member(jsii_name="resetOriginProtocol")
    def reset_origin_protocol(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOriginProtocol", []))

    @jsii.member(jsii_name="resetSecondaryHostnames")
    def reset_secondary_hostnames(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecondaryHostnames", []))

    @jsii.member(jsii_name="resetSslCertificate")
    def reset_ssl_certificate(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSslCertificate", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="resetUpdatedAt")
    def reset_updated_at(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdatedAt", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="options")
    def options(self) -> "CdnResourceOptionsOutputReference":
        return typing.cast("CdnResourceOptionsOutputReference", jsii.get(self, "options"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sslCertificate")
    def ssl_certificate(self) -> "CdnResourceSslCertificateOutputReference":
        return typing.cast("CdnResourceSslCertificateOutputReference", jsii.get(self, "sslCertificate"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "CdnResourceTimeoutsOutputReference":
        return typing.cast("CdnResourceTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="activeInput")
    def active_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "activeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cnameInput")
    def cname_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "cnameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="optionsInput")
    def options_input(self) -> typing.Optional["CdnResourceOptions"]:
        return typing.cast(typing.Optional["CdnResourceOptions"], jsii.get(self, "optionsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="originGroupIdInput")
    def origin_group_id_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "originGroupIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="originGroupNameInput")
    def origin_group_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "originGroupNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="originProtocolInput")
    def origin_protocol_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "originProtocolInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="secondaryHostnamesInput")
    def secondary_hostnames_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "secondaryHostnamesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sslCertificateInput")
    def ssl_certificate_input(self) -> typing.Optional["CdnResourceSslCertificate"]:
        return typing.cast(typing.Optional["CdnResourceSslCertificate"], jsii.get(self, "sslCertificateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "CdnResourceTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "CdnResourceTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updatedAtInput")
    def updated_at_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updatedAtInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="active")
    def active(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "active"))

    @active.setter
    def active(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "active", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cname")
    def cname(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "cname"))

    @cname.setter
    def cname(self, value: builtins.str) -> None:
        jsii.set(self, "cname", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="originGroupId")
    def origin_group_id(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "originGroupId"))

    @origin_group_id.setter
    def origin_group_id(self, value: jsii.Number) -> None:
        jsii.set(self, "originGroupId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="originGroupName")
    def origin_group_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "originGroupName"))

    @origin_group_name.setter
    def origin_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "originGroupName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="originProtocol")
    def origin_protocol(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "originProtocol"))

    @origin_protocol.setter
    def origin_protocol(self, value: builtins.str) -> None:
        jsii.set(self, "originProtocol", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="secondaryHostnames")
    def secondary_hostnames(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "secondaryHostnames"))

    @secondary_hostnames.setter
    def secondary_hostnames(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "secondaryHostnames", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updatedAt")
    def updated_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "updatedAt"))

    @updated_at.setter
    def updated_at(self, value: builtins.str) -> None:
        jsii.set(self, "updatedAt", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.CdnResourceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "active": "active",
        "cname": "cname",
        "id": "id",
        "options": "options",
        "origin_group_id": "originGroupId",
        "origin_group_name": "originGroupName",
        "origin_protocol": "originProtocol",
        "secondary_hostnames": "secondaryHostnames",
        "ssl_certificate": "sslCertificate",
        "timeouts": "timeouts",
        "updated_at": "updatedAt",
    },
)
class CdnResourceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        active: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        cname: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        options: typing.Optional["CdnResourceOptions"] = None,
        origin_group_id: typing.Optional[jsii.Number] = None,
        origin_group_name: typing.Optional[builtins.str] = None,
        origin_protocol: typing.Optional[builtins.str] = None,
        secondary_hostnames: typing.Optional[typing.Sequence[builtins.str]] = None,
        ssl_certificate: typing.Optional["CdnResourceSslCertificate"] = None,
        timeouts: typing.Optional["CdnResourceTimeouts"] = None,
        updated_at: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param active: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#active CdnResource#active}.
        :param cname: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#cname CdnResource#cname}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#id CdnResource#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param options: options block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#options CdnResource#options}
        :param origin_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#origin_group_id CdnResource#origin_group_id}.
        :param origin_group_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#origin_group_name CdnResource#origin_group_name}.
        :param origin_protocol: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#origin_protocol CdnResource#origin_protocol}.
        :param secondary_hostnames: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#secondary_hostnames CdnResource#secondary_hostnames}.
        :param ssl_certificate: ssl_certificate block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#ssl_certificate CdnResource#ssl_certificate}
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#timeouts CdnResource#timeouts}
        :param updated_at: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#updated_at CdnResource#updated_at}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(options, dict):
            options = CdnResourceOptions(**options)
        if isinstance(ssl_certificate, dict):
            ssl_certificate = CdnResourceSslCertificate(**ssl_certificate)
        if isinstance(timeouts, dict):
            timeouts = CdnResourceTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if active is not None:
            self._values["active"] = active
        if cname is not None:
            self._values["cname"] = cname
        if id is not None:
            self._values["id"] = id
        if options is not None:
            self._values["options"] = options
        if origin_group_id is not None:
            self._values["origin_group_id"] = origin_group_id
        if origin_group_name is not None:
            self._values["origin_group_name"] = origin_group_name
        if origin_protocol is not None:
            self._values["origin_protocol"] = origin_protocol
        if secondary_hostnames is not None:
            self._values["secondary_hostnames"] = secondary_hostnames
        if ssl_certificate is not None:
            self._values["ssl_certificate"] = ssl_certificate
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if updated_at is not None:
            self._values["updated_at"] = updated_at

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def active(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#active CdnResource#active}.'''
        result = self._values.get("active")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def cname(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#cname CdnResource#cname}.'''
        result = self._values.get("cname")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#id CdnResource#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def options(self) -> typing.Optional["CdnResourceOptions"]:
        '''options block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#options CdnResource#options}
        '''
        result = self._values.get("options")
        return typing.cast(typing.Optional["CdnResourceOptions"], result)

    @builtins.property
    def origin_group_id(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#origin_group_id CdnResource#origin_group_id}.'''
        result = self._values.get("origin_group_id")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def origin_group_name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#origin_group_name CdnResource#origin_group_name}.'''
        result = self._values.get("origin_group_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def origin_protocol(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#origin_protocol CdnResource#origin_protocol}.'''
        result = self._values.get("origin_protocol")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def secondary_hostnames(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#secondary_hostnames CdnResource#secondary_hostnames}.'''
        result = self._values.get("secondary_hostnames")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def ssl_certificate(self) -> typing.Optional["CdnResourceSslCertificate"]:
        '''ssl_certificate block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#ssl_certificate CdnResource#ssl_certificate}
        '''
        result = self._values.get("ssl_certificate")
        return typing.cast(typing.Optional["CdnResourceSslCertificate"], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["CdnResourceTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#timeouts CdnResource#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["CdnResourceTimeouts"], result)

    @builtins.property
    def updated_at(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#updated_at CdnResource#updated_at}.'''
        result = self._values.get("updated_at")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CdnResourceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.CdnResourceOptions",
    jsii_struct_bases=[],
    name_mapping={
        "allowed_http_methods": "allowedHttpMethods",
        "browser_cache_settings": "browserCacheSettings",
        "cache_http_headers": "cacheHttpHeaders",
        "cors": "cors",
        "custom_host_header": "customHostHeader",
        "custom_server_name": "customServerName",
        "disable_cache": "disableCache",
        "disable_proxy_force_ranges": "disableProxyForceRanges",
        "edge_cache_settings": "edgeCacheSettings",
        "fetched_compressed": "fetchedCompressed",
        "forward_host_header": "forwardHostHeader",
        "gzip_on": "gzipOn",
        "ignore_cookie": "ignoreCookie",
        "ignore_query_params": "ignoreQueryParams",
        "proxy_cache_methods_set": "proxyCacheMethodsSet",
        "query_params_blacklist": "queryParamsBlacklist",
        "query_params_whitelist": "queryParamsWhitelist",
        "redirect_https_to_http": "redirectHttpsToHttp",
        "redirect_http_to_https": "redirectHttpToHttps",
        "slice": "slice",
        "static_request_headers": "staticRequestHeaders",
        "static_response_headers": "staticResponseHeaders",
    },
)
class CdnResourceOptions:
    def __init__(
        self,
        *,
        allowed_http_methods: typing.Optional[typing.Sequence[builtins.str]] = None,
        browser_cache_settings: typing.Optional[jsii.Number] = None,
        cache_http_headers: typing.Optional[typing.Sequence[builtins.str]] = None,
        cors: typing.Optional[typing.Sequence[builtins.str]] = None,
        custom_host_header: typing.Optional[builtins.str] = None,
        custom_server_name: typing.Optional[builtins.str] = None,
        disable_cache: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        disable_proxy_force_ranges: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        edge_cache_settings: typing.Optional[jsii.Number] = None,
        fetched_compressed: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        forward_host_header: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        gzip_on: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        ignore_cookie: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        ignore_query_params: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        proxy_cache_methods_set: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        query_params_blacklist: typing.Optional[typing.Sequence[builtins.str]] = None,
        query_params_whitelist: typing.Optional[typing.Sequence[builtins.str]] = None,
        redirect_https_to_http: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        redirect_http_to_https: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        slice: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        static_request_headers: typing.Optional[typing.Sequence[builtins.str]] = None,
        static_response_headers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
    ) -> None:
        '''
        :param allowed_http_methods: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#allowed_http_methods CdnResource#allowed_http_methods}.
        :param browser_cache_settings: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#browser_cache_settings CdnResource#browser_cache_settings}.
        :param cache_http_headers: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#cache_http_headers CdnResource#cache_http_headers}.
        :param cors: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#cors CdnResource#cors}.
        :param custom_host_header: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#custom_host_header CdnResource#custom_host_header}.
        :param custom_server_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#custom_server_name CdnResource#custom_server_name}.
        :param disable_cache: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#disable_cache CdnResource#disable_cache}.
        :param disable_proxy_force_ranges: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#disable_proxy_force_ranges CdnResource#disable_proxy_force_ranges}.
        :param edge_cache_settings: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#edge_cache_settings CdnResource#edge_cache_settings}.
        :param fetched_compressed: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#fetched_compressed CdnResource#fetched_compressed}.
        :param forward_host_header: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#forward_host_header CdnResource#forward_host_header}.
        :param gzip_on: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#gzip_on CdnResource#gzip_on}.
        :param ignore_cookie: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#ignore_cookie CdnResource#ignore_cookie}.
        :param ignore_query_params: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#ignore_query_params CdnResource#ignore_query_params}.
        :param proxy_cache_methods_set: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#proxy_cache_methods_set CdnResource#proxy_cache_methods_set}.
        :param query_params_blacklist: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#query_params_blacklist CdnResource#query_params_blacklist}.
        :param query_params_whitelist: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#query_params_whitelist CdnResource#query_params_whitelist}.
        :param redirect_https_to_http: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#redirect_https_to_http CdnResource#redirect_https_to_http}.
        :param redirect_http_to_https: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#redirect_http_to_https CdnResource#redirect_http_to_https}.
        :param slice: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#slice CdnResource#slice}.
        :param static_request_headers: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#static_request_headers CdnResource#static_request_headers}.
        :param static_response_headers: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#static_response_headers CdnResource#static_response_headers}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if allowed_http_methods is not None:
            self._values["allowed_http_methods"] = allowed_http_methods
        if browser_cache_settings is not None:
            self._values["browser_cache_settings"] = browser_cache_settings
        if cache_http_headers is not None:
            self._values["cache_http_headers"] = cache_http_headers
        if cors is not None:
            self._values["cors"] = cors
        if custom_host_header is not None:
            self._values["custom_host_header"] = custom_host_header
        if custom_server_name is not None:
            self._values["custom_server_name"] = custom_server_name
        if disable_cache is not None:
            self._values["disable_cache"] = disable_cache
        if disable_proxy_force_ranges is not None:
            self._values["disable_proxy_force_ranges"] = disable_proxy_force_ranges
        if edge_cache_settings is not None:
            self._values["edge_cache_settings"] = edge_cache_settings
        if fetched_compressed is not None:
            self._values["fetched_compressed"] = fetched_compressed
        if forward_host_header is not None:
            self._values["forward_host_header"] = forward_host_header
        if gzip_on is not None:
            self._values["gzip_on"] = gzip_on
        if ignore_cookie is not None:
            self._values["ignore_cookie"] = ignore_cookie
        if ignore_query_params is not None:
            self._values["ignore_query_params"] = ignore_query_params
        if proxy_cache_methods_set is not None:
            self._values["proxy_cache_methods_set"] = proxy_cache_methods_set
        if query_params_blacklist is not None:
            self._values["query_params_blacklist"] = query_params_blacklist
        if query_params_whitelist is not None:
            self._values["query_params_whitelist"] = query_params_whitelist
        if redirect_https_to_http is not None:
            self._values["redirect_https_to_http"] = redirect_https_to_http
        if redirect_http_to_https is not None:
            self._values["redirect_http_to_https"] = redirect_http_to_https
        if slice is not None:
            self._values["slice"] = slice
        if static_request_headers is not None:
            self._values["static_request_headers"] = static_request_headers
        if static_response_headers is not None:
            self._values["static_response_headers"] = static_response_headers

    @builtins.property
    def allowed_http_methods(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#allowed_http_methods CdnResource#allowed_http_methods}.'''
        result = self._values.get("allowed_http_methods")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def browser_cache_settings(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#browser_cache_settings CdnResource#browser_cache_settings}.'''
        result = self._values.get("browser_cache_settings")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def cache_http_headers(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#cache_http_headers CdnResource#cache_http_headers}.'''
        result = self._values.get("cache_http_headers")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def cors(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#cors CdnResource#cors}.'''
        result = self._values.get("cors")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def custom_host_header(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#custom_host_header CdnResource#custom_host_header}.'''
        result = self._values.get("custom_host_header")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def custom_server_name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#custom_server_name CdnResource#custom_server_name}.'''
        result = self._values.get("custom_server_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def disable_cache(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#disable_cache CdnResource#disable_cache}.'''
        result = self._values.get("disable_cache")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def disable_proxy_force_ranges(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#disable_proxy_force_ranges CdnResource#disable_proxy_force_ranges}.'''
        result = self._values.get("disable_proxy_force_ranges")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def edge_cache_settings(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#edge_cache_settings CdnResource#edge_cache_settings}.'''
        result = self._values.get("edge_cache_settings")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fetched_compressed(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#fetched_compressed CdnResource#fetched_compressed}.'''
        result = self._values.get("fetched_compressed")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def forward_host_header(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#forward_host_header CdnResource#forward_host_header}.'''
        result = self._values.get("forward_host_header")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def gzip_on(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#gzip_on CdnResource#gzip_on}.'''
        result = self._values.get("gzip_on")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def ignore_cookie(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#ignore_cookie CdnResource#ignore_cookie}.'''
        result = self._values.get("ignore_cookie")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def ignore_query_params(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#ignore_query_params CdnResource#ignore_query_params}.'''
        result = self._values.get("ignore_query_params")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def proxy_cache_methods_set(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#proxy_cache_methods_set CdnResource#proxy_cache_methods_set}.'''
        result = self._values.get("proxy_cache_methods_set")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def query_params_blacklist(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#query_params_blacklist CdnResource#query_params_blacklist}.'''
        result = self._values.get("query_params_blacklist")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def query_params_whitelist(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#query_params_whitelist CdnResource#query_params_whitelist}.'''
        result = self._values.get("query_params_whitelist")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def redirect_https_to_http(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#redirect_https_to_http CdnResource#redirect_https_to_http}.'''
        result = self._values.get("redirect_https_to_http")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def redirect_http_to_https(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#redirect_http_to_https CdnResource#redirect_http_to_https}.'''
        result = self._values.get("redirect_http_to_https")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def slice(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#slice CdnResource#slice}.'''
        result = self._values.get("slice")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def static_request_headers(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#static_request_headers CdnResource#static_request_headers}.'''
        result = self._values.get("static_request_headers")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def static_response_headers(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#static_response_headers CdnResource#static_response_headers}.'''
        result = self._values.get("static_response_headers")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CdnResourceOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CdnResourceOptionsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.CdnResourceOptionsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAllowedHttpMethods")
    def reset_allowed_http_methods(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAllowedHttpMethods", []))

    @jsii.member(jsii_name="resetBrowserCacheSettings")
    def reset_browser_cache_settings(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetBrowserCacheSettings", []))

    @jsii.member(jsii_name="resetCacheHttpHeaders")
    def reset_cache_http_headers(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCacheHttpHeaders", []))

    @jsii.member(jsii_name="resetCors")
    def reset_cors(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCors", []))

    @jsii.member(jsii_name="resetCustomHostHeader")
    def reset_custom_host_header(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomHostHeader", []))

    @jsii.member(jsii_name="resetCustomServerName")
    def reset_custom_server_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomServerName", []))

    @jsii.member(jsii_name="resetDisableCache")
    def reset_disable_cache(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDisableCache", []))

    @jsii.member(jsii_name="resetDisableProxyForceRanges")
    def reset_disable_proxy_force_ranges(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDisableProxyForceRanges", []))

    @jsii.member(jsii_name="resetEdgeCacheSettings")
    def reset_edge_cache_settings(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEdgeCacheSettings", []))

    @jsii.member(jsii_name="resetFetchedCompressed")
    def reset_fetched_compressed(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFetchedCompressed", []))

    @jsii.member(jsii_name="resetForwardHostHeader")
    def reset_forward_host_header(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetForwardHostHeader", []))

    @jsii.member(jsii_name="resetGzipOn")
    def reset_gzip_on(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGzipOn", []))

    @jsii.member(jsii_name="resetIgnoreCookie")
    def reset_ignore_cookie(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIgnoreCookie", []))

    @jsii.member(jsii_name="resetIgnoreQueryParams")
    def reset_ignore_query_params(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIgnoreQueryParams", []))

    @jsii.member(jsii_name="resetProxyCacheMethodsSet")
    def reset_proxy_cache_methods_set(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetProxyCacheMethodsSet", []))

    @jsii.member(jsii_name="resetQueryParamsBlacklist")
    def reset_query_params_blacklist(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQueryParamsBlacklist", []))

    @jsii.member(jsii_name="resetQueryParamsWhitelist")
    def reset_query_params_whitelist(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQueryParamsWhitelist", []))

    @jsii.member(jsii_name="resetRedirectHttpsToHttp")
    def reset_redirect_https_to_http(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRedirectHttpsToHttp", []))

    @jsii.member(jsii_name="resetRedirectHttpToHttps")
    def reset_redirect_http_to_https(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRedirectHttpToHttps", []))

    @jsii.member(jsii_name="resetSlice")
    def reset_slice(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSlice", []))

    @jsii.member(jsii_name="resetStaticRequestHeaders")
    def reset_static_request_headers(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStaticRequestHeaders", []))

    @jsii.member(jsii_name="resetStaticResponseHeaders")
    def reset_static_response_headers(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStaticResponseHeaders", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allowedHttpMethodsInput")
    def allowed_http_methods_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "allowedHttpMethodsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="browserCacheSettingsInput")
    def browser_cache_settings_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "browserCacheSettingsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cacheHttpHeadersInput")
    def cache_http_headers_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "cacheHttpHeadersInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="corsInput")
    def cors_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "corsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="customHostHeaderInput")
    def custom_host_header_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "customHostHeaderInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="customServerNameInput")
    def custom_server_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "customServerNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="disableCacheInput")
    def disable_cache_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "disableCacheInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="disableProxyForceRangesInput")
    def disable_proxy_force_ranges_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "disableProxyForceRangesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="edgeCacheSettingsInput")
    def edge_cache_settings_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "edgeCacheSettingsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fetchedCompressedInput")
    def fetched_compressed_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "fetchedCompressedInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="forwardHostHeaderInput")
    def forward_host_header_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "forwardHostHeaderInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="gzipOnInput")
    def gzip_on_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "gzipOnInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ignoreCookieInput")
    def ignore_cookie_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "ignoreCookieInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ignoreQueryParamsInput")
    def ignore_query_params_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "ignoreQueryParamsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="proxyCacheMethodsSetInput")
    def proxy_cache_methods_set_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "proxyCacheMethodsSetInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queryParamsBlacklistInput")
    def query_params_blacklist_input(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "queryParamsBlacklistInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queryParamsWhitelistInput")
    def query_params_whitelist_input(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "queryParamsWhitelistInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="redirectHttpsToHttpInput")
    def redirect_https_to_http_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "redirectHttpsToHttpInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="redirectHttpToHttpsInput")
    def redirect_http_to_https_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "redirectHttpToHttpsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sliceInput")
    def slice_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "sliceInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="staticRequestHeadersInput")
    def static_request_headers_input(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "staticRequestHeadersInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="staticResponseHeadersInput")
    def static_response_headers_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "staticResponseHeadersInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allowedHttpMethods")
    def allowed_http_methods(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "allowedHttpMethods"))

    @allowed_http_methods.setter
    def allowed_http_methods(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "allowedHttpMethods", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="browserCacheSettings")
    def browser_cache_settings(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "browserCacheSettings"))

    @browser_cache_settings.setter
    def browser_cache_settings(self, value: jsii.Number) -> None:
        jsii.set(self, "browserCacheSettings", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cacheHttpHeaders")
    def cache_http_headers(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "cacheHttpHeaders"))

    @cache_http_headers.setter
    def cache_http_headers(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "cacheHttpHeaders", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cors")
    def cors(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "cors"))

    @cors.setter
    def cors(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "cors", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="customHostHeader")
    def custom_host_header(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "customHostHeader"))

    @custom_host_header.setter
    def custom_host_header(self, value: builtins.str) -> None:
        jsii.set(self, "customHostHeader", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="customServerName")
    def custom_server_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "customServerName"))

    @custom_server_name.setter
    def custom_server_name(self, value: builtins.str) -> None:
        jsii.set(self, "customServerName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="disableCache")
    def disable_cache(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "disableCache"))

    @disable_cache.setter
    def disable_cache(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "disableCache", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="disableProxyForceRanges")
    def disable_proxy_force_ranges(
        self,
    ) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "disableProxyForceRanges"))

    @disable_proxy_force_ranges.setter
    def disable_proxy_force_ranges(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "disableProxyForceRanges", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="edgeCacheSettings")
    def edge_cache_settings(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "edgeCacheSettings"))

    @edge_cache_settings.setter
    def edge_cache_settings(self, value: jsii.Number) -> None:
        jsii.set(self, "edgeCacheSettings", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fetchedCompressed")
    def fetched_compressed(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "fetchedCompressed"))

    @fetched_compressed.setter
    def fetched_compressed(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "fetchedCompressed", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="forwardHostHeader")
    def forward_host_header(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "forwardHostHeader"))

    @forward_host_header.setter
    def forward_host_header(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "forwardHostHeader", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="gzipOn")
    def gzip_on(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "gzipOn"))

    @gzip_on.setter
    def gzip_on(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "gzipOn", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ignoreCookie")
    def ignore_cookie(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "ignoreCookie"))

    @ignore_cookie.setter
    def ignore_cookie(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "ignoreCookie", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ignoreQueryParams")
    def ignore_query_params(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "ignoreQueryParams"))

    @ignore_query_params.setter
    def ignore_query_params(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "ignoreQueryParams", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="proxyCacheMethodsSet")
    def proxy_cache_methods_set(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "proxyCacheMethodsSet"))

    @proxy_cache_methods_set.setter
    def proxy_cache_methods_set(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "proxyCacheMethodsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queryParamsBlacklist")
    def query_params_blacklist(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "queryParamsBlacklist"))

    @query_params_blacklist.setter
    def query_params_blacklist(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "queryParamsBlacklist", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queryParamsWhitelist")
    def query_params_whitelist(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "queryParamsWhitelist"))

    @query_params_whitelist.setter
    def query_params_whitelist(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "queryParamsWhitelist", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="redirectHttpsToHttp")
    def redirect_https_to_http(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "redirectHttpsToHttp"))

    @redirect_https_to_http.setter
    def redirect_https_to_http(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "redirectHttpsToHttp", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="redirectHttpToHttps")
    def redirect_http_to_https(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "redirectHttpToHttps"))

    @redirect_http_to_https.setter
    def redirect_http_to_https(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "redirectHttpToHttps", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="slice")
    def slice(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "slice"))

    @slice.setter
    def slice(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "slice", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="staticRequestHeaders")
    def static_request_headers(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "staticRequestHeaders"))

    @static_request_headers.setter
    def static_request_headers(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "staticRequestHeaders", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="staticResponseHeaders")
    def static_response_headers(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "staticResponseHeaders"))

    @static_response_headers.setter
    def static_response_headers(
        self,
        value: typing.Mapping[builtins.str, builtins.str],
    ) -> None:
        jsii.set(self, "staticResponseHeaders", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[CdnResourceOptions]:
        return typing.cast(typing.Optional[CdnResourceOptions], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(self, value: typing.Optional[CdnResourceOptions]) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.CdnResourceSslCertificate",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "certificate_manager_id": "certificateManagerId"},
)
class CdnResourceSslCertificate:
    def __init__(
        self,
        *,
        type: builtins.str,
        certificate_manager_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#type CdnResource#type}.
        :param certificate_manager_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#certificate_manager_id CdnResource#certificate_manager_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }
        if certificate_manager_id is not None:
            self._values["certificate_manager_id"] = certificate_manager_id

    @builtins.property
    def type(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#type CdnResource#type}.'''
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def certificate_manager_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#certificate_manager_id CdnResource#certificate_manager_id}.'''
        result = self._values.get("certificate_manager_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CdnResourceSslCertificate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CdnResourceSslCertificateOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.CdnResourceSslCertificateOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCertificateManagerId")
    def reset_certificate_manager_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCertificateManagerId", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="certificateManagerIdInput")
    def certificate_manager_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "certificateManagerIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="typeInput")
    def type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "typeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="certificateManagerId")
    def certificate_manager_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "certificateManagerId"))

    @certificate_manager_id.setter
    def certificate_manager_id(self, value: builtins.str) -> None:
        jsii.set(self, "certificateManagerId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @type.setter
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[CdnResourceSslCertificate]:
        return typing.cast(typing.Optional[CdnResourceSslCertificate], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(self, value: typing.Optional[CdnResourceSslCertificate]) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.CdnResourceTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class CdnResourceTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#create CdnResource#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#delete CdnResource#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#update CdnResource#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#create CdnResource#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#delete CdnResource#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/cdn_resource#update CdnResource#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CdnResourceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CdnResourceTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.CdnResourceTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, CdnResourceTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, CdnResourceTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, CdnResourceTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ComputeDisk(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeDisk",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk yandex_compute_disk}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        block_size: typing.Optional[jsii.Number] = None,
        description: typing.Optional[builtins.str] = None,
        disk_placement_policy: typing.Optional["ComputeDiskDiskPlacementPolicy"] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        image_id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        size: typing.Optional[jsii.Number] = None,
        snapshot_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ComputeDiskTimeouts"] = None,
        type: typing.Optional[builtins.str] = None,
        zone: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk yandex_compute_disk} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param block_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#block_size ComputeDisk#block_size}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#description ComputeDisk#description}.
        :param disk_placement_policy: disk_placement_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#disk_placement_policy ComputeDisk#disk_placement_policy}
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#folder_id ComputeDisk#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#id ComputeDisk#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param image_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#image_id ComputeDisk#image_id}.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#labels ComputeDisk#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#name ComputeDisk#name}.
        :param size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#size ComputeDisk#size}.
        :param snapshot_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#snapshot_id ComputeDisk#snapshot_id}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#timeouts ComputeDisk#timeouts}
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#type ComputeDisk#type}.
        :param zone: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#zone ComputeDisk#zone}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = ComputeDiskConfig(
            block_size=block_size,
            description=description,
            disk_placement_policy=disk_placement_policy,
            folder_id=folder_id,
            id=id,
            image_id=image_id,
            labels=labels,
            name=name,
            size=size,
            snapshot_id=snapshot_id,
            timeouts=timeouts,
            type=type,
            zone=zone,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putDiskPlacementPolicy")
    def put_disk_placement_policy(
        self,
        *,
        disk_placement_group_id: builtins.str,
    ) -> None:
        '''
        :param disk_placement_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#disk_placement_group_id ComputeDisk#disk_placement_group_id}.
        '''
        value = ComputeDiskDiskPlacementPolicy(
            disk_placement_group_id=disk_placement_group_id
        )

        return typing.cast(None, jsii.invoke(self, "putDiskPlacementPolicy", [value]))

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#create ComputeDisk#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#delete ComputeDisk#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#update ComputeDisk#update}.
        '''
        value = ComputeDiskTimeouts(create=create, delete=delete, update=update)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetBlockSize")
    def reset_block_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetBlockSize", []))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetDiskPlacementPolicy")
    def reset_disk_placement_policy(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDiskPlacementPolicy", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetImageId")
    def reset_image_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetImageId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetSize")
    def reset_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSize", []))

    @jsii.member(jsii_name="resetSnapshotId")
    def reset_snapshot_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSnapshotId", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="resetType")
    def reset_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetType", []))

    @jsii.member(jsii_name="resetZone")
    def reset_zone(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetZone", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskPlacementPolicy")
    def disk_placement_policy(self) -> "ComputeDiskDiskPlacementPolicyOutputReference":
        return typing.cast("ComputeDiskDiskPlacementPolicyOutputReference", jsii.get(self, "diskPlacementPolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="productIds")
    def product_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "productIds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "ComputeDiskTimeoutsOutputReference":
        return typing.cast("ComputeDiskTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="blockSizeInput")
    def block_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "blockSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskPlacementPolicyInput")
    def disk_placement_policy_input(
        self,
    ) -> typing.Optional["ComputeDiskDiskPlacementPolicy"]:
        return typing.cast(typing.Optional["ComputeDiskDiskPlacementPolicy"], jsii.get(self, "diskPlacementPolicyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="imageIdInput")
    def image_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "imageIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sizeInput")
    def size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "sizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="snapshotIdInput")
    def snapshot_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "snapshotIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "ComputeDiskTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "ComputeDiskTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="typeInput")
    def type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "typeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneInput")
    def zone_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "zoneInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="blockSize")
    def block_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "blockSize"))

    @block_size.setter
    def block_size(self, value: jsii.Number) -> None:
        jsii.set(self, "blockSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="imageId")
    def image_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "imageId"))

    @image_id.setter
    def image_id(self, value: builtins.str) -> None:
        jsii.set(self, "imageId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="size")
    def size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "size"))

    @size.setter
    def size(self, value: jsii.Number) -> None:
        jsii.set(self, "size", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="snapshotId")
    def snapshot_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "snapshotId"))

    @snapshot_id.setter
    def snapshot_id(self, value: builtins.str) -> None:
        jsii.set(self, "snapshotId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @type.setter
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zone")
    def zone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zone"))

    @zone.setter
    def zone(self, value: builtins.str) -> None:
        jsii.set(self, "zone", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeDiskConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "block_size": "blockSize",
        "description": "description",
        "disk_placement_policy": "diskPlacementPolicy",
        "folder_id": "folderId",
        "id": "id",
        "image_id": "imageId",
        "labels": "labels",
        "name": "name",
        "size": "size",
        "snapshot_id": "snapshotId",
        "timeouts": "timeouts",
        "type": "type",
        "zone": "zone",
    },
)
class ComputeDiskConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        block_size: typing.Optional[jsii.Number] = None,
        description: typing.Optional[builtins.str] = None,
        disk_placement_policy: typing.Optional["ComputeDiskDiskPlacementPolicy"] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        image_id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        size: typing.Optional[jsii.Number] = None,
        snapshot_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ComputeDiskTimeouts"] = None,
        type: typing.Optional[builtins.str] = None,
        zone: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param block_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#block_size ComputeDisk#block_size}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#description ComputeDisk#description}.
        :param disk_placement_policy: disk_placement_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#disk_placement_policy ComputeDisk#disk_placement_policy}
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#folder_id ComputeDisk#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#id ComputeDisk#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param image_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#image_id ComputeDisk#image_id}.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#labels ComputeDisk#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#name ComputeDisk#name}.
        :param size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#size ComputeDisk#size}.
        :param snapshot_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#snapshot_id ComputeDisk#snapshot_id}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#timeouts ComputeDisk#timeouts}
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#type ComputeDisk#type}.
        :param zone: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#zone ComputeDisk#zone}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(disk_placement_policy, dict):
            disk_placement_policy = ComputeDiskDiskPlacementPolicy(**disk_placement_policy)
        if isinstance(timeouts, dict):
            timeouts = ComputeDiskTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if block_size is not None:
            self._values["block_size"] = block_size
        if description is not None:
            self._values["description"] = description
        if disk_placement_policy is not None:
            self._values["disk_placement_policy"] = disk_placement_policy
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if image_id is not None:
            self._values["image_id"] = image_id
        if labels is not None:
            self._values["labels"] = labels
        if name is not None:
            self._values["name"] = name
        if size is not None:
            self._values["size"] = size
        if snapshot_id is not None:
            self._values["snapshot_id"] = snapshot_id
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if type is not None:
            self._values["type"] = type
        if zone is not None:
            self._values["zone"] = zone

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def block_size(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#block_size ComputeDisk#block_size}.'''
        result = self._values.get("block_size")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#description ComputeDisk#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def disk_placement_policy(
        self,
    ) -> typing.Optional["ComputeDiskDiskPlacementPolicy"]:
        '''disk_placement_policy block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#disk_placement_policy ComputeDisk#disk_placement_policy}
        '''
        result = self._values.get("disk_placement_policy")
        return typing.cast(typing.Optional["ComputeDiskDiskPlacementPolicy"], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#folder_id ComputeDisk#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#id ComputeDisk#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def image_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#image_id ComputeDisk#image_id}.'''
        result = self._values.get("image_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#labels ComputeDisk#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#name ComputeDisk#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def size(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#size ComputeDisk#size}.'''
        result = self._values.get("size")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def snapshot_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#snapshot_id ComputeDisk#snapshot_id}.'''
        result = self._values.get("snapshot_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["ComputeDiskTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#timeouts ComputeDisk#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["ComputeDiskTimeouts"], result)

    @builtins.property
    def type(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#type ComputeDisk#type}.'''
        result = self._values.get("type")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def zone(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#zone ComputeDisk#zone}.'''
        result = self._values.get("zone")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeDiskConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeDiskDiskPlacementPolicy",
    jsii_struct_bases=[],
    name_mapping={"disk_placement_group_id": "diskPlacementGroupId"},
)
class ComputeDiskDiskPlacementPolicy:
    def __init__(self, *, disk_placement_group_id: builtins.str) -> None:
        '''
        :param disk_placement_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#disk_placement_group_id ComputeDisk#disk_placement_group_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "disk_placement_group_id": disk_placement_group_id,
        }

    @builtins.property
    def disk_placement_group_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#disk_placement_group_id ComputeDisk#disk_placement_group_id}.'''
        result = self._values.get("disk_placement_group_id")
        assert result is not None, "Required property 'disk_placement_group_id' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeDiskDiskPlacementPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeDiskDiskPlacementPolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeDiskDiskPlacementPolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskPlacementGroupIdInput")
    def disk_placement_group_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "diskPlacementGroupIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskPlacementGroupId")
    def disk_placement_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskPlacementGroupId"))

    @disk_placement_group_id.setter
    def disk_placement_group_id(self, value: builtins.str) -> None:
        jsii.set(self, "diskPlacementGroupId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[ComputeDiskDiskPlacementPolicy]:
        return typing.cast(typing.Optional[ComputeDiskDiskPlacementPolicy], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[ComputeDiskDiskPlacementPolicy],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ComputeDiskPlacementGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeDiskPlacementGroup",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk_placement_group yandex_compute_disk_placement_group}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ComputeDiskPlacementGroupTimeouts"] = None,
        zone: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk_placement_group yandex_compute_disk_placement_group} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk_placement_group#description ComputeDiskPlacementGroup#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk_placement_group#folder_id ComputeDiskPlacementGroup#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk_placement_group#id ComputeDiskPlacementGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk_placement_group#labels ComputeDiskPlacementGroup#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk_placement_group#name ComputeDiskPlacementGroup#name}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk_placement_group#timeouts ComputeDiskPlacementGroup#timeouts}
        :param zone: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk_placement_group#zone ComputeDiskPlacementGroup#zone}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = ComputeDiskPlacementGroupConfig(
            description=description,
            folder_id=folder_id,
            id=id,
            labels=labels,
            name=name,
            timeouts=timeouts,
            zone=zone,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk_placement_group#create ComputeDiskPlacementGroup#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk_placement_group#delete ComputeDiskPlacementGroup#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk_placement_group#update ComputeDiskPlacementGroup#update}.
        '''
        value = ComputeDiskPlacementGroupTimeouts(
            create=create, delete=delete, update=update
        )

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="resetZone")
    def reset_zone(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetZone", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "ComputeDiskPlacementGroupTimeoutsOutputReference":
        return typing.cast("ComputeDiskPlacementGroupTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "ComputeDiskPlacementGroupTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "ComputeDiskPlacementGroupTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneInput")
    def zone_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "zoneInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zone")
    def zone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zone"))

    @zone.setter
    def zone(self, value: builtins.str) -> None:
        jsii.set(self, "zone", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeDiskPlacementGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "description": "description",
        "folder_id": "folderId",
        "id": "id",
        "labels": "labels",
        "name": "name",
        "timeouts": "timeouts",
        "zone": "zone",
    },
)
class ComputeDiskPlacementGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ComputeDiskPlacementGroupTimeouts"] = None,
        zone: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk_placement_group#description ComputeDiskPlacementGroup#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk_placement_group#folder_id ComputeDiskPlacementGroup#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk_placement_group#id ComputeDiskPlacementGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk_placement_group#labels ComputeDiskPlacementGroup#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk_placement_group#name ComputeDiskPlacementGroup#name}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk_placement_group#timeouts ComputeDiskPlacementGroup#timeouts}
        :param zone: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk_placement_group#zone ComputeDiskPlacementGroup#zone}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ComputeDiskPlacementGroupTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if name is not None:
            self._values["name"] = name
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if zone is not None:
            self._values["zone"] = zone

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk_placement_group#description ComputeDiskPlacementGroup#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk_placement_group#folder_id ComputeDiskPlacementGroup#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk_placement_group#id ComputeDiskPlacementGroup#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk_placement_group#labels ComputeDiskPlacementGroup#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk_placement_group#name ComputeDiskPlacementGroup#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["ComputeDiskPlacementGroupTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk_placement_group#timeouts ComputeDiskPlacementGroup#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["ComputeDiskPlacementGroupTimeouts"], result)

    @builtins.property
    def zone(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk_placement_group#zone ComputeDiskPlacementGroup#zone}.'''
        result = self._values.get("zone")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeDiskPlacementGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeDiskPlacementGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class ComputeDiskPlacementGroupTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk_placement_group#create ComputeDiskPlacementGroup#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk_placement_group#delete ComputeDiskPlacementGroup#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk_placement_group#update ComputeDiskPlacementGroup#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk_placement_group#create ComputeDiskPlacementGroup#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk_placement_group#delete ComputeDiskPlacementGroup#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk_placement_group#update ComputeDiskPlacementGroup#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeDiskPlacementGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeDiskPlacementGroupTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeDiskPlacementGroupTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, ComputeDiskPlacementGroupTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, ComputeDiskPlacementGroupTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, ComputeDiskPlacementGroupTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeDiskTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class ComputeDiskTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#create ComputeDisk#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#delete ComputeDisk#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#update ComputeDisk#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#create ComputeDisk#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#delete ComputeDisk#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_disk#update ComputeDisk#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeDiskTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeDiskTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeDiskTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, ComputeDiskTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, ComputeDiskTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, ComputeDiskTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ComputeImage(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeImage",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/compute_image yandex_compute_image}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        description: typing.Optional[builtins.str] = None,
        family: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        min_disk_size: typing.Optional[jsii.Number] = None,
        name: typing.Optional[builtins.str] = None,
        os_type: typing.Optional[builtins.str] = None,
        pooled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        product_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        source_disk: typing.Optional[builtins.str] = None,
        source_family: typing.Optional[builtins.str] = None,
        source_image: typing.Optional[builtins.str] = None,
        source_snapshot: typing.Optional[builtins.str] = None,
        source_url: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ComputeImageTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/compute_image yandex_compute_image} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#description ComputeImage#description}.
        :param family: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#family ComputeImage#family}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#folder_id ComputeImage#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#id ComputeImage#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#labels ComputeImage#labels}.
        :param min_disk_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#min_disk_size ComputeImage#min_disk_size}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#name ComputeImage#name}.
        :param os_type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#os_type ComputeImage#os_type}.
        :param pooled: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#pooled ComputeImage#pooled}.
        :param product_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#product_ids ComputeImage#product_ids}.
        :param source_disk: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#source_disk ComputeImage#source_disk}.
        :param source_family: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#source_family ComputeImage#source_family}.
        :param source_image: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#source_image ComputeImage#source_image}.
        :param source_snapshot: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#source_snapshot ComputeImage#source_snapshot}.
        :param source_url: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#source_url ComputeImage#source_url}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#timeouts ComputeImage#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = ComputeImageConfig(
            description=description,
            family=family,
            folder_id=folder_id,
            id=id,
            labels=labels,
            min_disk_size=min_disk_size,
            name=name,
            os_type=os_type,
            pooled=pooled,
            product_ids=product_ids,
            source_disk=source_disk,
            source_family=source_family,
            source_image=source_image,
            source_snapshot=source_snapshot,
            source_url=source_url,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#create ComputeImage#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#delete ComputeImage#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#update ComputeImage#update}.
        '''
        value = ComputeImageTimeouts(create=create, delete=delete, update=update)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFamily")
    def reset_family(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFamily", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetMinDiskSize")
    def reset_min_disk_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMinDiskSize", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetOsType")
    def reset_os_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOsType", []))

    @jsii.member(jsii_name="resetPooled")
    def reset_pooled(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPooled", []))

    @jsii.member(jsii_name="resetProductIds")
    def reset_product_ids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetProductIds", []))

    @jsii.member(jsii_name="resetSourceDisk")
    def reset_source_disk(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSourceDisk", []))

    @jsii.member(jsii_name="resetSourceFamily")
    def reset_source_family(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSourceFamily", []))

    @jsii.member(jsii_name="resetSourceImage")
    def reset_source_image(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSourceImage", []))

    @jsii.member(jsii_name="resetSourceSnapshot")
    def reset_source_snapshot(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSourceSnapshot", []))

    @jsii.member(jsii_name="resetSourceUrl")
    def reset_source_url(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSourceUrl", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="size")
    def size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "size"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "ComputeImageTimeoutsOutputReference":
        return typing.cast("ComputeImageTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="familyInput")
    def family_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "familyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minDiskSizeInput")
    def min_disk_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "minDiskSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="osTypeInput")
    def os_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "osTypeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="pooledInput")
    def pooled_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "pooledInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="productIdsInput")
    def product_ids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "productIdsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sourceDiskInput")
    def source_disk_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sourceDiskInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sourceFamilyInput")
    def source_family_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sourceFamilyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sourceImageInput")
    def source_image_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sourceImageInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sourceSnapshotInput")
    def source_snapshot_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sourceSnapshotInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sourceUrlInput")
    def source_url_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sourceUrlInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "ComputeImageTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "ComputeImageTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="family")
    def family(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "family"))

    @family.setter
    def family(self, value: builtins.str) -> None:
        jsii.set(self, "family", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minDiskSize")
    def min_disk_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minDiskSize"))

    @min_disk_size.setter
    def min_disk_size(self, value: jsii.Number) -> None:
        jsii.set(self, "minDiskSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="osType")
    def os_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "osType"))

    @os_type.setter
    def os_type(self, value: builtins.str) -> None:
        jsii.set(self, "osType", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="pooled")
    def pooled(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "pooled"))

    @pooled.setter
    def pooled(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "pooled", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="productIds")
    def product_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "productIds"))

    @product_ids.setter
    def product_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "productIds", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sourceDisk")
    def source_disk(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sourceDisk"))

    @source_disk.setter
    def source_disk(self, value: builtins.str) -> None:
        jsii.set(self, "sourceDisk", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sourceFamily")
    def source_family(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sourceFamily"))

    @source_family.setter
    def source_family(self, value: builtins.str) -> None:
        jsii.set(self, "sourceFamily", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sourceImage")
    def source_image(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sourceImage"))

    @source_image.setter
    def source_image(self, value: builtins.str) -> None:
        jsii.set(self, "sourceImage", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sourceSnapshot")
    def source_snapshot(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sourceSnapshot"))

    @source_snapshot.setter
    def source_snapshot(self, value: builtins.str) -> None:
        jsii.set(self, "sourceSnapshot", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sourceUrl")
    def source_url(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sourceUrl"))

    @source_url.setter
    def source_url(self, value: builtins.str) -> None:
        jsii.set(self, "sourceUrl", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeImageConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "description": "description",
        "family": "family",
        "folder_id": "folderId",
        "id": "id",
        "labels": "labels",
        "min_disk_size": "minDiskSize",
        "name": "name",
        "os_type": "osType",
        "pooled": "pooled",
        "product_ids": "productIds",
        "source_disk": "sourceDisk",
        "source_family": "sourceFamily",
        "source_image": "sourceImage",
        "source_snapshot": "sourceSnapshot",
        "source_url": "sourceUrl",
        "timeouts": "timeouts",
    },
)
class ComputeImageConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        description: typing.Optional[builtins.str] = None,
        family: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        min_disk_size: typing.Optional[jsii.Number] = None,
        name: typing.Optional[builtins.str] = None,
        os_type: typing.Optional[builtins.str] = None,
        pooled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        product_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        source_disk: typing.Optional[builtins.str] = None,
        source_family: typing.Optional[builtins.str] = None,
        source_image: typing.Optional[builtins.str] = None,
        source_snapshot: typing.Optional[builtins.str] = None,
        source_url: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ComputeImageTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#description ComputeImage#description}.
        :param family: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#family ComputeImage#family}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#folder_id ComputeImage#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#id ComputeImage#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#labels ComputeImage#labels}.
        :param min_disk_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#min_disk_size ComputeImage#min_disk_size}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#name ComputeImage#name}.
        :param os_type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#os_type ComputeImage#os_type}.
        :param pooled: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#pooled ComputeImage#pooled}.
        :param product_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#product_ids ComputeImage#product_ids}.
        :param source_disk: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#source_disk ComputeImage#source_disk}.
        :param source_family: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#source_family ComputeImage#source_family}.
        :param source_image: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#source_image ComputeImage#source_image}.
        :param source_snapshot: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#source_snapshot ComputeImage#source_snapshot}.
        :param source_url: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#source_url ComputeImage#source_url}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#timeouts ComputeImage#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ComputeImageTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if family is not None:
            self._values["family"] = family
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if min_disk_size is not None:
            self._values["min_disk_size"] = min_disk_size
        if name is not None:
            self._values["name"] = name
        if os_type is not None:
            self._values["os_type"] = os_type
        if pooled is not None:
            self._values["pooled"] = pooled
        if product_ids is not None:
            self._values["product_ids"] = product_ids
        if source_disk is not None:
            self._values["source_disk"] = source_disk
        if source_family is not None:
            self._values["source_family"] = source_family
        if source_image is not None:
            self._values["source_image"] = source_image
        if source_snapshot is not None:
            self._values["source_snapshot"] = source_snapshot
        if source_url is not None:
            self._values["source_url"] = source_url
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#description ComputeImage#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def family(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#family ComputeImage#family}.'''
        result = self._values.get("family")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#folder_id ComputeImage#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#id ComputeImage#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#labels ComputeImage#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def min_disk_size(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#min_disk_size ComputeImage#min_disk_size}.'''
        result = self._values.get("min_disk_size")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#name ComputeImage#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def os_type(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#os_type ComputeImage#os_type}.'''
        result = self._values.get("os_type")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def pooled(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#pooled ComputeImage#pooled}.'''
        result = self._values.get("pooled")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def product_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#product_ids ComputeImage#product_ids}.'''
        result = self._values.get("product_ids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def source_disk(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#source_disk ComputeImage#source_disk}.'''
        result = self._values.get("source_disk")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def source_family(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#source_family ComputeImage#source_family}.'''
        result = self._values.get("source_family")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def source_image(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#source_image ComputeImage#source_image}.'''
        result = self._values.get("source_image")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def source_snapshot(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#source_snapshot ComputeImage#source_snapshot}.'''
        result = self._values.get("source_snapshot")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def source_url(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#source_url ComputeImage#source_url}.'''
        result = self._values.get("source_url")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["ComputeImageTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#timeouts ComputeImage#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["ComputeImageTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeImageConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeImageTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class ComputeImageTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#create ComputeImage#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#delete ComputeImage#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#update ComputeImage#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#create ComputeImage#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#delete ComputeImage#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_image#update ComputeImage#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeImageTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeImageTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeImageTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, ComputeImageTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, ComputeImageTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, ComputeImageTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ComputeInstance(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstance",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance yandex_compute_instance}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        boot_disk: "ComputeInstanceBootDisk",
        network_interface: typing.Union[cdktf.IResolvable, typing.Sequence["ComputeInstanceNetworkInterface"]],
        resources: "ComputeInstanceResources",
        allow_stopping_for_update: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        hostname: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        metadata: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        network_acceleration_type: typing.Optional[builtins.str] = None,
        placement_policy: typing.Optional["ComputeInstancePlacementPolicy"] = None,
        platform_id: typing.Optional[builtins.str] = None,
        scheduling_policy: typing.Optional["ComputeInstanceSchedulingPolicy"] = None,
        secondary_disk: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["ComputeInstanceSecondaryDisk"]]] = None,
        service_account_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ComputeInstanceTimeouts"] = None,
        zone: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance yandex_compute_instance} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param boot_disk: boot_disk block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#boot_disk ComputeInstance#boot_disk}
        :param network_interface: network_interface block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#network_interface ComputeInstance#network_interface}
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#resources ComputeInstance#resources}
        :param allow_stopping_for_update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#allow_stopping_for_update ComputeInstance#allow_stopping_for_update}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#description ComputeInstance#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#folder_id ComputeInstance#folder_id}.
        :param hostname: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#hostname ComputeInstance#hostname}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#id ComputeInstance#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#labels ComputeInstance#labels}.
        :param metadata: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#metadata ComputeInstance#metadata}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#name ComputeInstance#name}.
        :param network_acceleration_type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#network_acceleration_type ComputeInstance#network_acceleration_type}.
        :param placement_policy: placement_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#placement_policy ComputeInstance#placement_policy}
        :param platform_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#platform_id ComputeInstance#platform_id}.
        :param scheduling_policy: scheduling_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#scheduling_policy ComputeInstance#scheduling_policy}
        :param secondary_disk: secondary_disk block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#secondary_disk ComputeInstance#secondary_disk}
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#service_account_id ComputeInstance#service_account_id}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#timeouts ComputeInstance#timeouts}
        :param zone: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#zone ComputeInstance#zone}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = ComputeInstanceConfig(
            boot_disk=boot_disk,
            network_interface=network_interface,
            resources=resources,
            allow_stopping_for_update=allow_stopping_for_update,
            description=description,
            folder_id=folder_id,
            hostname=hostname,
            id=id,
            labels=labels,
            metadata=metadata,
            name=name,
            network_acceleration_type=network_acceleration_type,
            placement_policy=placement_policy,
            platform_id=platform_id,
            scheduling_policy=scheduling_policy,
            secondary_disk=secondary_disk,
            service_account_id=service_account_id,
            timeouts=timeouts,
            zone=zone,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putBootDisk")
    def put_boot_disk(
        self,
        *,
        auto_delete: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        device_name: typing.Optional[builtins.str] = None,
        disk_id: typing.Optional[builtins.str] = None,
        initialize_params: typing.Optional["ComputeInstanceBootDiskInitializeParams"] = None,
        mode: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param auto_delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#auto_delete ComputeInstance#auto_delete}.
        :param device_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#device_name ComputeInstance#device_name}.
        :param disk_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#disk_id ComputeInstance#disk_id}.
        :param initialize_params: initialize_params block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#initialize_params ComputeInstance#initialize_params}
        :param mode: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#mode ComputeInstance#mode}.
        '''
        value = ComputeInstanceBootDisk(
            auto_delete=auto_delete,
            device_name=device_name,
            disk_id=disk_id,
            initialize_params=initialize_params,
            mode=mode,
        )

        return typing.cast(None, jsii.invoke(self, "putBootDisk", [value]))

    @jsii.member(jsii_name="putNetworkInterface")
    def put_network_interface(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["ComputeInstanceNetworkInterface"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putNetworkInterface", [value]))

    @jsii.member(jsii_name="putPlacementPolicy")
    def put_placement_policy(
        self,
        *,
        host_affinity_rules: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["ComputeInstancePlacementPolicyHostAffinityRules"]]] = None,
        placement_group_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param host_affinity_rules: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#host_affinity_rules ComputeInstance#host_affinity_rules}.
        :param placement_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#placement_group_id ComputeInstance#placement_group_id}.
        '''
        value = ComputeInstancePlacementPolicy(
            host_affinity_rules=host_affinity_rules,
            placement_group_id=placement_group_id,
        )

        return typing.cast(None, jsii.invoke(self, "putPlacementPolicy", [value]))

    @jsii.member(jsii_name="putResources")
    def put_resources(
        self,
        *,
        cores: jsii.Number,
        memory: jsii.Number,
        core_fraction: typing.Optional[jsii.Number] = None,
        gpus: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param cores: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#cores ComputeInstance#cores}.
        :param memory: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#memory ComputeInstance#memory}.
        :param core_fraction: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#core_fraction ComputeInstance#core_fraction}.
        :param gpus: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#gpus ComputeInstance#gpus}.
        '''
        value = ComputeInstanceResources(
            cores=cores, memory=memory, core_fraction=core_fraction, gpus=gpus
        )

        return typing.cast(None, jsii.invoke(self, "putResources", [value]))

    @jsii.member(jsii_name="putSchedulingPolicy")
    def put_scheduling_policy(
        self,
        *,
        preemptible: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param preemptible: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#preemptible ComputeInstance#preemptible}.
        '''
        value = ComputeInstanceSchedulingPolicy(preemptible=preemptible)

        return typing.cast(None, jsii.invoke(self, "putSchedulingPolicy", [value]))

    @jsii.member(jsii_name="putSecondaryDisk")
    def put_secondary_disk(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["ComputeInstanceSecondaryDisk"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putSecondaryDisk", [value]))

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#create ComputeInstance#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#delete ComputeInstance#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#update ComputeInstance#update}.
        '''
        value = ComputeInstanceTimeouts(create=create, delete=delete, update=update)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetAllowStoppingForUpdate")
    def reset_allow_stopping_for_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAllowStoppingForUpdate", []))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetHostname")
    def reset_hostname(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHostname", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetMetadata")
    def reset_metadata(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetadata", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetNetworkAccelerationType")
    def reset_network_acceleration_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNetworkAccelerationType", []))

    @jsii.member(jsii_name="resetPlacementPolicy")
    def reset_placement_policy(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPlacementPolicy", []))

    @jsii.member(jsii_name="resetPlatformId")
    def reset_platform_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPlatformId", []))

    @jsii.member(jsii_name="resetSchedulingPolicy")
    def reset_scheduling_policy(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSchedulingPolicy", []))

    @jsii.member(jsii_name="resetSecondaryDisk")
    def reset_secondary_disk(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecondaryDisk", []))

    @jsii.member(jsii_name="resetServiceAccountId")
    def reset_service_account_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetServiceAccountId", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="resetZone")
    def reset_zone(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetZone", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bootDisk")
    def boot_disk(self) -> "ComputeInstanceBootDiskOutputReference":
        return typing.cast("ComputeInstanceBootDiskOutputReference", jsii.get(self, "bootDisk"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fqdn"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkInterface")
    def network_interface(self) -> "ComputeInstanceNetworkInterfaceList":
        return typing.cast("ComputeInstanceNetworkInterfaceList", jsii.get(self, "networkInterface"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="placementPolicy")
    def placement_policy(self) -> "ComputeInstancePlacementPolicyOutputReference":
        return typing.cast("ComputeInstancePlacementPolicyOutputReference", jsii.get(self, "placementPolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resources")
    def resources(self) -> "ComputeInstanceResourcesOutputReference":
        return typing.cast("ComputeInstanceResourcesOutputReference", jsii.get(self, "resources"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="schedulingPolicy")
    def scheduling_policy(self) -> "ComputeInstanceSchedulingPolicyOutputReference":
        return typing.cast("ComputeInstanceSchedulingPolicyOutputReference", jsii.get(self, "schedulingPolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="secondaryDisk")
    def secondary_disk(self) -> "ComputeInstanceSecondaryDiskList":
        return typing.cast("ComputeInstanceSecondaryDiskList", jsii.get(self, "secondaryDisk"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "ComputeInstanceTimeoutsOutputReference":
        return typing.cast("ComputeInstanceTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allowStoppingForUpdateInput")
    def allow_stopping_for_update_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "allowStoppingForUpdateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bootDiskInput")
    def boot_disk_input(self) -> typing.Optional["ComputeInstanceBootDisk"]:
        return typing.cast(typing.Optional["ComputeInstanceBootDisk"], jsii.get(self, "bootDiskInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostnameInput")
    def hostname_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "hostnameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metadataInput")
    def metadata_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "metadataInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkAccelerationTypeInput")
    def network_acceleration_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "networkAccelerationTypeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkInterfaceInput")
    def network_interface_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceNetworkInterface"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceNetworkInterface"]]], jsii.get(self, "networkInterfaceInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="placementPolicyInput")
    def placement_policy_input(
        self,
    ) -> typing.Optional["ComputeInstancePlacementPolicy"]:
        return typing.cast(typing.Optional["ComputeInstancePlacementPolicy"], jsii.get(self, "placementPolicyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="platformIdInput")
    def platform_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "platformIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcesInput")
    def resources_input(self) -> typing.Optional["ComputeInstanceResources"]:
        return typing.cast(typing.Optional["ComputeInstanceResources"], jsii.get(self, "resourcesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="schedulingPolicyInput")
    def scheduling_policy_input(
        self,
    ) -> typing.Optional["ComputeInstanceSchedulingPolicy"]:
        return typing.cast(typing.Optional["ComputeInstanceSchedulingPolicy"], jsii.get(self, "schedulingPolicyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="secondaryDiskInput")
    def secondary_disk_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceSecondaryDisk"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceSecondaryDisk"]]], jsii.get(self, "secondaryDiskInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountIdInput")
    def service_account_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceAccountIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "ComputeInstanceTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "ComputeInstanceTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneInput")
    def zone_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "zoneInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allowStoppingForUpdate")
    def allow_stopping_for_update(
        self,
    ) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "allowStoppingForUpdate"))

    @allow_stopping_for_update.setter
    def allow_stopping_for_update(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "allowStoppingForUpdate", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostname")
    def hostname(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "hostname"))

    @hostname.setter
    def hostname(self, value: builtins.str) -> None:
        jsii.set(self, "hostname", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metadata")
    def metadata(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "metadata"))

    @metadata.setter
    def metadata(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "metadata", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkAccelerationType")
    def network_acceleration_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkAccelerationType"))

    @network_acceleration_type.setter
    def network_acceleration_type(self, value: builtins.str) -> None:
        jsii.set(self, "networkAccelerationType", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="platformId")
    def platform_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "platformId"))

    @platform_id.setter
    def platform_id(self, value: builtins.str) -> None:
        jsii.set(self, "platformId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountId")
    def service_account_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceAccountId"))

    @service_account_id.setter
    def service_account_id(self, value: builtins.str) -> None:
        jsii.set(self, "serviceAccountId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zone")
    def zone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zone"))

    @zone.setter
    def zone(self, value: builtins.str) -> None:
        jsii.set(self, "zone", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceBootDisk",
    jsii_struct_bases=[],
    name_mapping={
        "auto_delete": "autoDelete",
        "device_name": "deviceName",
        "disk_id": "diskId",
        "initialize_params": "initializeParams",
        "mode": "mode",
    },
)
class ComputeInstanceBootDisk:
    def __init__(
        self,
        *,
        auto_delete: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        device_name: typing.Optional[builtins.str] = None,
        disk_id: typing.Optional[builtins.str] = None,
        initialize_params: typing.Optional["ComputeInstanceBootDiskInitializeParams"] = None,
        mode: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param auto_delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#auto_delete ComputeInstance#auto_delete}.
        :param device_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#device_name ComputeInstance#device_name}.
        :param disk_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#disk_id ComputeInstance#disk_id}.
        :param initialize_params: initialize_params block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#initialize_params ComputeInstance#initialize_params}
        :param mode: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#mode ComputeInstance#mode}.
        '''
        if isinstance(initialize_params, dict):
            initialize_params = ComputeInstanceBootDiskInitializeParams(**initialize_params)
        self._values: typing.Dict[str, typing.Any] = {}
        if auto_delete is not None:
            self._values["auto_delete"] = auto_delete
        if device_name is not None:
            self._values["device_name"] = device_name
        if disk_id is not None:
            self._values["disk_id"] = disk_id
        if initialize_params is not None:
            self._values["initialize_params"] = initialize_params
        if mode is not None:
            self._values["mode"] = mode

    @builtins.property
    def auto_delete(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#auto_delete ComputeInstance#auto_delete}.'''
        result = self._values.get("auto_delete")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def device_name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#device_name ComputeInstance#device_name}.'''
        result = self._values.get("device_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def disk_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#disk_id ComputeInstance#disk_id}.'''
        result = self._values.get("disk_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def initialize_params(
        self,
    ) -> typing.Optional["ComputeInstanceBootDiskInitializeParams"]:
        '''initialize_params block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#initialize_params ComputeInstance#initialize_params}
        '''
        result = self._values.get("initialize_params")
        return typing.cast(typing.Optional["ComputeInstanceBootDiskInitializeParams"], result)

    @builtins.property
    def mode(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#mode ComputeInstance#mode}.'''
        result = self._values.get("mode")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceBootDisk(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceBootDiskInitializeParams",
    jsii_struct_bases=[],
    name_mapping={
        "block_size": "blockSize",
        "description": "description",
        "image_id": "imageId",
        "name": "name",
        "size": "size",
        "snapshot_id": "snapshotId",
        "type": "type",
    },
)
class ComputeInstanceBootDiskInitializeParams:
    def __init__(
        self,
        *,
        block_size: typing.Optional[jsii.Number] = None,
        description: typing.Optional[builtins.str] = None,
        image_id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        size: typing.Optional[jsii.Number] = None,
        snapshot_id: typing.Optional[builtins.str] = None,
        type: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param block_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#block_size ComputeInstance#block_size}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#description ComputeInstance#description}.
        :param image_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#image_id ComputeInstance#image_id}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#name ComputeInstance#name}.
        :param size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#size ComputeInstance#size}.
        :param snapshot_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#snapshot_id ComputeInstance#snapshot_id}.
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#type ComputeInstance#type}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if block_size is not None:
            self._values["block_size"] = block_size
        if description is not None:
            self._values["description"] = description
        if image_id is not None:
            self._values["image_id"] = image_id
        if name is not None:
            self._values["name"] = name
        if size is not None:
            self._values["size"] = size
        if snapshot_id is not None:
            self._values["snapshot_id"] = snapshot_id
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def block_size(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#block_size ComputeInstance#block_size}.'''
        result = self._values.get("block_size")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#description ComputeInstance#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def image_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#image_id ComputeInstance#image_id}.'''
        result = self._values.get("image_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#name ComputeInstance#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def size(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#size ComputeInstance#size}.'''
        result = self._values.get("size")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def snapshot_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#snapshot_id ComputeInstance#snapshot_id}.'''
        result = self._values.get("snapshot_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def type(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#type ComputeInstance#type}.'''
        result = self._values.get("type")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceBootDiskInitializeParams(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeInstanceBootDiskInitializeParamsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceBootDiskInitializeParamsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetBlockSize")
    def reset_block_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetBlockSize", []))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetImageId")
    def reset_image_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetImageId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetSize")
    def reset_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSize", []))

    @jsii.member(jsii_name="resetSnapshotId")
    def reset_snapshot_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSnapshotId", []))

    @jsii.member(jsii_name="resetType")
    def reset_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetType", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="blockSizeInput")
    def block_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "blockSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="imageIdInput")
    def image_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "imageIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sizeInput")
    def size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "sizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="snapshotIdInput")
    def snapshot_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "snapshotIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="typeInput")
    def type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "typeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="blockSize")
    def block_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "blockSize"))

    @block_size.setter
    def block_size(self, value: jsii.Number) -> None:
        jsii.set(self, "blockSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="imageId")
    def image_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "imageId"))

    @image_id.setter
    def image_id(self, value: builtins.str) -> None:
        jsii.set(self, "imageId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="size")
    def size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "size"))

    @size.setter
    def size(self, value: jsii.Number) -> None:
        jsii.set(self, "size", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="snapshotId")
    def snapshot_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "snapshotId"))

    @snapshot_id.setter
    def snapshot_id(self, value: builtins.str) -> None:
        jsii.set(self, "snapshotId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @type.setter
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[ComputeInstanceBootDiskInitializeParams]:
        return typing.cast(typing.Optional[ComputeInstanceBootDiskInitializeParams], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[ComputeInstanceBootDiskInitializeParams],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ComputeInstanceBootDiskOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceBootDiskOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putInitializeParams")
    def put_initialize_params(
        self,
        *,
        block_size: typing.Optional[jsii.Number] = None,
        description: typing.Optional[builtins.str] = None,
        image_id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        size: typing.Optional[jsii.Number] = None,
        snapshot_id: typing.Optional[builtins.str] = None,
        type: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param block_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#block_size ComputeInstance#block_size}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#description ComputeInstance#description}.
        :param image_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#image_id ComputeInstance#image_id}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#name ComputeInstance#name}.
        :param size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#size ComputeInstance#size}.
        :param snapshot_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#snapshot_id ComputeInstance#snapshot_id}.
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#type ComputeInstance#type}.
        '''
        value = ComputeInstanceBootDiskInitializeParams(
            block_size=block_size,
            description=description,
            image_id=image_id,
            name=name,
            size=size,
            snapshot_id=snapshot_id,
            type=type,
        )

        return typing.cast(None, jsii.invoke(self, "putInitializeParams", [value]))

    @jsii.member(jsii_name="resetAutoDelete")
    def reset_auto_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAutoDelete", []))

    @jsii.member(jsii_name="resetDeviceName")
    def reset_device_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDeviceName", []))

    @jsii.member(jsii_name="resetDiskId")
    def reset_disk_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDiskId", []))

    @jsii.member(jsii_name="resetInitializeParams")
    def reset_initialize_params(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInitializeParams", []))

    @jsii.member(jsii_name="resetMode")
    def reset_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMode", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="initializeParams")
    def initialize_params(
        self,
    ) -> ComputeInstanceBootDiskInitializeParamsOutputReference:
        return typing.cast(ComputeInstanceBootDiskInitializeParamsOutputReference, jsii.get(self, "initializeParams"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoDeleteInput")
    def auto_delete_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "autoDeleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deviceNameInput")
    def device_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deviceNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskIdInput")
    def disk_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "diskIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="initializeParamsInput")
    def initialize_params_input(
        self,
    ) -> typing.Optional[ComputeInstanceBootDiskInitializeParams]:
        return typing.cast(typing.Optional[ComputeInstanceBootDiskInitializeParams], jsii.get(self, "initializeParamsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="modeInput")
    def mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "modeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoDelete")
    def auto_delete(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "autoDelete"))

    @auto_delete.setter
    def auto_delete(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "autoDelete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deviceName")
    def device_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "deviceName"))

    @device_name.setter
    def device_name(self, value: builtins.str) -> None:
        jsii.set(self, "deviceName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskId")
    def disk_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskId"))

    @disk_id.setter
    def disk_id(self, value: builtins.str) -> None:
        jsii.set(self, "diskId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mode")
    def mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "mode"))

    @mode.setter
    def mode(self, value: builtins.str) -> None:
        jsii.set(self, "mode", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[ComputeInstanceBootDisk]:
        return typing.cast(typing.Optional[ComputeInstanceBootDisk], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(self, value: typing.Optional[ComputeInstanceBootDisk]) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "boot_disk": "bootDisk",
        "network_interface": "networkInterface",
        "resources": "resources",
        "allow_stopping_for_update": "allowStoppingForUpdate",
        "description": "description",
        "folder_id": "folderId",
        "hostname": "hostname",
        "id": "id",
        "labels": "labels",
        "metadata": "metadata",
        "name": "name",
        "network_acceleration_type": "networkAccelerationType",
        "placement_policy": "placementPolicy",
        "platform_id": "platformId",
        "scheduling_policy": "schedulingPolicy",
        "secondary_disk": "secondaryDisk",
        "service_account_id": "serviceAccountId",
        "timeouts": "timeouts",
        "zone": "zone",
    },
)
class ComputeInstanceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        boot_disk: ComputeInstanceBootDisk,
        network_interface: typing.Union[cdktf.IResolvable, typing.Sequence["ComputeInstanceNetworkInterface"]],
        resources: "ComputeInstanceResources",
        allow_stopping_for_update: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        hostname: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        metadata: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        network_acceleration_type: typing.Optional[builtins.str] = None,
        placement_policy: typing.Optional["ComputeInstancePlacementPolicy"] = None,
        platform_id: typing.Optional[builtins.str] = None,
        scheduling_policy: typing.Optional["ComputeInstanceSchedulingPolicy"] = None,
        secondary_disk: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["ComputeInstanceSecondaryDisk"]]] = None,
        service_account_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ComputeInstanceTimeouts"] = None,
        zone: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param boot_disk: boot_disk block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#boot_disk ComputeInstance#boot_disk}
        :param network_interface: network_interface block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#network_interface ComputeInstance#network_interface}
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#resources ComputeInstance#resources}
        :param allow_stopping_for_update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#allow_stopping_for_update ComputeInstance#allow_stopping_for_update}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#description ComputeInstance#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#folder_id ComputeInstance#folder_id}.
        :param hostname: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#hostname ComputeInstance#hostname}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#id ComputeInstance#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#labels ComputeInstance#labels}.
        :param metadata: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#metadata ComputeInstance#metadata}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#name ComputeInstance#name}.
        :param network_acceleration_type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#network_acceleration_type ComputeInstance#network_acceleration_type}.
        :param placement_policy: placement_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#placement_policy ComputeInstance#placement_policy}
        :param platform_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#platform_id ComputeInstance#platform_id}.
        :param scheduling_policy: scheduling_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#scheduling_policy ComputeInstance#scheduling_policy}
        :param secondary_disk: secondary_disk block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#secondary_disk ComputeInstance#secondary_disk}
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#service_account_id ComputeInstance#service_account_id}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#timeouts ComputeInstance#timeouts}
        :param zone: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#zone ComputeInstance#zone}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(boot_disk, dict):
            boot_disk = ComputeInstanceBootDisk(**boot_disk)
        if isinstance(resources, dict):
            resources = ComputeInstanceResources(**resources)
        if isinstance(placement_policy, dict):
            placement_policy = ComputeInstancePlacementPolicy(**placement_policy)
        if isinstance(scheduling_policy, dict):
            scheduling_policy = ComputeInstanceSchedulingPolicy(**scheduling_policy)
        if isinstance(timeouts, dict):
            timeouts = ComputeInstanceTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "boot_disk": boot_disk,
            "network_interface": network_interface,
            "resources": resources,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if allow_stopping_for_update is not None:
            self._values["allow_stopping_for_update"] = allow_stopping_for_update
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if hostname is not None:
            self._values["hostname"] = hostname
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if metadata is not None:
            self._values["metadata"] = metadata
        if name is not None:
            self._values["name"] = name
        if network_acceleration_type is not None:
            self._values["network_acceleration_type"] = network_acceleration_type
        if placement_policy is not None:
            self._values["placement_policy"] = placement_policy
        if platform_id is not None:
            self._values["platform_id"] = platform_id
        if scheduling_policy is not None:
            self._values["scheduling_policy"] = scheduling_policy
        if secondary_disk is not None:
            self._values["secondary_disk"] = secondary_disk
        if service_account_id is not None:
            self._values["service_account_id"] = service_account_id
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if zone is not None:
            self._values["zone"] = zone

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def boot_disk(self) -> ComputeInstanceBootDisk:
        '''boot_disk block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#boot_disk ComputeInstance#boot_disk}
        '''
        result = self._values.get("boot_disk")
        assert result is not None, "Required property 'boot_disk' is missing"
        return typing.cast(ComputeInstanceBootDisk, result)

    @builtins.property
    def network_interface(
        self,
    ) -> typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceNetworkInterface"]]:
        '''network_interface block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#network_interface ComputeInstance#network_interface}
        '''
        result = self._values.get("network_interface")
        assert result is not None, "Required property 'network_interface' is missing"
        return typing.cast(typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceNetworkInterface"]], result)

    @builtins.property
    def resources(self) -> "ComputeInstanceResources":
        '''resources block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#resources ComputeInstance#resources}
        '''
        result = self._values.get("resources")
        assert result is not None, "Required property 'resources' is missing"
        return typing.cast("ComputeInstanceResources", result)

    @builtins.property
    def allow_stopping_for_update(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#allow_stopping_for_update ComputeInstance#allow_stopping_for_update}.'''
        result = self._values.get("allow_stopping_for_update")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#description ComputeInstance#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#folder_id ComputeInstance#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def hostname(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#hostname ComputeInstance#hostname}.'''
        result = self._values.get("hostname")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#id ComputeInstance#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#labels ComputeInstance#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def metadata(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#metadata ComputeInstance#metadata}.'''
        result = self._values.get("metadata")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#name ComputeInstance#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def network_acceleration_type(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#network_acceleration_type ComputeInstance#network_acceleration_type}.'''
        result = self._values.get("network_acceleration_type")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def placement_policy(self) -> typing.Optional["ComputeInstancePlacementPolicy"]:
        '''placement_policy block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#placement_policy ComputeInstance#placement_policy}
        '''
        result = self._values.get("placement_policy")
        return typing.cast(typing.Optional["ComputeInstancePlacementPolicy"], result)

    @builtins.property
    def platform_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#platform_id ComputeInstance#platform_id}.'''
        result = self._values.get("platform_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def scheduling_policy(self) -> typing.Optional["ComputeInstanceSchedulingPolicy"]:
        '''scheduling_policy block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#scheduling_policy ComputeInstance#scheduling_policy}
        '''
        result = self._values.get("scheduling_policy")
        return typing.cast(typing.Optional["ComputeInstanceSchedulingPolicy"], result)

    @builtins.property
    def secondary_disk(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceSecondaryDisk"]]]:
        '''secondary_disk block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#secondary_disk ComputeInstance#secondary_disk}
        '''
        result = self._values.get("secondary_disk")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceSecondaryDisk"]]], result)

    @builtins.property
    def service_account_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#service_account_id ComputeInstance#service_account_id}.'''
        result = self._values.get("service_account_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["ComputeInstanceTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#timeouts ComputeInstance#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["ComputeInstanceTimeouts"], result)

    @builtins.property
    def zone(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#zone ComputeInstance#zone}.'''
        result = self._values.get("zone")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeInstanceGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroup",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group yandex_compute_instance_group}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        allocation_policy: "ComputeInstanceGroupAllocationPolicy",
        deploy_policy: "ComputeInstanceGroupDeployPolicy",
        instance_template: "ComputeInstanceGroupInstanceTemplate",
        scale_policy: "ComputeInstanceGroupScalePolicy",
        service_account_id: builtins.str,
        application_load_balancer: typing.Optional["ComputeInstanceGroupApplicationLoadBalancer"] = None,
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        health_check: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["ComputeInstanceGroupHealthCheck"]]] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        load_balancer: typing.Optional["ComputeInstanceGroupLoadBalancer"] = None,
        max_checking_health_duration: typing.Optional[jsii.Number] = None,
        name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ComputeInstanceGroupTimeouts"] = None,
        variables: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group yandex_compute_instance_group} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param allocation_policy: allocation_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#allocation_policy ComputeInstanceGroup#allocation_policy}
        :param deploy_policy: deploy_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#deploy_policy ComputeInstanceGroup#deploy_policy}
        :param instance_template: instance_template block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#instance_template ComputeInstanceGroup#instance_template}
        :param scale_policy: scale_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#scale_policy ComputeInstanceGroup#scale_policy}
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#service_account_id ComputeInstanceGroup#service_account_id}.
        :param application_load_balancer: application_load_balancer block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#application_load_balancer ComputeInstanceGroup#application_load_balancer}
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#deletion_protection ComputeInstanceGroup#deletion_protection}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#description ComputeInstanceGroup#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#folder_id ComputeInstanceGroup#folder_id}.
        :param health_check: health_check block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#health_check ComputeInstanceGroup#health_check}
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#id ComputeInstanceGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#labels ComputeInstanceGroup#labels}.
        :param load_balancer: load_balancer block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#load_balancer ComputeInstanceGroup#load_balancer}
        :param max_checking_health_duration: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#max_checking_health_duration ComputeInstanceGroup#max_checking_health_duration}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#name ComputeInstanceGroup#name}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#timeouts ComputeInstanceGroup#timeouts}
        :param variables: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#variables ComputeInstanceGroup#variables}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = ComputeInstanceGroupConfig(
            allocation_policy=allocation_policy,
            deploy_policy=deploy_policy,
            instance_template=instance_template,
            scale_policy=scale_policy,
            service_account_id=service_account_id,
            application_load_balancer=application_load_balancer,
            deletion_protection=deletion_protection,
            description=description,
            folder_id=folder_id,
            health_check=health_check,
            id=id,
            labels=labels,
            load_balancer=load_balancer,
            max_checking_health_duration=max_checking_health_duration,
            name=name,
            timeouts=timeouts,
            variables=variables,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putAllocationPolicy")
    def put_allocation_policy(self, *, zones: typing.Sequence[builtins.str]) -> None:
        '''
        :param zones: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#zones ComputeInstanceGroup#zones}.
        '''
        value = ComputeInstanceGroupAllocationPolicy(zones=zones)

        return typing.cast(None, jsii.invoke(self, "putAllocationPolicy", [value]))

    @jsii.member(jsii_name="putApplicationLoadBalancer")
    def put_application_load_balancer(
        self,
        *,
        max_opening_traffic_duration: typing.Optional[jsii.Number] = None,
        target_group_description: typing.Optional[builtins.str] = None,
        target_group_labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        target_group_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param max_opening_traffic_duration: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#max_opening_traffic_duration ComputeInstanceGroup#max_opening_traffic_duration}.
        :param target_group_description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#target_group_description ComputeInstanceGroup#target_group_description}.
        :param target_group_labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#target_group_labels ComputeInstanceGroup#target_group_labels}.
        :param target_group_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#target_group_name ComputeInstanceGroup#target_group_name}.
        '''
        value = ComputeInstanceGroupApplicationLoadBalancer(
            max_opening_traffic_duration=max_opening_traffic_duration,
            target_group_description=target_group_description,
            target_group_labels=target_group_labels,
            target_group_name=target_group_name,
        )

        return typing.cast(None, jsii.invoke(self, "putApplicationLoadBalancer", [value]))

    @jsii.member(jsii_name="putDeployPolicy")
    def put_deploy_policy(
        self,
        *,
        max_expansion: jsii.Number,
        max_unavailable: jsii.Number,
        max_creating: typing.Optional[jsii.Number] = None,
        max_deleting: typing.Optional[jsii.Number] = None,
        startup_duration: typing.Optional[jsii.Number] = None,
        strategy: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param max_expansion: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#max_expansion ComputeInstanceGroup#max_expansion}.
        :param max_unavailable: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#max_unavailable ComputeInstanceGroup#max_unavailable}.
        :param max_creating: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#max_creating ComputeInstanceGroup#max_creating}.
        :param max_deleting: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#max_deleting ComputeInstanceGroup#max_deleting}.
        :param startup_duration: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#startup_duration ComputeInstanceGroup#startup_duration}.
        :param strategy: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#strategy ComputeInstanceGroup#strategy}.
        '''
        value = ComputeInstanceGroupDeployPolicy(
            max_expansion=max_expansion,
            max_unavailable=max_unavailable,
            max_creating=max_creating,
            max_deleting=max_deleting,
            startup_duration=startup_duration,
            strategy=strategy,
        )

        return typing.cast(None, jsii.invoke(self, "putDeployPolicy", [value]))

    @jsii.member(jsii_name="putHealthCheck")
    def put_health_check(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["ComputeInstanceGroupHealthCheck"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putHealthCheck", [value]))

    @jsii.member(jsii_name="putInstanceTemplate")
    def put_instance_template(
        self,
        *,
        boot_disk: "ComputeInstanceGroupInstanceTemplateBootDisk",
        network_interface: typing.Union[cdktf.IResolvable, typing.Sequence["ComputeInstanceGroupInstanceTemplateNetworkInterface"]],
        resources: "ComputeInstanceGroupInstanceTemplateResources",
        description: typing.Optional[builtins.str] = None,
        hostname: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        metadata: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        network_settings: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["ComputeInstanceGroupInstanceTemplateNetworkSettings"]]] = None,
        placement_policy: typing.Optional["ComputeInstanceGroupInstanceTemplatePlacementPolicy"] = None,
        platform_id: typing.Optional[builtins.str] = None,
        scheduling_policy: typing.Optional["ComputeInstanceGroupInstanceTemplateSchedulingPolicy"] = None,
        secondary_disk: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["ComputeInstanceGroupInstanceTemplateSecondaryDisk"]]] = None,
        service_account_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param boot_disk: boot_disk block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#boot_disk ComputeInstanceGroup#boot_disk}
        :param network_interface: network_interface block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#network_interface ComputeInstanceGroup#network_interface}
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#resources ComputeInstanceGroup#resources}
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#description ComputeInstanceGroup#description}.
        :param hostname: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#hostname ComputeInstanceGroup#hostname}.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#labels ComputeInstanceGroup#labels}.
        :param metadata: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#metadata ComputeInstanceGroup#metadata}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#name ComputeInstanceGroup#name}.
        :param network_settings: network_settings block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#network_settings ComputeInstanceGroup#network_settings}
        :param placement_policy: placement_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#placement_policy ComputeInstanceGroup#placement_policy}
        :param platform_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#platform_id ComputeInstanceGroup#platform_id}.
        :param scheduling_policy: scheduling_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#scheduling_policy ComputeInstanceGroup#scheduling_policy}
        :param secondary_disk: secondary_disk block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#secondary_disk ComputeInstanceGroup#secondary_disk}
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#service_account_id ComputeInstanceGroup#service_account_id}.
        '''
        value = ComputeInstanceGroupInstanceTemplate(
            boot_disk=boot_disk,
            network_interface=network_interface,
            resources=resources,
            description=description,
            hostname=hostname,
            labels=labels,
            metadata=metadata,
            name=name,
            network_settings=network_settings,
            placement_policy=placement_policy,
            platform_id=platform_id,
            scheduling_policy=scheduling_policy,
            secondary_disk=secondary_disk,
            service_account_id=service_account_id,
        )

        return typing.cast(None, jsii.invoke(self, "putInstanceTemplate", [value]))

    @jsii.member(jsii_name="putLoadBalancer")
    def put_load_balancer(
        self,
        *,
        max_opening_traffic_duration: typing.Optional[jsii.Number] = None,
        target_group_description: typing.Optional[builtins.str] = None,
        target_group_labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        target_group_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param max_opening_traffic_duration: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#max_opening_traffic_duration ComputeInstanceGroup#max_opening_traffic_duration}.
        :param target_group_description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#target_group_description ComputeInstanceGroup#target_group_description}.
        :param target_group_labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#target_group_labels ComputeInstanceGroup#target_group_labels}.
        :param target_group_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#target_group_name ComputeInstanceGroup#target_group_name}.
        '''
        value = ComputeInstanceGroupLoadBalancer(
            max_opening_traffic_duration=max_opening_traffic_duration,
            target_group_description=target_group_description,
            target_group_labels=target_group_labels,
            target_group_name=target_group_name,
        )

        return typing.cast(None, jsii.invoke(self, "putLoadBalancer", [value]))

    @jsii.member(jsii_name="putScalePolicy")
    def put_scale_policy(
        self,
        *,
        auto_scale: typing.Optional["ComputeInstanceGroupScalePolicyAutoScale"] = None,
        fixed_scale: typing.Optional["ComputeInstanceGroupScalePolicyFixedScale"] = None,
        test_auto_scale: typing.Optional["ComputeInstanceGroupScalePolicyTestAutoScale"] = None,
    ) -> None:
        '''
        :param auto_scale: auto_scale block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#auto_scale ComputeInstanceGroup#auto_scale}
        :param fixed_scale: fixed_scale block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#fixed_scale ComputeInstanceGroup#fixed_scale}
        :param test_auto_scale: test_auto_scale block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#test_auto_scale ComputeInstanceGroup#test_auto_scale}
        '''
        value = ComputeInstanceGroupScalePolicy(
            auto_scale=auto_scale,
            fixed_scale=fixed_scale,
            test_auto_scale=test_auto_scale,
        )

        return typing.cast(None, jsii.invoke(self, "putScalePolicy", [value]))

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#create ComputeInstanceGroup#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#delete ComputeInstanceGroup#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#update ComputeInstanceGroup#update}.
        '''
        value = ComputeInstanceGroupTimeouts(
            create=create, delete=delete, update=update
        )

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetApplicationLoadBalancer")
    def reset_application_load_balancer(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApplicationLoadBalancer", []))

    @jsii.member(jsii_name="resetDeletionProtection")
    def reset_deletion_protection(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDeletionProtection", []))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetHealthCheck")
    def reset_health_check(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHealthCheck", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetLoadBalancer")
    def reset_load_balancer(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLoadBalancer", []))

    @jsii.member(jsii_name="resetMaxCheckingHealthDuration")
    def reset_max_checking_health_duration(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxCheckingHealthDuration", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="resetVariables")
    def reset_variables(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetVariables", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allocationPolicy")
    def allocation_policy(
        self,
    ) -> "ComputeInstanceGroupAllocationPolicyOutputReference":
        return typing.cast("ComputeInstanceGroupAllocationPolicyOutputReference", jsii.get(self, "allocationPolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="applicationLoadBalancer")
    def application_load_balancer(
        self,
    ) -> "ComputeInstanceGroupApplicationLoadBalancerOutputReference":
        return typing.cast("ComputeInstanceGroupApplicationLoadBalancerOutputReference", jsii.get(self, "applicationLoadBalancer"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deployPolicy")
    def deploy_policy(self) -> "ComputeInstanceGroupDeployPolicyOutputReference":
        return typing.cast("ComputeInstanceGroupDeployPolicyOutputReference", jsii.get(self, "deployPolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthCheck")
    def health_check(self) -> "ComputeInstanceGroupHealthCheckList":
        return typing.cast("ComputeInstanceGroupHealthCheckList", jsii.get(self, "healthCheck"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="instances")
    def instances(self) -> "ComputeInstanceGroupInstancesList":
        return typing.cast("ComputeInstanceGroupInstancesList", jsii.get(self, "instances"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="instanceTemplate")
    def instance_template(
        self,
    ) -> "ComputeInstanceGroupInstanceTemplateOutputReference":
        return typing.cast("ComputeInstanceGroupInstanceTemplateOutputReference", jsii.get(self, "instanceTemplate"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="loadBalancer")
    def load_balancer(self) -> "ComputeInstanceGroupLoadBalancerOutputReference":
        return typing.cast("ComputeInstanceGroupLoadBalancerOutputReference", jsii.get(self, "loadBalancer"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="scalePolicy")
    def scale_policy(self) -> "ComputeInstanceGroupScalePolicyOutputReference":
        return typing.cast("ComputeInstanceGroupScalePolicyOutputReference", jsii.get(self, "scalePolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "ComputeInstanceGroupTimeoutsOutputReference":
        return typing.cast("ComputeInstanceGroupTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allocationPolicyInput")
    def allocation_policy_input(
        self,
    ) -> typing.Optional["ComputeInstanceGroupAllocationPolicy"]:
        return typing.cast(typing.Optional["ComputeInstanceGroupAllocationPolicy"], jsii.get(self, "allocationPolicyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="applicationLoadBalancerInput")
    def application_load_balancer_input(
        self,
    ) -> typing.Optional["ComputeInstanceGroupApplicationLoadBalancer"]:
        return typing.cast(typing.Optional["ComputeInstanceGroupApplicationLoadBalancer"], jsii.get(self, "applicationLoadBalancerInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtectionInput")
    def deletion_protection_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "deletionProtectionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deployPolicyInput")
    def deploy_policy_input(
        self,
    ) -> typing.Optional["ComputeInstanceGroupDeployPolicy"]:
        return typing.cast(typing.Optional["ComputeInstanceGroupDeployPolicy"], jsii.get(self, "deployPolicyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthCheckInput")
    def health_check_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceGroupHealthCheck"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceGroupHealthCheck"]]], jsii.get(self, "healthCheckInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="instanceTemplateInput")
    def instance_template_input(
        self,
    ) -> typing.Optional["ComputeInstanceGroupInstanceTemplate"]:
        return typing.cast(typing.Optional["ComputeInstanceGroupInstanceTemplate"], jsii.get(self, "instanceTemplateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="loadBalancerInput")
    def load_balancer_input(
        self,
    ) -> typing.Optional["ComputeInstanceGroupLoadBalancer"]:
        return typing.cast(typing.Optional["ComputeInstanceGroupLoadBalancer"], jsii.get(self, "loadBalancerInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxCheckingHealthDurationInput")
    def max_checking_health_duration_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxCheckingHealthDurationInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="scalePolicyInput")
    def scale_policy_input(self) -> typing.Optional["ComputeInstanceGroupScalePolicy"]:
        return typing.cast(typing.Optional["ComputeInstanceGroupScalePolicy"], jsii.get(self, "scalePolicyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountIdInput")
    def service_account_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceAccountIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "ComputeInstanceGroupTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "ComputeInstanceGroupTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="variablesInput")
    def variables_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "variablesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtection")
    def deletion_protection(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "deletionProtection"))

    @deletion_protection.setter
    def deletion_protection(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "deletionProtection", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxCheckingHealthDuration")
    def max_checking_health_duration(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxCheckingHealthDuration"))

    @max_checking_health_duration.setter
    def max_checking_health_duration(self, value: jsii.Number) -> None:
        jsii.set(self, "maxCheckingHealthDuration", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountId")
    def service_account_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceAccountId"))

    @service_account_id.setter
    def service_account_id(self, value: builtins.str) -> None:
        jsii.set(self, "serviceAccountId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="variables")
    def variables(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "variables"))

    @variables.setter
    def variables(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "variables", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupAllocationPolicy",
    jsii_struct_bases=[],
    name_mapping={"zones": "zones"},
)
class ComputeInstanceGroupAllocationPolicy:
    def __init__(self, *, zones: typing.Sequence[builtins.str]) -> None:
        '''
        :param zones: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#zones ComputeInstanceGroup#zones}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "zones": zones,
        }

    @builtins.property
    def zones(self) -> typing.List[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#zones ComputeInstanceGroup#zones}.'''
        result = self._values.get("zones")
        assert result is not None, "Required property 'zones' is missing"
        return typing.cast(typing.List[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceGroupAllocationPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeInstanceGroupAllocationPolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupAllocationPolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zonesInput")
    def zones_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "zonesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zones")
    def zones(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "zones"))

    @zones.setter
    def zones(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "zones", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[ComputeInstanceGroupAllocationPolicy]:
        return typing.cast(typing.Optional[ComputeInstanceGroupAllocationPolicy], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[ComputeInstanceGroupAllocationPolicy],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupApplicationLoadBalancer",
    jsii_struct_bases=[],
    name_mapping={
        "max_opening_traffic_duration": "maxOpeningTrafficDuration",
        "target_group_description": "targetGroupDescription",
        "target_group_labels": "targetGroupLabels",
        "target_group_name": "targetGroupName",
    },
)
class ComputeInstanceGroupApplicationLoadBalancer:
    def __init__(
        self,
        *,
        max_opening_traffic_duration: typing.Optional[jsii.Number] = None,
        target_group_description: typing.Optional[builtins.str] = None,
        target_group_labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        target_group_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param max_opening_traffic_duration: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#max_opening_traffic_duration ComputeInstanceGroup#max_opening_traffic_duration}.
        :param target_group_description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#target_group_description ComputeInstanceGroup#target_group_description}.
        :param target_group_labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#target_group_labels ComputeInstanceGroup#target_group_labels}.
        :param target_group_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#target_group_name ComputeInstanceGroup#target_group_name}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if max_opening_traffic_duration is not None:
            self._values["max_opening_traffic_duration"] = max_opening_traffic_duration
        if target_group_description is not None:
            self._values["target_group_description"] = target_group_description
        if target_group_labels is not None:
            self._values["target_group_labels"] = target_group_labels
        if target_group_name is not None:
            self._values["target_group_name"] = target_group_name

    @builtins.property
    def max_opening_traffic_duration(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#max_opening_traffic_duration ComputeInstanceGroup#max_opening_traffic_duration}.'''
        result = self._values.get("max_opening_traffic_duration")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def target_group_description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#target_group_description ComputeInstanceGroup#target_group_description}.'''
        result = self._values.get("target_group_description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def target_group_labels(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#target_group_labels ComputeInstanceGroup#target_group_labels}.'''
        result = self._values.get("target_group_labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def target_group_name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#target_group_name ComputeInstanceGroup#target_group_name}.'''
        result = self._values.get("target_group_name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceGroupApplicationLoadBalancer(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeInstanceGroupApplicationLoadBalancerOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupApplicationLoadBalancerOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetMaxOpeningTrafficDuration")
    def reset_max_opening_traffic_duration(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxOpeningTrafficDuration", []))

    @jsii.member(jsii_name="resetTargetGroupDescription")
    def reset_target_group_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTargetGroupDescription", []))

    @jsii.member(jsii_name="resetTargetGroupLabels")
    def reset_target_group_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTargetGroupLabels", []))

    @jsii.member(jsii_name="resetTargetGroupName")
    def reset_target_group_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTargetGroupName", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="statusMessage")
    def status_message(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "statusMessage"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupId")
    def target_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "targetGroupId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxOpeningTrafficDurationInput")
    def max_opening_traffic_duration_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxOpeningTrafficDurationInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupDescriptionInput")
    def target_group_description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "targetGroupDescriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupLabelsInput")
    def target_group_labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "targetGroupLabelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupNameInput")
    def target_group_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "targetGroupNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxOpeningTrafficDuration")
    def max_opening_traffic_duration(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxOpeningTrafficDuration"))

    @max_opening_traffic_duration.setter
    def max_opening_traffic_duration(self, value: jsii.Number) -> None:
        jsii.set(self, "maxOpeningTrafficDuration", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupDescription")
    def target_group_description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "targetGroupDescription"))

    @target_group_description.setter
    def target_group_description(self, value: builtins.str) -> None:
        jsii.set(self, "targetGroupDescription", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupLabels")
    def target_group_labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "targetGroupLabels"))

    @target_group_labels.setter
    def target_group_labels(
        self,
        value: typing.Mapping[builtins.str, builtins.str],
    ) -> None:
        jsii.set(self, "targetGroupLabels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupName")
    def target_group_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "targetGroupName"))

    @target_group_name.setter
    def target_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "targetGroupName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[ComputeInstanceGroupApplicationLoadBalancer]:
        return typing.cast(typing.Optional[ComputeInstanceGroupApplicationLoadBalancer], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[ComputeInstanceGroupApplicationLoadBalancer],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "allocation_policy": "allocationPolicy",
        "deploy_policy": "deployPolicy",
        "instance_template": "instanceTemplate",
        "scale_policy": "scalePolicy",
        "service_account_id": "serviceAccountId",
        "application_load_balancer": "applicationLoadBalancer",
        "deletion_protection": "deletionProtection",
        "description": "description",
        "folder_id": "folderId",
        "health_check": "healthCheck",
        "id": "id",
        "labels": "labels",
        "load_balancer": "loadBalancer",
        "max_checking_health_duration": "maxCheckingHealthDuration",
        "name": "name",
        "timeouts": "timeouts",
        "variables": "variables",
    },
)
class ComputeInstanceGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        allocation_policy: ComputeInstanceGroupAllocationPolicy,
        deploy_policy: "ComputeInstanceGroupDeployPolicy",
        instance_template: "ComputeInstanceGroupInstanceTemplate",
        scale_policy: "ComputeInstanceGroupScalePolicy",
        service_account_id: builtins.str,
        application_load_balancer: typing.Optional[ComputeInstanceGroupApplicationLoadBalancer] = None,
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        health_check: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["ComputeInstanceGroupHealthCheck"]]] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        load_balancer: typing.Optional["ComputeInstanceGroupLoadBalancer"] = None,
        max_checking_health_duration: typing.Optional[jsii.Number] = None,
        name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ComputeInstanceGroupTimeouts"] = None,
        variables: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param allocation_policy: allocation_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#allocation_policy ComputeInstanceGroup#allocation_policy}
        :param deploy_policy: deploy_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#deploy_policy ComputeInstanceGroup#deploy_policy}
        :param instance_template: instance_template block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#instance_template ComputeInstanceGroup#instance_template}
        :param scale_policy: scale_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#scale_policy ComputeInstanceGroup#scale_policy}
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#service_account_id ComputeInstanceGroup#service_account_id}.
        :param application_load_balancer: application_load_balancer block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#application_load_balancer ComputeInstanceGroup#application_load_balancer}
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#deletion_protection ComputeInstanceGroup#deletion_protection}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#description ComputeInstanceGroup#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#folder_id ComputeInstanceGroup#folder_id}.
        :param health_check: health_check block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#health_check ComputeInstanceGroup#health_check}
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#id ComputeInstanceGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#labels ComputeInstanceGroup#labels}.
        :param load_balancer: load_balancer block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#load_balancer ComputeInstanceGroup#load_balancer}
        :param max_checking_health_duration: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#max_checking_health_duration ComputeInstanceGroup#max_checking_health_duration}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#name ComputeInstanceGroup#name}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#timeouts ComputeInstanceGroup#timeouts}
        :param variables: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#variables ComputeInstanceGroup#variables}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(allocation_policy, dict):
            allocation_policy = ComputeInstanceGroupAllocationPolicy(**allocation_policy)
        if isinstance(deploy_policy, dict):
            deploy_policy = ComputeInstanceGroupDeployPolicy(**deploy_policy)
        if isinstance(instance_template, dict):
            instance_template = ComputeInstanceGroupInstanceTemplate(**instance_template)
        if isinstance(scale_policy, dict):
            scale_policy = ComputeInstanceGroupScalePolicy(**scale_policy)
        if isinstance(application_load_balancer, dict):
            application_load_balancer = ComputeInstanceGroupApplicationLoadBalancer(**application_load_balancer)
        if isinstance(load_balancer, dict):
            load_balancer = ComputeInstanceGroupLoadBalancer(**load_balancer)
        if isinstance(timeouts, dict):
            timeouts = ComputeInstanceGroupTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "allocation_policy": allocation_policy,
            "deploy_policy": deploy_policy,
            "instance_template": instance_template,
            "scale_policy": scale_policy,
            "service_account_id": service_account_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if application_load_balancer is not None:
            self._values["application_load_balancer"] = application_load_balancer
        if deletion_protection is not None:
            self._values["deletion_protection"] = deletion_protection
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if health_check is not None:
            self._values["health_check"] = health_check
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if load_balancer is not None:
            self._values["load_balancer"] = load_balancer
        if max_checking_health_duration is not None:
            self._values["max_checking_health_duration"] = max_checking_health_duration
        if name is not None:
            self._values["name"] = name
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if variables is not None:
            self._values["variables"] = variables

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def allocation_policy(self) -> ComputeInstanceGroupAllocationPolicy:
        '''allocation_policy block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#allocation_policy ComputeInstanceGroup#allocation_policy}
        '''
        result = self._values.get("allocation_policy")
        assert result is not None, "Required property 'allocation_policy' is missing"
        return typing.cast(ComputeInstanceGroupAllocationPolicy, result)

    @builtins.property
    def deploy_policy(self) -> "ComputeInstanceGroupDeployPolicy":
        '''deploy_policy block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#deploy_policy ComputeInstanceGroup#deploy_policy}
        '''
        result = self._values.get("deploy_policy")
        assert result is not None, "Required property 'deploy_policy' is missing"
        return typing.cast("ComputeInstanceGroupDeployPolicy", result)

    @builtins.property
    def instance_template(self) -> "ComputeInstanceGroupInstanceTemplate":
        '''instance_template block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#instance_template ComputeInstanceGroup#instance_template}
        '''
        result = self._values.get("instance_template")
        assert result is not None, "Required property 'instance_template' is missing"
        return typing.cast("ComputeInstanceGroupInstanceTemplate", result)

    @builtins.property
    def scale_policy(self) -> "ComputeInstanceGroupScalePolicy":
        '''scale_policy block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#scale_policy ComputeInstanceGroup#scale_policy}
        '''
        result = self._values.get("scale_policy")
        assert result is not None, "Required property 'scale_policy' is missing"
        return typing.cast("ComputeInstanceGroupScalePolicy", result)

    @builtins.property
    def service_account_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#service_account_id ComputeInstanceGroup#service_account_id}.'''
        result = self._values.get("service_account_id")
        assert result is not None, "Required property 'service_account_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def application_load_balancer(
        self,
    ) -> typing.Optional[ComputeInstanceGroupApplicationLoadBalancer]:
        '''application_load_balancer block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#application_load_balancer ComputeInstanceGroup#application_load_balancer}
        '''
        result = self._values.get("application_load_balancer")
        return typing.cast(typing.Optional[ComputeInstanceGroupApplicationLoadBalancer], result)

    @builtins.property
    def deletion_protection(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#deletion_protection ComputeInstanceGroup#deletion_protection}.'''
        result = self._values.get("deletion_protection")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#description ComputeInstanceGroup#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#folder_id ComputeInstanceGroup#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def health_check(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceGroupHealthCheck"]]]:
        '''health_check block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#health_check ComputeInstanceGroup#health_check}
        '''
        result = self._values.get("health_check")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceGroupHealthCheck"]]], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#id ComputeInstanceGroup#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#labels ComputeInstanceGroup#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def load_balancer(self) -> typing.Optional["ComputeInstanceGroupLoadBalancer"]:
        '''load_balancer block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#load_balancer ComputeInstanceGroup#load_balancer}
        '''
        result = self._values.get("load_balancer")
        return typing.cast(typing.Optional["ComputeInstanceGroupLoadBalancer"], result)

    @builtins.property
    def max_checking_health_duration(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#max_checking_health_duration ComputeInstanceGroup#max_checking_health_duration}.'''
        result = self._values.get("max_checking_health_duration")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#name ComputeInstanceGroup#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["ComputeInstanceGroupTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#timeouts ComputeInstanceGroup#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["ComputeInstanceGroupTimeouts"], result)

    @builtins.property
    def variables(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#variables ComputeInstanceGroup#variables}.'''
        result = self._values.get("variables")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupDeployPolicy",
    jsii_struct_bases=[],
    name_mapping={
        "max_expansion": "maxExpansion",
        "max_unavailable": "maxUnavailable",
        "max_creating": "maxCreating",
        "max_deleting": "maxDeleting",
        "startup_duration": "startupDuration",
        "strategy": "strategy",
    },
)
class ComputeInstanceGroupDeployPolicy:
    def __init__(
        self,
        *,
        max_expansion: jsii.Number,
        max_unavailable: jsii.Number,
        max_creating: typing.Optional[jsii.Number] = None,
        max_deleting: typing.Optional[jsii.Number] = None,
        startup_duration: typing.Optional[jsii.Number] = None,
        strategy: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param max_expansion: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#max_expansion ComputeInstanceGroup#max_expansion}.
        :param max_unavailable: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#max_unavailable ComputeInstanceGroup#max_unavailable}.
        :param max_creating: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#max_creating ComputeInstanceGroup#max_creating}.
        :param max_deleting: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#max_deleting ComputeInstanceGroup#max_deleting}.
        :param startup_duration: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#startup_duration ComputeInstanceGroup#startup_duration}.
        :param strategy: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#strategy ComputeInstanceGroup#strategy}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_expansion": max_expansion,
            "max_unavailable": max_unavailable,
        }
        if max_creating is not None:
            self._values["max_creating"] = max_creating
        if max_deleting is not None:
            self._values["max_deleting"] = max_deleting
        if startup_duration is not None:
            self._values["startup_duration"] = startup_duration
        if strategy is not None:
            self._values["strategy"] = strategy

    @builtins.property
    def max_expansion(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#max_expansion ComputeInstanceGroup#max_expansion}.'''
        result = self._values.get("max_expansion")
        assert result is not None, "Required property 'max_expansion' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def max_unavailable(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#max_unavailable ComputeInstanceGroup#max_unavailable}.'''
        result = self._values.get("max_unavailable")
        assert result is not None, "Required property 'max_unavailable' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def max_creating(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#max_creating ComputeInstanceGroup#max_creating}.'''
        result = self._values.get("max_creating")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_deleting(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#max_deleting ComputeInstanceGroup#max_deleting}.'''
        result = self._values.get("max_deleting")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def startup_duration(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#startup_duration ComputeInstanceGroup#startup_duration}.'''
        result = self._values.get("startup_duration")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def strategy(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#strategy ComputeInstanceGroup#strategy}.'''
        result = self._values.get("strategy")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceGroupDeployPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeInstanceGroupDeployPolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupDeployPolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetMaxCreating")
    def reset_max_creating(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxCreating", []))

    @jsii.member(jsii_name="resetMaxDeleting")
    def reset_max_deleting(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxDeleting", []))

    @jsii.member(jsii_name="resetStartupDuration")
    def reset_startup_duration(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStartupDuration", []))

    @jsii.member(jsii_name="resetStrategy")
    def reset_strategy(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStrategy", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxCreatingInput")
    def max_creating_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxCreatingInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxDeletingInput")
    def max_deleting_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxDeletingInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxExpansionInput")
    def max_expansion_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxExpansionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxUnavailableInput")
    def max_unavailable_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxUnavailableInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="startupDurationInput")
    def startup_duration_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "startupDurationInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="strategyInput")
    def strategy_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "strategyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxCreating")
    def max_creating(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxCreating"))

    @max_creating.setter
    def max_creating(self, value: jsii.Number) -> None:
        jsii.set(self, "maxCreating", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxDeleting")
    def max_deleting(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxDeleting"))

    @max_deleting.setter
    def max_deleting(self, value: jsii.Number) -> None:
        jsii.set(self, "maxDeleting", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxExpansion")
    def max_expansion(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxExpansion"))

    @max_expansion.setter
    def max_expansion(self, value: jsii.Number) -> None:
        jsii.set(self, "maxExpansion", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxUnavailable")
    def max_unavailable(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxUnavailable"))

    @max_unavailable.setter
    def max_unavailable(self, value: jsii.Number) -> None:
        jsii.set(self, "maxUnavailable", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="startupDuration")
    def startup_duration(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "startupDuration"))

    @startup_duration.setter
    def startup_duration(self, value: jsii.Number) -> None:
        jsii.set(self, "startupDuration", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="strategy")
    def strategy(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "strategy"))

    @strategy.setter
    def strategy(self, value: builtins.str) -> None:
        jsii.set(self, "strategy", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[ComputeInstanceGroupDeployPolicy]:
        return typing.cast(typing.Optional[ComputeInstanceGroupDeployPolicy], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[ComputeInstanceGroupDeployPolicy],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupHealthCheck",
    jsii_struct_bases=[],
    name_mapping={
        "healthy_threshold": "healthyThreshold",
        "http_options": "httpOptions",
        "interval": "interval",
        "tcp_options": "tcpOptions",
        "timeout": "timeout",
        "unhealthy_threshold": "unhealthyThreshold",
    },
)
class ComputeInstanceGroupHealthCheck:
    def __init__(
        self,
        *,
        healthy_threshold: typing.Optional[jsii.Number] = None,
        http_options: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["ComputeInstanceGroupHealthCheckHttpOptions"]]] = None,
        interval: typing.Optional[jsii.Number] = None,
        tcp_options: typing.Optional["ComputeInstanceGroupHealthCheckTcpOptions"] = None,
        timeout: typing.Optional[jsii.Number] = None,
        unhealthy_threshold: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param healthy_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#healthy_threshold ComputeInstanceGroup#healthy_threshold}.
        :param http_options: http_options block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#http_options ComputeInstanceGroup#http_options}
        :param interval: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#interval ComputeInstanceGroup#interval}.
        :param tcp_options: tcp_options block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#tcp_options ComputeInstanceGroup#tcp_options}
        :param timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#timeout ComputeInstanceGroup#timeout}.
        :param unhealthy_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#unhealthy_threshold ComputeInstanceGroup#unhealthy_threshold}.
        '''
        if isinstance(tcp_options, dict):
            tcp_options = ComputeInstanceGroupHealthCheckTcpOptions(**tcp_options)
        self._values: typing.Dict[str, typing.Any] = {}
        if healthy_threshold is not None:
            self._values["healthy_threshold"] = healthy_threshold
        if http_options is not None:
            self._values["http_options"] = http_options
        if interval is not None:
            self._values["interval"] = interval
        if tcp_options is not None:
            self._values["tcp_options"] = tcp_options
        if timeout is not None:
            self._values["timeout"] = timeout
        if unhealthy_threshold is not None:
            self._values["unhealthy_threshold"] = unhealthy_threshold

    @builtins.property
    def healthy_threshold(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#healthy_threshold ComputeInstanceGroup#healthy_threshold}.'''
        result = self._values.get("healthy_threshold")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def http_options(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceGroupHealthCheckHttpOptions"]]]:
        '''http_options block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#http_options ComputeInstanceGroup#http_options}
        '''
        result = self._values.get("http_options")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceGroupHealthCheckHttpOptions"]]], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#interval ComputeInstanceGroup#interval}.'''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def tcp_options(
        self,
    ) -> typing.Optional["ComputeInstanceGroupHealthCheckTcpOptions"]:
        '''tcp_options block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#tcp_options ComputeInstanceGroup#tcp_options}
        '''
        result = self._values.get("tcp_options")
        return typing.cast(typing.Optional["ComputeInstanceGroupHealthCheckTcpOptions"], result)

    @builtins.property
    def timeout(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#timeout ComputeInstanceGroup#timeout}.'''
        result = self._values.get("timeout")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def unhealthy_threshold(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#unhealthy_threshold ComputeInstanceGroup#unhealthy_threshold}.'''
        result = self._values.get("unhealthy_threshold")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceGroupHealthCheck(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupHealthCheckHttpOptions",
    jsii_struct_bases=[],
    name_mapping={"path": "path", "port": "port"},
)
class ComputeInstanceGroupHealthCheckHttpOptions:
    def __init__(self, *, path: builtins.str, port: jsii.Number) -> None:
        '''
        :param path: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#path ComputeInstanceGroup#path}.
        :param port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#port ComputeInstanceGroup#port}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "path": path,
            "port": port,
        }

    @builtins.property
    def path(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#path ComputeInstanceGroup#path}.'''
        result = self._values.get("path")
        assert result is not None, "Required property 'path' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def port(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#port ComputeInstanceGroup#port}.'''
        result = self._values.get("port")
        assert result is not None, "Required property 'port' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceGroupHealthCheckHttpOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeInstanceGroupHealthCheckHttpOptionsList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupHealthCheckHttpOptionsList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "ComputeInstanceGroupHealthCheckHttpOptionsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("ComputeInstanceGroupHealthCheckHttpOptionsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupHealthCheckHttpOptions]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupHealthCheckHttpOptions]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupHealthCheckHttpOptions]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ComputeInstanceGroupHealthCheckHttpOptionsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupHealthCheckHttpOptionsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="pathInput")
    def path_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "pathInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="portInput")
    def port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "portInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="path")
    def path(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "path"))

    @path.setter
    def path(self, value: builtins.str) -> None:
        jsii.set(self, "path", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "port"))

    @port.setter
    def port(self, value: jsii.Number) -> None:
        jsii.set(self, "port", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceGroupHealthCheckHttpOptions]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceGroupHealthCheckHttpOptions]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceGroupHealthCheckHttpOptions]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ComputeInstanceGroupHealthCheckList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupHealthCheckList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "ComputeInstanceGroupHealthCheckOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("ComputeInstanceGroupHealthCheckOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupHealthCheck]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupHealthCheck]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupHealthCheck]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ComputeInstanceGroupHealthCheckOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupHealthCheckOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putHttpOptions")
    def put_http_options(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence[ComputeInstanceGroupHealthCheckHttpOptions]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putHttpOptions", [value]))

    @jsii.member(jsii_name="putTcpOptions")
    def put_tcp_options(self, *, port: jsii.Number) -> None:
        '''
        :param port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#port ComputeInstanceGroup#port}.
        '''
        value = ComputeInstanceGroupHealthCheckTcpOptions(port=port)

        return typing.cast(None, jsii.invoke(self, "putTcpOptions", [value]))

    @jsii.member(jsii_name="resetHealthyThreshold")
    def reset_healthy_threshold(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHealthyThreshold", []))

    @jsii.member(jsii_name="resetHttpOptions")
    def reset_http_options(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttpOptions", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @jsii.member(jsii_name="resetTcpOptions")
    def reset_tcp_options(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTcpOptions", []))

    @jsii.member(jsii_name="resetTimeout")
    def reset_timeout(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeout", []))

    @jsii.member(jsii_name="resetUnhealthyThreshold")
    def reset_unhealthy_threshold(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUnhealthyThreshold", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpOptions")
    def http_options(self) -> ComputeInstanceGroupHealthCheckHttpOptionsList:
        return typing.cast(ComputeInstanceGroupHealthCheckHttpOptionsList, jsii.get(self, "httpOptions"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tcpOptions")
    def tcp_options(self) -> "ComputeInstanceGroupHealthCheckTcpOptionsOutputReference":
        return typing.cast("ComputeInstanceGroupHealthCheckTcpOptionsOutputReference", jsii.get(self, "tcpOptions"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthyThresholdInput")
    def healthy_threshold_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "healthyThresholdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpOptionsInput")
    def http_options_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupHealthCheckHttpOptions]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupHealthCheckHttpOptions]]], jsii.get(self, "httpOptionsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tcpOptionsInput")
    def tcp_options_input(
        self,
    ) -> typing.Optional["ComputeInstanceGroupHealthCheckTcpOptions"]:
        return typing.cast(typing.Optional["ComputeInstanceGroupHealthCheckTcpOptions"], jsii.get(self, "tcpOptionsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutInput")
    def timeout_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "timeoutInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="unhealthyThresholdInput")
    def unhealthy_threshold_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "unhealthyThresholdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthyThreshold")
    def healthy_threshold(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "healthyThreshold"))

    @healthy_threshold.setter
    def healthy_threshold(self, value: jsii.Number) -> None:
        jsii.set(self, "healthyThreshold", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        jsii.set(self, "interval", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeout")
    def timeout(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "timeout"))

    @timeout.setter
    def timeout(self, value: jsii.Number) -> None:
        jsii.set(self, "timeout", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="unhealthyThreshold")
    def unhealthy_threshold(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "unhealthyThreshold"))

    @unhealthy_threshold.setter
    def unhealthy_threshold(self, value: jsii.Number) -> None:
        jsii.set(self, "unhealthyThreshold", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceGroupHealthCheck]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceGroupHealthCheck]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceGroupHealthCheck]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupHealthCheckTcpOptions",
    jsii_struct_bases=[],
    name_mapping={"port": "port"},
)
class ComputeInstanceGroupHealthCheckTcpOptions:
    def __init__(self, *, port: jsii.Number) -> None:
        '''
        :param port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#port ComputeInstanceGroup#port}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "port": port,
        }

    @builtins.property
    def port(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#port ComputeInstanceGroup#port}.'''
        result = self._values.get("port")
        assert result is not None, "Required property 'port' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceGroupHealthCheckTcpOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeInstanceGroupHealthCheckTcpOptionsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupHealthCheckTcpOptionsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="portInput")
    def port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "portInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "port"))

    @port.setter
    def port(self, value: jsii.Number) -> None:
        jsii.set(self, "port", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[ComputeInstanceGroupHealthCheckTcpOptions]:
        return typing.cast(typing.Optional[ComputeInstanceGroupHealthCheckTcpOptions], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[ComputeInstanceGroupHealthCheckTcpOptions],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstanceTemplate",
    jsii_struct_bases=[],
    name_mapping={
        "boot_disk": "bootDisk",
        "network_interface": "networkInterface",
        "resources": "resources",
        "description": "description",
        "hostname": "hostname",
        "labels": "labels",
        "metadata": "metadata",
        "name": "name",
        "network_settings": "networkSettings",
        "placement_policy": "placementPolicy",
        "platform_id": "platformId",
        "scheduling_policy": "schedulingPolicy",
        "secondary_disk": "secondaryDisk",
        "service_account_id": "serviceAccountId",
    },
)
class ComputeInstanceGroupInstanceTemplate:
    def __init__(
        self,
        *,
        boot_disk: "ComputeInstanceGroupInstanceTemplateBootDisk",
        network_interface: typing.Union[cdktf.IResolvable, typing.Sequence["ComputeInstanceGroupInstanceTemplateNetworkInterface"]],
        resources: "ComputeInstanceGroupInstanceTemplateResources",
        description: typing.Optional[builtins.str] = None,
        hostname: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        metadata: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        network_settings: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["ComputeInstanceGroupInstanceTemplateNetworkSettings"]]] = None,
        placement_policy: typing.Optional["ComputeInstanceGroupInstanceTemplatePlacementPolicy"] = None,
        platform_id: typing.Optional[builtins.str] = None,
        scheduling_policy: typing.Optional["ComputeInstanceGroupInstanceTemplateSchedulingPolicy"] = None,
        secondary_disk: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["ComputeInstanceGroupInstanceTemplateSecondaryDisk"]]] = None,
        service_account_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param boot_disk: boot_disk block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#boot_disk ComputeInstanceGroup#boot_disk}
        :param network_interface: network_interface block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#network_interface ComputeInstanceGroup#network_interface}
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#resources ComputeInstanceGroup#resources}
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#description ComputeInstanceGroup#description}.
        :param hostname: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#hostname ComputeInstanceGroup#hostname}.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#labels ComputeInstanceGroup#labels}.
        :param metadata: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#metadata ComputeInstanceGroup#metadata}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#name ComputeInstanceGroup#name}.
        :param network_settings: network_settings block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#network_settings ComputeInstanceGroup#network_settings}
        :param placement_policy: placement_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#placement_policy ComputeInstanceGroup#placement_policy}
        :param platform_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#platform_id ComputeInstanceGroup#platform_id}.
        :param scheduling_policy: scheduling_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#scheduling_policy ComputeInstanceGroup#scheduling_policy}
        :param secondary_disk: secondary_disk block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#secondary_disk ComputeInstanceGroup#secondary_disk}
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#service_account_id ComputeInstanceGroup#service_account_id}.
        '''
        if isinstance(boot_disk, dict):
            boot_disk = ComputeInstanceGroupInstanceTemplateBootDisk(**boot_disk)
        if isinstance(resources, dict):
            resources = ComputeInstanceGroupInstanceTemplateResources(**resources)
        if isinstance(placement_policy, dict):
            placement_policy = ComputeInstanceGroupInstanceTemplatePlacementPolicy(**placement_policy)
        if isinstance(scheduling_policy, dict):
            scheduling_policy = ComputeInstanceGroupInstanceTemplateSchedulingPolicy(**scheduling_policy)
        self._values: typing.Dict[str, typing.Any] = {
            "boot_disk": boot_disk,
            "network_interface": network_interface,
            "resources": resources,
        }
        if description is not None:
            self._values["description"] = description
        if hostname is not None:
            self._values["hostname"] = hostname
        if labels is not None:
            self._values["labels"] = labels
        if metadata is not None:
            self._values["metadata"] = metadata
        if name is not None:
            self._values["name"] = name
        if network_settings is not None:
            self._values["network_settings"] = network_settings
        if placement_policy is not None:
            self._values["placement_policy"] = placement_policy
        if platform_id is not None:
            self._values["platform_id"] = platform_id
        if scheduling_policy is not None:
            self._values["scheduling_policy"] = scheduling_policy
        if secondary_disk is not None:
            self._values["secondary_disk"] = secondary_disk
        if service_account_id is not None:
            self._values["service_account_id"] = service_account_id

    @builtins.property
    def boot_disk(self) -> "ComputeInstanceGroupInstanceTemplateBootDisk":
        '''boot_disk block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#boot_disk ComputeInstanceGroup#boot_disk}
        '''
        result = self._values.get("boot_disk")
        assert result is not None, "Required property 'boot_disk' is missing"
        return typing.cast("ComputeInstanceGroupInstanceTemplateBootDisk", result)

    @builtins.property
    def network_interface(
        self,
    ) -> typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceGroupInstanceTemplateNetworkInterface"]]:
        '''network_interface block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#network_interface ComputeInstanceGroup#network_interface}
        '''
        result = self._values.get("network_interface")
        assert result is not None, "Required property 'network_interface' is missing"
        return typing.cast(typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceGroupInstanceTemplateNetworkInterface"]], result)

    @builtins.property
    def resources(self) -> "ComputeInstanceGroupInstanceTemplateResources":
        '''resources block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#resources ComputeInstanceGroup#resources}
        '''
        result = self._values.get("resources")
        assert result is not None, "Required property 'resources' is missing"
        return typing.cast("ComputeInstanceGroupInstanceTemplateResources", result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#description ComputeInstanceGroup#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def hostname(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#hostname ComputeInstanceGroup#hostname}.'''
        result = self._values.get("hostname")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#labels ComputeInstanceGroup#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def metadata(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#metadata ComputeInstanceGroup#metadata}.'''
        result = self._values.get("metadata")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#name ComputeInstanceGroup#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def network_settings(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceGroupInstanceTemplateNetworkSettings"]]]:
        '''network_settings block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#network_settings ComputeInstanceGroup#network_settings}
        '''
        result = self._values.get("network_settings")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceGroupInstanceTemplateNetworkSettings"]]], result)

    @builtins.property
    def placement_policy(
        self,
    ) -> typing.Optional["ComputeInstanceGroupInstanceTemplatePlacementPolicy"]:
        '''placement_policy block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#placement_policy ComputeInstanceGroup#placement_policy}
        '''
        result = self._values.get("placement_policy")
        return typing.cast(typing.Optional["ComputeInstanceGroupInstanceTemplatePlacementPolicy"], result)

    @builtins.property
    def platform_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#platform_id ComputeInstanceGroup#platform_id}.'''
        result = self._values.get("platform_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def scheduling_policy(
        self,
    ) -> typing.Optional["ComputeInstanceGroupInstanceTemplateSchedulingPolicy"]:
        '''scheduling_policy block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#scheduling_policy ComputeInstanceGroup#scheduling_policy}
        '''
        result = self._values.get("scheduling_policy")
        return typing.cast(typing.Optional["ComputeInstanceGroupInstanceTemplateSchedulingPolicy"], result)

    @builtins.property
    def secondary_disk(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceGroupInstanceTemplateSecondaryDisk"]]]:
        '''secondary_disk block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#secondary_disk ComputeInstanceGroup#secondary_disk}
        '''
        result = self._values.get("secondary_disk")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceGroupInstanceTemplateSecondaryDisk"]]], result)

    @builtins.property
    def service_account_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#service_account_id ComputeInstanceGroup#service_account_id}.'''
        result = self._values.get("service_account_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceGroupInstanceTemplate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstanceTemplateBootDisk",
    jsii_struct_bases=[],
    name_mapping={
        "device_name": "deviceName",
        "disk_id": "diskId",
        "initialize_params": "initializeParams",
        "mode": "mode",
    },
)
class ComputeInstanceGroupInstanceTemplateBootDisk:
    def __init__(
        self,
        *,
        device_name: typing.Optional[builtins.str] = None,
        disk_id: typing.Optional[builtins.str] = None,
        initialize_params: typing.Optional["ComputeInstanceGroupInstanceTemplateBootDiskInitializeParams"] = None,
        mode: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param device_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#device_name ComputeInstanceGroup#device_name}.
        :param disk_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#disk_id ComputeInstanceGroup#disk_id}.
        :param initialize_params: initialize_params block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#initialize_params ComputeInstanceGroup#initialize_params}
        :param mode: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#mode ComputeInstanceGroup#mode}.
        '''
        if isinstance(initialize_params, dict):
            initialize_params = ComputeInstanceGroupInstanceTemplateBootDiskInitializeParams(**initialize_params)
        self._values: typing.Dict[str, typing.Any] = {}
        if device_name is not None:
            self._values["device_name"] = device_name
        if disk_id is not None:
            self._values["disk_id"] = disk_id
        if initialize_params is not None:
            self._values["initialize_params"] = initialize_params
        if mode is not None:
            self._values["mode"] = mode

    @builtins.property
    def device_name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#device_name ComputeInstanceGroup#device_name}.'''
        result = self._values.get("device_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def disk_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#disk_id ComputeInstanceGroup#disk_id}.'''
        result = self._values.get("disk_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def initialize_params(
        self,
    ) -> typing.Optional["ComputeInstanceGroupInstanceTemplateBootDiskInitializeParams"]:
        '''initialize_params block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#initialize_params ComputeInstanceGroup#initialize_params}
        '''
        result = self._values.get("initialize_params")
        return typing.cast(typing.Optional["ComputeInstanceGroupInstanceTemplateBootDiskInitializeParams"], result)

    @builtins.property
    def mode(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#mode ComputeInstanceGroup#mode}.'''
        result = self._values.get("mode")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceGroupInstanceTemplateBootDisk(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstanceTemplateBootDiskInitializeParams",
    jsii_struct_bases=[],
    name_mapping={
        "description": "description",
        "image_id": "imageId",
        "size": "size",
        "snapshot_id": "snapshotId",
        "type": "type",
    },
)
class ComputeInstanceGroupInstanceTemplateBootDiskInitializeParams:
    def __init__(
        self,
        *,
        description: typing.Optional[builtins.str] = None,
        image_id: typing.Optional[builtins.str] = None,
        size: typing.Optional[jsii.Number] = None,
        snapshot_id: typing.Optional[builtins.str] = None,
        type: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#description ComputeInstanceGroup#description}.
        :param image_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#image_id ComputeInstanceGroup#image_id}.
        :param size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#size ComputeInstanceGroup#size}.
        :param snapshot_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#snapshot_id ComputeInstanceGroup#snapshot_id}.
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#type ComputeInstanceGroup#type}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if description is not None:
            self._values["description"] = description
        if image_id is not None:
            self._values["image_id"] = image_id
        if size is not None:
            self._values["size"] = size
        if snapshot_id is not None:
            self._values["snapshot_id"] = snapshot_id
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#description ComputeInstanceGroup#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def image_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#image_id ComputeInstanceGroup#image_id}.'''
        result = self._values.get("image_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def size(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#size ComputeInstanceGroup#size}.'''
        result = self._values.get("size")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def snapshot_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#snapshot_id ComputeInstanceGroup#snapshot_id}.'''
        result = self._values.get("snapshot_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def type(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#type ComputeInstanceGroup#type}.'''
        result = self._values.get("type")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceGroupInstanceTemplateBootDiskInitializeParams(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeInstanceGroupInstanceTemplateBootDiskInitializeParamsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstanceTemplateBootDiskInitializeParamsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetImageId")
    def reset_image_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetImageId", []))

    @jsii.member(jsii_name="resetSize")
    def reset_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSize", []))

    @jsii.member(jsii_name="resetSnapshotId")
    def reset_snapshot_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSnapshotId", []))

    @jsii.member(jsii_name="resetType")
    def reset_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetType", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="imageIdInput")
    def image_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "imageIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sizeInput")
    def size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "sizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="snapshotIdInput")
    def snapshot_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "snapshotIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="typeInput")
    def type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "typeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="imageId")
    def image_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "imageId"))

    @image_id.setter
    def image_id(self, value: builtins.str) -> None:
        jsii.set(self, "imageId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="size")
    def size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "size"))

    @size.setter
    def size(self, value: jsii.Number) -> None:
        jsii.set(self, "size", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="snapshotId")
    def snapshot_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "snapshotId"))

    @snapshot_id.setter
    def snapshot_id(self, value: builtins.str) -> None:
        jsii.set(self, "snapshotId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @type.setter
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[ComputeInstanceGroupInstanceTemplateBootDiskInitializeParams]:
        return typing.cast(typing.Optional[ComputeInstanceGroupInstanceTemplateBootDiskInitializeParams], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[ComputeInstanceGroupInstanceTemplateBootDiskInitializeParams],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ComputeInstanceGroupInstanceTemplateBootDiskOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstanceTemplateBootDiskOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putInitializeParams")
    def put_initialize_params(
        self,
        *,
        description: typing.Optional[builtins.str] = None,
        image_id: typing.Optional[builtins.str] = None,
        size: typing.Optional[jsii.Number] = None,
        snapshot_id: typing.Optional[builtins.str] = None,
        type: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#description ComputeInstanceGroup#description}.
        :param image_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#image_id ComputeInstanceGroup#image_id}.
        :param size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#size ComputeInstanceGroup#size}.
        :param snapshot_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#snapshot_id ComputeInstanceGroup#snapshot_id}.
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#type ComputeInstanceGroup#type}.
        '''
        value = ComputeInstanceGroupInstanceTemplateBootDiskInitializeParams(
            description=description,
            image_id=image_id,
            size=size,
            snapshot_id=snapshot_id,
            type=type,
        )

        return typing.cast(None, jsii.invoke(self, "putInitializeParams", [value]))

    @jsii.member(jsii_name="resetDeviceName")
    def reset_device_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDeviceName", []))

    @jsii.member(jsii_name="resetDiskId")
    def reset_disk_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDiskId", []))

    @jsii.member(jsii_name="resetInitializeParams")
    def reset_initialize_params(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInitializeParams", []))

    @jsii.member(jsii_name="resetMode")
    def reset_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMode", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="initializeParams")
    def initialize_params(
        self,
    ) -> ComputeInstanceGroupInstanceTemplateBootDiskInitializeParamsOutputReference:
        return typing.cast(ComputeInstanceGroupInstanceTemplateBootDiskInitializeParamsOutputReference, jsii.get(self, "initializeParams"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deviceNameInput")
    def device_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deviceNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskIdInput")
    def disk_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "diskIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="initializeParamsInput")
    def initialize_params_input(
        self,
    ) -> typing.Optional[ComputeInstanceGroupInstanceTemplateBootDiskInitializeParams]:
        return typing.cast(typing.Optional[ComputeInstanceGroupInstanceTemplateBootDiskInitializeParams], jsii.get(self, "initializeParamsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="modeInput")
    def mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "modeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deviceName")
    def device_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "deviceName"))

    @device_name.setter
    def device_name(self, value: builtins.str) -> None:
        jsii.set(self, "deviceName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskId")
    def disk_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskId"))

    @disk_id.setter
    def disk_id(self, value: builtins.str) -> None:
        jsii.set(self, "diskId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mode")
    def mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "mode"))

    @mode.setter
    def mode(self, value: builtins.str) -> None:
        jsii.set(self, "mode", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[ComputeInstanceGroupInstanceTemplateBootDisk]:
        return typing.cast(typing.Optional[ComputeInstanceGroupInstanceTemplateBootDisk], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[ComputeInstanceGroupInstanceTemplateBootDisk],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstanceTemplateNetworkInterface",
    jsii_struct_bases=[],
    name_mapping={
        "dns_record": "dnsRecord",
        "ip_address": "ipAddress",
        "ipv4": "ipv4",
        "ipv6": "ipv6",
        "ipv6_address": "ipv6Address",
        "ipv6_dns_record": "ipv6DnsRecord",
        "nat": "nat",
        "nat_dns_record": "natDnsRecord",
        "nat_ip_address": "natIpAddress",
        "network_id": "networkId",
        "security_group_ids": "securityGroupIds",
        "subnet_ids": "subnetIds",
    },
)
class ComputeInstanceGroupInstanceTemplateNetworkInterface:
    def __init__(
        self,
        *,
        dns_record: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["ComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecord"]]] = None,
        ip_address: typing.Optional[builtins.str] = None,
        ipv4: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        ipv6: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        ipv6_address: typing.Optional[builtins.str] = None,
        ipv6_dns_record: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["ComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecord"]]] = None,
        nat: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        nat_dns_record: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["ComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecord"]]] = None,
        nat_ip_address: typing.Optional[builtins.str] = None,
        network_id: typing.Optional[builtins.str] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        subnet_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param dns_record: dns_record block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#dns_record ComputeInstanceGroup#dns_record}
        :param ip_address: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#ip_address ComputeInstanceGroup#ip_address}.
        :param ipv4: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#ipv4 ComputeInstanceGroup#ipv4}.
        :param ipv6: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#ipv6 ComputeInstanceGroup#ipv6}.
        :param ipv6_address: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#ipv6_address ComputeInstanceGroup#ipv6_address}.
        :param ipv6_dns_record: ipv6_dns_record block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#ipv6_dns_record ComputeInstanceGroup#ipv6_dns_record}
        :param nat: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#nat ComputeInstanceGroup#nat}.
        :param nat_dns_record: nat_dns_record block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#nat_dns_record ComputeInstanceGroup#nat_dns_record}
        :param nat_ip_address: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#nat_ip_address ComputeInstanceGroup#nat_ip_address}.
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#network_id ComputeInstanceGroup#network_id}.
        :param security_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#security_group_ids ComputeInstanceGroup#security_group_ids}.
        :param subnet_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#subnet_ids ComputeInstanceGroup#subnet_ids}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if dns_record is not None:
            self._values["dns_record"] = dns_record
        if ip_address is not None:
            self._values["ip_address"] = ip_address
        if ipv4 is not None:
            self._values["ipv4"] = ipv4
        if ipv6 is not None:
            self._values["ipv6"] = ipv6
        if ipv6_address is not None:
            self._values["ipv6_address"] = ipv6_address
        if ipv6_dns_record is not None:
            self._values["ipv6_dns_record"] = ipv6_dns_record
        if nat is not None:
            self._values["nat"] = nat
        if nat_dns_record is not None:
            self._values["nat_dns_record"] = nat_dns_record
        if nat_ip_address is not None:
            self._values["nat_ip_address"] = nat_ip_address
        if network_id is not None:
            self._values["network_id"] = network_id
        if security_group_ids is not None:
            self._values["security_group_ids"] = security_group_ids
        if subnet_ids is not None:
            self._values["subnet_ids"] = subnet_ids

    @builtins.property
    def dns_record(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecord"]]]:
        '''dns_record block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#dns_record ComputeInstanceGroup#dns_record}
        '''
        result = self._values.get("dns_record")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecord"]]], result)

    @builtins.property
    def ip_address(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#ip_address ComputeInstanceGroup#ip_address}.'''
        result = self._values.get("ip_address")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def ipv4(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#ipv4 ComputeInstanceGroup#ipv4}.'''
        result = self._values.get("ipv4")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def ipv6(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#ipv6 ComputeInstanceGroup#ipv6}.'''
        result = self._values.get("ipv6")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def ipv6_address(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#ipv6_address ComputeInstanceGroup#ipv6_address}.'''
        result = self._values.get("ipv6_address")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def ipv6_dns_record(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecord"]]]:
        '''ipv6_dns_record block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#ipv6_dns_record ComputeInstanceGroup#ipv6_dns_record}
        '''
        result = self._values.get("ipv6_dns_record")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecord"]]], result)

    @builtins.property
    def nat(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#nat ComputeInstanceGroup#nat}.'''
        result = self._values.get("nat")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def nat_dns_record(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecord"]]]:
        '''nat_dns_record block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#nat_dns_record ComputeInstanceGroup#nat_dns_record}
        '''
        result = self._values.get("nat_dns_record")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecord"]]], result)

    @builtins.property
    def nat_ip_address(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#nat_ip_address ComputeInstanceGroup#nat_ip_address}.'''
        result = self._values.get("nat_ip_address")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def network_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#network_id ComputeInstanceGroup#network_id}.'''
        result = self._values.get("network_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def security_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#security_group_ids ComputeInstanceGroup#security_group_ids}.'''
        result = self._values.get("security_group_ids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def subnet_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#subnet_ids ComputeInstanceGroup#subnet_ids}.'''
        result = self._values.get("subnet_ids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceGroupInstanceTemplateNetworkInterface(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecord",
    jsii_struct_bases=[],
    name_mapping={
        "fqdn": "fqdn",
        "dns_zone_id": "dnsZoneId",
        "ptr": "ptr",
        "ttl": "ttl",
    },
)
class ComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecord:
    def __init__(
        self,
        *,
        fqdn: builtins.str,
        dns_zone_id: typing.Optional[builtins.str] = None,
        ptr: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        ttl: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param fqdn: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#fqdn ComputeInstanceGroup#fqdn}.
        :param dns_zone_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#dns_zone_id ComputeInstanceGroup#dns_zone_id}.
        :param ptr: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#ptr ComputeInstanceGroup#ptr}.
        :param ttl: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#ttl ComputeInstanceGroup#ttl}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "fqdn": fqdn,
        }
        if dns_zone_id is not None:
            self._values["dns_zone_id"] = dns_zone_id
        if ptr is not None:
            self._values["ptr"] = ptr
        if ttl is not None:
            self._values["ttl"] = ttl

    @builtins.property
    def fqdn(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#fqdn ComputeInstanceGroup#fqdn}.'''
        result = self._values.get("fqdn")
        assert result is not None, "Required property 'fqdn' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def dns_zone_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#dns_zone_id ComputeInstanceGroup#dns_zone_id}.'''
        result = self._values.get("dns_zone_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def ptr(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#ptr ComputeInstanceGroup#ptr}.'''
        result = self._values.get("ptr")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def ttl(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#ttl ComputeInstanceGroup#ttl}.'''
        result = self._values.get("ttl")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecord(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecordList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecordList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "ComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecordOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("ComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecordOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecord]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecord]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecord]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecordOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecordOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetDnsZoneId")
    def reset_dns_zone_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDnsZoneId", []))

    @jsii.member(jsii_name="resetPtr")
    def reset_ptr(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPtr", []))

    @jsii.member(jsii_name="resetTtl")
    def reset_ttl(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTtl", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dnsZoneIdInput")
    def dns_zone_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dnsZoneIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdnInput")
    def fqdn_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "fqdnInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ptrInput")
    def ptr_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "ptrInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ttlInput")
    def ttl_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "ttlInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dnsZoneId")
    def dns_zone_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dnsZoneId"))

    @dns_zone_id.setter
    def dns_zone_id(self, value: builtins.str) -> None:
        jsii.set(self, "dnsZoneId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fqdn"))

    @fqdn.setter
    def fqdn(self, value: builtins.str) -> None:
        jsii.set(self, "fqdn", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ptr")
    def ptr(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "ptr"))

    @ptr.setter
    def ptr(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "ptr", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ttl")
    def ttl(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "ttl"))

    @ttl.setter
    def ttl(self, value: jsii.Number) -> None:
        jsii.set(self, "ttl", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecord]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecord]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecord]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecord",
    jsii_struct_bases=[],
    name_mapping={
        "fqdn": "fqdn",
        "dns_zone_id": "dnsZoneId",
        "ptr": "ptr",
        "ttl": "ttl",
    },
)
class ComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecord:
    def __init__(
        self,
        *,
        fqdn: builtins.str,
        dns_zone_id: typing.Optional[builtins.str] = None,
        ptr: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        ttl: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param fqdn: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#fqdn ComputeInstanceGroup#fqdn}.
        :param dns_zone_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#dns_zone_id ComputeInstanceGroup#dns_zone_id}.
        :param ptr: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#ptr ComputeInstanceGroup#ptr}.
        :param ttl: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#ttl ComputeInstanceGroup#ttl}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "fqdn": fqdn,
        }
        if dns_zone_id is not None:
            self._values["dns_zone_id"] = dns_zone_id
        if ptr is not None:
            self._values["ptr"] = ptr
        if ttl is not None:
            self._values["ttl"] = ttl

    @builtins.property
    def fqdn(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#fqdn ComputeInstanceGroup#fqdn}.'''
        result = self._values.get("fqdn")
        assert result is not None, "Required property 'fqdn' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def dns_zone_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#dns_zone_id ComputeInstanceGroup#dns_zone_id}.'''
        result = self._values.get("dns_zone_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def ptr(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#ptr ComputeInstanceGroup#ptr}.'''
        result = self._values.get("ptr")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def ttl(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#ttl ComputeInstanceGroup#ttl}.'''
        result = self._values.get("ttl")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecord(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecordList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecordList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "ComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecordOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("ComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecordOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecord]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecord]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecord]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecordOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecordOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetDnsZoneId")
    def reset_dns_zone_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDnsZoneId", []))

    @jsii.member(jsii_name="resetPtr")
    def reset_ptr(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPtr", []))

    @jsii.member(jsii_name="resetTtl")
    def reset_ttl(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTtl", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dnsZoneIdInput")
    def dns_zone_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dnsZoneIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdnInput")
    def fqdn_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "fqdnInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ptrInput")
    def ptr_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "ptrInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ttlInput")
    def ttl_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "ttlInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dnsZoneId")
    def dns_zone_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dnsZoneId"))

    @dns_zone_id.setter
    def dns_zone_id(self, value: builtins.str) -> None:
        jsii.set(self, "dnsZoneId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fqdn"))

    @fqdn.setter
    def fqdn(self, value: builtins.str) -> None:
        jsii.set(self, "fqdn", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ptr")
    def ptr(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "ptr"))

    @ptr.setter
    def ptr(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "ptr", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ttl")
    def ttl(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "ttl"))

    @ttl.setter
    def ttl(self, value: jsii.Number) -> None:
        jsii.set(self, "ttl", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecord]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecord]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecord]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ComputeInstanceGroupInstanceTemplateNetworkInterfaceList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstanceTemplateNetworkInterfaceList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "ComputeInstanceGroupInstanceTemplateNetworkInterfaceOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("ComputeInstanceGroupInstanceTemplateNetworkInterfaceOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupInstanceTemplateNetworkInterface]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupInstanceTemplateNetworkInterface]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupInstanceTemplateNetworkInterface]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecord",
    jsii_struct_bases=[],
    name_mapping={
        "fqdn": "fqdn",
        "dns_zone_id": "dnsZoneId",
        "ptr": "ptr",
        "ttl": "ttl",
    },
)
class ComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecord:
    def __init__(
        self,
        *,
        fqdn: builtins.str,
        dns_zone_id: typing.Optional[builtins.str] = None,
        ptr: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        ttl: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param fqdn: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#fqdn ComputeInstanceGroup#fqdn}.
        :param dns_zone_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#dns_zone_id ComputeInstanceGroup#dns_zone_id}.
        :param ptr: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#ptr ComputeInstanceGroup#ptr}.
        :param ttl: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#ttl ComputeInstanceGroup#ttl}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "fqdn": fqdn,
        }
        if dns_zone_id is not None:
            self._values["dns_zone_id"] = dns_zone_id
        if ptr is not None:
            self._values["ptr"] = ptr
        if ttl is not None:
            self._values["ttl"] = ttl

    @builtins.property
    def fqdn(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#fqdn ComputeInstanceGroup#fqdn}.'''
        result = self._values.get("fqdn")
        assert result is not None, "Required property 'fqdn' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def dns_zone_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#dns_zone_id ComputeInstanceGroup#dns_zone_id}.'''
        result = self._values.get("dns_zone_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def ptr(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#ptr ComputeInstanceGroup#ptr}.'''
        result = self._values.get("ptr")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def ttl(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#ttl ComputeInstanceGroup#ttl}.'''
        result = self._values.get("ttl")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecord(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecordList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecordList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "ComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecordOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("ComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecordOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecord]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecord]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecord]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecordOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecordOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetDnsZoneId")
    def reset_dns_zone_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDnsZoneId", []))

    @jsii.member(jsii_name="resetPtr")
    def reset_ptr(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPtr", []))

    @jsii.member(jsii_name="resetTtl")
    def reset_ttl(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTtl", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dnsZoneIdInput")
    def dns_zone_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dnsZoneIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdnInput")
    def fqdn_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "fqdnInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ptrInput")
    def ptr_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "ptrInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ttlInput")
    def ttl_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "ttlInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dnsZoneId")
    def dns_zone_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dnsZoneId"))

    @dns_zone_id.setter
    def dns_zone_id(self, value: builtins.str) -> None:
        jsii.set(self, "dnsZoneId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fqdn"))

    @fqdn.setter
    def fqdn(self, value: builtins.str) -> None:
        jsii.set(self, "fqdn", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ptr")
    def ptr(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "ptr"))

    @ptr.setter
    def ptr(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "ptr", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ttl")
    def ttl(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "ttl"))

    @ttl.setter
    def ttl(self, value: jsii.Number) -> None:
        jsii.set(self, "ttl", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecord]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecord]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecord]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ComputeInstanceGroupInstanceTemplateNetworkInterfaceOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstanceTemplateNetworkInterfaceOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putDnsRecord")
    def put_dns_record(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence[ComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecord]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putDnsRecord", [value]))

    @jsii.member(jsii_name="putIpv6DnsRecord")
    def put_ipv6_dns_record(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence[ComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecord]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putIpv6DnsRecord", [value]))

    @jsii.member(jsii_name="putNatDnsRecord")
    def put_nat_dns_record(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence[ComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecord]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putNatDnsRecord", [value]))

    @jsii.member(jsii_name="resetDnsRecord")
    def reset_dns_record(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDnsRecord", []))

    @jsii.member(jsii_name="resetIpAddress")
    def reset_ip_address(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIpAddress", []))

    @jsii.member(jsii_name="resetIpv4")
    def reset_ipv4(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIpv4", []))

    @jsii.member(jsii_name="resetIpv6")
    def reset_ipv6(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIpv6", []))

    @jsii.member(jsii_name="resetIpv6Address")
    def reset_ipv6_address(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIpv6Address", []))

    @jsii.member(jsii_name="resetIpv6DnsRecord")
    def reset_ipv6_dns_record(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIpv6DnsRecord", []))

    @jsii.member(jsii_name="resetNat")
    def reset_nat(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNat", []))

    @jsii.member(jsii_name="resetNatDnsRecord")
    def reset_nat_dns_record(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNatDnsRecord", []))

    @jsii.member(jsii_name="resetNatIpAddress")
    def reset_nat_ip_address(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNatIpAddress", []))

    @jsii.member(jsii_name="resetNetworkId")
    def reset_network_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNetworkId", []))

    @jsii.member(jsii_name="resetSecurityGroupIds")
    def reset_security_group_ids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityGroupIds", []))

    @jsii.member(jsii_name="resetSubnetIds")
    def reset_subnet_ids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSubnetIds", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dnsRecord")
    def dns_record(
        self,
    ) -> ComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecordList:
        return typing.cast(ComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecordList, jsii.get(self, "dnsRecord"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv6DnsRecord")
    def ipv6_dns_record(
        self,
    ) -> ComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecordList:
        return typing.cast(ComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecordList, jsii.get(self, "ipv6DnsRecord"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="natDnsRecord")
    def nat_dns_record(
        self,
    ) -> ComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecordList:
        return typing.cast(ComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecordList, jsii.get(self, "natDnsRecord"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dnsRecordInput")
    def dns_record_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecord]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecord]]], jsii.get(self, "dnsRecordInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipAddressInput")
    def ip_address_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "ipAddressInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv4Input")
    def ipv4_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "ipv4Input"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv6AddressInput")
    def ipv6_address_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "ipv6AddressInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv6DnsRecordInput")
    def ipv6_dns_record_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecord]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecord]]], jsii.get(self, "ipv6DnsRecordInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv6Input")
    def ipv6_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "ipv6Input"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="natDnsRecordInput")
    def nat_dns_record_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecord]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecord]]], jsii.get(self, "natDnsRecordInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="natInput")
    def nat_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "natInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="natIpAddressInput")
    def nat_ip_address_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "natIpAddressInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkIdInput")
    def network_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "networkIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIdsInput")
    def security_group_ids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "securityGroupIdsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIdsInput")
    def subnet_ids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "subnetIdsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipAddress")
    def ip_address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ipAddress"))

    @ip_address.setter
    def ip_address(self, value: builtins.str) -> None:
        jsii.set(self, "ipAddress", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv4")
    def ipv4(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "ipv4"))

    @ipv4.setter
    def ipv4(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "ipv4", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv6")
    def ipv6(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "ipv6"))

    @ipv6.setter
    def ipv6(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "ipv6", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv6Address")
    def ipv6_address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ipv6Address"))

    @ipv6_address.setter
    def ipv6_address(self, value: builtins.str) -> None:
        jsii.set(self, "ipv6Address", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nat")
    def nat(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "nat"))

    @nat.setter
    def nat(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "nat", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="natIpAddress")
    def nat_ip_address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "natIpAddress"))

    @nat_ip_address.setter
    def nat_ip_address(self, value: builtins.str) -> None:
        jsii.set(self, "natIpAddress", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @network_id.setter
    def network_id(self, value: builtins.str) -> None:
        jsii.set(self, "networkId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "securityGroupIds"))

    @security_group_ids.setter
    def security_group_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "securityGroupIds", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "subnetIds"))

    @subnet_ids.setter
    def subnet_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "subnetIds", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceGroupInstanceTemplateNetworkInterface]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceGroupInstanceTemplateNetworkInterface]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceGroupInstanceTemplateNetworkInterface]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstanceTemplateNetworkSettings",
    jsii_struct_bases=[],
    name_mapping={"type": "type"},
)
class ComputeInstanceGroupInstanceTemplateNetworkSettings:
    def __init__(self, *, type: typing.Optional[builtins.str] = None) -> None:
        '''
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#type ComputeInstanceGroup#type}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def type(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#type ComputeInstanceGroup#type}.'''
        result = self._values.get("type")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceGroupInstanceTemplateNetworkSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeInstanceGroupInstanceTemplateNetworkSettingsList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstanceTemplateNetworkSettingsList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "ComputeInstanceGroupInstanceTemplateNetworkSettingsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("ComputeInstanceGroupInstanceTemplateNetworkSettingsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupInstanceTemplateNetworkSettings]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupInstanceTemplateNetworkSettings]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupInstanceTemplateNetworkSettings]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ComputeInstanceGroupInstanceTemplateNetworkSettingsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstanceTemplateNetworkSettingsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetType")
    def reset_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetType", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="typeInput")
    def type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "typeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @type.setter
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceGroupInstanceTemplateNetworkSettings]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceGroupInstanceTemplateNetworkSettings]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceGroupInstanceTemplateNetworkSettings]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ComputeInstanceGroupInstanceTemplateOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstanceTemplateOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putBootDisk")
    def put_boot_disk(
        self,
        *,
        device_name: typing.Optional[builtins.str] = None,
        disk_id: typing.Optional[builtins.str] = None,
        initialize_params: typing.Optional[ComputeInstanceGroupInstanceTemplateBootDiskInitializeParams] = None,
        mode: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param device_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#device_name ComputeInstanceGroup#device_name}.
        :param disk_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#disk_id ComputeInstanceGroup#disk_id}.
        :param initialize_params: initialize_params block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#initialize_params ComputeInstanceGroup#initialize_params}
        :param mode: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#mode ComputeInstanceGroup#mode}.
        '''
        value = ComputeInstanceGroupInstanceTemplateBootDisk(
            device_name=device_name,
            disk_id=disk_id,
            initialize_params=initialize_params,
            mode=mode,
        )

        return typing.cast(None, jsii.invoke(self, "putBootDisk", [value]))

    @jsii.member(jsii_name="putNetworkInterface")
    def put_network_interface(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence[ComputeInstanceGroupInstanceTemplateNetworkInterface]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putNetworkInterface", [value]))

    @jsii.member(jsii_name="putNetworkSettings")
    def put_network_settings(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence[ComputeInstanceGroupInstanceTemplateNetworkSettings]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putNetworkSettings", [value]))

    @jsii.member(jsii_name="putPlacementPolicy")
    def put_placement_policy(self, *, placement_group_id: builtins.str) -> None:
        '''
        :param placement_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#placement_group_id ComputeInstanceGroup#placement_group_id}.
        '''
        value = ComputeInstanceGroupInstanceTemplatePlacementPolicy(
            placement_group_id=placement_group_id
        )

        return typing.cast(None, jsii.invoke(self, "putPlacementPolicy", [value]))

    @jsii.member(jsii_name="putResources")
    def put_resources(
        self,
        *,
        cores: jsii.Number,
        memory: jsii.Number,
        core_fraction: typing.Optional[jsii.Number] = None,
        gpus: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param cores: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#cores ComputeInstanceGroup#cores}.
        :param memory: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#memory ComputeInstanceGroup#memory}.
        :param core_fraction: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#core_fraction ComputeInstanceGroup#core_fraction}.
        :param gpus: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#gpus ComputeInstanceGroup#gpus}.
        '''
        value = ComputeInstanceGroupInstanceTemplateResources(
            cores=cores, memory=memory, core_fraction=core_fraction, gpus=gpus
        )

        return typing.cast(None, jsii.invoke(self, "putResources", [value]))

    @jsii.member(jsii_name="putSchedulingPolicy")
    def put_scheduling_policy(
        self,
        *,
        preemptible: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param preemptible: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#preemptible ComputeInstanceGroup#preemptible}.
        '''
        value = ComputeInstanceGroupInstanceTemplateSchedulingPolicy(
            preemptible=preemptible
        )

        return typing.cast(None, jsii.invoke(self, "putSchedulingPolicy", [value]))

    @jsii.member(jsii_name="putSecondaryDisk")
    def put_secondary_disk(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["ComputeInstanceGroupInstanceTemplateSecondaryDisk"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putSecondaryDisk", [value]))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetHostname")
    def reset_hostname(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHostname", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetMetadata")
    def reset_metadata(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetadata", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetNetworkSettings")
    def reset_network_settings(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNetworkSettings", []))

    @jsii.member(jsii_name="resetPlacementPolicy")
    def reset_placement_policy(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPlacementPolicy", []))

    @jsii.member(jsii_name="resetPlatformId")
    def reset_platform_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPlatformId", []))

    @jsii.member(jsii_name="resetSchedulingPolicy")
    def reset_scheduling_policy(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSchedulingPolicy", []))

    @jsii.member(jsii_name="resetSecondaryDisk")
    def reset_secondary_disk(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecondaryDisk", []))

    @jsii.member(jsii_name="resetServiceAccountId")
    def reset_service_account_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetServiceAccountId", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bootDisk")
    def boot_disk(self) -> ComputeInstanceGroupInstanceTemplateBootDiskOutputReference:
        return typing.cast(ComputeInstanceGroupInstanceTemplateBootDiskOutputReference, jsii.get(self, "bootDisk"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkInterface")
    def network_interface(
        self,
    ) -> ComputeInstanceGroupInstanceTemplateNetworkInterfaceList:
        return typing.cast(ComputeInstanceGroupInstanceTemplateNetworkInterfaceList, jsii.get(self, "networkInterface"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkSettings")
    def network_settings(
        self,
    ) -> ComputeInstanceGroupInstanceTemplateNetworkSettingsList:
        return typing.cast(ComputeInstanceGroupInstanceTemplateNetworkSettingsList, jsii.get(self, "networkSettings"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="placementPolicy")
    def placement_policy(
        self,
    ) -> "ComputeInstanceGroupInstanceTemplatePlacementPolicyOutputReference":
        return typing.cast("ComputeInstanceGroupInstanceTemplatePlacementPolicyOutputReference", jsii.get(self, "placementPolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resources")
    def resources(
        self,
    ) -> "ComputeInstanceGroupInstanceTemplateResourcesOutputReference":
        return typing.cast("ComputeInstanceGroupInstanceTemplateResourcesOutputReference", jsii.get(self, "resources"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="schedulingPolicy")
    def scheduling_policy(
        self,
    ) -> "ComputeInstanceGroupInstanceTemplateSchedulingPolicyOutputReference":
        return typing.cast("ComputeInstanceGroupInstanceTemplateSchedulingPolicyOutputReference", jsii.get(self, "schedulingPolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="secondaryDisk")
    def secondary_disk(self) -> "ComputeInstanceGroupInstanceTemplateSecondaryDiskList":
        return typing.cast("ComputeInstanceGroupInstanceTemplateSecondaryDiskList", jsii.get(self, "secondaryDisk"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bootDiskInput")
    def boot_disk_input(
        self,
    ) -> typing.Optional[ComputeInstanceGroupInstanceTemplateBootDisk]:
        return typing.cast(typing.Optional[ComputeInstanceGroupInstanceTemplateBootDisk], jsii.get(self, "bootDiskInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostnameInput")
    def hostname_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "hostnameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metadataInput")
    def metadata_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "metadataInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkInterfaceInput")
    def network_interface_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupInstanceTemplateNetworkInterface]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupInstanceTemplateNetworkInterface]]], jsii.get(self, "networkInterfaceInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkSettingsInput")
    def network_settings_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupInstanceTemplateNetworkSettings]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupInstanceTemplateNetworkSettings]]], jsii.get(self, "networkSettingsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="placementPolicyInput")
    def placement_policy_input(
        self,
    ) -> typing.Optional["ComputeInstanceGroupInstanceTemplatePlacementPolicy"]:
        return typing.cast(typing.Optional["ComputeInstanceGroupInstanceTemplatePlacementPolicy"], jsii.get(self, "placementPolicyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="platformIdInput")
    def platform_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "platformIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcesInput")
    def resources_input(
        self,
    ) -> typing.Optional["ComputeInstanceGroupInstanceTemplateResources"]:
        return typing.cast(typing.Optional["ComputeInstanceGroupInstanceTemplateResources"], jsii.get(self, "resourcesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="schedulingPolicyInput")
    def scheduling_policy_input(
        self,
    ) -> typing.Optional["ComputeInstanceGroupInstanceTemplateSchedulingPolicy"]:
        return typing.cast(typing.Optional["ComputeInstanceGroupInstanceTemplateSchedulingPolicy"], jsii.get(self, "schedulingPolicyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="secondaryDiskInput")
    def secondary_disk_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceGroupInstanceTemplateSecondaryDisk"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceGroupInstanceTemplateSecondaryDisk"]]], jsii.get(self, "secondaryDiskInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountIdInput")
    def service_account_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceAccountIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostname")
    def hostname(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "hostname"))

    @hostname.setter
    def hostname(self, value: builtins.str) -> None:
        jsii.set(self, "hostname", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metadata")
    def metadata(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "metadata"))

    @metadata.setter
    def metadata(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "metadata", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="platformId")
    def platform_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "platformId"))

    @platform_id.setter
    def platform_id(self, value: builtins.str) -> None:
        jsii.set(self, "platformId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountId")
    def service_account_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceAccountId"))

    @service_account_id.setter
    def service_account_id(self, value: builtins.str) -> None:
        jsii.set(self, "serviceAccountId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[ComputeInstanceGroupInstanceTemplate]:
        return typing.cast(typing.Optional[ComputeInstanceGroupInstanceTemplate], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[ComputeInstanceGroupInstanceTemplate],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstanceTemplatePlacementPolicy",
    jsii_struct_bases=[],
    name_mapping={"placement_group_id": "placementGroupId"},
)
class ComputeInstanceGroupInstanceTemplatePlacementPolicy:
    def __init__(self, *, placement_group_id: builtins.str) -> None:
        '''
        :param placement_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#placement_group_id ComputeInstanceGroup#placement_group_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "placement_group_id": placement_group_id,
        }

    @builtins.property
    def placement_group_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#placement_group_id ComputeInstanceGroup#placement_group_id}.'''
        result = self._values.get("placement_group_id")
        assert result is not None, "Required property 'placement_group_id' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceGroupInstanceTemplatePlacementPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeInstanceGroupInstanceTemplatePlacementPolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstanceTemplatePlacementPolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="placementGroupIdInput")
    def placement_group_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "placementGroupIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="placementGroupId")
    def placement_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "placementGroupId"))

    @placement_group_id.setter
    def placement_group_id(self, value: builtins.str) -> None:
        jsii.set(self, "placementGroupId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[ComputeInstanceGroupInstanceTemplatePlacementPolicy]:
        return typing.cast(typing.Optional[ComputeInstanceGroupInstanceTemplatePlacementPolicy], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[ComputeInstanceGroupInstanceTemplatePlacementPolicy],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstanceTemplateResources",
    jsii_struct_bases=[],
    name_mapping={
        "cores": "cores",
        "memory": "memory",
        "core_fraction": "coreFraction",
        "gpus": "gpus",
    },
)
class ComputeInstanceGroupInstanceTemplateResources:
    def __init__(
        self,
        *,
        cores: jsii.Number,
        memory: jsii.Number,
        core_fraction: typing.Optional[jsii.Number] = None,
        gpus: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param cores: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#cores ComputeInstanceGroup#cores}.
        :param memory: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#memory ComputeInstanceGroup#memory}.
        :param core_fraction: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#core_fraction ComputeInstanceGroup#core_fraction}.
        :param gpus: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#gpus ComputeInstanceGroup#gpus}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "cores": cores,
            "memory": memory,
        }
        if core_fraction is not None:
            self._values["core_fraction"] = core_fraction
        if gpus is not None:
            self._values["gpus"] = gpus

    @builtins.property
    def cores(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#cores ComputeInstanceGroup#cores}.'''
        result = self._values.get("cores")
        assert result is not None, "Required property 'cores' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def memory(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#memory ComputeInstanceGroup#memory}.'''
        result = self._values.get("memory")
        assert result is not None, "Required property 'memory' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def core_fraction(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#core_fraction ComputeInstanceGroup#core_fraction}.'''
        result = self._values.get("core_fraction")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def gpus(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#gpus ComputeInstanceGroup#gpus}.'''
        result = self._values.get("gpus")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceGroupInstanceTemplateResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeInstanceGroupInstanceTemplateResourcesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstanceTemplateResourcesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCoreFraction")
    def reset_core_fraction(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCoreFraction", []))

    @jsii.member(jsii_name="resetGpus")
    def reset_gpus(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGpus", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="coreFractionInput")
    def core_fraction_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "coreFractionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="coresInput")
    def cores_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "coresInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="gpusInput")
    def gpus_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "gpusInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="memoryInput")
    def memory_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "memoryInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="coreFraction")
    def core_fraction(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "coreFraction"))

    @core_fraction.setter
    def core_fraction(self, value: jsii.Number) -> None:
        jsii.set(self, "coreFraction", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cores")
    def cores(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "cores"))

    @cores.setter
    def cores(self, value: jsii.Number) -> None:
        jsii.set(self, "cores", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="gpus")
    def gpus(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "gpus"))

    @gpus.setter
    def gpus(self, value: jsii.Number) -> None:
        jsii.set(self, "gpus", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="memory")
    def memory(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "memory"))

    @memory.setter
    def memory(self, value: jsii.Number) -> None:
        jsii.set(self, "memory", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[ComputeInstanceGroupInstanceTemplateResources]:
        return typing.cast(typing.Optional[ComputeInstanceGroupInstanceTemplateResources], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[ComputeInstanceGroupInstanceTemplateResources],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstanceTemplateSchedulingPolicy",
    jsii_struct_bases=[],
    name_mapping={"preemptible": "preemptible"},
)
class ComputeInstanceGroupInstanceTemplateSchedulingPolicy:
    def __init__(
        self,
        *,
        preemptible: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param preemptible: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#preemptible ComputeInstanceGroup#preemptible}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if preemptible is not None:
            self._values["preemptible"] = preemptible

    @builtins.property
    def preemptible(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#preemptible ComputeInstanceGroup#preemptible}.'''
        result = self._values.get("preemptible")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceGroupInstanceTemplateSchedulingPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeInstanceGroupInstanceTemplateSchedulingPolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstanceTemplateSchedulingPolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetPreemptible")
    def reset_preemptible(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPreemptible", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="preemptibleInput")
    def preemptible_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "preemptibleInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="preemptible")
    def preemptible(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "preemptible"))

    @preemptible.setter
    def preemptible(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "preemptible", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[ComputeInstanceGroupInstanceTemplateSchedulingPolicy]:
        return typing.cast(typing.Optional[ComputeInstanceGroupInstanceTemplateSchedulingPolicy], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[ComputeInstanceGroupInstanceTemplateSchedulingPolicy],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstanceTemplateSecondaryDisk",
    jsii_struct_bases=[],
    name_mapping={
        "device_name": "deviceName",
        "disk_id": "diskId",
        "initialize_params": "initializeParams",
        "mode": "mode",
    },
)
class ComputeInstanceGroupInstanceTemplateSecondaryDisk:
    def __init__(
        self,
        *,
        device_name: typing.Optional[builtins.str] = None,
        disk_id: typing.Optional[builtins.str] = None,
        initialize_params: typing.Optional["ComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParams"] = None,
        mode: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param device_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#device_name ComputeInstanceGroup#device_name}.
        :param disk_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#disk_id ComputeInstanceGroup#disk_id}.
        :param initialize_params: initialize_params block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#initialize_params ComputeInstanceGroup#initialize_params}
        :param mode: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#mode ComputeInstanceGroup#mode}.
        '''
        if isinstance(initialize_params, dict):
            initialize_params = ComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParams(**initialize_params)
        self._values: typing.Dict[str, typing.Any] = {}
        if device_name is not None:
            self._values["device_name"] = device_name
        if disk_id is not None:
            self._values["disk_id"] = disk_id
        if initialize_params is not None:
            self._values["initialize_params"] = initialize_params
        if mode is not None:
            self._values["mode"] = mode

    @builtins.property
    def device_name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#device_name ComputeInstanceGroup#device_name}.'''
        result = self._values.get("device_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def disk_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#disk_id ComputeInstanceGroup#disk_id}.'''
        result = self._values.get("disk_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def initialize_params(
        self,
    ) -> typing.Optional["ComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParams"]:
        '''initialize_params block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#initialize_params ComputeInstanceGroup#initialize_params}
        '''
        result = self._values.get("initialize_params")
        return typing.cast(typing.Optional["ComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParams"], result)

    @builtins.property
    def mode(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#mode ComputeInstanceGroup#mode}.'''
        result = self._values.get("mode")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceGroupInstanceTemplateSecondaryDisk(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParams",
    jsii_struct_bases=[],
    name_mapping={
        "description": "description",
        "image_id": "imageId",
        "size": "size",
        "snapshot_id": "snapshotId",
        "type": "type",
    },
)
class ComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParams:
    def __init__(
        self,
        *,
        description: typing.Optional[builtins.str] = None,
        image_id: typing.Optional[builtins.str] = None,
        size: typing.Optional[jsii.Number] = None,
        snapshot_id: typing.Optional[builtins.str] = None,
        type: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#description ComputeInstanceGroup#description}.
        :param image_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#image_id ComputeInstanceGroup#image_id}.
        :param size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#size ComputeInstanceGroup#size}.
        :param snapshot_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#snapshot_id ComputeInstanceGroup#snapshot_id}.
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#type ComputeInstanceGroup#type}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if description is not None:
            self._values["description"] = description
        if image_id is not None:
            self._values["image_id"] = image_id
        if size is not None:
            self._values["size"] = size
        if snapshot_id is not None:
            self._values["snapshot_id"] = snapshot_id
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#description ComputeInstanceGroup#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def image_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#image_id ComputeInstanceGroup#image_id}.'''
        result = self._values.get("image_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def size(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#size ComputeInstanceGroup#size}.'''
        result = self._values.get("size")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def snapshot_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#snapshot_id ComputeInstanceGroup#snapshot_id}.'''
        result = self._values.get("snapshot_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def type(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#type ComputeInstanceGroup#type}.'''
        result = self._values.get("type")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParams(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParamsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParamsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetImageId")
    def reset_image_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetImageId", []))

    @jsii.member(jsii_name="resetSize")
    def reset_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSize", []))

    @jsii.member(jsii_name="resetSnapshotId")
    def reset_snapshot_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSnapshotId", []))

    @jsii.member(jsii_name="resetType")
    def reset_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetType", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="imageIdInput")
    def image_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "imageIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sizeInput")
    def size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "sizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="snapshotIdInput")
    def snapshot_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "snapshotIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="typeInput")
    def type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "typeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="imageId")
    def image_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "imageId"))

    @image_id.setter
    def image_id(self, value: builtins.str) -> None:
        jsii.set(self, "imageId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="size")
    def size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "size"))

    @size.setter
    def size(self, value: jsii.Number) -> None:
        jsii.set(self, "size", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="snapshotId")
    def snapshot_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "snapshotId"))

    @snapshot_id.setter
    def snapshot_id(self, value: builtins.str) -> None:
        jsii.set(self, "snapshotId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @type.setter
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[ComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParams]:
        return typing.cast(typing.Optional[ComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParams], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[ComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParams],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ComputeInstanceGroupInstanceTemplateSecondaryDiskList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstanceTemplateSecondaryDiskList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "ComputeInstanceGroupInstanceTemplateSecondaryDiskOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("ComputeInstanceGroupInstanceTemplateSecondaryDiskOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupInstanceTemplateSecondaryDisk]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupInstanceTemplateSecondaryDisk]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupInstanceTemplateSecondaryDisk]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ComputeInstanceGroupInstanceTemplateSecondaryDiskOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstanceTemplateSecondaryDiskOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putInitializeParams")
    def put_initialize_params(
        self,
        *,
        description: typing.Optional[builtins.str] = None,
        image_id: typing.Optional[builtins.str] = None,
        size: typing.Optional[jsii.Number] = None,
        snapshot_id: typing.Optional[builtins.str] = None,
        type: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#description ComputeInstanceGroup#description}.
        :param image_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#image_id ComputeInstanceGroup#image_id}.
        :param size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#size ComputeInstanceGroup#size}.
        :param snapshot_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#snapshot_id ComputeInstanceGroup#snapshot_id}.
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#type ComputeInstanceGroup#type}.
        '''
        value = ComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParams(
            description=description,
            image_id=image_id,
            size=size,
            snapshot_id=snapshot_id,
            type=type,
        )

        return typing.cast(None, jsii.invoke(self, "putInitializeParams", [value]))

    @jsii.member(jsii_name="resetDeviceName")
    def reset_device_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDeviceName", []))

    @jsii.member(jsii_name="resetDiskId")
    def reset_disk_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDiskId", []))

    @jsii.member(jsii_name="resetInitializeParams")
    def reset_initialize_params(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInitializeParams", []))

    @jsii.member(jsii_name="resetMode")
    def reset_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMode", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="initializeParams")
    def initialize_params(
        self,
    ) -> ComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParamsOutputReference:
        return typing.cast(ComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParamsOutputReference, jsii.get(self, "initializeParams"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deviceNameInput")
    def device_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deviceNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskIdInput")
    def disk_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "diskIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="initializeParamsInput")
    def initialize_params_input(
        self,
    ) -> typing.Optional[ComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParams]:
        return typing.cast(typing.Optional[ComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParams], jsii.get(self, "initializeParamsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="modeInput")
    def mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "modeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deviceName")
    def device_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "deviceName"))

    @device_name.setter
    def device_name(self, value: builtins.str) -> None:
        jsii.set(self, "deviceName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskId")
    def disk_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskId"))

    @disk_id.setter
    def disk_id(self, value: builtins.str) -> None:
        jsii.set(self, "diskId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mode")
    def mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "mode"))

    @mode.setter
    def mode(self, value: builtins.str) -> None:
        jsii.set(self, "mode", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceGroupInstanceTemplateSecondaryDisk]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceGroupInstanceTemplateSecondaryDisk]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceGroupInstanceTemplateSecondaryDisk]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstances",
    jsii_struct_bases=[],
    name_mapping={},
)
class ComputeInstanceGroupInstances:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceGroupInstances(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeInstanceGroupInstancesList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstancesList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "ComputeInstanceGroupInstancesOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("ComputeInstanceGroupInstancesOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstancesNetworkInterface",
    jsii_struct_bases=[],
    name_mapping={},
)
class ComputeInstanceGroupInstancesNetworkInterface:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceGroupInstancesNetworkInterface(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeInstanceGroupInstancesNetworkInterfaceList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstancesNetworkInterfaceList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "ComputeInstanceGroupInstancesNetworkInterfaceOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("ComputeInstanceGroupInstancesNetworkInterfaceOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class ComputeInstanceGroupInstancesNetworkInterfaceOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstancesNetworkInterfaceOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="index")
    def index(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "index"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipAddress")
    def ip_address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ipAddress"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv4")
    def ipv4(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "ipv4"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv6")
    def ipv6(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "ipv6"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv6Address")
    def ipv6_address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ipv6Address"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="macAddress")
    def mac_address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "macAddress"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nat")
    def nat(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "nat"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="natIpAddress")
    def nat_ip_address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "natIpAddress"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="natIpVersion")
    def nat_ip_version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "natIpVersion"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[ComputeInstanceGroupInstancesNetworkInterface]:
        return typing.cast(typing.Optional[ComputeInstanceGroupInstancesNetworkInterface], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[ComputeInstanceGroupInstancesNetworkInterface],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ComputeInstanceGroupInstancesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupInstancesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fqdn"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="instanceId")
    def instance_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "instanceId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkInterface")
    def network_interface(self) -> ComputeInstanceGroupInstancesNetworkInterfaceList:
        return typing.cast(ComputeInstanceGroupInstancesNetworkInterfaceList, jsii.get(self, "networkInterface"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="statusChangedAt")
    def status_changed_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "statusChangedAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="statusMessage")
    def status_message(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "statusMessage"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneId")
    def zone_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zoneId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[ComputeInstanceGroupInstances]:
        return typing.cast(typing.Optional[ComputeInstanceGroupInstances], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[ComputeInstanceGroupInstances],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupLoadBalancer",
    jsii_struct_bases=[],
    name_mapping={
        "max_opening_traffic_duration": "maxOpeningTrafficDuration",
        "target_group_description": "targetGroupDescription",
        "target_group_labels": "targetGroupLabels",
        "target_group_name": "targetGroupName",
    },
)
class ComputeInstanceGroupLoadBalancer:
    def __init__(
        self,
        *,
        max_opening_traffic_duration: typing.Optional[jsii.Number] = None,
        target_group_description: typing.Optional[builtins.str] = None,
        target_group_labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        target_group_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param max_opening_traffic_duration: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#max_opening_traffic_duration ComputeInstanceGroup#max_opening_traffic_duration}.
        :param target_group_description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#target_group_description ComputeInstanceGroup#target_group_description}.
        :param target_group_labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#target_group_labels ComputeInstanceGroup#target_group_labels}.
        :param target_group_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#target_group_name ComputeInstanceGroup#target_group_name}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if max_opening_traffic_duration is not None:
            self._values["max_opening_traffic_duration"] = max_opening_traffic_duration
        if target_group_description is not None:
            self._values["target_group_description"] = target_group_description
        if target_group_labels is not None:
            self._values["target_group_labels"] = target_group_labels
        if target_group_name is not None:
            self._values["target_group_name"] = target_group_name

    @builtins.property
    def max_opening_traffic_duration(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#max_opening_traffic_duration ComputeInstanceGroup#max_opening_traffic_duration}.'''
        result = self._values.get("max_opening_traffic_duration")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def target_group_description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#target_group_description ComputeInstanceGroup#target_group_description}.'''
        result = self._values.get("target_group_description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def target_group_labels(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#target_group_labels ComputeInstanceGroup#target_group_labels}.'''
        result = self._values.get("target_group_labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def target_group_name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#target_group_name ComputeInstanceGroup#target_group_name}.'''
        result = self._values.get("target_group_name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceGroupLoadBalancer(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeInstanceGroupLoadBalancerOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupLoadBalancerOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetMaxOpeningTrafficDuration")
    def reset_max_opening_traffic_duration(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxOpeningTrafficDuration", []))

    @jsii.member(jsii_name="resetTargetGroupDescription")
    def reset_target_group_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTargetGroupDescription", []))

    @jsii.member(jsii_name="resetTargetGroupLabels")
    def reset_target_group_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTargetGroupLabels", []))

    @jsii.member(jsii_name="resetTargetGroupName")
    def reset_target_group_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTargetGroupName", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="statusMessage")
    def status_message(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "statusMessage"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupId")
    def target_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "targetGroupId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxOpeningTrafficDurationInput")
    def max_opening_traffic_duration_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxOpeningTrafficDurationInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupDescriptionInput")
    def target_group_description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "targetGroupDescriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupLabelsInput")
    def target_group_labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "targetGroupLabelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupNameInput")
    def target_group_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "targetGroupNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxOpeningTrafficDuration")
    def max_opening_traffic_duration(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxOpeningTrafficDuration"))

    @max_opening_traffic_duration.setter
    def max_opening_traffic_duration(self, value: jsii.Number) -> None:
        jsii.set(self, "maxOpeningTrafficDuration", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupDescription")
    def target_group_description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "targetGroupDescription"))

    @target_group_description.setter
    def target_group_description(self, value: builtins.str) -> None:
        jsii.set(self, "targetGroupDescription", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupLabels")
    def target_group_labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "targetGroupLabels"))

    @target_group_labels.setter
    def target_group_labels(
        self,
        value: typing.Mapping[builtins.str, builtins.str],
    ) -> None:
        jsii.set(self, "targetGroupLabels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupName")
    def target_group_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "targetGroupName"))

    @target_group_name.setter
    def target_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "targetGroupName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[ComputeInstanceGroupLoadBalancer]:
        return typing.cast(typing.Optional[ComputeInstanceGroupLoadBalancer], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[ComputeInstanceGroupLoadBalancer],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupScalePolicy",
    jsii_struct_bases=[],
    name_mapping={
        "auto_scale": "autoScale",
        "fixed_scale": "fixedScale",
        "test_auto_scale": "testAutoScale",
    },
)
class ComputeInstanceGroupScalePolicy:
    def __init__(
        self,
        *,
        auto_scale: typing.Optional["ComputeInstanceGroupScalePolicyAutoScale"] = None,
        fixed_scale: typing.Optional["ComputeInstanceGroupScalePolicyFixedScale"] = None,
        test_auto_scale: typing.Optional["ComputeInstanceGroupScalePolicyTestAutoScale"] = None,
    ) -> None:
        '''
        :param auto_scale: auto_scale block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#auto_scale ComputeInstanceGroup#auto_scale}
        :param fixed_scale: fixed_scale block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#fixed_scale ComputeInstanceGroup#fixed_scale}
        :param test_auto_scale: test_auto_scale block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#test_auto_scale ComputeInstanceGroup#test_auto_scale}
        '''
        if isinstance(auto_scale, dict):
            auto_scale = ComputeInstanceGroupScalePolicyAutoScale(**auto_scale)
        if isinstance(fixed_scale, dict):
            fixed_scale = ComputeInstanceGroupScalePolicyFixedScale(**fixed_scale)
        if isinstance(test_auto_scale, dict):
            test_auto_scale = ComputeInstanceGroupScalePolicyTestAutoScale(**test_auto_scale)
        self._values: typing.Dict[str, typing.Any] = {}
        if auto_scale is not None:
            self._values["auto_scale"] = auto_scale
        if fixed_scale is not None:
            self._values["fixed_scale"] = fixed_scale
        if test_auto_scale is not None:
            self._values["test_auto_scale"] = test_auto_scale

    @builtins.property
    def auto_scale(self) -> typing.Optional["ComputeInstanceGroupScalePolicyAutoScale"]:
        '''auto_scale block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#auto_scale ComputeInstanceGroup#auto_scale}
        '''
        result = self._values.get("auto_scale")
        return typing.cast(typing.Optional["ComputeInstanceGroupScalePolicyAutoScale"], result)

    @builtins.property
    def fixed_scale(
        self,
    ) -> typing.Optional["ComputeInstanceGroupScalePolicyFixedScale"]:
        '''fixed_scale block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#fixed_scale ComputeInstanceGroup#fixed_scale}
        '''
        result = self._values.get("fixed_scale")
        return typing.cast(typing.Optional["ComputeInstanceGroupScalePolicyFixedScale"], result)

    @builtins.property
    def test_auto_scale(
        self,
    ) -> typing.Optional["ComputeInstanceGroupScalePolicyTestAutoScale"]:
        '''test_auto_scale block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#test_auto_scale ComputeInstanceGroup#test_auto_scale}
        '''
        result = self._values.get("test_auto_scale")
        return typing.cast(typing.Optional["ComputeInstanceGroupScalePolicyTestAutoScale"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceGroupScalePolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupScalePolicyAutoScale",
    jsii_struct_bases=[],
    name_mapping={
        "initial_size": "initialSize",
        "measurement_duration": "measurementDuration",
        "cpu_utilization_target": "cpuUtilizationTarget",
        "custom_rule": "customRule",
        "max_size": "maxSize",
        "min_zone_size": "minZoneSize",
        "stabilization_duration": "stabilizationDuration",
        "warmup_duration": "warmupDuration",
    },
)
class ComputeInstanceGroupScalePolicyAutoScale:
    def __init__(
        self,
        *,
        initial_size: jsii.Number,
        measurement_duration: jsii.Number,
        cpu_utilization_target: typing.Optional[jsii.Number] = None,
        custom_rule: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["ComputeInstanceGroupScalePolicyAutoScaleCustomRule"]]] = None,
        max_size: typing.Optional[jsii.Number] = None,
        min_zone_size: typing.Optional[jsii.Number] = None,
        stabilization_duration: typing.Optional[jsii.Number] = None,
        warmup_duration: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param initial_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#initial_size ComputeInstanceGroup#initial_size}.
        :param measurement_duration: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#measurement_duration ComputeInstanceGroup#measurement_duration}.
        :param cpu_utilization_target: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#cpu_utilization_target ComputeInstanceGroup#cpu_utilization_target}.
        :param custom_rule: custom_rule block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#custom_rule ComputeInstanceGroup#custom_rule}
        :param max_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#max_size ComputeInstanceGroup#max_size}.
        :param min_zone_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#min_zone_size ComputeInstanceGroup#min_zone_size}.
        :param stabilization_duration: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#stabilization_duration ComputeInstanceGroup#stabilization_duration}.
        :param warmup_duration: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#warmup_duration ComputeInstanceGroup#warmup_duration}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "initial_size": initial_size,
            "measurement_duration": measurement_duration,
        }
        if cpu_utilization_target is not None:
            self._values["cpu_utilization_target"] = cpu_utilization_target
        if custom_rule is not None:
            self._values["custom_rule"] = custom_rule
        if max_size is not None:
            self._values["max_size"] = max_size
        if min_zone_size is not None:
            self._values["min_zone_size"] = min_zone_size
        if stabilization_duration is not None:
            self._values["stabilization_duration"] = stabilization_duration
        if warmup_duration is not None:
            self._values["warmup_duration"] = warmup_duration

    @builtins.property
    def initial_size(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#initial_size ComputeInstanceGroup#initial_size}.'''
        result = self._values.get("initial_size")
        assert result is not None, "Required property 'initial_size' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def measurement_duration(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#measurement_duration ComputeInstanceGroup#measurement_duration}.'''
        result = self._values.get("measurement_duration")
        assert result is not None, "Required property 'measurement_duration' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def cpu_utilization_target(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#cpu_utilization_target ComputeInstanceGroup#cpu_utilization_target}.'''
        result = self._values.get("cpu_utilization_target")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def custom_rule(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceGroupScalePolicyAutoScaleCustomRule"]]]:
        '''custom_rule block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#custom_rule ComputeInstanceGroup#custom_rule}
        '''
        result = self._values.get("custom_rule")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceGroupScalePolicyAutoScaleCustomRule"]]], result)

    @builtins.property
    def max_size(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#max_size ComputeInstanceGroup#max_size}.'''
        result = self._values.get("max_size")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def min_zone_size(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#min_zone_size ComputeInstanceGroup#min_zone_size}.'''
        result = self._values.get("min_zone_size")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def stabilization_duration(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#stabilization_duration ComputeInstanceGroup#stabilization_duration}.'''
        result = self._values.get("stabilization_duration")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def warmup_duration(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#warmup_duration ComputeInstanceGroup#warmup_duration}.'''
        result = self._values.get("warmup_duration")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceGroupScalePolicyAutoScale(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupScalePolicyAutoScaleCustomRule",
    jsii_struct_bases=[],
    name_mapping={
        "metric_name": "metricName",
        "metric_type": "metricType",
        "rule_type": "ruleType",
        "target": "target",
        "folder_id": "folderId",
        "labels": "labels",
        "service": "service",
    },
)
class ComputeInstanceGroupScalePolicyAutoScaleCustomRule:
    def __init__(
        self,
        *,
        metric_name: builtins.str,
        metric_type: builtins.str,
        rule_type: builtins.str,
        target: jsii.Number,
        folder_id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        service: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param metric_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#metric_name ComputeInstanceGroup#metric_name}.
        :param metric_type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#metric_type ComputeInstanceGroup#metric_type}.
        :param rule_type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#rule_type ComputeInstanceGroup#rule_type}.
        :param target: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#target ComputeInstanceGroup#target}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#folder_id ComputeInstanceGroup#folder_id}.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#labels ComputeInstanceGroup#labels}.
        :param service: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#service ComputeInstanceGroup#service}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "metric_name": metric_name,
            "metric_type": metric_type,
            "rule_type": rule_type,
            "target": target,
        }
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if labels is not None:
            self._values["labels"] = labels
        if service is not None:
            self._values["service"] = service

    @builtins.property
    def metric_name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#metric_name ComputeInstanceGroup#metric_name}.'''
        result = self._values.get("metric_name")
        assert result is not None, "Required property 'metric_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def metric_type(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#metric_type ComputeInstanceGroup#metric_type}.'''
        result = self._values.get("metric_type")
        assert result is not None, "Required property 'metric_type' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def rule_type(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#rule_type ComputeInstanceGroup#rule_type}.'''
        result = self._values.get("rule_type")
        assert result is not None, "Required property 'rule_type' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def target(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#target ComputeInstanceGroup#target}.'''
        result = self._values.get("target")
        assert result is not None, "Required property 'target' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#folder_id ComputeInstanceGroup#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#labels ComputeInstanceGroup#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def service(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#service ComputeInstanceGroup#service}.'''
        result = self._values.get("service")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceGroupScalePolicyAutoScaleCustomRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeInstanceGroupScalePolicyAutoScaleCustomRuleList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupScalePolicyAutoScaleCustomRuleList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "ComputeInstanceGroupScalePolicyAutoScaleCustomRuleOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("ComputeInstanceGroupScalePolicyAutoScaleCustomRuleOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupScalePolicyAutoScaleCustomRule]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupScalePolicyAutoScaleCustomRule]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupScalePolicyAutoScaleCustomRule]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ComputeInstanceGroupScalePolicyAutoScaleCustomRuleOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupScalePolicyAutoScaleCustomRuleOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetService")
    def reset_service(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetService", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricNameInput")
    def metric_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricTypeInput")
    def metric_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricTypeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ruleTypeInput")
    def rule_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "ruleTypeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceInput")
    def service_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetInput")
    def target_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "targetInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricName")
    def metric_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metricName"))

    @metric_name.setter
    def metric_name(self, value: builtins.str) -> None:
        jsii.set(self, "metricName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricType")
    def metric_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metricType"))

    @metric_type.setter
    def metric_type(self, value: builtins.str) -> None:
        jsii.set(self, "metricType", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ruleType")
    def rule_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ruleType"))

    @rule_type.setter
    def rule_type(self, value: builtins.str) -> None:
        jsii.set(self, "ruleType", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="service")
    def service(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "service"))

    @service.setter
    def service(self, value: builtins.str) -> None:
        jsii.set(self, "service", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="target")
    def target(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "target"))

    @target.setter
    def target(self, value: jsii.Number) -> None:
        jsii.set(self, "target", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceGroupScalePolicyAutoScaleCustomRule]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceGroupScalePolicyAutoScaleCustomRule]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceGroupScalePolicyAutoScaleCustomRule]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ComputeInstanceGroupScalePolicyAutoScaleOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupScalePolicyAutoScaleOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCustomRule")
    def put_custom_rule(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence[ComputeInstanceGroupScalePolicyAutoScaleCustomRule]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putCustomRule", [value]))

    @jsii.member(jsii_name="resetCpuUtilizationTarget")
    def reset_cpu_utilization_target(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCpuUtilizationTarget", []))

    @jsii.member(jsii_name="resetCustomRule")
    def reset_custom_rule(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomRule", []))

    @jsii.member(jsii_name="resetMaxSize")
    def reset_max_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxSize", []))

    @jsii.member(jsii_name="resetMinZoneSize")
    def reset_min_zone_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMinZoneSize", []))

    @jsii.member(jsii_name="resetStabilizationDuration")
    def reset_stabilization_duration(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStabilizationDuration", []))

    @jsii.member(jsii_name="resetWarmupDuration")
    def reset_warmup_duration(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetWarmupDuration", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="customRule")
    def custom_rule(self) -> ComputeInstanceGroupScalePolicyAutoScaleCustomRuleList:
        return typing.cast(ComputeInstanceGroupScalePolicyAutoScaleCustomRuleList, jsii.get(self, "customRule"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cpuUtilizationTargetInput")
    def cpu_utilization_target_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "cpuUtilizationTargetInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="customRuleInput")
    def custom_rule_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupScalePolicyAutoScaleCustomRule]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupScalePolicyAutoScaleCustomRule]]], jsii.get(self, "customRuleInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="initialSizeInput")
    def initial_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "initialSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxSizeInput")
    def max_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="measurementDurationInput")
    def measurement_duration_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "measurementDurationInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minZoneSizeInput")
    def min_zone_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "minZoneSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="stabilizationDurationInput")
    def stabilization_duration_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "stabilizationDurationInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="warmupDurationInput")
    def warmup_duration_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "warmupDurationInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cpuUtilizationTarget")
    def cpu_utilization_target(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "cpuUtilizationTarget"))

    @cpu_utilization_target.setter
    def cpu_utilization_target(self, value: jsii.Number) -> None:
        jsii.set(self, "cpuUtilizationTarget", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="initialSize")
    def initial_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "initialSize"))

    @initial_size.setter
    def initial_size(self, value: jsii.Number) -> None:
        jsii.set(self, "initialSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxSize")
    def max_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxSize"))

    @max_size.setter
    def max_size(self, value: jsii.Number) -> None:
        jsii.set(self, "maxSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="measurementDuration")
    def measurement_duration(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "measurementDuration"))

    @measurement_duration.setter
    def measurement_duration(self, value: jsii.Number) -> None:
        jsii.set(self, "measurementDuration", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minZoneSize")
    def min_zone_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minZoneSize"))

    @min_zone_size.setter
    def min_zone_size(self, value: jsii.Number) -> None:
        jsii.set(self, "minZoneSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="stabilizationDuration")
    def stabilization_duration(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "stabilizationDuration"))

    @stabilization_duration.setter
    def stabilization_duration(self, value: jsii.Number) -> None:
        jsii.set(self, "stabilizationDuration", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="warmupDuration")
    def warmup_duration(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "warmupDuration"))

    @warmup_duration.setter
    def warmup_duration(self, value: jsii.Number) -> None:
        jsii.set(self, "warmupDuration", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[ComputeInstanceGroupScalePolicyAutoScale]:
        return typing.cast(typing.Optional[ComputeInstanceGroupScalePolicyAutoScale], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[ComputeInstanceGroupScalePolicyAutoScale],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupScalePolicyFixedScale",
    jsii_struct_bases=[],
    name_mapping={"size": "size"},
)
class ComputeInstanceGroupScalePolicyFixedScale:
    def __init__(self, *, size: jsii.Number) -> None:
        '''
        :param size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#size ComputeInstanceGroup#size}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "size": size,
        }

    @builtins.property
    def size(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#size ComputeInstanceGroup#size}.'''
        result = self._values.get("size")
        assert result is not None, "Required property 'size' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceGroupScalePolicyFixedScale(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeInstanceGroupScalePolicyFixedScaleOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupScalePolicyFixedScaleOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sizeInput")
    def size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "sizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="size")
    def size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "size"))

    @size.setter
    def size(self, value: jsii.Number) -> None:
        jsii.set(self, "size", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[ComputeInstanceGroupScalePolicyFixedScale]:
        return typing.cast(typing.Optional[ComputeInstanceGroupScalePolicyFixedScale], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[ComputeInstanceGroupScalePolicyFixedScale],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ComputeInstanceGroupScalePolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupScalePolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putAutoScale")
    def put_auto_scale(
        self,
        *,
        initial_size: jsii.Number,
        measurement_duration: jsii.Number,
        cpu_utilization_target: typing.Optional[jsii.Number] = None,
        custom_rule: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence[ComputeInstanceGroupScalePolicyAutoScaleCustomRule]]] = None,
        max_size: typing.Optional[jsii.Number] = None,
        min_zone_size: typing.Optional[jsii.Number] = None,
        stabilization_duration: typing.Optional[jsii.Number] = None,
        warmup_duration: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param initial_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#initial_size ComputeInstanceGroup#initial_size}.
        :param measurement_duration: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#measurement_duration ComputeInstanceGroup#measurement_duration}.
        :param cpu_utilization_target: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#cpu_utilization_target ComputeInstanceGroup#cpu_utilization_target}.
        :param custom_rule: custom_rule block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#custom_rule ComputeInstanceGroup#custom_rule}
        :param max_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#max_size ComputeInstanceGroup#max_size}.
        :param min_zone_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#min_zone_size ComputeInstanceGroup#min_zone_size}.
        :param stabilization_duration: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#stabilization_duration ComputeInstanceGroup#stabilization_duration}.
        :param warmup_duration: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#warmup_duration ComputeInstanceGroup#warmup_duration}.
        '''
        value = ComputeInstanceGroupScalePolicyAutoScale(
            initial_size=initial_size,
            measurement_duration=measurement_duration,
            cpu_utilization_target=cpu_utilization_target,
            custom_rule=custom_rule,
            max_size=max_size,
            min_zone_size=min_zone_size,
            stabilization_duration=stabilization_duration,
            warmup_duration=warmup_duration,
        )

        return typing.cast(None, jsii.invoke(self, "putAutoScale", [value]))

    @jsii.member(jsii_name="putFixedScale")
    def put_fixed_scale(self, *, size: jsii.Number) -> None:
        '''
        :param size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#size ComputeInstanceGroup#size}.
        '''
        value = ComputeInstanceGroupScalePolicyFixedScale(size=size)

        return typing.cast(None, jsii.invoke(self, "putFixedScale", [value]))

    @jsii.member(jsii_name="putTestAutoScale")
    def put_test_auto_scale(
        self,
        *,
        initial_size: jsii.Number,
        measurement_duration: jsii.Number,
        cpu_utilization_target: typing.Optional[jsii.Number] = None,
        custom_rule: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["ComputeInstanceGroupScalePolicyTestAutoScaleCustomRule"]]] = None,
        max_size: typing.Optional[jsii.Number] = None,
        min_zone_size: typing.Optional[jsii.Number] = None,
        stabilization_duration: typing.Optional[jsii.Number] = None,
        warmup_duration: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param initial_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#initial_size ComputeInstanceGroup#initial_size}.
        :param measurement_duration: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#measurement_duration ComputeInstanceGroup#measurement_duration}.
        :param cpu_utilization_target: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#cpu_utilization_target ComputeInstanceGroup#cpu_utilization_target}.
        :param custom_rule: custom_rule block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#custom_rule ComputeInstanceGroup#custom_rule}
        :param max_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#max_size ComputeInstanceGroup#max_size}.
        :param min_zone_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#min_zone_size ComputeInstanceGroup#min_zone_size}.
        :param stabilization_duration: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#stabilization_duration ComputeInstanceGroup#stabilization_duration}.
        :param warmup_duration: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#warmup_duration ComputeInstanceGroup#warmup_duration}.
        '''
        value = ComputeInstanceGroupScalePolicyTestAutoScale(
            initial_size=initial_size,
            measurement_duration=measurement_duration,
            cpu_utilization_target=cpu_utilization_target,
            custom_rule=custom_rule,
            max_size=max_size,
            min_zone_size=min_zone_size,
            stabilization_duration=stabilization_duration,
            warmup_duration=warmup_duration,
        )

        return typing.cast(None, jsii.invoke(self, "putTestAutoScale", [value]))

    @jsii.member(jsii_name="resetAutoScale")
    def reset_auto_scale(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAutoScale", []))

    @jsii.member(jsii_name="resetFixedScale")
    def reset_fixed_scale(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFixedScale", []))

    @jsii.member(jsii_name="resetTestAutoScale")
    def reset_test_auto_scale(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTestAutoScale", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoScale")
    def auto_scale(self) -> ComputeInstanceGroupScalePolicyAutoScaleOutputReference:
        return typing.cast(ComputeInstanceGroupScalePolicyAutoScaleOutputReference, jsii.get(self, "autoScale"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fixedScale")
    def fixed_scale(self) -> ComputeInstanceGroupScalePolicyFixedScaleOutputReference:
        return typing.cast(ComputeInstanceGroupScalePolicyFixedScaleOutputReference, jsii.get(self, "fixedScale"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="testAutoScale")
    def test_auto_scale(
        self,
    ) -> "ComputeInstanceGroupScalePolicyTestAutoScaleOutputReference":
        return typing.cast("ComputeInstanceGroupScalePolicyTestAutoScaleOutputReference", jsii.get(self, "testAutoScale"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoScaleInput")
    def auto_scale_input(
        self,
    ) -> typing.Optional[ComputeInstanceGroupScalePolicyAutoScale]:
        return typing.cast(typing.Optional[ComputeInstanceGroupScalePolicyAutoScale], jsii.get(self, "autoScaleInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fixedScaleInput")
    def fixed_scale_input(
        self,
    ) -> typing.Optional[ComputeInstanceGroupScalePolicyFixedScale]:
        return typing.cast(typing.Optional[ComputeInstanceGroupScalePolicyFixedScale], jsii.get(self, "fixedScaleInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="testAutoScaleInput")
    def test_auto_scale_input(
        self,
    ) -> typing.Optional["ComputeInstanceGroupScalePolicyTestAutoScale"]:
        return typing.cast(typing.Optional["ComputeInstanceGroupScalePolicyTestAutoScale"], jsii.get(self, "testAutoScaleInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[ComputeInstanceGroupScalePolicy]:
        return typing.cast(typing.Optional[ComputeInstanceGroupScalePolicy], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[ComputeInstanceGroupScalePolicy],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupScalePolicyTestAutoScale",
    jsii_struct_bases=[],
    name_mapping={
        "initial_size": "initialSize",
        "measurement_duration": "measurementDuration",
        "cpu_utilization_target": "cpuUtilizationTarget",
        "custom_rule": "customRule",
        "max_size": "maxSize",
        "min_zone_size": "minZoneSize",
        "stabilization_duration": "stabilizationDuration",
        "warmup_duration": "warmupDuration",
    },
)
class ComputeInstanceGroupScalePolicyTestAutoScale:
    def __init__(
        self,
        *,
        initial_size: jsii.Number,
        measurement_duration: jsii.Number,
        cpu_utilization_target: typing.Optional[jsii.Number] = None,
        custom_rule: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["ComputeInstanceGroupScalePolicyTestAutoScaleCustomRule"]]] = None,
        max_size: typing.Optional[jsii.Number] = None,
        min_zone_size: typing.Optional[jsii.Number] = None,
        stabilization_duration: typing.Optional[jsii.Number] = None,
        warmup_duration: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param initial_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#initial_size ComputeInstanceGroup#initial_size}.
        :param measurement_duration: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#measurement_duration ComputeInstanceGroup#measurement_duration}.
        :param cpu_utilization_target: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#cpu_utilization_target ComputeInstanceGroup#cpu_utilization_target}.
        :param custom_rule: custom_rule block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#custom_rule ComputeInstanceGroup#custom_rule}
        :param max_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#max_size ComputeInstanceGroup#max_size}.
        :param min_zone_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#min_zone_size ComputeInstanceGroup#min_zone_size}.
        :param stabilization_duration: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#stabilization_duration ComputeInstanceGroup#stabilization_duration}.
        :param warmup_duration: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#warmup_duration ComputeInstanceGroup#warmup_duration}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "initial_size": initial_size,
            "measurement_duration": measurement_duration,
        }
        if cpu_utilization_target is not None:
            self._values["cpu_utilization_target"] = cpu_utilization_target
        if custom_rule is not None:
            self._values["custom_rule"] = custom_rule
        if max_size is not None:
            self._values["max_size"] = max_size
        if min_zone_size is not None:
            self._values["min_zone_size"] = min_zone_size
        if stabilization_duration is not None:
            self._values["stabilization_duration"] = stabilization_duration
        if warmup_duration is not None:
            self._values["warmup_duration"] = warmup_duration

    @builtins.property
    def initial_size(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#initial_size ComputeInstanceGroup#initial_size}.'''
        result = self._values.get("initial_size")
        assert result is not None, "Required property 'initial_size' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def measurement_duration(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#measurement_duration ComputeInstanceGroup#measurement_duration}.'''
        result = self._values.get("measurement_duration")
        assert result is not None, "Required property 'measurement_duration' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def cpu_utilization_target(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#cpu_utilization_target ComputeInstanceGroup#cpu_utilization_target}.'''
        result = self._values.get("cpu_utilization_target")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def custom_rule(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceGroupScalePolicyTestAutoScaleCustomRule"]]]:
        '''custom_rule block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#custom_rule ComputeInstanceGroup#custom_rule}
        '''
        result = self._values.get("custom_rule")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceGroupScalePolicyTestAutoScaleCustomRule"]]], result)

    @builtins.property
    def max_size(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#max_size ComputeInstanceGroup#max_size}.'''
        result = self._values.get("max_size")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def min_zone_size(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#min_zone_size ComputeInstanceGroup#min_zone_size}.'''
        result = self._values.get("min_zone_size")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def stabilization_duration(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#stabilization_duration ComputeInstanceGroup#stabilization_duration}.'''
        result = self._values.get("stabilization_duration")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def warmup_duration(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#warmup_duration ComputeInstanceGroup#warmup_duration}.'''
        result = self._values.get("warmup_duration")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceGroupScalePolicyTestAutoScale(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupScalePolicyTestAutoScaleCustomRule",
    jsii_struct_bases=[],
    name_mapping={
        "metric_name": "metricName",
        "metric_type": "metricType",
        "rule_type": "ruleType",
        "target": "target",
        "folder_id": "folderId",
        "labels": "labels",
        "service": "service",
    },
)
class ComputeInstanceGroupScalePolicyTestAutoScaleCustomRule:
    def __init__(
        self,
        *,
        metric_name: builtins.str,
        metric_type: builtins.str,
        rule_type: builtins.str,
        target: jsii.Number,
        folder_id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        service: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param metric_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#metric_name ComputeInstanceGroup#metric_name}.
        :param metric_type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#metric_type ComputeInstanceGroup#metric_type}.
        :param rule_type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#rule_type ComputeInstanceGroup#rule_type}.
        :param target: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#target ComputeInstanceGroup#target}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#folder_id ComputeInstanceGroup#folder_id}.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#labels ComputeInstanceGroup#labels}.
        :param service: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#service ComputeInstanceGroup#service}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "metric_name": metric_name,
            "metric_type": metric_type,
            "rule_type": rule_type,
            "target": target,
        }
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if labels is not None:
            self._values["labels"] = labels
        if service is not None:
            self._values["service"] = service

    @builtins.property
    def metric_name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#metric_name ComputeInstanceGroup#metric_name}.'''
        result = self._values.get("metric_name")
        assert result is not None, "Required property 'metric_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def metric_type(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#metric_type ComputeInstanceGroup#metric_type}.'''
        result = self._values.get("metric_type")
        assert result is not None, "Required property 'metric_type' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def rule_type(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#rule_type ComputeInstanceGroup#rule_type}.'''
        result = self._values.get("rule_type")
        assert result is not None, "Required property 'rule_type' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def target(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#target ComputeInstanceGroup#target}.'''
        result = self._values.get("target")
        assert result is not None, "Required property 'target' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#folder_id ComputeInstanceGroup#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#labels ComputeInstanceGroup#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def service(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#service ComputeInstanceGroup#service}.'''
        result = self._values.get("service")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceGroupScalePolicyTestAutoScaleCustomRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeInstanceGroupScalePolicyTestAutoScaleCustomRuleList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupScalePolicyTestAutoScaleCustomRuleList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "ComputeInstanceGroupScalePolicyTestAutoScaleCustomRuleOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("ComputeInstanceGroupScalePolicyTestAutoScaleCustomRuleOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupScalePolicyTestAutoScaleCustomRule]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupScalePolicyTestAutoScaleCustomRule]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupScalePolicyTestAutoScaleCustomRule]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ComputeInstanceGroupScalePolicyTestAutoScaleCustomRuleOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupScalePolicyTestAutoScaleCustomRuleOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetService")
    def reset_service(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetService", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricNameInput")
    def metric_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricTypeInput")
    def metric_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "metricTypeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ruleTypeInput")
    def rule_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "ruleTypeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceInput")
    def service_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetInput")
    def target_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "targetInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricName")
    def metric_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metricName"))

    @metric_name.setter
    def metric_name(self, value: builtins.str) -> None:
        jsii.set(self, "metricName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricType")
    def metric_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metricType"))

    @metric_type.setter
    def metric_type(self, value: builtins.str) -> None:
        jsii.set(self, "metricType", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ruleType")
    def rule_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ruleType"))

    @rule_type.setter
    def rule_type(self, value: builtins.str) -> None:
        jsii.set(self, "ruleType", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="service")
    def service(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "service"))

    @service.setter
    def service(self, value: builtins.str) -> None:
        jsii.set(self, "service", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="target")
    def target(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "target"))

    @target.setter
    def target(self, value: jsii.Number) -> None:
        jsii.set(self, "target", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceGroupScalePolicyTestAutoScaleCustomRule]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceGroupScalePolicyTestAutoScaleCustomRule]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceGroupScalePolicyTestAutoScaleCustomRule]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ComputeInstanceGroupScalePolicyTestAutoScaleOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupScalePolicyTestAutoScaleOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCustomRule")
    def put_custom_rule(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence[ComputeInstanceGroupScalePolicyTestAutoScaleCustomRule]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putCustomRule", [value]))

    @jsii.member(jsii_name="resetCpuUtilizationTarget")
    def reset_cpu_utilization_target(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCpuUtilizationTarget", []))

    @jsii.member(jsii_name="resetCustomRule")
    def reset_custom_rule(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomRule", []))

    @jsii.member(jsii_name="resetMaxSize")
    def reset_max_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxSize", []))

    @jsii.member(jsii_name="resetMinZoneSize")
    def reset_min_zone_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMinZoneSize", []))

    @jsii.member(jsii_name="resetStabilizationDuration")
    def reset_stabilization_duration(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStabilizationDuration", []))

    @jsii.member(jsii_name="resetWarmupDuration")
    def reset_warmup_duration(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetWarmupDuration", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="customRule")
    def custom_rule(self) -> ComputeInstanceGroupScalePolicyTestAutoScaleCustomRuleList:
        return typing.cast(ComputeInstanceGroupScalePolicyTestAutoScaleCustomRuleList, jsii.get(self, "customRule"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cpuUtilizationTargetInput")
    def cpu_utilization_target_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "cpuUtilizationTargetInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="customRuleInput")
    def custom_rule_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupScalePolicyTestAutoScaleCustomRule]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceGroupScalePolicyTestAutoScaleCustomRule]]], jsii.get(self, "customRuleInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="initialSizeInput")
    def initial_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "initialSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxSizeInput")
    def max_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="measurementDurationInput")
    def measurement_duration_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "measurementDurationInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minZoneSizeInput")
    def min_zone_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "minZoneSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="stabilizationDurationInput")
    def stabilization_duration_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "stabilizationDurationInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="warmupDurationInput")
    def warmup_duration_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "warmupDurationInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cpuUtilizationTarget")
    def cpu_utilization_target(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "cpuUtilizationTarget"))

    @cpu_utilization_target.setter
    def cpu_utilization_target(self, value: jsii.Number) -> None:
        jsii.set(self, "cpuUtilizationTarget", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="initialSize")
    def initial_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "initialSize"))

    @initial_size.setter
    def initial_size(self, value: jsii.Number) -> None:
        jsii.set(self, "initialSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxSize")
    def max_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxSize"))

    @max_size.setter
    def max_size(self, value: jsii.Number) -> None:
        jsii.set(self, "maxSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="measurementDuration")
    def measurement_duration(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "measurementDuration"))

    @measurement_duration.setter
    def measurement_duration(self, value: jsii.Number) -> None:
        jsii.set(self, "measurementDuration", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minZoneSize")
    def min_zone_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minZoneSize"))

    @min_zone_size.setter
    def min_zone_size(self, value: jsii.Number) -> None:
        jsii.set(self, "minZoneSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="stabilizationDuration")
    def stabilization_duration(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "stabilizationDuration"))

    @stabilization_duration.setter
    def stabilization_duration(self, value: jsii.Number) -> None:
        jsii.set(self, "stabilizationDuration", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="warmupDuration")
    def warmup_duration(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "warmupDuration"))

    @warmup_duration.setter
    def warmup_duration(self, value: jsii.Number) -> None:
        jsii.set(self, "warmupDuration", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[ComputeInstanceGroupScalePolicyTestAutoScale]:
        return typing.cast(typing.Optional[ComputeInstanceGroupScalePolicyTestAutoScale], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[ComputeInstanceGroupScalePolicyTestAutoScale],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class ComputeInstanceGroupTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#create ComputeInstanceGroup#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#delete ComputeInstanceGroup#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#update ComputeInstanceGroup#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#create ComputeInstanceGroup#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#delete ComputeInstanceGroup#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance_group#update ComputeInstanceGroup#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeInstanceGroupTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceGroupTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceGroupTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceGroupTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceGroupTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceNetworkInterface",
    jsii_struct_bases=[],
    name_mapping={
        "subnet_id": "subnetId",
        "dns_record": "dnsRecord",
        "ip_address": "ipAddress",
        "ipv4": "ipv4",
        "ipv6": "ipv6",
        "ipv6_address": "ipv6Address",
        "ipv6_dns_record": "ipv6DnsRecord",
        "nat": "nat",
        "nat_dns_record": "natDnsRecord",
        "nat_ip_address": "natIpAddress",
        "security_group_ids": "securityGroupIds",
    },
)
class ComputeInstanceNetworkInterface:
    def __init__(
        self,
        *,
        subnet_id: builtins.str,
        dns_record: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["ComputeInstanceNetworkInterfaceDnsRecord"]]] = None,
        ip_address: typing.Optional[builtins.str] = None,
        ipv4: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        ipv6: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        ipv6_address: typing.Optional[builtins.str] = None,
        ipv6_dns_record: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["ComputeInstanceNetworkInterfaceIpv6DnsRecord"]]] = None,
        nat: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        nat_dns_record: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["ComputeInstanceNetworkInterfaceNatDnsRecord"]]] = None,
        nat_ip_address: typing.Optional[builtins.str] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param subnet_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#subnet_id ComputeInstance#subnet_id}.
        :param dns_record: dns_record block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#dns_record ComputeInstance#dns_record}
        :param ip_address: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#ip_address ComputeInstance#ip_address}.
        :param ipv4: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#ipv4 ComputeInstance#ipv4}.
        :param ipv6: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#ipv6 ComputeInstance#ipv6}.
        :param ipv6_address: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#ipv6_address ComputeInstance#ipv6_address}.
        :param ipv6_dns_record: ipv6_dns_record block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#ipv6_dns_record ComputeInstance#ipv6_dns_record}
        :param nat: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#nat ComputeInstance#nat}.
        :param nat_dns_record: nat_dns_record block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#nat_dns_record ComputeInstance#nat_dns_record}
        :param nat_ip_address: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#nat_ip_address ComputeInstance#nat_ip_address}.
        :param security_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#security_group_ids ComputeInstance#security_group_ids}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "subnet_id": subnet_id,
        }
        if dns_record is not None:
            self._values["dns_record"] = dns_record
        if ip_address is not None:
            self._values["ip_address"] = ip_address
        if ipv4 is not None:
            self._values["ipv4"] = ipv4
        if ipv6 is not None:
            self._values["ipv6"] = ipv6
        if ipv6_address is not None:
            self._values["ipv6_address"] = ipv6_address
        if ipv6_dns_record is not None:
            self._values["ipv6_dns_record"] = ipv6_dns_record
        if nat is not None:
            self._values["nat"] = nat
        if nat_dns_record is not None:
            self._values["nat_dns_record"] = nat_dns_record
        if nat_ip_address is not None:
            self._values["nat_ip_address"] = nat_ip_address
        if security_group_ids is not None:
            self._values["security_group_ids"] = security_group_ids

    @builtins.property
    def subnet_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#subnet_id ComputeInstance#subnet_id}.'''
        result = self._values.get("subnet_id")
        assert result is not None, "Required property 'subnet_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def dns_record(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceNetworkInterfaceDnsRecord"]]]:
        '''dns_record block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#dns_record ComputeInstance#dns_record}
        '''
        result = self._values.get("dns_record")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceNetworkInterfaceDnsRecord"]]], result)

    @builtins.property
    def ip_address(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#ip_address ComputeInstance#ip_address}.'''
        result = self._values.get("ip_address")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def ipv4(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#ipv4 ComputeInstance#ipv4}.'''
        result = self._values.get("ipv4")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def ipv6(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#ipv6 ComputeInstance#ipv6}.'''
        result = self._values.get("ipv6")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def ipv6_address(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#ipv6_address ComputeInstance#ipv6_address}.'''
        result = self._values.get("ipv6_address")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def ipv6_dns_record(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceNetworkInterfaceIpv6DnsRecord"]]]:
        '''ipv6_dns_record block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#ipv6_dns_record ComputeInstance#ipv6_dns_record}
        '''
        result = self._values.get("ipv6_dns_record")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceNetworkInterfaceIpv6DnsRecord"]]], result)

    @builtins.property
    def nat(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#nat ComputeInstance#nat}.'''
        result = self._values.get("nat")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def nat_dns_record(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceNetworkInterfaceNatDnsRecord"]]]:
        '''nat_dns_record block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#nat_dns_record ComputeInstance#nat_dns_record}
        '''
        result = self._values.get("nat_dns_record")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstanceNetworkInterfaceNatDnsRecord"]]], result)

    @builtins.property
    def nat_ip_address(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#nat_ip_address ComputeInstance#nat_ip_address}.'''
        result = self._values.get("nat_ip_address")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def security_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#security_group_ids ComputeInstance#security_group_ids}.'''
        result = self._values.get("security_group_ids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceNetworkInterface(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceNetworkInterfaceDnsRecord",
    jsii_struct_bases=[],
    name_mapping={
        "fqdn": "fqdn",
        "dns_zone_id": "dnsZoneId",
        "ptr": "ptr",
        "ttl": "ttl",
    },
)
class ComputeInstanceNetworkInterfaceDnsRecord:
    def __init__(
        self,
        *,
        fqdn: builtins.str,
        dns_zone_id: typing.Optional[builtins.str] = None,
        ptr: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        ttl: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param fqdn: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#fqdn ComputeInstance#fqdn}.
        :param dns_zone_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#dns_zone_id ComputeInstance#dns_zone_id}.
        :param ptr: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#ptr ComputeInstance#ptr}.
        :param ttl: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#ttl ComputeInstance#ttl}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "fqdn": fqdn,
        }
        if dns_zone_id is not None:
            self._values["dns_zone_id"] = dns_zone_id
        if ptr is not None:
            self._values["ptr"] = ptr
        if ttl is not None:
            self._values["ttl"] = ttl

    @builtins.property
    def fqdn(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#fqdn ComputeInstance#fqdn}.'''
        result = self._values.get("fqdn")
        assert result is not None, "Required property 'fqdn' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def dns_zone_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#dns_zone_id ComputeInstance#dns_zone_id}.'''
        result = self._values.get("dns_zone_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def ptr(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#ptr ComputeInstance#ptr}.'''
        result = self._values.get("ptr")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def ttl(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#ttl ComputeInstance#ttl}.'''
        result = self._values.get("ttl")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceNetworkInterfaceDnsRecord(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeInstanceNetworkInterfaceDnsRecordList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceNetworkInterfaceDnsRecordList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "ComputeInstanceNetworkInterfaceDnsRecordOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("ComputeInstanceNetworkInterfaceDnsRecordOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceNetworkInterfaceDnsRecord]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceNetworkInterfaceDnsRecord]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceNetworkInterfaceDnsRecord]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ComputeInstanceNetworkInterfaceDnsRecordOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceNetworkInterfaceDnsRecordOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetDnsZoneId")
    def reset_dns_zone_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDnsZoneId", []))

    @jsii.member(jsii_name="resetPtr")
    def reset_ptr(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPtr", []))

    @jsii.member(jsii_name="resetTtl")
    def reset_ttl(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTtl", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dnsZoneIdInput")
    def dns_zone_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dnsZoneIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdnInput")
    def fqdn_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "fqdnInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ptrInput")
    def ptr_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "ptrInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ttlInput")
    def ttl_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "ttlInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dnsZoneId")
    def dns_zone_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dnsZoneId"))

    @dns_zone_id.setter
    def dns_zone_id(self, value: builtins.str) -> None:
        jsii.set(self, "dnsZoneId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fqdn"))

    @fqdn.setter
    def fqdn(self, value: builtins.str) -> None:
        jsii.set(self, "fqdn", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ptr")
    def ptr(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "ptr"))

    @ptr.setter
    def ptr(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "ptr", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ttl")
    def ttl(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "ttl"))

    @ttl.setter
    def ttl(self, value: jsii.Number) -> None:
        jsii.set(self, "ttl", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceNetworkInterfaceDnsRecord]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceNetworkInterfaceDnsRecord]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceNetworkInterfaceDnsRecord]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceNetworkInterfaceIpv6DnsRecord",
    jsii_struct_bases=[],
    name_mapping={
        "fqdn": "fqdn",
        "dns_zone_id": "dnsZoneId",
        "ptr": "ptr",
        "ttl": "ttl",
    },
)
class ComputeInstanceNetworkInterfaceIpv6DnsRecord:
    def __init__(
        self,
        *,
        fqdn: builtins.str,
        dns_zone_id: typing.Optional[builtins.str] = None,
        ptr: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        ttl: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param fqdn: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#fqdn ComputeInstance#fqdn}.
        :param dns_zone_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#dns_zone_id ComputeInstance#dns_zone_id}.
        :param ptr: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#ptr ComputeInstance#ptr}.
        :param ttl: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#ttl ComputeInstance#ttl}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "fqdn": fqdn,
        }
        if dns_zone_id is not None:
            self._values["dns_zone_id"] = dns_zone_id
        if ptr is not None:
            self._values["ptr"] = ptr
        if ttl is not None:
            self._values["ttl"] = ttl

    @builtins.property
    def fqdn(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#fqdn ComputeInstance#fqdn}.'''
        result = self._values.get("fqdn")
        assert result is not None, "Required property 'fqdn' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def dns_zone_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#dns_zone_id ComputeInstance#dns_zone_id}.'''
        result = self._values.get("dns_zone_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def ptr(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#ptr ComputeInstance#ptr}.'''
        result = self._values.get("ptr")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def ttl(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#ttl ComputeInstance#ttl}.'''
        result = self._values.get("ttl")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceNetworkInterfaceIpv6DnsRecord(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeInstanceNetworkInterfaceIpv6DnsRecordList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceNetworkInterfaceIpv6DnsRecordList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "ComputeInstanceNetworkInterfaceIpv6DnsRecordOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("ComputeInstanceNetworkInterfaceIpv6DnsRecordOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceNetworkInterfaceIpv6DnsRecord]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceNetworkInterfaceIpv6DnsRecord]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceNetworkInterfaceIpv6DnsRecord]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ComputeInstanceNetworkInterfaceIpv6DnsRecordOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceNetworkInterfaceIpv6DnsRecordOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetDnsZoneId")
    def reset_dns_zone_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDnsZoneId", []))

    @jsii.member(jsii_name="resetPtr")
    def reset_ptr(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPtr", []))

    @jsii.member(jsii_name="resetTtl")
    def reset_ttl(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTtl", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dnsZoneIdInput")
    def dns_zone_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dnsZoneIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdnInput")
    def fqdn_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "fqdnInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ptrInput")
    def ptr_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "ptrInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ttlInput")
    def ttl_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "ttlInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dnsZoneId")
    def dns_zone_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dnsZoneId"))

    @dns_zone_id.setter
    def dns_zone_id(self, value: builtins.str) -> None:
        jsii.set(self, "dnsZoneId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fqdn"))

    @fqdn.setter
    def fqdn(self, value: builtins.str) -> None:
        jsii.set(self, "fqdn", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ptr")
    def ptr(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "ptr"))

    @ptr.setter
    def ptr(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "ptr", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ttl")
    def ttl(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "ttl"))

    @ttl.setter
    def ttl(self, value: jsii.Number) -> None:
        jsii.set(self, "ttl", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceNetworkInterfaceIpv6DnsRecord]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceNetworkInterfaceIpv6DnsRecord]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceNetworkInterfaceIpv6DnsRecord]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ComputeInstanceNetworkInterfaceList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceNetworkInterfaceList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "ComputeInstanceNetworkInterfaceOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("ComputeInstanceNetworkInterfaceOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceNetworkInterface]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceNetworkInterface]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceNetworkInterface]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceNetworkInterfaceNatDnsRecord",
    jsii_struct_bases=[],
    name_mapping={
        "fqdn": "fqdn",
        "dns_zone_id": "dnsZoneId",
        "ptr": "ptr",
        "ttl": "ttl",
    },
)
class ComputeInstanceNetworkInterfaceNatDnsRecord:
    def __init__(
        self,
        *,
        fqdn: builtins.str,
        dns_zone_id: typing.Optional[builtins.str] = None,
        ptr: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        ttl: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param fqdn: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#fqdn ComputeInstance#fqdn}.
        :param dns_zone_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#dns_zone_id ComputeInstance#dns_zone_id}.
        :param ptr: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#ptr ComputeInstance#ptr}.
        :param ttl: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#ttl ComputeInstance#ttl}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "fqdn": fqdn,
        }
        if dns_zone_id is not None:
            self._values["dns_zone_id"] = dns_zone_id
        if ptr is not None:
            self._values["ptr"] = ptr
        if ttl is not None:
            self._values["ttl"] = ttl

    @builtins.property
    def fqdn(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#fqdn ComputeInstance#fqdn}.'''
        result = self._values.get("fqdn")
        assert result is not None, "Required property 'fqdn' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def dns_zone_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#dns_zone_id ComputeInstance#dns_zone_id}.'''
        result = self._values.get("dns_zone_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def ptr(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#ptr ComputeInstance#ptr}.'''
        result = self._values.get("ptr")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def ttl(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#ttl ComputeInstance#ttl}.'''
        result = self._values.get("ttl")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceNetworkInterfaceNatDnsRecord(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeInstanceNetworkInterfaceNatDnsRecordList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceNetworkInterfaceNatDnsRecordList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "ComputeInstanceNetworkInterfaceNatDnsRecordOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("ComputeInstanceNetworkInterfaceNatDnsRecordOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceNetworkInterfaceNatDnsRecord]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceNetworkInterfaceNatDnsRecord]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceNetworkInterfaceNatDnsRecord]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ComputeInstanceNetworkInterfaceNatDnsRecordOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceNetworkInterfaceNatDnsRecordOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetDnsZoneId")
    def reset_dns_zone_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDnsZoneId", []))

    @jsii.member(jsii_name="resetPtr")
    def reset_ptr(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPtr", []))

    @jsii.member(jsii_name="resetTtl")
    def reset_ttl(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTtl", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dnsZoneIdInput")
    def dns_zone_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dnsZoneIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdnInput")
    def fqdn_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "fqdnInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ptrInput")
    def ptr_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "ptrInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ttlInput")
    def ttl_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "ttlInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dnsZoneId")
    def dns_zone_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dnsZoneId"))

    @dns_zone_id.setter
    def dns_zone_id(self, value: builtins.str) -> None:
        jsii.set(self, "dnsZoneId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fqdn"))

    @fqdn.setter
    def fqdn(self, value: builtins.str) -> None:
        jsii.set(self, "fqdn", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ptr")
    def ptr(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "ptr"))

    @ptr.setter
    def ptr(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "ptr", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ttl")
    def ttl(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "ttl"))

    @ttl.setter
    def ttl(self, value: jsii.Number) -> None:
        jsii.set(self, "ttl", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceNetworkInterfaceNatDnsRecord]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceNetworkInterfaceNatDnsRecord]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceNetworkInterfaceNatDnsRecord]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ComputeInstanceNetworkInterfaceOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceNetworkInterfaceOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putDnsRecord")
    def put_dns_record(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence[ComputeInstanceNetworkInterfaceDnsRecord]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putDnsRecord", [value]))

    @jsii.member(jsii_name="putIpv6DnsRecord")
    def put_ipv6_dns_record(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence[ComputeInstanceNetworkInterfaceIpv6DnsRecord]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putIpv6DnsRecord", [value]))

    @jsii.member(jsii_name="putNatDnsRecord")
    def put_nat_dns_record(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence[ComputeInstanceNetworkInterfaceNatDnsRecord]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putNatDnsRecord", [value]))

    @jsii.member(jsii_name="resetDnsRecord")
    def reset_dns_record(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDnsRecord", []))

    @jsii.member(jsii_name="resetIpAddress")
    def reset_ip_address(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIpAddress", []))

    @jsii.member(jsii_name="resetIpv4")
    def reset_ipv4(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIpv4", []))

    @jsii.member(jsii_name="resetIpv6")
    def reset_ipv6(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIpv6", []))

    @jsii.member(jsii_name="resetIpv6Address")
    def reset_ipv6_address(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIpv6Address", []))

    @jsii.member(jsii_name="resetIpv6DnsRecord")
    def reset_ipv6_dns_record(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIpv6DnsRecord", []))

    @jsii.member(jsii_name="resetNat")
    def reset_nat(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNat", []))

    @jsii.member(jsii_name="resetNatDnsRecord")
    def reset_nat_dns_record(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNatDnsRecord", []))

    @jsii.member(jsii_name="resetNatIpAddress")
    def reset_nat_ip_address(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNatIpAddress", []))

    @jsii.member(jsii_name="resetSecurityGroupIds")
    def reset_security_group_ids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityGroupIds", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dnsRecord")
    def dns_record(self) -> ComputeInstanceNetworkInterfaceDnsRecordList:
        return typing.cast(ComputeInstanceNetworkInterfaceDnsRecordList, jsii.get(self, "dnsRecord"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="index")
    def index(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "index"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv6DnsRecord")
    def ipv6_dns_record(self) -> ComputeInstanceNetworkInterfaceIpv6DnsRecordList:
        return typing.cast(ComputeInstanceNetworkInterfaceIpv6DnsRecordList, jsii.get(self, "ipv6DnsRecord"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="macAddress")
    def mac_address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "macAddress"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="natDnsRecord")
    def nat_dns_record(self) -> ComputeInstanceNetworkInterfaceNatDnsRecordList:
        return typing.cast(ComputeInstanceNetworkInterfaceNatDnsRecordList, jsii.get(self, "natDnsRecord"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="natIpVersion")
    def nat_ip_version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "natIpVersion"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dnsRecordInput")
    def dns_record_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceNetworkInterfaceDnsRecord]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceNetworkInterfaceDnsRecord]]], jsii.get(self, "dnsRecordInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipAddressInput")
    def ip_address_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "ipAddressInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv4Input")
    def ipv4_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "ipv4Input"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv6AddressInput")
    def ipv6_address_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "ipv6AddressInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv6DnsRecordInput")
    def ipv6_dns_record_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceNetworkInterfaceIpv6DnsRecord]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceNetworkInterfaceIpv6DnsRecord]]], jsii.get(self, "ipv6DnsRecordInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv6Input")
    def ipv6_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "ipv6Input"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="natDnsRecordInput")
    def nat_dns_record_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceNetworkInterfaceNatDnsRecord]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceNetworkInterfaceNatDnsRecord]]], jsii.get(self, "natDnsRecordInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="natInput")
    def nat_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "natInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="natIpAddressInput")
    def nat_ip_address_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "natIpAddressInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIdsInput")
    def security_group_ids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "securityGroupIdsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIdInput")
    def subnet_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "subnetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipAddress")
    def ip_address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ipAddress"))

    @ip_address.setter
    def ip_address(self, value: builtins.str) -> None:
        jsii.set(self, "ipAddress", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv4")
    def ipv4(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "ipv4"))

    @ipv4.setter
    def ipv4(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "ipv4", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv6")
    def ipv6(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "ipv6"))

    @ipv6.setter
    def ipv6(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "ipv6", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv6Address")
    def ipv6_address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ipv6Address"))

    @ipv6_address.setter
    def ipv6_address(self, value: builtins.str) -> None:
        jsii.set(self, "ipv6Address", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nat")
    def nat(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "nat"))

    @nat.setter
    def nat(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "nat", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="natIpAddress")
    def nat_ip_address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "natIpAddress"))

    @nat_ip_address.setter
    def nat_ip_address(self, value: builtins.str) -> None:
        jsii.set(self, "natIpAddress", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "securityGroupIds"))

    @security_group_ids.setter
    def security_group_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "securityGroupIds", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @subnet_id.setter
    def subnet_id(self, value: builtins.str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceNetworkInterface]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceNetworkInterface]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceNetworkInterface]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstancePlacementPolicy",
    jsii_struct_bases=[],
    name_mapping={
        "host_affinity_rules": "hostAffinityRules",
        "placement_group_id": "placementGroupId",
    },
)
class ComputeInstancePlacementPolicy:
    def __init__(
        self,
        *,
        host_affinity_rules: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["ComputeInstancePlacementPolicyHostAffinityRules"]]] = None,
        placement_group_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param host_affinity_rules: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#host_affinity_rules ComputeInstance#host_affinity_rules}.
        :param placement_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#placement_group_id ComputeInstance#placement_group_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if host_affinity_rules is not None:
            self._values["host_affinity_rules"] = host_affinity_rules
        if placement_group_id is not None:
            self._values["placement_group_id"] = placement_group_id

    @builtins.property
    def host_affinity_rules(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstancePlacementPolicyHostAffinityRules"]]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#host_affinity_rules ComputeInstance#host_affinity_rules}.'''
        result = self._values.get("host_affinity_rules")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["ComputeInstancePlacementPolicyHostAffinityRules"]]], result)

    @builtins.property
    def placement_group_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#placement_group_id ComputeInstance#placement_group_id}.'''
        result = self._values.get("placement_group_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstancePlacementPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstancePlacementPolicyHostAffinityRules",
    jsii_struct_bases=[],
    name_mapping={"key": "key", "op": "op", "values": "values"},
)
class ComputeInstancePlacementPolicyHostAffinityRules:
    def __init__(
        self,
        *,
        key: typing.Optional[builtins.str] = None,
        op: typing.Optional[builtins.str] = None,
        values: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param key: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#key ComputeInstance#key}.
        :param op: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#op ComputeInstance#op}.
        :param values: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#values ComputeInstance#values}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if key is not None:
            self._values["key"] = key
        if op is not None:
            self._values["op"] = op
        if values is not None:
            self._values["values"] = values

    @builtins.property
    def key(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#key ComputeInstance#key}.'''
        result = self._values.get("key")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def op(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#op ComputeInstance#op}.'''
        result = self._values.get("op")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def values(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#values ComputeInstance#values}.'''
        result = self._values.get("values")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstancePlacementPolicyHostAffinityRules(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeInstancePlacementPolicyHostAffinityRulesList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstancePlacementPolicyHostAffinityRulesList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "ComputeInstancePlacementPolicyHostAffinityRulesOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("ComputeInstancePlacementPolicyHostAffinityRulesOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstancePlacementPolicyHostAffinityRules]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstancePlacementPolicyHostAffinityRules]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstancePlacementPolicyHostAffinityRules]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ComputeInstancePlacementPolicyHostAffinityRulesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstancePlacementPolicyHostAffinityRulesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetKey")
    def reset_key(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetKey", []))

    @jsii.member(jsii_name="resetOp")
    def reset_op(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOp", []))

    @jsii.member(jsii_name="resetValues")
    def reset_values(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetValues", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="keyInput")
    def key_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "keyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="opInput")
    def op_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "opInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="valuesInput")
    def values_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "valuesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="key")
    def key(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "key"))

    @key.setter
    def key(self, value: builtins.str) -> None:
        jsii.set(self, "key", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="op")
    def op(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "op"))

    @op.setter
    def op(self, value: builtins.str) -> None:
        jsii.set(self, "op", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="values")
    def values(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "values"))

    @values.setter
    def values(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "values", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstancePlacementPolicyHostAffinityRules]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstancePlacementPolicyHostAffinityRules]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstancePlacementPolicyHostAffinityRules]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ComputeInstancePlacementPolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstancePlacementPolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putHostAffinityRules")
    def put_host_affinity_rules(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence[ComputeInstancePlacementPolicyHostAffinityRules]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putHostAffinityRules", [value]))

    @jsii.member(jsii_name="resetHostAffinityRules")
    def reset_host_affinity_rules(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHostAffinityRules", []))

    @jsii.member(jsii_name="resetPlacementGroupId")
    def reset_placement_group_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPlacementGroupId", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostAffinityRules")
    def host_affinity_rules(
        self,
    ) -> ComputeInstancePlacementPolicyHostAffinityRulesList:
        return typing.cast(ComputeInstancePlacementPolicyHostAffinityRulesList, jsii.get(self, "hostAffinityRules"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostAffinityRulesInput")
    def host_affinity_rules_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstancePlacementPolicyHostAffinityRules]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstancePlacementPolicyHostAffinityRules]]], jsii.get(self, "hostAffinityRulesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="placementGroupIdInput")
    def placement_group_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "placementGroupIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="placementGroupId")
    def placement_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "placementGroupId"))

    @placement_group_id.setter
    def placement_group_id(self, value: builtins.str) -> None:
        jsii.set(self, "placementGroupId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[ComputeInstancePlacementPolicy]:
        return typing.cast(typing.Optional[ComputeInstancePlacementPolicy], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[ComputeInstancePlacementPolicy],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceResources",
    jsii_struct_bases=[],
    name_mapping={
        "cores": "cores",
        "memory": "memory",
        "core_fraction": "coreFraction",
        "gpus": "gpus",
    },
)
class ComputeInstanceResources:
    def __init__(
        self,
        *,
        cores: jsii.Number,
        memory: jsii.Number,
        core_fraction: typing.Optional[jsii.Number] = None,
        gpus: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param cores: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#cores ComputeInstance#cores}.
        :param memory: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#memory ComputeInstance#memory}.
        :param core_fraction: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#core_fraction ComputeInstance#core_fraction}.
        :param gpus: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#gpus ComputeInstance#gpus}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "cores": cores,
            "memory": memory,
        }
        if core_fraction is not None:
            self._values["core_fraction"] = core_fraction
        if gpus is not None:
            self._values["gpus"] = gpus

    @builtins.property
    def cores(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#cores ComputeInstance#cores}.'''
        result = self._values.get("cores")
        assert result is not None, "Required property 'cores' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def memory(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#memory ComputeInstance#memory}.'''
        result = self._values.get("memory")
        assert result is not None, "Required property 'memory' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def core_fraction(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#core_fraction ComputeInstance#core_fraction}.'''
        result = self._values.get("core_fraction")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def gpus(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#gpus ComputeInstance#gpus}.'''
        result = self._values.get("gpus")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeInstanceResourcesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceResourcesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCoreFraction")
    def reset_core_fraction(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCoreFraction", []))

    @jsii.member(jsii_name="resetGpus")
    def reset_gpus(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGpus", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="coreFractionInput")
    def core_fraction_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "coreFractionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="coresInput")
    def cores_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "coresInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="gpusInput")
    def gpus_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "gpusInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="memoryInput")
    def memory_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "memoryInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="coreFraction")
    def core_fraction(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "coreFraction"))

    @core_fraction.setter
    def core_fraction(self, value: jsii.Number) -> None:
        jsii.set(self, "coreFraction", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cores")
    def cores(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "cores"))

    @cores.setter
    def cores(self, value: jsii.Number) -> None:
        jsii.set(self, "cores", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="gpus")
    def gpus(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "gpus"))

    @gpus.setter
    def gpus(self, value: jsii.Number) -> None:
        jsii.set(self, "gpus", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="memory")
    def memory(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "memory"))

    @memory.setter
    def memory(self, value: jsii.Number) -> None:
        jsii.set(self, "memory", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[ComputeInstanceResources]:
        return typing.cast(typing.Optional[ComputeInstanceResources], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(self, value: typing.Optional[ComputeInstanceResources]) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceSchedulingPolicy",
    jsii_struct_bases=[],
    name_mapping={"preemptible": "preemptible"},
)
class ComputeInstanceSchedulingPolicy:
    def __init__(
        self,
        *,
        preemptible: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param preemptible: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#preemptible ComputeInstance#preemptible}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if preemptible is not None:
            self._values["preemptible"] = preemptible

    @builtins.property
    def preemptible(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#preemptible ComputeInstance#preemptible}.'''
        result = self._values.get("preemptible")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceSchedulingPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeInstanceSchedulingPolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceSchedulingPolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetPreemptible")
    def reset_preemptible(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPreemptible", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="preemptibleInput")
    def preemptible_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "preemptibleInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="preemptible")
    def preemptible(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "preemptible"))

    @preemptible.setter
    def preemptible(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "preemptible", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[ComputeInstanceSchedulingPolicy]:
        return typing.cast(typing.Optional[ComputeInstanceSchedulingPolicy], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[ComputeInstanceSchedulingPolicy],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceSecondaryDisk",
    jsii_struct_bases=[],
    name_mapping={
        "disk_id": "diskId",
        "auto_delete": "autoDelete",
        "device_name": "deviceName",
        "mode": "mode",
    },
)
class ComputeInstanceSecondaryDisk:
    def __init__(
        self,
        *,
        disk_id: builtins.str,
        auto_delete: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        device_name: typing.Optional[builtins.str] = None,
        mode: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param disk_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#disk_id ComputeInstance#disk_id}.
        :param auto_delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#auto_delete ComputeInstance#auto_delete}.
        :param device_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#device_name ComputeInstance#device_name}.
        :param mode: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#mode ComputeInstance#mode}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "disk_id": disk_id,
        }
        if auto_delete is not None:
            self._values["auto_delete"] = auto_delete
        if device_name is not None:
            self._values["device_name"] = device_name
        if mode is not None:
            self._values["mode"] = mode

    @builtins.property
    def disk_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#disk_id ComputeInstance#disk_id}.'''
        result = self._values.get("disk_id")
        assert result is not None, "Required property 'disk_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def auto_delete(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#auto_delete ComputeInstance#auto_delete}.'''
        result = self._values.get("auto_delete")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def device_name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#device_name ComputeInstance#device_name}.'''
        result = self._values.get("device_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def mode(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#mode ComputeInstance#mode}.'''
        result = self._values.get("mode")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceSecondaryDisk(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeInstanceSecondaryDiskList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceSecondaryDiskList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "ComputeInstanceSecondaryDiskOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("ComputeInstanceSecondaryDiskOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceSecondaryDisk]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceSecondaryDisk]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ComputeInstanceSecondaryDisk]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ComputeInstanceSecondaryDiskOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceSecondaryDiskOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetAutoDelete")
    def reset_auto_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAutoDelete", []))

    @jsii.member(jsii_name="resetDeviceName")
    def reset_device_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDeviceName", []))

    @jsii.member(jsii_name="resetMode")
    def reset_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMode", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoDeleteInput")
    def auto_delete_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "autoDeleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deviceNameInput")
    def device_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deviceNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskIdInput")
    def disk_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "diskIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="modeInput")
    def mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "modeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoDelete")
    def auto_delete(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "autoDelete"))

    @auto_delete.setter
    def auto_delete(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "autoDelete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deviceName")
    def device_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "deviceName"))

    @device_name.setter
    def device_name(self, value: builtins.str) -> None:
        jsii.set(self, "deviceName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskId")
    def disk_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskId"))

    @disk_id.setter
    def disk_id(self, value: builtins.str) -> None:
        jsii.set(self, "diskId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mode")
    def mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "mode"))

    @mode.setter
    def mode(self, value: builtins.str) -> None:
        jsii.set(self, "mode", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceSecondaryDisk]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceSecondaryDisk]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceSecondaryDisk]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeInstanceTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class ComputeInstanceTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#create ComputeInstance#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#delete ComputeInstance#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#update ComputeInstance#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#create ComputeInstance#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#delete ComputeInstance#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_instance#update ComputeInstance#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeInstanceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeInstanceTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeInstanceTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, ComputeInstanceTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ComputePlacementGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputePlacementGroup",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/compute_placement_group yandex_compute_placement_group}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ComputePlacementGroupTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/compute_placement_group yandex_compute_placement_group} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_placement_group#description ComputePlacementGroup#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_placement_group#folder_id ComputePlacementGroup#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_placement_group#id ComputePlacementGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_placement_group#labels ComputePlacementGroup#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_placement_group#name ComputePlacementGroup#name}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_placement_group#timeouts ComputePlacementGroup#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = ComputePlacementGroupConfig(
            description=description,
            folder_id=folder_id,
            id=id,
            labels=labels,
            name=name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_placement_group#create ComputePlacementGroup#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_placement_group#delete ComputePlacementGroup#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_placement_group#update ComputePlacementGroup#update}.
        '''
        value = ComputePlacementGroupTimeouts(
            create=create, delete=delete, update=update
        )

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "ComputePlacementGroupTimeoutsOutputReference":
        return typing.cast("ComputePlacementGroupTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "ComputePlacementGroupTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "ComputePlacementGroupTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputePlacementGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "description": "description",
        "folder_id": "folderId",
        "id": "id",
        "labels": "labels",
        "name": "name",
        "timeouts": "timeouts",
    },
)
class ComputePlacementGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ComputePlacementGroupTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_placement_group#description ComputePlacementGroup#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_placement_group#folder_id ComputePlacementGroup#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_placement_group#id ComputePlacementGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_placement_group#labels ComputePlacementGroup#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_placement_group#name ComputePlacementGroup#name}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_placement_group#timeouts ComputePlacementGroup#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ComputePlacementGroupTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if name is not None:
            self._values["name"] = name
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_placement_group#description ComputePlacementGroup#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_placement_group#folder_id ComputePlacementGroup#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_placement_group#id ComputePlacementGroup#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_placement_group#labels ComputePlacementGroup#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_placement_group#name ComputePlacementGroup#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["ComputePlacementGroupTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_placement_group#timeouts ComputePlacementGroup#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["ComputePlacementGroupTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputePlacementGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputePlacementGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class ComputePlacementGroupTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_placement_group#create ComputePlacementGroup#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_placement_group#delete ComputePlacementGroup#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_placement_group#update ComputePlacementGroup#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_placement_group#create ComputePlacementGroup#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_placement_group#delete ComputePlacementGroup#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_placement_group#update ComputePlacementGroup#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputePlacementGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputePlacementGroupTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputePlacementGroupTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, ComputePlacementGroupTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, ComputePlacementGroupTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, ComputePlacementGroupTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ComputeSnapshot(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeSnapshot",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/compute_snapshot yandex_compute_snapshot}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        source_disk_id: builtins.str,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ComputeSnapshotTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/compute_snapshot yandex_compute_snapshot} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param source_disk_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_snapshot#source_disk_id ComputeSnapshot#source_disk_id}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_snapshot#description ComputeSnapshot#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_snapshot#folder_id ComputeSnapshot#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_snapshot#id ComputeSnapshot#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_snapshot#labels ComputeSnapshot#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_snapshot#name ComputeSnapshot#name}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_snapshot#timeouts ComputeSnapshot#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = ComputeSnapshotConfig(
            source_disk_id=source_disk_id,
            description=description,
            folder_id=folder_id,
            id=id,
            labels=labels,
            name=name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_snapshot#create ComputeSnapshot#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_snapshot#delete ComputeSnapshot#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_snapshot#update ComputeSnapshot#update}.
        '''
        value = ComputeSnapshotTimeouts(create=create, delete=delete, update=update)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSize")
    def disk_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "diskSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="storageSize")
    def storage_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "storageSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "ComputeSnapshotTimeoutsOutputReference":
        return typing.cast("ComputeSnapshotTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sourceDiskIdInput")
    def source_disk_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sourceDiskIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "ComputeSnapshotTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "ComputeSnapshotTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sourceDiskId")
    def source_disk_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sourceDiskId"))

    @source_disk_id.setter
    def source_disk_id(self, value: builtins.str) -> None:
        jsii.set(self, "sourceDiskId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeSnapshotConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "source_disk_id": "sourceDiskId",
        "description": "description",
        "folder_id": "folderId",
        "id": "id",
        "labels": "labels",
        "name": "name",
        "timeouts": "timeouts",
    },
)
class ComputeSnapshotConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        source_disk_id: builtins.str,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ComputeSnapshotTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param source_disk_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_snapshot#source_disk_id ComputeSnapshot#source_disk_id}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_snapshot#description ComputeSnapshot#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_snapshot#folder_id ComputeSnapshot#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_snapshot#id ComputeSnapshot#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_snapshot#labels ComputeSnapshot#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_snapshot#name ComputeSnapshot#name}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_snapshot#timeouts ComputeSnapshot#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ComputeSnapshotTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "source_disk_id": source_disk_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if name is not None:
            self._values["name"] = name
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def source_disk_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_snapshot#source_disk_id ComputeSnapshot#source_disk_id}.'''
        result = self._values.get("source_disk_id")
        assert result is not None, "Required property 'source_disk_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_snapshot#description ComputeSnapshot#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_snapshot#folder_id ComputeSnapshot#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_snapshot#id ComputeSnapshot#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_snapshot#labels ComputeSnapshot#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_snapshot#name ComputeSnapshot#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["ComputeSnapshotTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_snapshot#timeouts ComputeSnapshot#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["ComputeSnapshotTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeSnapshotConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ComputeSnapshotTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class ComputeSnapshotTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_snapshot#create ComputeSnapshot#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_snapshot#delete ComputeSnapshot#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_snapshot#update ComputeSnapshot#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_snapshot#create ComputeSnapshot#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_snapshot#delete ComputeSnapshot#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/compute_snapshot#update ComputeSnapshot#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ComputeSnapshotTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ComputeSnapshotTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ComputeSnapshotTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, ComputeSnapshotTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, ComputeSnapshotTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, ComputeSnapshotTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ContainerRegistry(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ContainerRegistry",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/container_registry yandex_container_registry}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ContainerRegistryTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/container_registry yandex_container_registry} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry#folder_id ContainerRegistry#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry#id ContainerRegistry#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry#labels ContainerRegistry#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry#name ContainerRegistry#name}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry#timeouts ContainerRegistry#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = ContainerRegistryConfig(
            folder_id=folder_id,
            id=id,
            labels=labels,
            name=name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry#create ContainerRegistry#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry#delete ContainerRegistry#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry#update ContainerRegistry#update}.
        '''
        value = ContainerRegistryTimeouts(create=create, delete=delete, update=update)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "ContainerRegistryTimeoutsOutputReference":
        return typing.cast("ContainerRegistryTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "ContainerRegistryTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "ContainerRegistryTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ContainerRegistryConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "folder_id": "folderId",
        "id": "id",
        "labels": "labels",
        "name": "name",
        "timeouts": "timeouts",
    },
)
class ContainerRegistryConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ContainerRegistryTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry#folder_id ContainerRegistry#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry#id ContainerRegistry#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry#labels ContainerRegistry#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry#name ContainerRegistry#name}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry#timeouts ContainerRegistry#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ContainerRegistryTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if name is not None:
            self._values["name"] = name
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry#folder_id ContainerRegistry#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry#id ContainerRegistry#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry#labels ContainerRegistry#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry#name ContainerRegistry#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["ContainerRegistryTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry#timeouts ContainerRegistry#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["ContainerRegistryTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ContainerRegistryConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ContainerRegistryIamBinding(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ContainerRegistryIamBinding",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/container_registry_iam_binding yandex_container_registry_iam_binding}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        members: typing.Sequence[builtins.str],
        registry_id: builtins.str,
        role: builtins.str,
        id: typing.Optional[builtins.str] = None,
        sleep_after: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/container_registry_iam_binding yandex_container_registry_iam_binding} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param members: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry_iam_binding#members ContainerRegistryIamBinding#members}.
        :param registry_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry_iam_binding#registry_id ContainerRegistryIamBinding#registry_id}.
        :param role: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry_iam_binding#role ContainerRegistryIamBinding#role}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry_iam_binding#id ContainerRegistryIamBinding#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param sleep_after: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry_iam_binding#sleep_after ContainerRegistryIamBinding#sleep_after}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = ContainerRegistryIamBindingConfig(
            members=members,
            registry_id=registry_id,
            role=role,
            id=id,
            sleep_after=sleep_after,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetSleepAfter")
    def reset_sleep_after(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSleepAfter", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="membersInput")
    def members_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "membersInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="registryIdInput")
    def registry_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "registryIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="roleInput")
    def role_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "roleInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sleepAfterInput")
    def sleep_after_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "sleepAfterInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="members")
    def members(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "members"))

    @members.setter
    def members(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "members", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="registryId")
    def registry_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "registryId"))

    @registry_id.setter
    def registry_id(self, value: builtins.str) -> None:
        jsii.set(self, "registryId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="role")
    def role(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "role"))

    @role.setter
    def role(self, value: builtins.str) -> None:
        jsii.set(self, "role", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sleepAfter")
    def sleep_after(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "sleepAfter"))

    @sleep_after.setter
    def sleep_after(self, value: jsii.Number) -> None:
        jsii.set(self, "sleepAfter", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ContainerRegistryIamBindingConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "members": "members",
        "registry_id": "registryId",
        "role": "role",
        "id": "id",
        "sleep_after": "sleepAfter",
    },
)
class ContainerRegistryIamBindingConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        members: typing.Sequence[builtins.str],
        registry_id: builtins.str,
        role: builtins.str,
        id: typing.Optional[builtins.str] = None,
        sleep_after: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param members: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry_iam_binding#members ContainerRegistryIamBinding#members}.
        :param registry_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry_iam_binding#registry_id ContainerRegistryIamBinding#registry_id}.
        :param role: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry_iam_binding#role ContainerRegistryIamBinding#role}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry_iam_binding#id ContainerRegistryIamBinding#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param sleep_after: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry_iam_binding#sleep_after ContainerRegistryIamBinding#sleep_after}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {
            "members": members,
            "registry_id": registry_id,
            "role": role,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if id is not None:
            self._values["id"] = id
        if sleep_after is not None:
            self._values["sleep_after"] = sleep_after

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def members(self) -> typing.List[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry_iam_binding#members ContainerRegistryIamBinding#members}.'''
        result = self._values.get("members")
        assert result is not None, "Required property 'members' is missing"
        return typing.cast(typing.List[builtins.str], result)

    @builtins.property
    def registry_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry_iam_binding#registry_id ContainerRegistryIamBinding#registry_id}.'''
        result = self._values.get("registry_id")
        assert result is not None, "Required property 'registry_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def role(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry_iam_binding#role ContainerRegistryIamBinding#role}.'''
        result = self._values.get("role")
        assert result is not None, "Required property 'role' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry_iam_binding#id ContainerRegistryIamBinding#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def sleep_after(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry_iam_binding#sleep_after ContainerRegistryIamBinding#sleep_after}.'''
        result = self._values.get("sleep_after")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ContainerRegistryIamBindingConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ContainerRegistryTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class ContainerRegistryTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry#create ContainerRegistry#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry#delete ContainerRegistry#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry#update ContainerRegistry#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry#create ContainerRegistry#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry#delete ContainerRegistry#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_registry#update ContainerRegistry#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ContainerRegistryTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ContainerRegistryTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ContainerRegistryTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, ContainerRegistryTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, ContainerRegistryTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, ContainerRegistryTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ContainerRepository(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ContainerRepository",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/container_repository yandex_container_repository}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ContainerRepositoryTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/container_repository yandex_container_repository} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_repository#id ContainerRepository#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_repository#name ContainerRepository#name}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_repository#timeouts ContainerRepository#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = ContainerRepositoryConfig(
            id=id,
            name=name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_repository#create ContainerRepository#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_repository#delete ContainerRepository#delete}.
        '''
        value = ContainerRepositoryTimeouts(create=create, delete=delete)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "ContainerRepositoryTimeoutsOutputReference":
        return typing.cast("ContainerRepositoryTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "ContainerRepositoryTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "ContainerRepositoryTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ContainerRepositoryConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "id": "id",
        "name": "name",
        "timeouts": "timeouts",
    },
)
class ContainerRepositoryConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ContainerRepositoryTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_repository#id ContainerRepository#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_repository#name ContainerRepository#name}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_repository#timeouts ContainerRepository#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ContainerRepositoryTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_repository#id ContainerRepository#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_repository#name ContainerRepository#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["ContainerRepositoryTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_repository#timeouts ContainerRepository#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["ContainerRepositoryTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ContainerRepositoryConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ContainerRepositoryIamBinding(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ContainerRepositoryIamBinding",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/container_repository_iam_binding yandex_container_repository_iam_binding}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        members: typing.Sequence[builtins.str],
        repository_id: builtins.str,
        role: builtins.str,
        id: typing.Optional[builtins.str] = None,
        sleep_after: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/container_repository_iam_binding yandex_container_repository_iam_binding} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param members: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_repository_iam_binding#members ContainerRepositoryIamBinding#members}.
        :param repository_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_repository_iam_binding#repository_id ContainerRepositoryIamBinding#repository_id}.
        :param role: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_repository_iam_binding#role ContainerRepositoryIamBinding#role}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_repository_iam_binding#id ContainerRepositoryIamBinding#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param sleep_after: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_repository_iam_binding#sleep_after ContainerRepositoryIamBinding#sleep_after}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = ContainerRepositoryIamBindingConfig(
            members=members,
            repository_id=repository_id,
            role=role,
            id=id,
            sleep_after=sleep_after,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetSleepAfter")
    def reset_sleep_after(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSleepAfter", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="membersInput")
    def members_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "membersInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="repositoryIdInput")
    def repository_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "repositoryIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="roleInput")
    def role_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "roleInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sleepAfterInput")
    def sleep_after_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "sleepAfterInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="members")
    def members(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "members"))

    @members.setter
    def members(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "members", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="repositoryId")
    def repository_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "repositoryId"))

    @repository_id.setter
    def repository_id(self, value: builtins.str) -> None:
        jsii.set(self, "repositoryId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="role")
    def role(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "role"))

    @role.setter
    def role(self, value: builtins.str) -> None:
        jsii.set(self, "role", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sleepAfter")
    def sleep_after(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "sleepAfter"))

    @sleep_after.setter
    def sleep_after(self, value: jsii.Number) -> None:
        jsii.set(self, "sleepAfter", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ContainerRepositoryIamBindingConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "members": "members",
        "repository_id": "repositoryId",
        "role": "role",
        "id": "id",
        "sleep_after": "sleepAfter",
    },
)
class ContainerRepositoryIamBindingConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        members: typing.Sequence[builtins.str],
        repository_id: builtins.str,
        role: builtins.str,
        id: typing.Optional[builtins.str] = None,
        sleep_after: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param members: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_repository_iam_binding#members ContainerRepositoryIamBinding#members}.
        :param repository_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_repository_iam_binding#repository_id ContainerRepositoryIamBinding#repository_id}.
        :param role: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_repository_iam_binding#role ContainerRepositoryIamBinding#role}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_repository_iam_binding#id ContainerRepositoryIamBinding#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param sleep_after: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_repository_iam_binding#sleep_after ContainerRepositoryIamBinding#sleep_after}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {
            "members": members,
            "repository_id": repository_id,
            "role": role,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if id is not None:
            self._values["id"] = id
        if sleep_after is not None:
            self._values["sleep_after"] = sleep_after

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def members(self) -> typing.List[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_repository_iam_binding#members ContainerRepositoryIamBinding#members}.'''
        result = self._values.get("members")
        assert result is not None, "Required property 'members' is missing"
        return typing.cast(typing.List[builtins.str], result)

    @builtins.property
    def repository_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_repository_iam_binding#repository_id ContainerRepositoryIamBinding#repository_id}.'''
        result = self._values.get("repository_id")
        assert result is not None, "Required property 'repository_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def role(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_repository_iam_binding#role ContainerRepositoryIamBinding#role}.'''
        result = self._values.get("role")
        assert result is not None, "Required property 'role' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_repository_iam_binding#id ContainerRepositoryIamBinding#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def sleep_after(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_repository_iam_binding#sleep_after ContainerRepositoryIamBinding#sleep_after}.'''
        result = self._values.get("sleep_after")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ContainerRepositoryIamBindingConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ContainerRepositoryTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete"},
)
class ContainerRepositoryTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_repository#create ContainerRepository#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_repository#delete ContainerRepository#delete}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_repository#create ContainerRepository#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/container_repository#delete ContainerRepository#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ContainerRepositoryTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ContainerRepositoryTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ContainerRepositoryTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, ContainerRepositoryTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, ContainerRepositoryTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, ContainerRepositoryTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexAlbBackendGroup(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroup",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group yandex_alb_backend_group}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        backend_group_id: typing.Optional[builtins.str] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        grpc_backend: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["DataYandexAlbBackendGroupGrpcBackend"]]] = None,
        http_backend: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["DataYandexAlbBackendGroupHttpBackend"]]] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        stream_backend: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["DataYandexAlbBackendGroupStreamBackend"]]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group yandex_alb_backend_group} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param backend_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#backend_group_id DataYandexAlbBackendGroup#backend_group_id}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#description DataYandexAlbBackendGroup#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#folder_id DataYandexAlbBackendGroup#folder_id}.
        :param grpc_backend: grpc_backend block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#grpc_backend DataYandexAlbBackendGroup#grpc_backend}
        :param http_backend: http_backend block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#http_backend DataYandexAlbBackendGroup#http_backend}
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#id DataYandexAlbBackendGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#labels DataYandexAlbBackendGroup#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#name DataYandexAlbBackendGroup#name}.
        :param stream_backend: stream_backend block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#stream_backend DataYandexAlbBackendGroup#stream_backend}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexAlbBackendGroupConfig(
            backend_group_id=backend_group_id,
            description=description,
            folder_id=folder_id,
            grpc_backend=grpc_backend,
            http_backend=http_backend,
            id=id,
            labels=labels,
            name=name,
            stream_backend=stream_backend,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putGrpcBackend")
    def put_grpc_backend(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["DataYandexAlbBackendGroupGrpcBackend"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putGrpcBackend", [value]))

    @jsii.member(jsii_name="putHttpBackend")
    def put_http_backend(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["DataYandexAlbBackendGroupHttpBackend"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putHttpBackend", [value]))

    @jsii.member(jsii_name="putStreamBackend")
    def put_stream_backend(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["DataYandexAlbBackendGroupStreamBackend"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putStreamBackend", [value]))

    @jsii.member(jsii_name="resetBackendGroupId")
    def reset_backend_group_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetBackendGroupId", []))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetGrpcBackend")
    def reset_grpc_backend(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGrpcBackend", []))

    @jsii.member(jsii_name="resetHttpBackend")
    def reset_http_backend(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttpBackend", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetStreamBackend")
    def reset_stream_backend(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStreamBackend", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="grpcBackend")
    def grpc_backend(self) -> "DataYandexAlbBackendGroupGrpcBackendList":
        return typing.cast("DataYandexAlbBackendGroupGrpcBackendList", jsii.get(self, "grpcBackend"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpBackend")
    def http_backend(self) -> "DataYandexAlbBackendGroupHttpBackendList":
        return typing.cast("DataYandexAlbBackendGroupHttpBackendList", jsii.get(self, "httpBackend"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="streamBackend")
    def stream_backend(self) -> "DataYandexAlbBackendGroupStreamBackendList":
        return typing.cast("DataYandexAlbBackendGroupStreamBackendList", jsii.get(self, "streamBackend"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backendGroupIdInput")
    def backend_group_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "backendGroupIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="grpcBackendInput")
    def grpc_backend_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataYandexAlbBackendGroupGrpcBackend"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataYandexAlbBackendGroupGrpcBackend"]]], jsii.get(self, "grpcBackendInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpBackendInput")
    def http_backend_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataYandexAlbBackendGroupHttpBackend"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataYandexAlbBackendGroupHttpBackend"]]], jsii.get(self, "httpBackendInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="streamBackendInput")
    def stream_backend_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataYandexAlbBackendGroupStreamBackend"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataYandexAlbBackendGroupStreamBackend"]]], jsii.get(self, "streamBackendInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backendGroupId")
    def backend_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "backendGroupId"))

    @backend_group_id.setter
    def backend_group_id(self, value: builtins.str) -> None:
        jsii.set(self, "backendGroupId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "backend_group_id": "backendGroupId",
        "description": "description",
        "folder_id": "folderId",
        "grpc_backend": "grpcBackend",
        "http_backend": "httpBackend",
        "id": "id",
        "labels": "labels",
        "name": "name",
        "stream_backend": "streamBackend",
    },
)
class DataYandexAlbBackendGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        backend_group_id: typing.Optional[builtins.str] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        grpc_backend: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["DataYandexAlbBackendGroupGrpcBackend"]]] = None,
        http_backend: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["DataYandexAlbBackendGroupHttpBackend"]]] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        stream_backend: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["DataYandexAlbBackendGroupStreamBackend"]]] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param backend_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#backend_group_id DataYandexAlbBackendGroup#backend_group_id}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#description DataYandexAlbBackendGroup#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#folder_id DataYandexAlbBackendGroup#folder_id}.
        :param grpc_backend: grpc_backend block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#grpc_backend DataYandexAlbBackendGroup#grpc_backend}
        :param http_backend: http_backend block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#http_backend DataYandexAlbBackendGroup#http_backend}
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#id DataYandexAlbBackendGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#labels DataYandexAlbBackendGroup#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#name DataYandexAlbBackendGroup#name}.
        :param stream_backend: stream_backend block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#stream_backend DataYandexAlbBackendGroup#stream_backend}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if backend_group_id is not None:
            self._values["backend_group_id"] = backend_group_id
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if grpc_backend is not None:
            self._values["grpc_backend"] = grpc_backend
        if http_backend is not None:
            self._values["http_backend"] = http_backend
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if name is not None:
            self._values["name"] = name
        if stream_backend is not None:
            self._values["stream_backend"] = stream_backend

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def backend_group_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#backend_group_id DataYandexAlbBackendGroup#backend_group_id}.'''
        result = self._values.get("backend_group_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#description DataYandexAlbBackendGroup#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#folder_id DataYandexAlbBackendGroup#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def grpc_backend(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataYandexAlbBackendGroupGrpcBackend"]]]:
        '''grpc_backend block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#grpc_backend DataYandexAlbBackendGroup#grpc_backend}
        '''
        result = self._values.get("grpc_backend")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataYandexAlbBackendGroupGrpcBackend"]]], result)

    @builtins.property
    def http_backend(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataYandexAlbBackendGroupHttpBackend"]]]:
        '''http_backend block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#http_backend DataYandexAlbBackendGroup#http_backend}
        '''
        result = self._values.get("http_backend")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataYandexAlbBackendGroupHttpBackend"]]], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#id DataYandexAlbBackendGroup#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#labels DataYandexAlbBackendGroup#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#name DataYandexAlbBackendGroup#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def stream_backend(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataYandexAlbBackendGroupStreamBackend"]]]:
        '''stream_backend block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#stream_backend DataYandexAlbBackendGroup#stream_backend}
        '''
        result = self._values.get("stream_backend")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataYandexAlbBackendGroupStreamBackend"]]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbBackendGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupGrpcBackend",
    jsii_struct_bases=[],
    name_mapping={
        "healthcheck": "healthcheck",
        "load_balancing_config": "loadBalancingConfig",
        "port": "port",
        "tls": "tls",
        "weight": "weight",
    },
)
class DataYandexAlbBackendGroupGrpcBackend:
    def __init__(
        self,
        *,
        healthcheck: typing.Optional["DataYandexAlbBackendGroupGrpcBackendHealthcheck"] = None,
        load_balancing_config: typing.Optional["DataYandexAlbBackendGroupGrpcBackendLoadBalancingConfig"] = None,
        port: typing.Optional[jsii.Number] = None,
        tls: typing.Optional["DataYandexAlbBackendGroupGrpcBackendTls"] = None,
        weight: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param healthcheck: healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#healthcheck DataYandexAlbBackendGroup#healthcheck}
        :param load_balancing_config: load_balancing_config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#load_balancing_config DataYandexAlbBackendGroup#load_balancing_config}
        :param port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#port DataYandexAlbBackendGroup#port}.
        :param tls: tls block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#tls DataYandexAlbBackendGroup#tls}
        :param weight: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#weight DataYandexAlbBackendGroup#weight}.
        '''
        if isinstance(healthcheck, dict):
            healthcheck = DataYandexAlbBackendGroupGrpcBackendHealthcheck(**healthcheck)
        if isinstance(load_balancing_config, dict):
            load_balancing_config = DataYandexAlbBackendGroupGrpcBackendLoadBalancingConfig(**load_balancing_config)
        if isinstance(tls, dict):
            tls = DataYandexAlbBackendGroupGrpcBackendTls(**tls)
        self._values: typing.Dict[str, typing.Any] = {}
        if healthcheck is not None:
            self._values["healthcheck"] = healthcheck
        if load_balancing_config is not None:
            self._values["load_balancing_config"] = load_balancing_config
        if port is not None:
            self._values["port"] = port
        if tls is not None:
            self._values["tls"] = tls
        if weight is not None:
            self._values["weight"] = weight

    @builtins.property
    def healthcheck(
        self,
    ) -> typing.Optional["DataYandexAlbBackendGroupGrpcBackendHealthcheck"]:
        '''healthcheck block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#healthcheck DataYandexAlbBackendGroup#healthcheck}
        '''
        result = self._values.get("healthcheck")
        return typing.cast(typing.Optional["DataYandexAlbBackendGroupGrpcBackendHealthcheck"], result)

    @builtins.property
    def load_balancing_config(
        self,
    ) -> typing.Optional["DataYandexAlbBackendGroupGrpcBackendLoadBalancingConfig"]:
        '''load_balancing_config block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#load_balancing_config DataYandexAlbBackendGroup#load_balancing_config}
        '''
        result = self._values.get("load_balancing_config")
        return typing.cast(typing.Optional["DataYandexAlbBackendGroupGrpcBackendLoadBalancingConfig"], result)

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#port DataYandexAlbBackendGroup#port}.'''
        result = self._values.get("port")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def tls(self) -> typing.Optional["DataYandexAlbBackendGroupGrpcBackendTls"]:
        '''tls block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#tls DataYandexAlbBackendGroup#tls}
        '''
        result = self._values.get("tls")
        return typing.cast(typing.Optional["DataYandexAlbBackendGroupGrpcBackendTls"], result)

    @builtins.property
    def weight(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#weight DataYandexAlbBackendGroup#weight}.'''
        result = self._values.get("weight")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbBackendGroupGrpcBackend(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupGrpcBackendHealthcheck",
    jsii_struct_bases=[],
    name_mapping={
        "grpc_healthcheck": "grpcHealthcheck",
        "healthcheck_port": "healthcheckPort",
        "healthy_threshold": "healthyThreshold",
        "http_healthcheck": "httpHealthcheck",
        "interval_jitter_percent": "intervalJitterPercent",
        "stream_healthcheck": "streamHealthcheck",
        "unhealthy_threshold": "unhealthyThreshold",
    },
)
class DataYandexAlbBackendGroupGrpcBackendHealthcheck:
    def __init__(
        self,
        *,
        grpc_healthcheck: typing.Optional["DataYandexAlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheck"] = None,
        healthcheck_port: typing.Optional[jsii.Number] = None,
        healthy_threshold: typing.Optional[jsii.Number] = None,
        http_healthcheck: typing.Optional["DataYandexAlbBackendGroupGrpcBackendHealthcheckHttpHealthcheck"] = None,
        interval_jitter_percent: typing.Optional[jsii.Number] = None,
        stream_healthcheck: typing.Optional["DataYandexAlbBackendGroupGrpcBackendHealthcheckStreamHealthcheck"] = None,
        unhealthy_threshold: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param grpc_healthcheck: grpc_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#grpc_healthcheck DataYandexAlbBackendGroup#grpc_healthcheck}
        :param healthcheck_port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#healthcheck_port DataYandexAlbBackendGroup#healthcheck_port}.
        :param healthy_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#healthy_threshold DataYandexAlbBackendGroup#healthy_threshold}.
        :param http_healthcheck: http_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#http_healthcheck DataYandexAlbBackendGroup#http_healthcheck}
        :param interval_jitter_percent: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#interval_jitter_percent DataYandexAlbBackendGroup#interval_jitter_percent}.
        :param stream_healthcheck: stream_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#stream_healthcheck DataYandexAlbBackendGroup#stream_healthcheck}
        :param unhealthy_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#unhealthy_threshold DataYandexAlbBackendGroup#unhealthy_threshold}.
        '''
        if isinstance(grpc_healthcheck, dict):
            grpc_healthcheck = DataYandexAlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheck(**grpc_healthcheck)
        if isinstance(http_healthcheck, dict):
            http_healthcheck = DataYandexAlbBackendGroupGrpcBackendHealthcheckHttpHealthcheck(**http_healthcheck)
        if isinstance(stream_healthcheck, dict):
            stream_healthcheck = DataYandexAlbBackendGroupGrpcBackendHealthcheckStreamHealthcheck(**stream_healthcheck)
        self._values: typing.Dict[str, typing.Any] = {}
        if grpc_healthcheck is not None:
            self._values["grpc_healthcheck"] = grpc_healthcheck
        if healthcheck_port is not None:
            self._values["healthcheck_port"] = healthcheck_port
        if healthy_threshold is not None:
            self._values["healthy_threshold"] = healthy_threshold
        if http_healthcheck is not None:
            self._values["http_healthcheck"] = http_healthcheck
        if interval_jitter_percent is not None:
            self._values["interval_jitter_percent"] = interval_jitter_percent
        if stream_healthcheck is not None:
            self._values["stream_healthcheck"] = stream_healthcheck
        if unhealthy_threshold is not None:
            self._values["unhealthy_threshold"] = unhealthy_threshold

    @builtins.property
    def grpc_healthcheck(
        self,
    ) -> typing.Optional["DataYandexAlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheck"]:
        '''grpc_healthcheck block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#grpc_healthcheck DataYandexAlbBackendGroup#grpc_healthcheck}
        '''
        result = self._values.get("grpc_healthcheck")
        return typing.cast(typing.Optional["DataYandexAlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheck"], result)

    @builtins.property
    def healthcheck_port(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#healthcheck_port DataYandexAlbBackendGroup#healthcheck_port}.'''
        result = self._values.get("healthcheck_port")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def healthy_threshold(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#healthy_threshold DataYandexAlbBackendGroup#healthy_threshold}.'''
        result = self._values.get("healthy_threshold")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def http_healthcheck(
        self,
    ) -> typing.Optional["DataYandexAlbBackendGroupGrpcBackendHealthcheckHttpHealthcheck"]:
        '''http_healthcheck block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#http_healthcheck DataYandexAlbBackendGroup#http_healthcheck}
        '''
        result = self._values.get("http_healthcheck")
        return typing.cast(typing.Optional["DataYandexAlbBackendGroupGrpcBackendHealthcheckHttpHealthcheck"], result)

    @builtins.property
    def interval_jitter_percent(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#interval_jitter_percent DataYandexAlbBackendGroup#interval_jitter_percent}.'''
        result = self._values.get("interval_jitter_percent")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def stream_healthcheck(
        self,
    ) -> typing.Optional["DataYandexAlbBackendGroupGrpcBackendHealthcheckStreamHealthcheck"]:
        '''stream_healthcheck block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#stream_healthcheck DataYandexAlbBackendGroup#stream_healthcheck}
        '''
        result = self._values.get("stream_healthcheck")
        return typing.cast(typing.Optional["DataYandexAlbBackendGroupGrpcBackendHealthcheckStreamHealthcheck"], result)

    @builtins.property
    def unhealthy_threshold(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#unhealthy_threshold DataYandexAlbBackendGroup#unhealthy_threshold}.'''
        result = self._values.get("unhealthy_threshold")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbBackendGroupGrpcBackendHealthcheck(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheck",
    jsii_struct_bases=[],
    name_mapping={"service_name": "serviceName"},
)
class DataYandexAlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheck:
    def __init__(self, *, service_name: typing.Optional[builtins.str] = None) -> None:
        '''
        :param service_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#service_name DataYandexAlbBackendGroup#service_name}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if service_name is not None:
            self._values["service_name"] = service_name

    @builtins.property
    def service_name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#service_name DataYandexAlbBackendGroup#service_name}.'''
        result = self._values.get("service_name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheck(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheckOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheckOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetServiceName")
    def reset_service_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetServiceName", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceNameInput")
    def service_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceName")
    def service_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceName"))

    @service_name.setter
    def service_name(self, value: builtins.str) -> None:
        jsii.set(self, "serviceName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheck]:
        return typing.cast(typing.Optional[DataYandexAlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheck], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheck],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupGrpcBackendHealthcheckHttpHealthcheck",
    jsii_struct_bases=[],
    name_mapping={"host": "host", "http2": "http2"},
)
class DataYandexAlbBackendGroupGrpcBackendHealthcheckHttpHealthcheck:
    def __init__(
        self,
        *,
        host: typing.Optional[builtins.str] = None,
        http2: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param host: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#host DataYandexAlbBackendGroup#host}.
        :param http2: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#http2 DataYandexAlbBackendGroup#http2}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if host is not None:
            self._values["host"] = host
        if http2 is not None:
            self._values["http2"] = http2

    @builtins.property
    def host(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#host DataYandexAlbBackendGroup#host}.'''
        result = self._values.get("host")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def http2(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#http2 DataYandexAlbBackendGroup#http2}.'''
        result = self._values.get("http2")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbBackendGroupGrpcBackendHealthcheckHttpHealthcheck(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbBackendGroupGrpcBackendHealthcheckHttpHealthcheckOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupGrpcBackendHealthcheckHttpHealthcheckOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetHost")
    def reset_host(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHost", []))

    @jsii.member(jsii_name="resetHttp2")
    def reset_http2(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttp2", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="path")
    def path(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "path"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostInput")
    def host_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "hostInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="http2Input")
    def http2_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "http2Input"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="host")
    def host(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "host"))

    @host.setter
    def host(self, value: builtins.str) -> None:
        jsii.set(self, "host", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="http2")
    def http2(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "http2"))

    @http2.setter
    def http2(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "http2", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbBackendGroupGrpcBackendHealthcheckHttpHealthcheck]:
        return typing.cast(typing.Optional[DataYandexAlbBackendGroupGrpcBackendHealthcheckHttpHealthcheck], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbBackendGroupGrpcBackendHealthcheckHttpHealthcheck],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexAlbBackendGroupGrpcBackendHealthcheckOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupGrpcBackendHealthcheckOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putGrpcHealthcheck")
    def put_grpc_healthcheck(
        self,
        *,
        service_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param service_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#service_name DataYandexAlbBackendGroup#service_name}.
        '''
        value = DataYandexAlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheck(
            service_name=service_name
        )

        return typing.cast(None, jsii.invoke(self, "putGrpcHealthcheck", [value]))

    @jsii.member(jsii_name="putHttpHealthcheck")
    def put_http_healthcheck(
        self,
        *,
        host: typing.Optional[builtins.str] = None,
        http2: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param host: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#host DataYandexAlbBackendGroup#host}.
        :param http2: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#http2 DataYandexAlbBackendGroup#http2}.
        '''
        value = DataYandexAlbBackendGroupGrpcBackendHealthcheckHttpHealthcheck(
            host=host, http2=http2
        )

        return typing.cast(None, jsii.invoke(self, "putHttpHealthcheck", [value]))

    @jsii.member(jsii_name="putStreamHealthcheck")
    def put_stream_healthcheck(
        self,
        *,
        receive: typing.Optional[builtins.str] = None,
        send: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param receive: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#receive DataYandexAlbBackendGroup#receive}.
        :param send: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#send DataYandexAlbBackendGroup#send}.
        '''
        value = DataYandexAlbBackendGroupGrpcBackendHealthcheckStreamHealthcheck(
            receive=receive, send=send
        )

        return typing.cast(None, jsii.invoke(self, "putStreamHealthcheck", [value]))

    @jsii.member(jsii_name="resetGrpcHealthcheck")
    def reset_grpc_healthcheck(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGrpcHealthcheck", []))

    @jsii.member(jsii_name="resetHealthcheckPort")
    def reset_healthcheck_port(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHealthcheckPort", []))

    @jsii.member(jsii_name="resetHealthyThreshold")
    def reset_healthy_threshold(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHealthyThreshold", []))

    @jsii.member(jsii_name="resetHttpHealthcheck")
    def reset_http_healthcheck(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttpHealthcheck", []))

    @jsii.member(jsii_name="resetIntervalJitterPercent")
    def reset_interval_jitter_percent(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIntervalJitterPercent", []))

    @jsii.member(jsii_name="resetStreamHealthcheck")
    def reset_stream_healthcheck(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStreamHealthcheck", []))

    @jsii.member(jsii_name="resetUnhealthyThreshold")
    def reset_unhealthy_threshold(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUnhealthyThreshold", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="grpcHealthcheck")
    def grpc_healthcheck(
        self,
    ) -> DataYandexAlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheckOutputReference:
        return typing.cast(DataYandexAlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheckOutputReference, jsii.get(self, "grpcHealthcheck"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpHealthcheck")
    def http_healthcheck(
        self,
    ) -> DataYandexAlbBackendGroupGrpcBackendHealthcheckHttpHealthcheckOutputReference:
        return typing.cast(DataYandexAlbBackendGroupGrpcBackendHealthcheckHttpHealthcheckOutputReference, jsii.get(self, "httpHealthcheck"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="interval")
    def interval(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "interval"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="streamHealthcheck")
    def stream_healthcheck(
        self,
    ) -> "DataYandexAlbBackendGroupGrpcBackendHealthcheckStreamHealthcheckOutputReference":
        return typing.cast("DataYandexAlbBackendGroupGrpcBackendHealthcheckStreamHealthcheckOutputReference", jsii.get(self, "streamHealthcheck"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeout")
    def timeout(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "timeout"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="grpcHealthcheckInput")
    def grpc_healthcheck_input(
        self,
    ) -> typing.Optional[DataYandexAlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheck]:
        return typing.cast(typing.Optional[DataYandexAlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheck], jsii.get(self, "grpcHealthcheckInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthcheckPortInput")
    def healthcheck_port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "healthcheckPortInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthyThresholdInput")
    def healthy_threshold_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "healthyThresholdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpHealthcheckInput")
    def http_healthcheck_input(
        self,
    ) -> typing.Optional[DataYandexAlbBackendGroupGrpcBackendHealthcheckHttpHealthcheck]:
        return typing.cast(typing.Optional[DataYandexAlbBackendGroupGrpcBackendHealthcheckHttpHealthcheck], jsii.get(self, "httpHealthcheckInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="intervalJitterPercentInput")
    def interval_jitter_percent_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalJitterPercentInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="streamHealthcheckInput")
    def stream_healthcheck_input(
        self,
    ) -> typing.Optional["DataYandexAlbBackendGroupGrpcBackendHealthcheckStreamHealthcheck"]:
        return typing.cast(typing.Optional["DataYandexAlbBackendGroupGrpcBackendHealthcheckStreamHealthcheck"], jsii.get(self, "streamHealthcheckInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="unhealthyThresholdInput")
    def unhealthy_threshold_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "unhealthyThresholdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthcheckPort")
    def healthcheck_port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "healthcheckPort"))

    @healthcheck_port.setter
    def healthcheck_port(self, value: jsii.Number) -> None:
        jsii.set(self, "healthcheckPort", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthyThreshold")
    def healthy_threshold(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "healthyThreshold"))

    @healthy_threshold.setter
    def healthy_threshold(self, value: jsii.Number) -> None:
        jsii.set(self, "healthyThreshold", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="intervalJitterPercent")
    def interval_jitter_percent(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "intervalJitterPercent"))

    @interval_jitter_percent.setter
    def interval_jitter_percent(self, value: jsii.Number) -> None:
        jsii.set(self, "intervalJitterPercent", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="unhealthyThreshold")
    def unhealthy_threshold(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "unhealthyThreshold"))

    @unhealthy_threshold.setter
    def unhealthy_threshold(self, value: jsii.Number) -> None:
        jsii.set(self, "unhealthyThreshold", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbBackendGroupGrpcBackendHealthcheck]:
        return typing.cast(typing.Optional[DataYandexAlbBackendGroupGrpcBackendHealthcheck], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbBackendGroupGrpcBackendHealthcheck],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupGrpcBackendHealthcheckStreamHealthcheck",
    jsii_struct_bases=[],
    name_mapping={"receive": "receive", "send": "send"},
)
class DataYandexAlbBackendGroupGrpcBackendHealthcheckStreamHealthcheck:
    def __init__(
        self,
        *,
        receive: typing.Optional[builtins.str] = None,
        send: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param receive: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#receive DataYandexAlbBackendGroup#receive}.
        :param send: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#send DataYandexAlbBackendGroup#send}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if receive is not None:
            self._values["receive"] = receive
        if send is not None:
            self._values["send"] = send

    @builtins.property
    def receive(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#receive DataYandexAlbBackendGroup#receive}.'''
        result = self._values.get("receive")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def send(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#send DataYandexAlbBackendGroup#send}.'''
        result = self._values.get("send")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbBackendGroupGrpcBackendHealthcheckStreamHealthcheck(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbBackendGroupGrpcBackendHealthcheckStreamHealthcheckOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupGrpcBackendHealthcheckStreamHealthcheckOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetReceive")
    def reset_receive(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetReceive", []))

    @jsii.member(jsii_name="resetSend")
    def reset_send(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSend", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="receiveInput")
    def receive_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "receiveInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sendInput")
    def send_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sendInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="receive")
    def receive(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "receive"))

    @receive.setter
    def receive(self, value: builtins.str) -> None:
        jsii.set(self, "receive", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="send")
    def send(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "send"))

    @send.setter
    def send(self, value: builtins.str) -> None:
        jsii.set(self, "send", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbBackendGroupGrpcBackendHealthcheckStreamHealthcheck]:
        return typing.cast(typing.Optional[DataYandexAlbBackendGroupGrpcBackendHealthcheckStreamHealthcheck], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbBackendGroupGrpcBackendHealthcheckStreamHealthcheck],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexAlbBackendGroupGrpcBackendList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupGrpcBackendList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbBackendGroupGrpcBackendOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbBackendGroupGrpcBackendOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataYandexAlbBackendGroupGrpcBackend]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataYandexAlbBackendGroupGrpcBackend]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataYandexAlbBackendGroupGrpcBackend]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupGrpcBackendLoadBalancingConfig",
    jsii_struct_bases=[],
    name_mapping={
        "locality_aware_routing_percent": "localityAwareRoutingPercent",
        "panic_threshold": "panicThreshold",
        "strict_locality": "strictLocality",
    },
)
class DataYandexAlbBackendGroupGrpcBackendLoadBalancingConfig:
    def __init__(
        self,
        *,
        locality_aware_routing_percent: typing.Optional[jsii.Number] = None,
        panic_threshold: typing.Optional[jsii.Number] = None,
        strict_locality: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param locality_aware_routing_percent: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#locality_aware_routing_percent DataYandexAlbBackendGroup#locality_aware_routing_percent}.
        :param panic_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#panic_threshold DataYandexAlbBackendGroup#panic_threshold}.
        :param strict_locality: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#strict_locality DataYandexAlbBackendGroup#strict_locality}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if locality_aware_routing_percent is not None:
            self._values["locality_aware_routing_percent"] = locality_aware_routing_percent
        if panic_threshold is not None:
            self._values["panic_threshold"] = panic_threshold
        if strict_locality is not None:
            self._values["strict_locality"] = strict_locality

    @builtins.property
    def locality_aware_routing_percent(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#locality_aware_routing_percent DataYandexAlbBackendGroup#locality_aware_routing_percent}.'''
        result = self._values.get("locality_aware_routing_percent")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def panic_threshold(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#panic_threshold DataYandexAlbBackendGroup#panic_threshold}.'''
        result = self._values.get("panic_threshold")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def strict_locality(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#strict_locality DataYandexAlbBackendGroup#strict_locality}.'''
        result = self._values.get("strict_locality")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbBackendGroupGrpcBackendLoadBalancingConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbBackendGroupGrpcBackendLoadBalancingConfigOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupGrpcBackendLoadBalancingConfigOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetLocalityAwareRoutingPercent")
    def reset_locality_aware_routing_percent(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLocalityAwareRoutingPercent", []))

    @jsii.member(jsii_name="resetPanicThreshold")
    def reset_panic_threshold(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPanicThreshold", []))

    @jsii.member(jsii_name="resetStrictLocality")
    def reset_strict_locality(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStrictLocality", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="localityAwareRoutingPercentInput")
    def locality_aware_routing_percent_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "localityAwareRoutingPercentInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="panicThresholdInput")
    def panic_threshold_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "panicThresholdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="strictLocalityInput")
    def strict_locality_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "strictLocalityInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="localityAwareRoutingPercent")
    def locality_aware_routing_percent(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "localityAwareRoutingPercent"))

    @locality_aware_routing_percent.setter
    def locality_aware_routing_percent(self, value: jsii.Number) -> None:
        jsii.set(self, "localityAwareRoutingPercent", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="panicThreshold")
    def panic_threshold(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "panicThreshold"))

    @panic_threshold.setter
    def panic_threshold(self, value: jsii.Number) -> None:
        jsii.set(self, "panicThreshold", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="strictLocality")
    def strict_locality(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "strictLocality"))

    @strict_locality.setter
    def strict_locality(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "strictLocality", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbBackendGroupGrpcBackendLoadBalancingConfig]:
        return typing.cast(typing.Optional[DataYandexAlbBackendGroupGrpcBackendLoadBalancingConfig], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbBackendGroupGrpcBackendLoadBalancingConfig],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexAlbBackendGroupGrpcBackendOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupGrpcBackendOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putHealthcheck")
    def put_healthcheck(
        self,
        *,
        grpc_healthcheck: typing.Optional[DataYandexAlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheck] = None,
        healthcheck_port: typing.Optional[jsii.Number] = None,
        healthy_threshold: typing.Optional[jsii.Number] = None,
        http_healthcheck: typing.Optional[DataYandexAlbBackendGroupGrpcBackendHealthcheckHttpHealthcheck] = None,
        interval_jitter_percent: typing.Optional[jsii.Number] = None,
        stream_healthcheck: typing.Optional[DataYandexAlbBackendGroupGrpcBackendHealthcheckStreamHealthcheck] = None,
        unhealthy_threshold: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param grpc_healthcheck: grpc_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#grpc_healthcheck DataYandexAlbBackendGroup#grpc_healthcheck}
        :param healthcheck_port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#healthcheck_port DataYandexAlbBackendGroup#healthcheck_port}.
        :param healthy_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#healthy_threshold DataYandexAlbBackendGroup#healthy_threshold}.
        :param http_healthcheck: http_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#http_healthcheck DataYandexAlbBackendGroup#http_healthcheck}
        :param interval_jitter_percent: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#interval_jitter_percent DataYandexAlbBackendGroup#interval_jitter_percent}.
        :param stream_healthcheck: stream_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#stream_healthcheck DataYandexAlbBackendGroup#stream_healthcheck}
        :param unhealthy_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#unhealthy_threshold DataYandexAlbBackendGroup#unhealthy_threshold}.
        '''
        value = DataYandexAlbBackendGroupGrpcBackendHealthcheck(
            grpc_healthcheck=grpc_healthcheck,
            healthcheck_port=healthcheck_port,
            healthy_threshold=healthy_threshold,
            http_healthcheck=http_healthcheck,
            interval_jitter_percent=interval_jitter_percent,
            stream_healthcheck=stream_healthcheck,
            unhealthy_threshold=unhealthy_threshold,
        )

        return typing.cast(None, jsii.invoke(self, "putHealthcheck", [value]))

    @jsii.member(jsii_name="putLoadBalancingConfig")
    def put_load_balancing_config(
        self,
        *,
        locality_aware_routing_percent: typing.Optional[jsii.Number] = None,
        panic_threshold: typing.Optional[jsii.Number] = None,
        strict_locality: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param locality_aware_routing_percent: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#locality_aware_routing_percent DataYandexAlbBackendGroup#locality_aware_routing_percent}.
        :param panic_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#panic_threshold DataYandexAlbBackendGroup#panic_threshold}.
        :param strict_locality: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#strict_locality DataYandexAlbBackendGroup#strict_locality}.
        '''
        value = DataYandexAlbBackendGroupGrpcBackendLoadBalancingConfig(
            locality_aware_routing_percent=locality_aware_routing_percent,
            panic_threshold=panic_threshold,
            strict_locality=strict_locality,
        )

        return typing.cast(None, jsii.invoke(self, "putLoadBalancingConfig", [value]))

    @jsii.member(jsii_name="putTls")
    def put_tls(
        self,
        *,
        sni: typing.Optional[builtins.str] = None,
        validation_context: typing.Optional["DataYandexAlbBackendGroupGrpcBackendTlsValidationContext"] = None,
    ) -> None:
        '''
        :param sni: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#sni DataYandexAlbBackendGroup#sni}.
        :param validation_context: validation_context block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#validation_context DataYandexAlbBackendGroup#validation_context}
        '''
        value = DataYandexAlbBackendGroupGrpcBackendTls(
            sni=sni, validation_context=validation_context
        )

        return typing.cast(None, jsii.invoke(self, "putTls", [value]))

    @jsii.member(jsii_name="resetHealthcheck")
    def reset_healthcheck(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHealthcheck", []))

    @jsii.member(jsii_name="resetLoadBalancingConfig")
    def reset_load_balancing_config(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLoadBalancingConfig", []))

    @jsii.member(jsii_name="resetPort")
    def reset_port(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPort", []))

    @jsii.member(jsii_name="resetTls")
    def reset_tls(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTls", []))

    @jsii.member(jsii_name="resetWeight")
    def reset_weight(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetWeight", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthcheck")
    def healthcheck(
        self,
    ) -> DataYandexAlbBackendGroupGrpcBackendHealthcheckOutputReference:
        return typing.cast(DataYandexAlbBackendGroupGrpcBackendHealthcheckOutputReference, jsii.get(self, "healthcheck"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="loadBalancingConfig")
    def load_balancing_config(
        self,
    ) -> DataYandexAlbBackendGroupGrpcBackendLoadBalancingConfigOutputReference:
        return typing.cast(DataYandexAlbBackendGroupGrpcBackendLoadBalancingConfigOutputReference, jsii.get(self, "loadBalancingConfig"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupIds")
    def target_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "targetGroupIds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tls")
    def tls(self) -> "DataYandexAlbBackendGroupGrpcBackendTlsOutputReference":
        return typing.cast("DataYandexAlbBackendGroupGrpcBackendTlsOutputReference", jsii.get(self, "tls"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthcheckInput")
    def healthcheck_input(
        self,
    ) -> typing.Optional[DataYandexAlbBackendGroupGrpcBackendHealthcheck]:
        return typing.cast(typing.Optional[DataYandexAlbBackendGroupGrpcBackendHealthcheck], jsii.get(self, "healthcheckInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="loadBalancingConfigInput")
    def load_balancing_config_input(
        self,
    ) -> typing.Optional[DataYandexAlbBackendGroupGrpcBackendLoadBalancingConfig]:
        return typing.cast(typing.Optional[DataYandexAlbBackendGroupGrpcBackendLoadBalancingConfig], jsii.get(self, "loadBalancingConfigInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="portInput")
    def port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "portInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tlsInput")
    def tls_input(self) -> typing.Optional["DataYandexAlbBackendGroupGrpcBackendTls"]:
        return typing.cast(typing.Optional["DataYandexAlbBackendGroupGrpcBackendTls"], jsii.get(self, "tlsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="weightInput")
    def weight_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "weightInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "port"))

    @port.setter
    def port(self, value: jsii.Number) -> None:
        jsii.set(self, "port", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="weight")
    def weight(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "weight"))

    @weight.setter
    def weight(self, value: jsii.Number) -> None:
        jsii.set(self, "weight", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, DataYandexAlbBackendGroupGrpcBackend]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, DataYandexAlbBackendGroupGrpcBackend]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, DataYandexAlbBackendGroupGrpcBackend]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupGrpcBackendTls",
    jsii_struct_bases=[],
    name_mapping={"sni": "sni", "validation_context": "validationContext"},
)
class DataYandexAlbBackendGroupGrpcBackendTls:
    def __init__(
        self,
        *,
        sni: typing.Optional[builtins.str] = None,
        validation_context: typing.Optional["DataYandexAlbBackendGroupGrpcBackendTlsValidationContext"] = None,
    ) -> None:
        '''
        :param sni: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#sni DataYandexAlbBackendGroup#sni}.
        :param validation_context: validation_context block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#validation_context DataYandexAlbBackendGroup#validation_context}
        '''
        if isinstance(validation_context, dict):
            validation_context = DataYandexAlbBackendGroupGrpcBackendTlsValidationContext(**validation_context)
        self._values: typing.Dict[str, typing.Any] = {}
        if sni is not None:
            self._values["sni"] = sni
        if validation_context is not None:
            self._values["validation_context"] = validation_context

    @builtins.property
    def sni(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#sni DataYandexAlbBackendGroup#sni}.'''
        result = self._values.get("sni")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def validation_context(
        self,
    ) -> typing.Optional["DataYandexAlbBackendGroupGrpcBackendTlsValidationContext"]:
        '''validation_context block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#validation_context DataYandexAlbBackendGroup#validation_context}
        '''
        result = self._values.get("validation_context")
        return typing.cast(typing.Optional["DataYandexAlbBackendGroupGrpcBackendTlsValidationContext"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbBackendGroupGrpcBackendTls(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbBackendGroupGrpcBackendTlsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupGrpcBackendTlsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putValidationContext")
    def put_validation_context(
        self,
        *,
        trusted_ca_bytes: typing.Optional[builtins.str] = None,
        trusted_ca_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param trusted_ca_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#trusted_ca_bytes DataYandexAlbBackendGroup#trusted_ca_bytes}.
        :param trusted_ca_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#trusted_ca_id DataYandexAlbBackendGroup#trusted_ca_id}.
        '''
        value = DataYandexAlbBackendGroupGrpcBackendTlsValidationContext(
            trusted_ca_bytes=trusted_ca_bytes, trusted_ca_id=trusted_ca_id
        )

        return typing.cast(None, jsii.invoke(self, "putValidationContext", [value]))

    @jsii.member(jsii_name="resetSni")
    def reset_sni(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSni", []))

    @jsii.member(jsii_name="resetValidationContext")
    def reset_validation_context(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetValidationContext", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="validationContext")
    def validation_context(
        self,
    ) -> "DataYandexAlbBackendGroupGrpcBackendTlsValidationContextOutputReference":
        return typing.cast("DataYandexAlbBackendGroupGrpcBackendTlsValidationContextOutputReference", jsii.get(self, "validationContext"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sniInput")
    def sni_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sniInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="validationContextInput")
    def validation_context_input(
        self,
    ) -> typing.Optional["DataYandexAlbBackendGroupGrpcBackendTlsValidationContext"]:
        return typing.cast(typing.Optional["DataYandexAlbBackendGroupGrpcBackendTlsValidationContext"], jsii.get(self, "validationContextInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sni")
    def sni(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sni"))

    @sni.setter
    def sni(self, value: builtins.str) -> None:
        jsii.set(self, "sni", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbBackendGroupGrpcBackendTls]:
        return typing.cast(typing.Optional[DataYandexAlbBackendGroupGrpcBackendTls], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbBackendGroupGrpcBackendTls],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupGrpcBackendTlsValidationContext",
    jsii_struct_bases=[],
    name_mapping={
        "trusted_ca_bytes": "trustedCaBytes",
        "trusted_ca_id": "trustedCaId",
    },
)
class DataYandexAlbBackendGroupGrpcBackendTlsValidationContext:
    def __init__(
        self,
        *,
        trusted_ca_bytes: typing.Optional[builtins.str] = None,
        trusted_ca_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param trusted_ca_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#trusted_ca_bytes DataYandexAlbBackendGroup#trusted_ca_bytes}.
        :param trusted_ca_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#trusted_ca_id DataYandexAlbBackendGroup#trusted_ca_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if trusted_ca_bytes is not None:
            self._values["trusted_ca_bytes"] = trusted_ca_bytes
        if trusted_ca_id is not None:
            self._values["trusted_ca_id"] = trusted_ca_id

    @builtins.property
    def trusted_ca_bytes(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#trusted_ca_bytes DataYandexAlbBackendGroup#trusted_ca_bytes}.'''
        result = self._values.get("trusted_ca_bytes")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def trusted_ca_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#trusted_ca_id DataYandexAlbBackendGroup#trusted_ca_id}.'''
        result = self._values.get("trusted_ca_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbBackendGroupGrpcBackendTlsValidationContext(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbBackendGroupGrpcBackendTlsValidationContextOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupGrpcBackendTlsValidationContextOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetTrustedCaBytes")
    def reset_trusted_ca_bytes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTrustedCaBytes", []))

    @jsii.member(jsii_name="resetTrustedCaId")
    def reset_trusted_ca_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTrustedCaId", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="trustedCaBytesInput")
    def trusted_ca_bytes_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "trustedCaBytesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="trustedCaIdInput")
    def trusted_ca_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "trustedCaIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="trustedCaBytes")
    def trusted_ca_bytes(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "trustedCaBytes"))

    @trusted_ca_bytes.setter
    def trusted_ca_bytes(self, value: builtins.str) -> None:
        jsii.set(self, "trustedCaBytes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="trustedCaId")
    def trusted_ca_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "trustedCaId"))

    @trusted_ca_id.setter
    def trusted_ca_id(self, value: builtins.str) -> None:
        jsii.set(self, "trustedCaId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbBackendGroupGrpcBackendTlsValidationContext]:
        return typing.cast(typing.Optional[DataYandexAlbBackendGroupGrpcBackendTlsValidationContext], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbBackendGroupGrpcBackendTlsValidationContext],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupHttpBackend",
    jsii_struct_bases=[],
    name_mapping={
        "healthcheck": "healthcheck",
        "http2": "http2",
        "load_balancing_config": "loadBalancingConfig",
        "port": "port",
        "storage_bucket": "storageBucket",
        "target_group_ids": "targetGroupIds",
        "tls": "tls",
        "weight": "weight",
    },
)
class DataYandexAlbBackendGroupHttpBackend:
    def __init__(
        self,
        *,
        healthcheck: typing.Optional["DataYandexAlbBackendGroupHttpBackendHealthcheck"] = None,
        http2: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        load_balancing_config: typing.Optional["DataYandexAlbBackendGroupHttpBackendLoadBalancingConfig"] = None,
        port: typing.Optional[jsii.Number] = None,
        storage_bucket: typing.Optional[builtins.str] = None,
        target_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        tls: typing.Optional["DataYandexAlbBackendGroupHttpBackendTls"] = None,
        weight: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param healthcheck: healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#healthcheck DataYandexAlbBackendGroup#healthcheck}
        :param http2: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#http2 DataYandexAlbBackendGroup#http2}.
        :param load_balancing_config: load_balancing_config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#load_balancing_config DataYandexAlbBackendGroup#load_balancing_config}
        :param port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#port DataYandexAlbBackendGroup#port}.
        :param storage_bucket: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#storage_bucket DataYandexAlbBackendGroup#storage_bucket}.
        :param target_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#target_group_ids DataYandexAlbBackendGroup#target_group_ids}.
        :param tls: tls block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#tls DataYandexAlbBackendGroup#tls}
        :param weight: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#weight DataYandexAlbBackendGroup#weight}.
        '''
        if isinstance(healthcheck, dict):
            healthcheck = DataYandexAlbBackendGroupHttpBackendHealthcheck(**healthcheck)
        if isinstance(load_balancing_config, dict):
            load_balancing_config = DataYandexAlbBackendGroupHttpBackendLoadBalancingConfig(**load_balancing_config)
        if isinstance(tls, dict):
            tls = DataYandexAlbBackendGroupHttpBackendTls(**tls)
        self._values: typing.Dict[str, typing.Any] = {}
        if healthcheck is not None:
            self._values["healthcheck"] = healthcheck
        if http2 is not None:
            self._values["http2"] = http2
        if load_balancing_config is not None:
            self._values["load_balancing_config"] = load_balancing_config
        if port is not None:
            self._values["port"] = port
        if storage_bucket is not None:
            self._values["storage_bucket"] = storage_bucket
        if target_group_ids is not None:
            self._values["target_group_ids"] = target_group_ids
        if tls is not None:
            self._values["tls"] = tls
        if weight is not None:
            self._values["weight"] = weight

    @builtins.property
    def healthcheck(
        self,
    ) -> typing.Optional["DataYandexAlbBackendGroupHttpBackendHealthcheck"]:
        '''healthcheck block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#healthcheck DataYandexAlbBackendGroup#healthcheck}
        '''
        result = self._values.get("healthcheck")
        return typing.cast(typing.Optional["DataYandexAlbBackendGroupHttpBackendHealthcheck"], result)

    @builtins.property
    def http2(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#http2 DataYandexAlbBackendGroup#http2}.'''
        result = self._values.get("http2")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def load_balancing_config(
        self,
    ) -> typing.Optional["DataYandexAlbBackendGroupHttpBackendLoadBalancingConfig"]:
        '''load_balancing_config block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#load_balancing_config DataYandexAlbBackendGroup#load_balancing_config}
        '''
        result = self._values.get("load_balancing_config")
        return typing.cast(typing.Optional["DataYandexAlbBackendGroupHttpBackendLoadBalancingConfig"], result)

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#port DataYandexAlbBackendGroup#port}.'''
        result = self._values.get("port")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def storage_bucket(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#storage_bucket DataYandexAlbBackendGroup#storage_bucket}.'''
        result = self._values.get("storage_bucket")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def target_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#target_group_ids DataYandexAlbBackendGroup#target_group_ids}.'''
        result = self._values.get("target_group_ids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def tls(self) -> typing.Optional["DataYandexAlbBackendGroupHttpBackendTls"]:
        '''tls block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#tls DataYandexAlbBackendGroup#tls}
        '''
        result = self._values.get("tls")
        return typing.cast(typing.Optional["DataYandexAlbBackendGroupHttpBackendTls"], result)

    @builtins.property
    def weight(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#weight DataYandexAlbBackendGroup#weight}.'''
        result = self._values.get("weight")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbBackendGroupHttpBackend(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupHttpBackendHealthcheck",
    jsii_struct_bases=[],
    name_mapping={
        "grpc_healthcheck": "grpcHealthcheck",
        "healthcheck_port": "healthcheckPort",
        "healthy_threshold": "healthyThreshold",
        "http_healthcheck": "httpHealthcheck",
        "interval_jitter_percent": "intervalJitterPercent",
        "stream_healthcheck": "streamHealthcheck",
        "unhealthy_threshold": "unhealthyThreshold",
    },
)
class DataYandexAlbBackendGroupHttpBackendHealthcheck:
    def __init__(
        self,
        *,
        grpc_healthcheck: typing.Optional["DataYandexAlbBackendGroupHttpBackendHealthcheckGrpcHealthcheck"] = None,
        healthcheck_port: typing.Optional[jsii.Number] = None,
        healthy_threshold: typing.Optional[jsii.Number] = None,
        http_healthcheck: typing.Optional["DataYandexAlbBackendGroupHttpBackendHealthcheckHttpHealthcheck"] = None,
        interval_jitter_percent: typing.Optional[jsii.Number] = None,
        stream_healthcheck: typing.Optional["DataYandexAlbBackendGroupHttpBackendHealthcheckStreamHealthcheck"] = None,
        unhealthy_threshold: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param grpc_healthcheck: grpc_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#grpc_healthcheck DataYandexAlbBackendGroup#grpc_healthcheck}
        :param healthcheck_port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#healthcheck_port DataYandexAlbBackendGroup#healthcheck_port}.
        :param healthy_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#healthy_threshold DataYandexAlbBackendGroup#healthy_threshold}.
        :param http_healthcheck: http_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#http_healthcheck DataYandexAlbBackendGroup#http_healthcheck}
        :param interval_jitter_percent: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#interval_jitter_percent DataYandexAlbBackendGroup#interval_jitter_percent}.
        :param stream_healthcheck: stream_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#stream_healthcheck DataYandexAlbBackendGroup#stream_healthcheck}
        :param unhealthy_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#unhealthy_threshold DataYandexAlbBackendGroup#unhealthy_threshold}.
        '''
        if isinstance(grpc_healthcheck, dict):
            grpc_healthcheck = DataYandexAlbBackendGroupHttpBackendHealthcheckGrpcHealthcheck(**grpc_healthcheck)
        if isinstance(http_healthcheck, dict):
            http_healthcheck = DataYandexAlbBackendGroupHttpBackendHealthcheckHttpHealthcheck(**http_healthcheck)
        if isinstance(stream_healthcheck, dict):
            stream_healthcheck = DataYandexAlbBackendGroupHttpBackendHealthcheckStreamHealthcheck(**stream_healthcheck)
        self._values: typing.Dict[str, typing.Any] = {}
        if grpc_healthcheck is not None:
            self._values["grpc_healthcheck"] = grpc_healthcheck
        if healthcheck_port is not None:
            self._values["healthcheck_port"] = healthcheck_port
        if healthy_threshold is not None:
            self._values["healthy_threshold"] = healthy_threshold
        if http_healthcheck is not None:
            self._values["http_healthcheck"] = http_healthcheck
        if interval_jitter_percent is not None:
            self._values["interval_jitter_percent"] = interval_jitter_percent
        if stream_healthcheck is not None:
            self._values["stream_healthcheck"] = stream_healthcheck
        if unhealthy_threshold is not None:
            self._values["unhealthy_threshold"] = unhealthy_threshold

    @builtins.property
    def grpc_healthcheck(
        self,
    ) -> typing.Optional["DataYandexAlbBackendGroupHttpBackendHealthcheckGrpcHealthcheck"]:
        '''grpc_healthcheck block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#grpc_healthcheck DataYandexAlbBackendGroup#grpc_healthcheck}
        '''
        result = self._values.get("grpc_healthcheck")
        return typing.cast(typing.Optional["DataYandexAlbBackendGroupHttpBackendHealthcheckGrpcHealthcheck"], result)

    @builtins.property
    def healthcheck_port(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#healthcheck_port DataYandexAlbBackendGroup#healthcheck_port}.'''
        result = self._values.get("healthcheck_port")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def healthy_threshold(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#healthy_threshold DataYandexAlbBackendGroup#healthy_threshold}.'''
        result = self._values.get("healthy_threshold")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def http_healthcheck(
        self,
    ) -> typing.Optional["DataYandexAlbBackendGroupHttpBackendHealthcheckHttpHealthcheck"]:
        '''http_healthcheck block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#http_healthcheck DataYandexAlbBackendGroup#http_healthcheck}
        '''
        result = self._values.get("http_healthcheck")
        return typing.cast(typing.Optional["DataYandexAlbBackendGroupHttpBackendHealthcheckHttpHealthcheck"], result)

    @builtins.property
    def interval_jitter_percent(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#interval_jitter_percent DataYandexAlbBackendGroup#interval_jitter_percent}.'''
        result = self._values.get("interval_jitter_percent")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def stream_healthcheck(
        self,
    ) -> typing.Optional["DataYandexAlbBackendGroupHttpBackendHealthcheckStreamHealthcheck"]:
        '''stream_healthcheck block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#stream_healthcheck DataYandexAlbBackendGroup#stream_healthcheck}
        '''
        result = self._values.get("stream_healthcheck")
        return typing.cast(typing.Optional["DataYandexAlbBackendGroupHttpBackendHealthcheckStreamHealthcheck"], result)

    @builtins.property
    def unhealthy_threshold(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#unhealthy_threshold DataYandexAlbBackendGroup#unhealthy_threshold}.'''
        result = self._values.get("unhealthy_threshold")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbBackendGroupHttpBackendHealthcheck(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupHttpBackendHealthcheckGrpcHealthcheck",
    jsii_struct_bases=[],
    name_mapping={"service_name": "serviceName"},
)
class DataYandexAlbBackendGroupHttpBackendHealthcheckGrpcHealthcheck:
    def __init__(self, *, service_name: typing.Optional[builtins.str] = None) -> None:
        '''
        :param service_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#service_name DataYandexAlbBackendGroup#service_name}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if service_name is not None:
            self._values["service_name"] = service_name

    @builtins.property
    def service_name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#service_name DataYandexAlbBackendGroup#service_name}.'''
        result = self._values.get("service_name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbBackendGroupHttpBackendHealthcheckGrpcHealthcheck(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbBackendGroupHttpBackendHealthcheckGrpcHealthcheckOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupHttpBackendHealthcheckGrpcHealthcheckOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetServiceName")
    def reset_service_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetServiceName", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceNameInput")
    def service_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceName")
    def service_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceName"))

    @service_name.setter
    def service_name(self, value: builtins.str) -> None:
        jsii.set(self, "serviceName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbBackendGroupHttpBackendHealthcheckGrpcHealthcheck]:
        return typing.cast(typing.Optional[DataYandexAlbBackendGroupHttpBackendHealthcheckGrpcHealthcheck], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbBackendGroupHttpBackendHealthcheckGrpcHealthcheck],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupHttpBackendHealthcheckHttpHealthcheck",
    jsii_struct_bases=[],
    name_mapping={"host": "host", "http2": "http2"},
)
class DataYandexAlbBackendGroupHttpBackendHealthcheckHttpHealthcheck:
    def __init__(
        self,
        *,
        host: typing.Optional[builtins.str] = None,
        http2: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param host: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#host DataYandexAlbBackendGroup#host}.
        :param http2: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#http2 DataYandexAlbBackendGroup#http2}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if host is not None:
            self._values["host"] = host
        if http2 is not None:
            self._values["http2"] = http2

    @builtins.property
    def host(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#host DataYandexAlbBackendGroup#host}.'''
        result = self._values.get("host")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def http2(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#http2 DataYandexAlbBackendGroup#http2}.'''
        result = self._values.get("http2")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbBackendGroupHttpBackendHealthcheckHttpHealthcheck(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbBackendGroupHttpBackendHealthcheckHttpHealthcheckOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupHttpBackendHealthcheckHttpHealthcheckOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetHost")
    def reset_host(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHost", []))

    @jsii.member(jsii_name="resetHttp2")
    def reset_http2(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttp2", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="path")
    def path(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "path"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostInput")
    def host_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "hostInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="http2Input")
    def http2_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "http2Input"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="host")
    def host(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "host"))

    @host.setter
    def host(self, value: builtins.str) -> None:
        jsii.set(self, "host", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="http2")
    def http2(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "http2"))

    @http2.setter
    def http2(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "http2", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbBackendGroupHttpBackendHealthcheckHttpHealthcheck]:
        return typing.cast(typing.Optional[DataYandexAlbBackendGroupHttpBackendHealthcheckHttpHealthcheck], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbBackendGroupHttpBackendHealthcheckHttpHealthcheck],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexAlbBackendGroupHttpBackendHealthcheckOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupHttpBackendHealthcheckOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putGrpcHealthcheck")
    def put_grpc_healthcheck(
        self,
        *,
        service_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param service_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#service_name DataYandexAlbBackendGroup#service_name}.
        '''
        value = DataYandexAlbBackendGroupHttpBackendHealthcheckGrpcHealthcheck(
            service_name=service_name
        )

        return typing.cast(None, jsii.invoke(self, "putGrpcHealthcheck", [value]))

    @jsii.member(jsii_name="putHttpHealthcheck")
    def put_http_healthcheck(
        self,
        *,
        host: typing.Optional[builtins.str] = None,
        http2: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param host: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#host DataYandexAlbBackendGroup#host}.
        :param http2: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#http2 DataYandexAlbBackendGroup#http2}.
        '''
        value = DataYandexAlbBackendGroupHttpBackendHealthcheckHttpHealthcheck(
            host=host, http2=http2
        )

        return typing.cast(None, jsii.invoke(self, "putHttpHealthcheck", [value]))

    @jsii.member(jsii_name="putStreamHealthcheck")
    def put_stream_healthcheck(
        self,
        *,
        receive: typing.Optional[builtins.str] = None,
        send: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param receive: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#receive DataYandexAlbBackendGroup#receive}.
        :param send: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#send DataYandexAlbBackendGroup#send}.
        '''
        value = DataYandexAlbBackendGroupHttpBackendHealthcheckStreamHealthcheck(
            receive=receive, send=send
        )

        return typing.cast(None, jsii.invoke(self, "putStreamHealthcheck", [value]))

    @jsii.member(jsii_name="resetGrpcHealthcheck")
    def reset_grpc_healthcheck(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGrpcHealthcheck", []))

    @jsii.member(jsii_name="resetHealthcheckPort")
    def reset_healthcheck_port(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHealthcheckPort", []))

    @jsii.member(jsii_name="resetHealthyThreshold")
    def reset_healthy_threshold(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHealthyThreshold", []))

    @jsii.member(jsii_name="resetHttpHealthcheck")
    def reset_http_healthcheck(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttpHealthcheck", []))

    @jsii.member(jsii_name="resetIntervalJitterPercent")
    def reset_interval_jitter_percent(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIntervalJitterPercent", []))

    @jsii.member(jsii_name="resetStreamHealthcheck")
    def reset_stream_healthcheck(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStreamHealthcheck", []))

    @jsii.member(jsii_name="resetUnhealthyThreshold")
    def reset_unhealthy_threshold(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUnhealthyThreshold", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="grpcHealthcheck")
    def grpc_healthcheck(
        self,
    ) -> DataYandexAlbBackendGroupHttpBackendHealthcheckGrpcHealthcheckOutputReference:
        return typing.cast(DataYandexAlbBackendGroupHttpBackendHealthcheckGrpcHealthcheckOutputReference, jsii.get(self, "grpcHealthcheck"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpHealthcheck")
    def http_healthcheck(
        self,
    ) -> DataYandexAlbBackendGroupHttpBackendHealthcheckHttpHealthcheckOutputReference:
        return typing.cast(DataYandexAlbBackendGroupHttpBackendHealthcheckHttpHealthcheckOutputReference, jsii.get(self, "httpHealthcheck"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="interval")
    def interval(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "interval"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="streamHealthcheck")
    def stream_healthcheck(
        self,
    ) -> "DataYandexAlbBackendGroupHttpBackendHealthcheckStreamHealthcheckOutputReference":
        return typing.cast("DataYandexAlbBackendGroupHttpBackendHealthcheckStreamHealthcheckOutputReference", jsii.get(self, "streamHealthcheck"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeout")
    def timeout(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "timeout"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="grpcHealthcheckInput")
    def grpc_healthcheck_input(
        self,
    ) -> typing.Optional[DataYandexAlbBackendGroupHttpBackendHealthcheckGrpcHealthcheck]:
        return typing.cast(typing.Optional[DataYandexAlbBackendGroupHttpBackendHealthcheckGrpcHealthcheck], jsii.get(self, "grpcHealthcheckInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthcheckPortInput")
    def healthcheck_port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "healthcheckPortInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthyThresholdInput")
    def healthy_threshold_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "healthyThresholdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpHealthcheckInput")
    def http_healthcheck_input(
        self,
    ) -> typing.Optional[DataYandexAlbBackendGroupHttpBackendHealthcheckHttpHealthcheck]:
        return typing.cast(typing.Optional[DataYandexAlbBackendGroupHttpBackendHealthcheckHttpHealthcheck], jsii.get(self, "httpHealthcheckInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="intervalJitterPercentInput")
    def interval_jitter_percent_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalJitterPercentInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="streamHealthcheckInput")
    def stream_healthcheck_input(
        self,
    ) -> typing.Optional["DataYandexAlbBackendGroupHttpBackendHealthcheckStreamHealthcheck"]:
        return typing.cast(typing.Optional["DataYandexAlbBackendGroupHttpBackendHealthcheckStreamHealthcheck"], jsii.get(self, "streamHealthcheckInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="unhealthyThresholdInput")
    def unhealthy_threshold_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "unhealthyThresholdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthcheckPort")
    def healthcheck_port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "healthcheckPort"))

    @healthcheck_port.setter
    def healthcheck_port(self, value: jsii.Number) -> None:
        jsii.set(self, "healthcheckPort", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthyThreshold")
    def healthy_threshold(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "healthyThreshold"))

    @healthy_threshold.setter
    def healthy_threshold(self, value: jsii.Number) -> None:
        jsii.set(self, "healthyThreshold", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="intervalJitterPercent")
    def interval_jitter_percent(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "intervalJitterPercent"))

    @interval_jitter_percent.setter
    def interval_jitter_percent(self, value: jsii.Number) -> None:
        jsii.set(self, "intervalJitterPercent", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="unhealthyThreshold")
    def unhealthy_threshold(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "unhealthyThreshold"))

    @unhealthy_threshold.setter
    def unhealthy_threshold(self, value: jsii.Number) -> None:
        jsii.set(self, "unhealthyThreshold", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbBackendGroupHttpBackendHealthcheck]:
        return typing.cast(typing.Optional[DataYandexAlbBackendGroupHttpBackendHealthcheck], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbBackendGroupHttpBackendHealthcheck],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupHttpBackendHealthcheckStreamHealthcheck",
    jsii_struct_bases=[],
    name_mapping={"receive": "receive", "send": "send"},
)
class DataYandexAlbBackendGroupHttpBackendHealthcheckStreamHealthcheck:
    def __init__(
        self,
        *,
        receive: typing.Optional[builtins.str] = None,
        send: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param receive: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#receive DataYandexAlbBackendGroup#receive}.
        :param send: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#send DataYandexAlbBackendGroup#send}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if receive is not None:
            self._values["receive"] = receive
        if send is not None:
            self._values["send"] = send

    @builtins.property
    def receive(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#receive DataYandexAlbBackendGroup#receive}.'''
        result = self._values.get("receive")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def send(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#send DataYandexAlbBackendGroup#send}.'''
        result = self._values.get("send")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbBackendGroupHttpBackendHealthcheckStreamHealthcheck(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbBackendGroupHttpBackendHealthcheckStreamHealthcheckOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupHttpBackendHealthcheckStreamHealthcheckOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetReceive")
    def reset_receive(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetReceive", []))

    @jsii.member(jsii_name="resetSend")
    def reset_send(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSend", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="receiveInput")
    def receive_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "receiveInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sendInput")
    def send_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sendInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="receive")
    def receive(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "receive"))

    @receive.setter
    def receive(self, value: builtins.str) -> None:
        jsii.set(self, "receive", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="send")
    def send(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "send"))

    @send.setter
    def send(self, value: builtins.str) -> None:
        jsii.set(self, "send", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbBackendGroupHttpBackendHealthcheckStreamHealthcheck]:
        return typing.cast(typing.Optional[DataYandexAlbBackendGroupHttpBackendHealthcheckStreamHealthcheck], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbBackendGroupHttpBackendHealthcheckStreamHealthcheck],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexAlbBackendGroupHttpBackendList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupHttpBackendList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbBackendGroupHttpBackendOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbBackendGroupHttpBackendOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataYandexAlbBackendGroupHttpBackend]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataYandexAlbBackendGroupHttpBackend]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataYandexAlbBackendGroupHttpBackend]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupHttpBackendLoadBalancingConfig",
    jsii_struct_bases=[],
    name_mapping={
        "locality_aware_routing_percent": "localityAwareRoutingPercent",
        "panic_threshold": "panicThreshold",
        "strict_locality": "strictLocality",
    },
)
class DataYandexAlbBackendGroupHttpBackendLoadBalancingConfig:
    def __init__(
        self,
        *,
        locality_aware_routing_percent: typing.Optional[jsii.Number] = None,
        panic_threshold: typing.Optional[jsii.Number] = None,
        strict_locality: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param locality_aware_routing_percent: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#locality_aware_routing_percent DataYandexAlbBackendGroup#locality_aware_routing_percent}.
        :param panic_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#panic_threshold DataYandexAlbBackendGroup#panic_threshold}.
        :param strict_locality: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#strict_locality DataYandexAlbBackendGroup#strict_locality}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if locality_aware_routing_percent is not None:
            self._values["locality_aware_routing_percent"] = locality_aware_routing_percent
        if panic_threshold is not None:
            self._values["panic_threshold"] = panic_threshold
        if strict_locality is not None:
            self._values["strict_locality"] = strict_locality

    @builtins.property
    def locality_aware_routing_percent(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#locality_aware_routing_percent DataYandexAlbBackendGroup#locality_aware_routing_percent}.'''
        result = self._values.get("locality_aware_routing_percent")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def panic_threshold(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#panic_threshold DataYandexAlbBackendGroup#panic_threshold}.'''
        result = self._values.get("panic_threshold")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def strict_locality(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#strict_locality DataYandexAlbBackendGroup#strict_locality}.'''
        result = self._values.get("strict_locality")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbBackendGroupHttpBackendLoadBalancingConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbBackendGroupHttpBackendLoadBalancingConfigOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupHttpBackendLoadBalancingConfigOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetLocalityAwareRoutingPercent")
    def reset_locality_aware_routing_percent(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLocalityAwareRoutingPercent", []))

    @jsii.member(jsii_name="resetPanicThreshold")
    def reset_panic_threshold(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPanicThreshold", []))

    @jsii.member(jsii_name="resetStrictLocality")
    def reset_strict_locality(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStrictLocality", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="localityAwareRoutingPercentInput")
    def locality_aware_routing_percent_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "localityAwareRoutingPercentInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="panicThresholdInput")
    def panic_threshold_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "panicThresholdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="strictLocalityInput")
    def strict_locality_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "strictLocalityInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="localityAwareRoutingPercent")
    def locality_aware_routing_percent(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "localityAwareRoutingPercent"))

    @locality_aware_routing_percent.setter
    def locality_aware_routing_percent(self, value: jsii.Number) -> None:
        jsii.set(self, "localityAwareRoutingPercent", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="panicThreshold")
    def panic_threshold(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "panicThreshold"))

    @panic_threshold.setter
    def panic_threshold(self, value: jsii.Number) -> None:
        jsii.set(self, "panicThreshold", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="strictLocality")
    def strict_locality(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "strictLocality"))

    @strict_locality.setter
    def strict_locality(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "strictLocality", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbBackendGroupHttpBackendLoadBalancingConfig]:
        return typing.cast(typing.Optional[DataYandexAlbBackendGroupHttpBackendLoadBalancingConfig], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbBackendGroupHttpBackendLoadBalancingConfig],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexAlbBackendGroupHttpBackendOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupHttpBackendOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putHealthcheck")
    def put_healthcheck(
        self,
        *,
        grpc_healthcheck: typing.Optional[DataYandexAlbBackendGroupHttpBackendHealthcheckGrpcHealthcheck] = None,
        healthcheck_port: typing.Optional[jsii.Number] = None,
        healthy_threshold: typing.Optional[jsii.Number] = None,
        http_healthcheck: typing.Optional[DataYandexAlbBackendGroupHttpBackendHealthcheckHttpHealthcheck] = None,
        interval_jitter_percent: typing.Optional[jsii.Number] = None,
        stream_healthcheck: typing.Optional[DataYandexAlbBackendGroupHttpBackendHealthcheckStreamHealthcheck] = None,
        unhealthy_threshold: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param grpc_healthcheck: grpc_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#grpc_healthcheck DataYandexAlbBackendGroup#grpc_healthcheck}
        :param healthcheck_port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#healthcheck_port DataYandexAlbBackendGroup#healthcheck_port}.
        :param healthy_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#healthy_threshold DataYandexAlbBackendGroup#healthy_threshold}.
        :param http_healthcheck: http_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#http_healthcheck DataYandexAlbBackendGroup#http_healthcheck}
        :param interval_jitter_percent: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#interval_jitter_percent DataYandexAlbBackendGroup#interval_jitter_percent}.
        :param stream_healthcheck: stream_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#stream_healthcheck DataYandexAlbBackendGroup#stream_healthcheck}
        :param unhealthy_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#unhealthy_threshold DataYandexAlbBackendGroup#unhealthy_threshold}.
        '''
        value = DataYandexAlbBackendGroupHttpBackendHealthcheck(
            grpc_healthcheck=grpc_healthcheck,
            healthcheck_port=healthcheck_port,
            healthy_threshold=healthy_threshold,
            http_healthcheck=http_healthcheck,
            interval_jitter_percent=interval_jitter_percent,
            stream_healthcheck=stream_healthcheck,
            unhealthy_threshold=unhealthy_threshold,
        )

        return typing.cast(None, jsii.invoke(self, "putHealthcheck", [value]))

    @jsii.member(jsii_name="putLoadBalancingConfig")
    def put_load_balancing_config(
        self,
        *,
        locality_aware_routing_percent: typing.Optional[jsii.Number] = None,
        panic_threshold: typing.Optional[jsii.Number] = None,
        strict_locality: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param locality_aware_routing_percent: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#locality_aware_routing_percent DataYandexAlbBackendGroup#locality_aware_routing_percent}.
        :param panic_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#panic_threshold DataYandexAlbBackendGroup#panic_threshold}.
        :param strict_locality: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#strict_locality DataYandexAlbBackendGroup#strict_locality}.
        '''
        value = DataYandexAlbBackendGroupHttpBackendLoadBalancingConfig(
            locality_aware_routing_percent=locality_aware_routing_percent,
            panic_threshold=panic_threshold,
            strict_locality=strict_locality,
        )

        return typing.cast(None, jsii.invoke(self, "putLoadBalancingConfig", [value]))

    @jsii.member(jsii_name="putTls")
    def put_tls(
        self,
        *,
        sni: typing.Optional[builtins.str] = None,
        validation_context: typing.Optional["DataYandexAlbBackendGroupHttpBackendTlsValidationContext"] = None,
    ) -> None:
        '''
        :param sni: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#sni DataYandexAlbBackendGroup#sni}.
        :param validation_context: validation_context block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#validation_context DataYandexAlbBackendGroup#validation_context}
        '''
        value = DataYandexAlbBackendGroupHttpBackendTls(
            sni=sni, validation_context=validation_context
        )

        return typing.cast(None, jsii.invoke(self, "putTls", [value]))

    @jsii.member(jsii_name="resetHealthcheck")
    def reset_healthcheck(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHealthcheck", []))

    @jsii.member(jsii_name="resetHttp2")
    def reset_http2(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttp2", []))

    @jsii.member(jsii_name="resetLoadBalancingConfig")
    def reset_load_balancing_config(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLoadBalancingConfig", []))

    @jsii.member(jsii_name="resetPort")
    def reset_port(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPort", []))

    @jsii.member(jsii_name="resetStorageBucket")
    def reset_storage_bucket(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStorageBucket", []))

    @jsii.member(jsii_name="resetTargetGroupIds")
    def reset_target_group_ids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTargetGroupIds", []))

    @jsii.member(jsii_name="resetTls")
    def reset_tls(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTls", []))

    @jsii.member(jsii_name="resetWeight")
    def reset_weight(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetWeight", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthcheck")
    def healthcheck(
        self,
    ) -> DataYandexAlbBackendGroupHttpBackendHealthcheckOutputReference:
        return typing.cast(DataYandexAlbBackendGroupHttpBackendHealthcheckOutputReference, jsii.get(self, "healthcheck"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="loadBalancingConfig")
    def load_balancing_config(
        self,
    ) -> DataYandexAlbBackendGroupHttpBackendLoadBalancingConfigOutputReference:
        return typing.cast(DataYandexAlbBackendGroupHttpBackendLoadBalancingConfigOutputReference, jsii.get(self, "loadBalancingConfig"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tls")
    def tls(self) -> "DataYandexAlbBackendGroupHttpBackendTlsOutputReference":
        return typing.cast("DataYandexAlbBackendGroupHttpBackendTlsOutputReference", jsii.get(self, "tls"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthcheckInput")
    def healthcheck_input(
        self,
    ) -> typing.Optional[DataYandexAlbBackendGroupHttpBackendHealthcheck]:
        return typing.cast(typing.Optional[DataYandexAlbBackendGroupHttpBackendHealthcheck], jsii.get(self, "healthcheckInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="http2Input")
    def http2_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "http2Input"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="loadBalancingConfigInput")
    def load_balancing_config_input(
        self,
    ) -> typing.Optional[DataYandexAlbBackendGroupHttpBackendLoadBalancingConfig]:
        return typing.cast(typing.Optional[DataYandexAlbBackendGroupHttpBackendLoadBalancingConfig], jsii.get(self, "loadBalancingConfigInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="portInput")
    def port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "portInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="storageBucketInput")
    def storage_bucket_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "storageBucketInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupIdsInput")
    def target_group_ids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "targetGroupIdsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tlsInput")
    def tls_input(self) -> typing.Optional["DataYandexAlbBackendGroupHttpBackendTls"]:
        return typing.cast(typing.Optional["DataYandexAlbBackendGroupHttpBackendTls"], jsii.get(self, "tlsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="weightInput")
    def weight_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "weightInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="http2")
    def http2(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "http2"))

    @http2.setter
    def http2(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "http2", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "port"))

    @port.setter
    def port(self, value: jsii.Number) -> None:
        jsii.set(self, "port", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="storageBucket")
    def storage_bucket(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "storageBucket"))

    @storage_bucket.setter
    def storage_bucket(self, value: builtins.str) -> None:
        jsii.set(self, "storageBucket", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupIds")
    def target_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "targetGroupIds"))

    @target_group_ids.setter
    def target_group_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "targetGroupIds", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="weight")
    def weight(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "weight"))

    @weight.setter
    def weight(self, value: jsii.Number) -> None:
        jsii.set(self, "weight", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, DataYandexAlbBackendGroupHttpBackend]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, DataYandexAlbBackendGroupHttpBackend]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, DataYandexAlbBackendGroupHttpBackend]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupHttpBackendTls",
    jsii_struct_bases=[],
    name_mapping={"sni": "sni", "validation_context": "validationContext"},
)
class DataYandexAlbBackendGroupHttpBackendTls:
    def __init__(
        self,
        *,
        sni: typing.Optional[builtins.str] = None,
        validation_context: typing.Optional["DataYandexAlbBackendGroupHttpBackendTlsValidationContext"] = None,
    ) -> None:
        '''
        :param sni: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#sni DataYandexAlbBackendGroup#sni}.
        :param validation_context: validation_context block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#validation_context DataYandexAlbBackendGroup#validation_context}
        '''
        if isinstance(validation_context, dict):
            validation_context = DataYandexAlbBackendGroupHttpBackendTlsValidationContext(**validation_context)
        self._values: typing.Dict[str, typing.Any] = {}
        if sni is not None:
            self._values["sni"] = sni
        if validation_context is not None:
            self._values["validation_context"] = validation_context

    @builtins.property
    def sni(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#sni DataYandexAlbBackendGroup#sni}.'''
        result = self._values.get("sni")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def validation_context(
        self,
    ) -> typing.Optional["DataYandexAlbBackendGroupHttpBackendTlsValidationContext"]:
        '''validation_context block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#validation_context DataYandexAlbBackendGroup#validation_context}
        '''
        result = self._values.get("validation_context")
        return typing.cast(typing.Optional["DataYandexAlbBackendGroupHttpBackendTlsValidationContext"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbBackendGroupHttpBackendTls(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbBackendGroupHttpBackendTlsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupHttpBackendTlsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putValidationContext")
    def put_validation_context(
        self,
        *,
        trusted_ca_bytes: typing.Optional[builtins.str] = None,
        trusted_ca_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param trusted_ca_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#trusted_ca_bytes DataYandexAlbBackendGroup#trusted_ca_bytes}.
        :param trusted_ca_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#trusted_ca_id DataYandexAlbBackendGroup#trusted_ca_id}.
        '''
        value = DataYandexAlbBackendGroupHttpBackendTlsValidationContext(
            trusted_ca_bytes=trusted_ca_bytes, trusted_ca_id=trusted_ca_id
        )

        return typing.cast(None, jsii.invoke(self, "putValidationContext", [value]))

    @jsii.member(jsii_name="resetSni")
    def reset_sni(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSni", []))

    @jsii.member(jsii_name="resetValidationContext")
    def reset_validation_context(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetValidationContext", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="validationContext")
    def validation_context(
        self,
    ) -> "DataYandexAlbBackendGroupHttpBackendTlsValidationContextOutputReference":
        return typing.cast("DataYandexAlbBackendGroupHttpBackendTlsValidationContextOutputReference", jsii.get(self, "validationContext"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sniInput")
    def sni_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sniInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="validationContextInput")
    def validation_context_input(
        self,
    ) -> typing.Optional["DataYandexAlbBackendGroupHttpBackendTlsValidationContext"]:
        return typing.cast(typing.Optional["DataYandexAlbBackendGroupHttpBackendTlsValidationContext"], jsii.get(self, "validationContextInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sni")
    def sni(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sni"))

    @sni.setter
    def sni(self, value: builtins.str) -> None:
        jsii.set(self, "sni", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbBackendGroupHttpBackendTls]:
        return typing.cast(typing.Optional[DataYandexAlbBackendGroupHttpBackendTls], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbBackendGroupHttpBackendTls],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupHttpBackendTlsValidationContext",
    jsii_struct_bases=[],
    name_mapping={
        "trusted_ca_bytes": "trustedCaBytes",
        "trusted_ca_id": "trustedCaId",
    },
)
class DataYandexAlbBackendGroupHttpBackendTlsValidationContext:
    def __init__(
        self,
        *,
        trusted_ca_bytes: typing.Optional[builtins.str] = None,
        trusted_ca_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param trusted_ca_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#trusted_ca_bytes DataYandexAlbBackendGroup#trusted_ca_bytes}.
        :param trusted_ca_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#trusted_ca_id DataYandexAlbBackendGroup#trusted_ca_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if trusted_ca_bytes is not None:
            self._values["trusted_ca_bytes"] = trusted_ca_bytes
        if trusted_ca_id is not None:
            self._values["trusted_ca_id"] = trusted_ca_id

    @builtins.property
    def trusted_ca_bytes(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#trusted_ca_bytes DataYandexAlbBackendGroup#trusted_ca_bytes}.'''
        result = self._values.get("trusted_ca_bytes")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def trusted_ca_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#trusted_ca_id DataYandexAlbBackendGroup#trusted_ca_id}.'''
        result = self._values.get("trusted_ca_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbBackendGroupHttpBackendTlsValidationContext(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbBackendGroupHttpBackendTlsValidationContextOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupHttpBackendTlsValidationContextOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetTrustedCaBytes")
    def reset_trusted_ca_bytes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTrustedCaBytes", []))

    @jsii.member(jsii_name="resetTrustedCaId")
    def reset_trusted_ca_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTrustedCaId", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="trustedCaBytesInput")
    def trusted_ca_bytes_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "trustedCaBytesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="trustedCaIdInput")
    def trusted_ca_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "trustedCaIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="trustedCaBytes")
    def trusted_ca_bytes(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "trustedCaBytes"))

    @trusted_ca_bytes.setter
    def trusted_ca_bytes(self, value: builtins.str) -> None:
        jsii.set(self, "trustedCaBytes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="trustedCaId")
    def trusted_ca_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "trustedCaId"))

    @trusted_ca_id.setter
    def trusted_ca_id(self, value: builtins.str) -> None:
        jsii.set(self, "trustedCaId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbBackendGroupHttpBackendTlsValidationContext]:
        return typing.cast(typing.Optional[DataYandexAlbBackendGroupHttpBackendTlsValidationContext], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbBackendGroupHttpBackendTlsValidationContext],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupStreamBackend",
    jsii_struct_bases=[],
    name_mapping={
        "healthcheck": "healthcheck",
        "load_balancing_config": "loadBalancingConfig",
        "port": "port",
        "tls": "tls",
        "weight": "weight",
    },
)
class DataYandexAlbBackendGroupStreamBackend:
    def __init__(
        self,
        *,
        healthcheck: typing.Optional["DataYandexAlbBackendGroupStreamBackendHealthcheck"] = None,
        load_balancing_config: typing.Optional["DataYandexAlbBackendGroupStreamBackendLoadBalancingConfig"] = None,
        port: typing.Optional[jsii.Number] = None,
        tls: typing.Optional["DataYandexAlbBackendGroupStreamBackendTls"] = None,
        weight: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param healthcheck: healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#healthcheck DataYandexAlbBackendGroup#healthcheck}
        :param load_balancing_config: load_balancing_config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#load_balancing_config DataYandexAlbBackendGroup#load_balancing_config}
        :param port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#port DataYandexAlbBackendGroup#port}.
        :param tls: tls block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#tls DataYandexAlbBackendGroup#tls}
        :param weight: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#weight DataYandexAlbBackendGroup#weight}.
        '''
        if isinstance(healthcheck, dict):
            healthcheck = DataYandexAlbBackendGroupStreamBackendHealthcheck(**healthcheck)
        if isinstance(load_balancing_config, dict):
            load_balancing_config = DataYandexAlbBackendGroupStreamBackendLoadBalancingConfig(**load_balancing_config)
        if isinstance(tls, dict):
            tls = DataYandexAlbBackendGroupStreamBackendTls(**tls)
        self._values: typing.Dict[str, typing.Any] = {}
        if healthcheck is not None:
            self._values["healthcheck"] = healthcheck
        if load_balancing_config is not None:
            self._values["load_balancing_config"] = load_balancing_config
        if port is not None:
            self._values["port"] = port
        if tls is not None:
            self._values["tls"] = tls
        if weight is not None:
            self._values["weight"] = weight

    @builtins.property
    def healthcheck(
        self,
    ) -> typing.Optional["DataYandexAlbBackendGroupStreamBackendHealthcheck"]:
        '''healthcheck block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#healthcheck DataYandexAlbBackendGroup#healthcheck}
        '''
        result = self._values.get("healthcheck")
        return typing.cast(typing.Optional["DataYandexAlbBackendGroupStreamBackendHealthcheck"], result)

    @builtins.property
    def load_balancing_config(
        self,
    ) -> typing.Optional["DataYandexAlbBackendGroupStreamBackendLoadBalancingConfig"]:
        '''load_balancing_config block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#load_balancing_config DataYandexAlbBackendGroup#load_balancing_config}
        '''
        result = self._values.get("load_balancing_config")
        return typing.cast(typing.Optional["DataYandexAlbBackendGroupStreamBackendLoadBalancingConfig"], result)

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#port DataYandexAlbBackendGroup#port}.'''
        result = self._values.get("port")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def tls(self) -> typing.Optional["DataYandexAlbBackendGroupStreamBackendTls"]:
        '''tls block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#tls DataYandexAlbBackendGroup#tls}
        '''
        result = self._values.get("tls")
        return typing.cast(typing.Optional["DataYandexAlbBackendGroupStreamBackendTls"], result)

    @builtins.property
    def weight(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#weight DataYandexAlbBackendGroup#weight}.'''
        result = self._values.get("weight")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbBackendGroupStreamBackend(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupStreamBackendHealthcheck",
    jsii_struct_bases=[],
    name_mapping={
        "grpc_healthcheck": "grpcHealthcheck",
        "healthcheck_port": "healthcheckPort",
        "healthy_threshold": "healthyThreshold",
        "http_healthcheck": "httpHealthcheck",
        "interval_jitter_percent": "intervalJitterPercent",
        "stream_healthcheck": "streamHealthcheck",
        "unhealthy_threshold": "unhealthyThreshold",
    },
)
class DataYandexAlbBackendGroupStreamBackendHealthcheck:
    def __init__(
        self,
        *,
        grpc_healthcheck: typing.Optional["DataYandexAlbBackendGroupStreamBackendHealthcheckGrpcHealthcheck"] = None,
        healthcheck_port: typing.Optional[jsii.Number] = None,
        healthy_threshold: typing.Optional[jsii.Number] = None,
        http_healthcheck: typing.Optional["DataYandexAlbBackendGroupStreamBackendHealthcheckHttpHealthcheck"] = None,
        interval_jitter_percent: typing.Optional[jsii.Number] = None,
        stream_healthcheck: typing.Optional["DataYandexAlbBackendGroupStreamBackendHealthcheckStreamHealthcheck"] = None,
        unhealthy_threshold: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param grpc_healthcheck: grpc_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#grpc_healthcheck DataYandexAlbBackendGroup#grpc_healthcheck}
        :param healthcheck_port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#healthcheck_port DataYandexAlbBackendGroup#healthcheck_port}.
        :param healthy_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#healthy_threshold DataYandexAlbBackendGroup#healthy_threshold}.
        :param http_healthcheck: http_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#http_healthcheck DataYandexAlbBackendGroup#http_healthcheck}
        :param interval_jitter_percent: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#interval_jitter_percent DataYandexAlbBackendGroup#interval_jitter_percent}.
        :param stream_healthcheck: stream_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#stream_healthcheck DataYandexAlbBackendGroup#stream_healthcheck}
        :param unhealthy_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#unhealthy_threshold DataYandexAlbBackendGroup#unhealthy_threshold}.
        '''
        if isinstance(grpc_healthcheck, dict):
            grpc_healthcheck = DataYandexAlbBackendGroupStreamBackendHealthcheckGrpcHealthcheck(**grpc_healthcheck)
        if isinstance(http_healthcheck, dict):
            http_healthcheck = DataYandexAlbBackendGroupStreamBackendHealthcheckHttpHealthcheck(**http_healthcheck)
        if isinstance(stream_healthcheck, dict):
            stream_healthcheck = DataYandexAlbBackendGroupStreamBackendHealthcheckStreamHealthcheck(**stream_healthcheck)
        self._values: typing.Dict[str, typing.Any] = {}
        if grpc_healthcheck is not None:
            self._values["grpc_healthcheck"] = grpc_healthcheck
        if healthcheck_port is not None:
            self._values["healthcheck_port"] = healthcheck_port
        if healthy_threshold is not None:
            self._values["healthy_threshold"] = healthy_threshold
        if http_healthcheck is not None:
            self._values["http_healthcheck"] = http_healthcheck
        if interval_jitter_percent is not None:
            self._values["interval_jitter_percent"] = interval_jitter_percent
        if stream_healthcheck is not None:
            self._values["stream_healthcheck"] = stream_healthcheck
        if unhealthy_threshold is not None:
            self._values["unhealthy_threshold"] = unhealthy_threshold

    @builtins.property
    def grpc_healthcheck(
        self,
    ) -> typing.Optional["DataYandexAlbBackendGroupStreamBackendHealthcheckGrpcHealthcheck"]:
        '''grpc_healthcheck block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#grpc_healthcheck DataYandexAlbBackendGroup#grpc_healthcheck}
        '''
        result = self._values.get("grpc_healthcheck")
        return typing.cast(typing.Optional["DataYandexAlbBackendGroupStreamBackendHealthcheckGrpcHealthcheck"], result)

    @builtins.property
    def healthcheck_port(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#healthcheck_port DataYandexAlbBackendGroup#healthcheck_port}.'''
        result = self._values.get("healthcheck_port")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def healthy_threshold(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#healthy_threshold DataYandexAlbBackendGroup#healthy_threshold}.'''
        result = self._values.get("healthy_threshold")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def http_healthcheck(
        self,
    ) -> typing.Optional["DataYandexAlbBackendGroupStreamBackendHealthcheckHttpHealthcheck"]:
        '''http_healthcheck block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#http_healthcheck DataYandexAlbBackendGroup#http_healthcheck}
        '''
        result = self._values.get("http_healthcheck")
        return typing.cast(typing.Optional["DataYandexAlbBackendGroupStreamBackendHealthcheckHttpHealthcheck"], result)

    @builtins.property
    def interval_jitter_percent(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#interval_jitter_percent DataYandexAlbBackendGroup#interval_jitter_percent}.'''
        result = self._values.get("interval_jitter_percent")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def stream_healthcheck(
        self,
    ) -> typing.Optional["DataYandexAlbBackendGroupStreamBackendHealthcheckStreamHealthcheck"]:
        '''stream_healthcheck block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#stream_healthcheck DataYandexAlbBackendGroup#stream_healthcheck}
        '''
        result = self._values.get("stream_healthcheck")
        return typing.cast(typing.Optional["DataYandexAlbBackendGroupStreamBackendHealthcheckStreamHealthcheck"], result)

    @builtins.property
    def unhealthy_threshold(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#unhealthy_threshold DataYandexAlbBackendGroup#unhealthy_threshold}.'''
        result = self._values.get("unhealthy_threshold")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbBackendGroupStreamBackendHealthcheck(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupStreamBackendHealthcheckGrpcHealthcheck",
    jsii_struct_bases=[],
    name_mapping={"service_name": "serviceName"},
)
class DataYandexAlbBackendGroupStreamBackendHealthcheckGrpcHealthcheck:
    def __init__(self, *, service_name: typing.Optional[builtins.str] = None) -> None:
        '''
        :param service_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#service_name DataYandexAlbBackendGroup#service_name}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if service_name is not None:
            self._values["service_name"] = service_name

    @builtins.property
    def service_name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#service_name DataYandexAlbBackendGroup#service_name}.'''
        result = self._values.get("service_name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbBackendGroupStreamBackendHealthcheckGrpcHealthcheck(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbBackendGroupStreamBackendHealthcheckGrpcHealthcheckOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupStreamBackendHealthcheckGrpcHealthcheckOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetServiceName")
    def reset_service_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetServiceName", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceNameInput")
    def service_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceName")
    def service_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceName"))

    @service_name.setter
    def service_name(self, value: builtins.str) -> None:
        jsii.set(self, "serviceName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbBackendGroupStreamBackendHealthcheckGrpcHealthcheck]:
        return typing.cast(typing.Optional[DataYandexAlbBackendGroupStreamBackendHealthcheckGrpcHealthcheck], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbBackendGroupStreamBackendHealthcheckGrpcHealthcheck],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupStreamBackendHealthcheckHttpHealthcheck",
    jsii_struct_bases=[],
    name_mapping={"host": "host", "http2": "http2"},
)
class DataYandexAlbBackendGroupStreamBackendHealthcheckHttpHealthcheck:
    def __init__(
        self,
        *,
        host: typing.Optional[builtins.str] = None,
        http2: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param host: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#host DataYandexAlbBackendGroup#host}.
        :param http2: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#http2 DataYandexAlbBackendGroup#http2}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if host is not None:
            self._values["host"] = host
        if http2 is not None:
            self._values["http2"] = http2

    @builtins.property
    def host(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#host DataYandexAlbBackendGroup#host}.'''
        result = self._values.get("host")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def http2(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#http2 DataYandexAlbBackendGroup#http2}.'''
        result = self._values.get("http2")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbBackendGroupStreamBackendHealthcheckHttpHealthcheck(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbBackendGroupStreamBackendHealthcheckHttpHealthcheckOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupStreamBackendHealthcheckHttpHealthcheckOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetHost")
    def reset_host(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHost", []))

    @jsii.member(jsii_name="resetHttp2")
    def reset_http2(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttp2", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="path")
    def path(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "path"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostInput")
    def host_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "hostInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="http2Input")
    def http2_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "http2Input"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="host")
    def host(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "host"))

    @host.setter
    def host(self, value: builtins.str) -> None:
        jsii.set(self, "host", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="http2")
    def http2(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "http2"))

    @http2.setter
    def http2(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "http2", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbBackendGroupStreamBackendHealthcheckHttpHealthcheck]:
        return typing.cast(typing.Optional[DataYandexAlbBackendGroupStreamBackendHealthcheckHttpHealthcheck], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbBackendGroupStreamBackendHealthcheckHttpHealthcheck],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexAlbBackendGroupStreamBackendHealthcheckOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupStreamBackendHealthcheckOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putGrpcHealthcheck")
    def put_grpc_healthcheck(
        self,
        *,
        service_name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param service_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#service_name DataYandexAlbBackendGroup#service_name}.
        '''
        value = DataYandexAlbBackendGroupStreamBackendHealthcheckGrpcHealthcheck(
            service_name=service_name
        )

        return typing.cast(None, jsii.invoke(self, "putGrpcHealthcheck", [value]))

    @jsii.member(jsii_name="putHttpHealthcheck")
    def put_http_healthcheck(
        self,
        *,
        host: typing.Optional[builtins.str] = None,
        http2: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param host: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#host DataYandexAlbBackendGroup#host}.
        :param http2: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#http2 DataYandexAlbBackendGroup#http2}.
        '''
        value = DataYandexAlbBackendGroupStreamBackendHealthcheckHttpHealthcheck(
            host=host, http2=http2
        )

        return typing.cast(None, jsii.invoke(self, "putHttpHealthcheck", [value]))

    @jsii.member(jsii_name="putStreamHealthcheck")
    def put_stream_healthcheck(
        self,
        *,
        receive: typing.Optional[builtins.str] = None,
        send: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param receive: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#receive DataYandexAlbBackendGroup#receive}.
        :param send: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#send DataYandexAlbBackendGroup#send}.
        '''
        value = DataYandexAlbBackendGroupStreamBackendHealthcheckStreamHealthcheck(
            receive=receive, send=send
        )

        return typing.cast(None, jsii.invoke(self, "putStreamHealthcheck", [value]))

    @jsii.member(jsii_name="resetGrpcHealthcheck")
    def reset_grpc_healthcheck(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGrpcHealthcheck", []))

    @jsii.member(jsii_name="resetHealthcheckPort")
    def reset_healthcheck_port(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHealthcheckPort", []))

    @jsii.member(jsii_name="resetHealthyThreshold")
    def reset_healthy_threshold(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHealthyThreshold", []))

    @jsii.member(jsii_name="resetHttpHealthcheck")
    def reset_http_healthcheck(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttpHealthcheck", []))

    @jsii.member(jsii_name="resetIntervalJitterPercent")
    def reset_interval_jitter_percent(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIntervalJitterPercent", []))

    @jsii.member(jsii_name="resetStreamHealthcheck")
    def reset_stream_healthcheck(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStreamHealthcheck", []))

    @jsii.member(jsii_name="resetUnhealthyThreshold")
    def reset_unhealthy_threshold(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUnhealthyThreshold", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="grpcHealthcheck")
    def grpc_healthcheck(
        self,
    ) -> DataYandexAlbBackendGroupStreamBackendHealthcheckGrpcHealthcheckOutputReference:
        return typing.cast(DataYandexAlbBackendGroupStreamBackendHealthcheckGrpcHealthcheckOutputReference, jsii.get(self, "grpcHealthcheck"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpHealthcheck")
    def http_healthcheck(
        self,
    ) -> DataYandexAlbBackendGroupStreamBackendHealthcheckHttpHealthcheckOutputReference:
        return typing.cast(DataYandexAlbBackendGroupStreamBackendHealthcheckHttpHealthcheckOutputReference, jsii.get(self, "httpHealthcheck"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="interval")
    def interval(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "interval"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="streamHealthcheck")
    def stream_healthcheck(
        self,
    ) -> "DataYandexAlbBackendGroupStreamBackendHealthcheckStreamHealthcheckOutputReference":
        return typing.cast("DataYandexAlbBackendGroupStreamBackendHealthcheckStreamHealthcheckOutputReference", jsii.get(self, "streamHealthcheck"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeout")
    def timeout(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "timeout"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="grpcHealthcheckInput")
    def grpc_healthcheck_input(
        self,
    ) -> typing.Optional[DataYandexAlbBackendGroupStreamBackendHealthcheckGrpcHealthcheck]:
        return typing.cast(typing.Optional[DataYandexAlbBackendGroupStreamBackendHealthcheckGrpcHealthcheck], jsii.get(self, "grpcHealthcheckInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthcheckPortInput")
    def healthcheck_port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "healthcheckPortInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthyThresholdInput")
    def healthy_threshold_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "healthyThresholdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpHealthcheckInput")
    def http_healthcheck_input(
        self,
    ) -> typing.Optional[DataYandexAlbBackendGroupStreamBackendHealthcheckHttpHealthcheck]:
        return typing.cast(typing.Optional[DataYandexAlbBackendGroupStreamBackendHealthcheckHttpHealthcheck], jsii.get(self, "httpHealthcheckInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="intervalJitterPercentInput")
    def interval_jitter_percent_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalJitterPercentInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="streamHealthcheckInput")
    def stream_healthcheck_input(
        self,
    ) -> typing.Optional["DataYandexAlbBackendGroupStreamBackendHealthcheckStreamHealthcheck"]:
        return typing.cast(typing.Optional["DataYandexAlbBackendGroupStreamBackendHealthcheckStreamHealthcheck"], jsii.get(self, "streamHealthcheckInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="unhealthyThresholdInput")
    def unhealthy_threshold_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "unhealthyThresholdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthcheckPort")
    def healthcheck_port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "healthcheckPort"))

    @healthcheck_port.setter
    def healthcheck_port(self, value: jsii.Number) -> None:
        jsii.set(self, "healthcheckPort", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthyThreshold")
    def healthy_threshold(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "healthyThreshold"))

    @healthy_threshold.setter
    def healthy_threshold(self, value: jsii.Number) -> None:
        jsii.set(self, "healthyThreshold", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="intervalJitterPercent")
    def interval_jitter_percent(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "intervalJitterPercent"))

    @interval_jitter_percent.setter
    def interval_jitter_percent(self, value: jsii.Number) -> None:
        jsii.set(self, "intervalJitterPercent", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="unhealthyThreshold")
    def unhealthy_threshold(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "unhealthyThreshold"))

    @unhealthy_threshold.setter
    def unhealthy_threshold(self, value: jsii.Number) -> None:
        jsii.set(self, "unhealthyThreshold", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbBackendGroupStreamBackendHealthcheck]:
        return typing.cast(typing.Optional[DataYandexAlbBackendGroupStreamBackendHealthcheck], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbBackendGroupStreamBackendHealthcheck],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupStreamBackendHealthcheckStreamHealthcheck",
    jsii_struct_bases=[],
    name_mapping={"receive": "receive", "send": "send"},
)
class DataYandexAlbBackendGroupStreamBackendHealthcheckStreamHealthcheck:
    def __init__(
        self,
        *,
        receive: typing.Optional[builtins.str] = None,
        send: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param receive: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#receive DataYandexAlbBackendGroup#receive}.
        :param send: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#send DataYandexAlbBackendGroup#send}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if receive is not None:
            self._values["receive"] = receive
        if send is not None:
            self._values["send"] = send

    @builtins.property
    def receive(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#receive DataYandexAlbBackendGroup#receive}.'''
        result = self._values.get("receive")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def send(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#send DataYandexAlbBackendGroup#send}.'''
        result = self._values.get("send")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbBackendGroupStreamBackendHealthcheckStreamHealthcheck(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbBackendGroupStreamBackendHealthcheckStreamHealthcheckOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupStreamBackendHealthcheckStreamHealthcheckOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetReceive")
    def reset_receive(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetReceive", []))

    @jsii.member(jsii_name="resetSend")
    def reset_send(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSend", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="receiveInput")
    def receive_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "receiveInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sendInput")
    def send_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sendInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="receive")
    def receive(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "receive"))

    @receive.setter
    def receive(self, value: builtins.str) -> None:
        jsii.set(self, "receive", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="send")
    def send(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "send"))

    @send.setter
    def send(self, value: builtins.str) -> None:
        jsii.set(self, "send", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbBackendGroupStreamBackendHealthcheckStreamHealthcheck]:
        return typing.cast(typing.Optional[DataYandexAlbBackendGroupStreamBackendHealthcheckStreamHealthcheck], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbBackendGroupStreamBackendHealthcheckStreamHealthcheck],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexAlbBackendGroupStreamBackendList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupStreamBackendList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbBackendGroupStreamBackendOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbBackendGroupStreamBackendOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataYandexAlbBackendGroupStreamBackend]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataYandexAlbBackendGroupStreamBackend]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataYandexAlbBackendGroupStreamBackend]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupStreamBackendLoadBalancingConfig",
    jsii_struct_bases=[],
    name_mapping={
        "locality_aware_routing_percent": "localityAwareRoutingPercent",
        "panic_threshold": "panicThreshold",
        "strict_locality": "strictLocality",
    },
)
class DataYandexAlbBackendGroupStreamBackendLoadBalancingConfig:
    def __init__(
        self,
        *,
        locality_aware_routing_percent: typing.Optional[jsii.Number] = None,
        panic_threshold: typing.Optional[jsii.Number] = None,
        strict_locality: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param locality_aware_routing_percent: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#locality_aware_routing_percent DataYandexAlbBackendGroup#locality_aware_routing_percent}.
        :param panic_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#panic_threshold DataYandexAlbBackendGroup#panic_threshold}.
        :param strict_locality: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#strict_locality DataYandexAlbBackendGroup#strict_locality}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if locality_aware_routing_percent is not None:
            self._values["locality_aware_routing_percent"] = locality_aware_routing_percent
        if panic_threshold is not None:
            self._values["panic_threshold"] = panic_threshold
        if strict_locality is not None:
            self._values["strict_locality"] = strict_locality

    @builtins.property
    def locality_aware_routing_percent(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#locality_aware_routing_percent DataYandexAlbBackendGroup#locality_aware_routing_percent}.'''
        result = self._values.get("locality_aware_routing_percent")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def panic_threshold(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#panic_threshold DataYandexAlbBackendGroup#panic_threshold}.'''
        result = self._values.get("panic_threshold")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def strict_locality(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#strict_locality DataYandexAlbBackendGroup#strict_locality}.'''
        result = self._values.get("strict_locality")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbBackendGroupStreamBackendLoadBalancingConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbBackendGroupStreamBackendLoadBalancingConfigOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupStreamBackendLoadBalancingConfigOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetLocalityAwareRoutingPercent")
    def reset_locality_aware_routing_percent(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLocalityAwareRoutingPercent", []))

    @jsii.member(jsii_name="resetPanicThreshold")
    def reset_panic_threshold(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPanicThreshold", []))

    @jsii.member(jsii_name="resetStrictLocality")
    def reset_strict_locality(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStrictLocality", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="localityAwareRoutingPercentInput")
    def locality_aware_routing_percent_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "localityAwareRoutingPercentInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="panicThresholdInput")
    def panic_threshold_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "panicThresholdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="strictLocalityInput")
    def strict_locality_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "strictLocalityInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="localityAwareRoutingPercent")
    def locality_aware_routing_percent(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "localityAwareRoutingPercent"))

    @locality_aware_routing_percent.setter
    def locality_aware_routing_percent(self, value: jsii.Number) -> None:
        jsii.set(self, "localityAwareRoutingPercent", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="panicThreshold")
    def panic_threshold(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "panicThreshold"))

    @panic_threshold.setter
    def panic_threshold(self, value: jsii.Number) -> None:
        jsii.set(self, "panicThreshold", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="strictLocality")
    def strict_locality(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "strictLocality"))

    @strict_locality.setter
    def strict_locality(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "strictLocality", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbBackendGroupStreamBackendLoadBalancingConfig]:
        return typing.cast(typing.Optional[DataYandexAlbBackendGroupStreamBackendLoadBalancingConfig], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbBackendGroupStreamBackendLoadBalancingConfig],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexAlbBackendGroupStreamBackendOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupStreamBackendOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putHealthcheck")
    def put_healthcheck(
        self,
        *,
        grpc_healthcheck: typing.Optional[DataYandexAlbBackendGroupStreamBackendHealthcheckGrpcHealthcheck] = None,
        healthcheck_port: typing.Optional[jsii.Number] = None,
        healthy_threshold: typing.Optional[jsii.Number] = None,
        http_healthcheck: typing.Optional[DataYandexAlbBackendGroupStreamBackendHealthcheckHttpHealthcheck] = None,
        interval_jitter_percent: typing.Optional[jsii.Number] = None,
        stream_healthcheck: typing.Optional[DataYandexAlbBackendGroupStreamBackendHealthcheckStreamHealthcheck] = None,
        unhealthy_threshold: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param grpc_healthcheck: grpc_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#grpc_healthcheck DataYandexAlbBackendGroup#grpc_healthcheck}
        :param healthcheck_port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#healthcheck_port DataYandexAlbBackendGroup#healthcheck_port}.
        :param healthy_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#healthy_threshold DataYandexAlbBackendGroup#healthy_threshold}.
        :param http_healthcheck: http_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#http_healthcheck DataYandexAlbBackendGroup#http_healthcheck}
        :param interval_jitter_percent: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#interval_jitter_percent DataYandexAlbBackendGroup#interval_jitter_percent}.
        :param stream_healthcheck: stream_healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#stream_healthcheck DataYandexAlbBackendGroup#stream_healthcheck}
        :param unhealthy_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#unhealthy_threshold DataYandexAlbBackendGroup#unhealthy_threshold}.
        '''
        value = DataYandexAlbBackendGroupStreamBackendHealthcheck(
            grpc_healthcheck=grpc_healthcheck,
            healthcheck_port=healthcheck_port,
            healthy_threshold=healthy_threshold,
            http_healthcheck=http_healthcheck,
            interval_jitter_percent=interval_jitter_percent,
            stream_healthcheck=stream_healthcheck,
            unhealthy_threshold=unhealthy_threshold,
        )

        return typing.cast(None, jsii.invoke(self, "putHealthcheck", [value]))

    @jsii.member(jsii_name="putLoadBalancingConfig")
    def put_load_balancing_config(
        self,
        *,
        locality_aware_routing_percent: typing.Optional[jsii.Number] = None,
        panic_threshold: typing.Optional[jsii.Number] = None,
        strict_locality: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param locality_aware_routing_percent: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#locality_aware_routing_percent DataYandexAlbBackendGroup#locality_aware_routing_percent}.
        :param panic_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#panic_threshold DataYandexAlbBackendGroup#panic_threshold}.
        :param strict_locality: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#strict_locality DataYandexAlbBackendGroup#strict_locality}.
        '''
        value = DataYandexAlbBackendGroupStreamBackendLoadBalancingConfig(
            locality_aware_routing_percent=locality_aware_routing_percent,
            panic_threshold=panic_threshold,
            strict_locality=strict_locality,
        )

        return typing.cast(None, jsii.invoke(self, "putLoadBalancingConfig", [value]))

    @jsii.member(jsii_name="putTls")
    def put_tls(
        self,
        *,
        sni: typing.Optional[builtins.str] = None,
        validation_context: typing.Optional["DataYandexAlbBackendGroupStreamBackendTlsValidationContext"] = None,
    ) -> None:
        '''
        :param sni: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#sni DataYandexAlbBackendGroup#sni}.
        :param validation_context: validation_context block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#validation_context DataYandexAlbBackendGroup#validation_context}
        '''
        value = DataYandexAlbBackendGroupStreamBackendTls(
            sni=sni, validation_context=validation_context
        )

        return typing.cast(None, jsii.invoke(self, "putTls", [value]))

    @jsii.member(jsii_name="resetHealthcheck")
    def reset_healthcheck(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHealthcheck", []))

    @jsii.member(jsii_name="resetLoadBalancingConfig")
    def reset_load_balancing_config(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLoadBalancingConfig", []))

    @jsii.member(jsii_name="resetPort")
    def reset_port(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPort", []))

    @jsii.member(jsii_name="resetTls")
    def reset_tls(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTls", []))

    @jsii.member(jsii_name="resetWeight")
    def reset_weight(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetWeight", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthcheck")
    def healthcheck(
        self,
    ) -> DataYandexAlbBackendGroupStreamBackendHealthcheckOutputReference:
        return typing.cast(DataYandexAlbBackendGroupStreamBackendHealthcheckOutputReference, jsii.get(self, "healthcheck"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="loadBalancingConfig")
    def load_balancing_config(
        self,
    ) -> DataYandexAlbBackendGroupStreamBackendLoadBalancingConfigOutputReference:
        return typing.cast(DataYandexAlbBackendGroupStreamBackendLoadBalancingConfigOutputReference, jsii.get(self, "loadBalancingConfig"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupIds")
    def target_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "targetGroupIds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tls")
    def tls(self) -> "DataYandexAlbBackendGroupStreamBackendTlsOutputReference":
        return typing.cast("DataYandexAlbBackendGroupStreamBackendTlsOutputReference", jsii.get(self, "tls"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthcheckInput")
    def healthcheck_input(
        self,
    ) -> typing.Optional[DataYandexAlbBackendGroupStreamBackendHealthcheck]:
        return typing.cast(typing.Optional[DataYandexAlbBackendGroupStreamBackendHealthcheck], jsii.get(self, "healthcheckInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="loadBalancingConfigInput")
    def load_balancing_config_input(
        self,
    ) -> typing.Optional[DataYandexAlbBackendGroupStreamBackendLoadBalancingConfig]:
        return typing.cast(typing.Optional[DataYandexAlbBackendGroupStreamBackendLoadBalancingConfig], jsii.get(self, "loadBalancingConfigInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="portInput")
    def port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "portInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tlsInput")
    def tls_input(self) -> typing.Optional["DataYandexAlbBackendGroupStreamBackendTls"]:
        return typing.cast(typing.Optional["DataYandexAlbBackendGroupStreamBackendTls"], jsii.get(self, "tlsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="weightInput")
    def weight_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "weightInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "port"))

    @port.setter
    def port(self, value: jsii.Number) -> None:
        jsii.set(self, "port", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="weight")
    def weight(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "weight"))

    @weight.setter
    def weight(self, value: jsii.Number) -> None:
        jsii.set(self, "weight", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, DataYandexAlbBackendGroupStreamBackend]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, DataYandexAlbBackendGroupStreamBackend]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, DataYandexAlbBackendGroupStreamBackend]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupStreamBackendTls",
    jsii_struct_bases=[],
    name_mapping={"sni": "sni", "validation_context": "validationContext"},
)
class DataYandexAlbBackendGroupStreamBackendTls:
    def __init__(
        self,
        *,
        sni: typing.Optional[builtins.str] = None,
        validation_context: typing.Optional["DataYandexAlbBackendGroupStreamBackendTlsValidationContext"] = None,
    ) -> None:
        '''
        :param sni: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#sni DataYandexAlbBackendGroup#sni}.
        :param validation_context: validation_context block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#validation_context DataYandexAlbBackendGroup#validation_context}
        '''
        if isinstance(validation_context, dict):
            validation_context = DataYandexAlbBackendGroupStreamBackendTlsValidationContext(**validation_context)
        self._values: typing.Dict[str, typing.Any] = {}
        if sni is not None:
            self._values["sni"] = sni
        if validation_context is not None:
            self._values["validation_context"] = validation_context

    @builtins.property
    def sni(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#sni DataYandexAlbBackendGroup#sni}.'''
        result = self._values.get("sni")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def validation_context(
        self,
    ) -> typing.Optional["DataYandexAlbBackendGroupStreamBackendTlsValidationContext"]:
        '''validation_context block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#validation_context DataYandexAlbBackendGroup#validation_context}
        '''
        result = self._values.get("validation_context")
        return typing.cast(typing.Optional["DataYandexAlbBackendGroupStreamBackendTlsValidationContext"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbBackendGroupStreamBackendTls(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbBackendGroupStreamBackendTlsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupStreamBackendTlsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putValidationContext")
    def put_validation_context(
        self,
        *,
        trusted_ca_bytes: typing.Optional[builtins.str] = None,
        trusted_ca_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param trusted_ca_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#trusted_ca_bytes DataYandexAlbBackendGroup#trusted_ca_bytes}.
        :param trusted_ca_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#trusted_ca_id DataYandexAlbBackendGroup#trusted_ca_id}.
        '''
        value = DataYandexAlbBackendGroupStreamBackendTlsValidationContext(
            trusted_ca_bytes=trusted_ca_bytes, trusted_ca_id=trusted_ca_id
        )

        return typing.cast(None, jsii.invoke(self, "putValidationContext", [value]))

    @jsii.member(jsii_name="resetSni")
    def reset_sni(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSni", []))

    @jsii.member(jsii_name="resetValidationContext")
    def reset_validation_context(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetValidationContext", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="validationContext")
    def validation_context(
        self,
    ) -> "DataYandexAlbBackendGroupStreamBackendTlsValidationContextOutputReference":
        return typing.cast("DataYandexAlbBackendGroupStreamBackendTlsValidationContextOutputReference", jsii.get(self, "validationContext"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sniInput")
    def sni_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sniInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="validationContextInput")
    def validation_context_input(
        self,
    ) -> typing.Optional["DataYandexAlbBackendGroupStreamBackendTlsValidationContext"]:
        return typing.cast(typing.Optional["DataYandexAlbBackendGroupStreamBackendTlsValidationContext"], jsii.get(self, "validationContextInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sni")
    def sni(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sni"))

    @sni.setter
    def sni(self, value: builtins.str) -> None:
        jsii.set(self, "sni", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbBackendGroupStreamBackendTls]:
        return typing.cast(typing.Optional[DataYandexAlbBackendGroupStreamBackendTls], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbBackendGroupStreamBackendTls],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupStreamBackendTlsValidationContext",
    jsii_struct_bases=[],
    name_mapping={
        "trusted_ca_bytes": "trustedCaBytes",
        "trusted_ca_id": "trustedCaId",
    },
)
class DataYandexAlbBackendGroupStreamBackendTlsValidationContext:
    def __init__(
        self,
        *,
        trusted_ca_bytes: typing.Optional[builtins.str] = None,
        trusted_ca_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param trusted_ca_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#trusted_ca_bytes DataYandexAlbBackendGroup#trusted_ca_bytes}.
        :param trusted_ca_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#trusted_ca_id DataYandexAlbBackendGroup#trusted_ca_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if trusted_ca_bytes is not None:
            self._values["trusted_ca_bytes"] = trusted_ca_bytes
        if trusted_ca_id is not None:
            self._values["trusted_ca_id"] = trusted_ca_id

    @builtins.property
    def trusted_ca_bytes(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#trusted_ca_bytes DataYandexAlbBackendGroup#trusted_ca_bytes}.'''
        result = self._values.get("trusted_ca_bytes")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def trusted_ca_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_backend_group#trusted_ca_id DataYandexAlbBackendGroup#trusted_ca_id}.'''
        result = self._values.get("trusted_ca_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbBackendGroupStreamBackendTlsValidationContext(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbBackendGroupStreamBackendTlsValidationContextOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbBackendGroupStreamBackendTlsValidationContextOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetTrustedCaBytes")
    def reset_trusted_ca_bytes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTrustedCaBytes", []))

    @jsii.member(jsii_name="resetTrustedCaId")
    def reset_trusted_ca_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTrustedCaId", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="trustedCaBytesInput")
    def trusted_ca_bytes_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "trustedCaBytesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="trustedCaIdInput")
    def trusted_ca_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "trustedCaIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="trustedCaBytes")
    def trusted_ca_bytes(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "trustedCaBytes"))

    @trusted_ca_bytes.setter
    def trusted_ca_bytes(self, value: builtins.str) -> None:
        jsii.set(self, "trustedCaBytes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="trustedCaId")
    def trusted_ca_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "trustedCaId"))

    @trusted_ca_id.setter
    def trusted_ca_id(self, value: builtins.str) -> None:
        jsii.set(self, "trustedCaId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbBackendGroupStreamBackendTlsValidationContext]:
        return typing.cast(typing.Optional[DataYandexAlbBackendGroupStreamBackendTlsValidationContext], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbBackendGroupStreamBackendTlsValidationContext],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexAlbHttpRouter(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbHttpRouter",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/alb_http_router yandex_alb_http_router}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        http_router_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/alb_http_router yandex_alb_http_router} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_http_router#description DataYandexAlbHttpRouter#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_http_router#folder_id DataYandexAlbHttpRouter#folder_id}.
        :param http_router_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_http_router#http_router_id DataYandexAlbHttpRouter#http_router_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_http_router#id DataYandexAlbHttpRouter#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_http_router#name DataYandexAlbHttpRouter#name}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexAlbHttpRouterConfig(
            description=description,
            folder_id=folder_id,
            http_router_id=http_router_id,
            id=id,
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetHttpRouterId")
    def reset_http_router_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttpRouterId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpRouterIdInput")
    def http_router_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "httpRouterIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpRouterId")
    def http_router_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "httpRouterId"))

    @http_router_id.setter
    def http_router_id(self, value: builtins.str) -> None:
        jsii.set(self, "httpRouterId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbHttpRouterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "description": "description",
        "folder_id": "folderId",
        "http_router_id": "httpRouterId",
        "id": "id",
        "name": "name",
    },
)
class DataYandexAlbHttpRouterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        http_router_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_http_router#description DataYandexAlbHttpRouter#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_http_router#folder_id DataYandexAlbHttpRouter#folder_id}.
        :param http_router_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_http_router#http_router_id DataYandexAlbHttpRouter#http_router_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_http_router#id DataYandexAlbHttpRouter#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_http_router#name DataYandexAlbHttpRouter#name}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if http_router_id is not None:
            self._values["http_router_id"] = http_router_id
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_http_router#description DataYandexAlbHttpRouter#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_http_router#folder_id DataYandexAlbHttpRouter#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def http_router_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_http_router#http_router_id DataYandexAlbHttpRouter#http_router_id}.'''
        result = self._values.get("http_router_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_http_router#id DataYandexAlbHttpRouter#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_http_router#name DataYandexAlbHttpRouter#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbHttpRouterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbLoadBalancer(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancer",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/alb_load_balancer yandex_alb_load_balancer}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        id: typing.Optional[builtins.str] = None,
        load_balancer_id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DataYandexAlbLoadBalancerTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/alb_load_balancer yandex_alb_load_balancer} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_load_balancer#id DataYandexAlbLoadBalancer#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param load_balancer_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_load_balancer#load_balancer_id DataYandexAlbLoadBalancer#load_balancer_id}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_load_balancer#name DataYandexAlbLoadBalancer#name}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_load_balancer#timeouts DataYandexAlbLoadBalancer#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexAlbLoadBalancerConfig(
            id=id,
            load_balancer_id=load_balancer_id,
            name=name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_load_balancer#create DataYandexAlbLoadBalancer#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_load_balancer#delete DataYandexAlbLoadBalancer#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_load_balancer#update DataYandexAlbLoadBalancer#update}.
        '''
        value = DataYandexAlbLoadBalancerTimeouts(
            create=create, delete=delete, update=update
        )

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLoadBalancerId")
    def reset_load_balancer_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLoadBalancerId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allocationPolicy")
    def allocation_policy(self) -> "DataYandexAlbLoadBalancerAllocationPolicyList":
        return typing.cast("DataYandexAlbLoadBalancerAllocationPolicyList", jsii.get(self, "allocationPolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="listener")
    def listener(self) -> "DataYandexAlbLoadBalancerListenerList":
        return typing.cast("DataYandexAlbLoadBalancerListenerList", jsii.get(self, "listener"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logGroupId")
    def log_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "logGroupId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="regionId")
    def region_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "regionId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "securityGroupIds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "DataYandexAlbLoadBalancerTimeoutsOutputReference":
        return typing.cast("DataYandexAlbLoadBalancerTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="loadBalancerIdInput")
    def load_balancer_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "loadBalancerIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "DataYandexAlbLoadBalancerTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "DataYandexAlbLoadBalancerTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="loadBalancerId")
    def load_balancer_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "loadBalancerId"))

    @load_balancer_id.setter
    def load_balancer_id(self, value: builtins.str) -> None:
        jsii.set(self, "loadBalancerId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerAllocationPolicy",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbLoadBalancerAllocationPolicy:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbLoadBalancerAllocationPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbLoadBalancerAllocationPolicyList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerAllocationPolicyList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbLoadBalancerAllocationPolicyOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbLoadBalancerAllocationPolicyOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerAllocationPolicyLocation",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbLoadBalancerAllocationPolicyLocation:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbLoadBalancerAllocationPolicyLocation(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbLoadBalancerAllocationPolicyLocationList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerAllocationPolicyLocationList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbLoadBalancerAllocationPolicyLocationOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbLoadBalancerAllocationPolicyLocationOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbLoadBalancerAllocationPolicyLocationOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerAllocationPolicyLocationOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="disableTraffic")
    def disable_traffic(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "disableTraffic"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneId")
    def zone_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zoneId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbLoadBalancerAllocationPolicyLocation]:
        return typing.cast(typing.Optional[DataYandexAlbLoadBalancerAllocationPolicyLocation], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbLoadBalancerAllocationPolicyLocation],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexAlbLoadBalancerAllocationPolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerAllocationPolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="location")
    def location(self) -> DataYandexAlbLoadBalancerAllocationPolicyLocationList:
        return typing.cast(DataYandexAlbLoadBalancerAllocationPolicyLocationList, jsii.get(self, "location"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbLoadBalancerAllocationPolicy]:
        return typing.cast(typing.Optional[DataYandexAlbLoadBalancerAllocationPolicy], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbLoadBalancerAllocationPolicy],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "id": "id",
        "load_balancer_id": "loadBalancerId",
        "name": "name",
        "timeouts": "timeouts",
    },
)
class DataYandexAlbLoadBalancerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        id: typing.Optional[builtins.str] = None,
        load_balancer_id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DataYandexAlbLoadBalancerTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_load_balancer#id DataYandexAlbLoadBalancer#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param load_balancer_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_load_balancer#load_balancer_id DataYandexAlbLoadBalancer#load_balancer_id}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_load_balancer#name DataYandexAlbLoadBalancer#name}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_load_balancer#timeouts DataYandexAlbLoadBalancer#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataYandexAlbLoadBalancerTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if id is not None:
            self._values["id"] = id
        if load_balancer_id is not None:
            self._values["load_balancer_id"] = load_balancer_id
        if name is not None:
            self._values["name"] = name
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_load_balancer#id DataYandexAlbLoadBalancer#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def load_balancer_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_load_balancer#load_balancer_id DataYandexAlbLoadBalancer#load_balancer_id}.'''
        result = self._values.get("load_balancer_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_load_balancer#name DataYandexAlbLoadBalancer#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["DataYandexAlbLoadBalancerTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_load_balancer#timeouts DataYandexAlbLoadBalancer#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["DataYandexAlbLoadBalancerTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbLoadBalancerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListener",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbLoadBalancerListener:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbLoadBalancerListener(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerEndpoint",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbLoadBalancerListenerEndpoint:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbLoadBalancerListenerEndpoint(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerEndpointAddress",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbLoadBalancerListenerEndpointAddress:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbLoadBalancerListenerEndpointAddress(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerEndpointAddressExternalIpv4Address",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbLoadBalancerListenerEndpointAddressExternalIpv4Address:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbLoadBalancerListenerEndpointAddressExternalIpv4Address(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbLoadBalancerListenerEndpointAddressExternalIpv4AddressList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerEndpointAddressExternalIpv4AddressList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbLoadBalancerListenerEndpointAddressExternalIpv4AddressOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbLoadBalancerListenerEndpointAddressExternalIpv4AddressOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbLoadBalancerListenerEndpointAddressExternalIpv4AddressOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerEndpointAddressExternalIpv4AddressOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="address")
    def address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "address"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbLoadBalancerListenerEndpointAddressExternalIpv4Address]:
        return typing.cast(typing.Optional[DataYandexAlbLoadBalancerListenerEndpointAddressExternalIpv4Address], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbLoadBalancerListenerEndpointAddressExternalIpv4Address],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerEndpointAddressExternalIpv6Address",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbLoadBalancerListenerEndpointAddressExternalIpv6Address:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbLoadBalancerListenerEndpointAddressExternalIpv6Address(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbLoadBalancerListenerEndpointAddressExternalIpv6AddressList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerEndpointAddressExternalIpv6AddressList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbLoadBalancerListenerEndpointAddressExternalIpv6AddressOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbLoadBalancerListenerEndpointAddressExternalIpv6AddressOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbLoadBalancerListenerEndpointAddressExternalIpv6AddressOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerEndpointAddressExternalIpv6AddressOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="address")
    def address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "address"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbLoadBalancerListenerEndpointAddressExternalIpv6Address]:
        return typing.cast(typing.Optional[DataYandexAlbLoadBalancerListenerEndpointAddressExternalIpv6Address], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbLoadBalancerListenerEndpointAddressExternalIpv6Address],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerEndpointAddressInternalIpv4Address",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbLoadBalancerListenerEndpointAddressInternalIpv4Address:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbLoadBalancerListenerEndpointAddressInternalIpv4Address(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbLoadBalancerListenerEndpointAddressInternalIpv4AddressList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerEndpointAddressInternalIpv4AddressList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbLoadBalancerListenerEndpointAddressInternalIpv4AddressOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbLoadBalancerListenerEndpointAddressInternalIpv4AddressOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbLoadBalancerListenerEndpointAddressInternalIpv4AddressOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerEndpointAddressInternalIpv4AddressOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="address")
    def address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "address"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbLoadBalancerListenerEndpointAddressInternalIpv4Address]:
        return typing.cast(typing.Optional[DataYandexAlbLoadBalancerListenerEndpointAddressInternalIpv4Address], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbLoadBalancerListenerEndpointAddressInternalIpv4Address],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexAlbLoadBalancerListenerEndpointAddressList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerEndpointAddressList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbLoadBalancerListenerEndpointAddressOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbLoadBalancerListenerEndpointAddressOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbLoadBalancerListenerEndpointAddressOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerEndpointAddressOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="externalIpv4Address")
    def external_ipv4_address(
        self,
    ) -> DataYandexAlbLoadBalancerListenerEndpointAddressExternalIpv4AddressList:
        return typing.cast(DataYandexAlbLoadBalancerListenerEndpointAddressExternalIpv4AddressList, jsii.get(self, "externalIpv4Address"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="externalIpv6Address")
    def external_ipv6_address(
        self,
    ) -> DataYandexAlbLoadBalancerListenerEndpointAddressExternalIpv6AddressList:
        return typing.cast(DataYandexAlbLoadBalancerListenerEndpointAddressExternalIpv6AddressList, jsii.get(self, "externalIpv6Address"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalIpv4Address")
    def internal_ipv4_address(
        self,
    ) -> DataYandexAlbLoadBalancerListenerEndpointAddressInternalIpv4AddressList:
        return typing.cast(DataYandexAlbLoadBalancerListenerEndpointAddressInternalIpv4AddressList, jsii.get(self, "internalIpv4Address"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbLoadBalancerListenerEndpointAddress]:
        return typing.cast(typing.Optional[DataYandexAlbLoadBalancerListenerEndpointAddress], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbLoadBalancerListenerEndpointAddress],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexAlbLoadBalancerListenerEndpointList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerEndpointList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbLoadBalancerListenerEndpointOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbLoadBalancerListenerEndpointOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbLoadBalancerListenerEndpointOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerEndpointOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="address")
    def address(self) -> DataYandexAlbLoadBalancerListenerEndpointAddressList:
        return typing.cast(DataYandexAlbLoadBalancerListenerEndpointAddressList, jsii.get(self, "address"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ports")
    def ports(self) -> typing.List[jsii.Number]:
        return typing.cast(typing.List[jsii.Number], jsii.get(self, "ports"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbLoadBalancerListenerEndpoint]:
        return typing.cast(typing.Optional[DataYandexAlbLoadBalancerListenerEndpoint], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbLoadBalancerListenerEndpoint],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerHttp",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbLoadBalancerListenerHttp:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbLoadBalancerListenerHttp(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerHttpHandler",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbLoadBalancerListenerHttpHandler:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbLoadBalancerListenerHttpHandler(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerHttpHandlerHttp2Options",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbLoadBalancerListenerHttpHandlerHttp2Options:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbLoadBalancerListenerHttpHandlerHttp2Options(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbLoadBalancerListenerHttpHandlerHttp2OptionsList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerHttpHandlerHttp2OptionsList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbLoadBalancerListenerHttpHandlerHttp2OptionsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbLoadBalancerListenerHttpHandlerHttp2OptionsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbLoadBalancerListenerHttpHandlerHttp2OptionsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerHttpHandlerHttp2OptionsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxConcurrentStreams")
    def max_concurrent_streams(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxConcurrentStreams"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbLoadBalancerListenerHttpHandlerHttp2Options]:
        return typing.cast(typing.Optional[DataYandexAlbLoadBalancerListenerHttpHandlerHttp2Options], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbLoadBalancerListenerHttpHandlerHttp2Options],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexAlbLoadBalancerListenerHttpHandlerList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerHttpHandlerList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbLoadBalancerListenerHttpHandlerOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbLoadBalancerListenerHttpHandlerOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbLoadBalancerListenerHttpHandlerOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerHttpHandlerOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allowHttp10")
    def allow_http10(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "allowHttp10"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="http2Options")
    def http2_options(
        self,
    ) -> DataYandexAlbLoadBalancerListenerHttpHandlerHttp2OptionsList:
        return typing.cast(DataYandexAlbLoadBalancerListenerHttpHandlerHttp2OptionsList, jsii.get(self, "http2Options"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpRouterId")
    def http_router_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "httpRouterId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbLoadBalancerListenerHttpHandler]:
        return typing.cast(typing.Optional[DataYandexAlbLoadBalancerListenerHttpHandler], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbLoadBalancerListenerHttpHandler],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexAlbLoadBalancerListenerHttpList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerHttpList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbLoadBalancerListenerHttpOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbLoadBalancerListenerHttpOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbLoadBalancerListenerHttpOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerHttpOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="handler")
    def handler(self) -> DataYandexAlbLoadBalancerListenerHttpHandlerList:
        return typing.cast(DataYandexAlbLoadBalancerListenerHttpHandlerList, jsii.get(self, "handler"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="redirects")
    def redirects(self) -> "DataYandexAlbLoadBalancerListenerHttpRedirectsList":
        return typing.cast("DataYandexAlbLoadBalancerListenerHttpRedirectsList", jsii.get(self, "redirects"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexAlbLoadBalancerListenerHttp]:
        return typing.cast(typing.Optional[DataYandexAlbLoadBalancerListenerHttp], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbLoadBalancerListenerHttp],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerHttpRedirects",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbLoadBalancerListenerHttpRedirects:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbLoadBalancerListenerHttpRedirects(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbLoadBalancerListenerHttpRedirectsList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerHttpRedirectsList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbLoadBalancerListenerHttpRedirectsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbLoadBalancerListenerHttpRedirectsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbLoadBalancerListenerHttpRedirectsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerHttpRedirectsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpToHttps")
    def http_to_https(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "httpToHttps"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbLoadBalancerListenerHttpRedirects]:
        return typing.cast(typing.Optional[DataYandexAlbLoadBalancerListenerHttpRedirects], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbLoadBalancerListenerHttpRedirects],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexAlbLoadBalancerListenerList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbLoadBalancerListenerOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbLoadBalancerListenerOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbLoadBalancerListenerOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> DataYandexAlbLoadBalancerListenerEndpointList:
        return typing.cast(DataYandexAlbLoadBalancerListenerEndpointList, jsii.get(self, "endpoint"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="http")
    def http(self) -> DataYandexAlbLoadBalancerListenerHttpList:
        return typing.cast(DataYandexAlbLoadBalancerListenerHttpList, jsii.get(self, "http"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="stream")
    def stream(self) -> "DataYandexAlbLoadBalancerListenerStreamList":
        return typing.cast("DataYandexAlbLoadBalancerListenerStreamList", jsii.get(self, "stream"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tls")
    def tls(self) -> "DataYandexAlbLoadBalancerListenerTlsList":
        return typing.cast("DataYandexAlbLoadBalancerListenerTlsList", jsii.get(self, "tls"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexAlbLoadBalancerListener]:
        return typing.cast(typing.Optional[DataYandexAlbLoadBalancerListener], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbLoadBalancerListener],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerStream",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbLoadBalancerListenerStream:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbLoadBalancerListenerStream(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerStreamHandler",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbLoadBalancerListenerStreamHandler:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbLoadBalancerListenerStreamHandler(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbLoadBalancerListenerStreamHandlerList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerStreamHandlerList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbLoadBalancerListenerStreamHandlerOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbLoadBalancerListenerStreamHandlerOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbLoadBalancerListenerStreamHandlerOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerStreamHandlerOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backendGroupId")
    def backend_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "backendGroupId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbLoadBalancerListenerStreamHandler]:
        return typing.cast(typing.Optional[DataYandexAlbLoadBalancerListenerStreamHandler], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbLoadBalancerListenerStreamHandler],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexAlbLoadBalancerListenerStreamList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerStreamList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbLoadBalancerListenerStreamOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbLoadBalancerListenerStreamOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbLoadBalancerListenerStreamOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerStreamOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="handler")
    def handler(self) -> DataYandexAlbLoadBalancerListenerStreamHandlerList:
        return typing.cast(DataYandexAlbLoadBalancerListenerStreamHandlerList, jsii.get(self, "handler"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbLoadBalancerListenerStream]:
        return typing.cast(typing.Optional[DataYandexAlbLoadBalancerListenerStream], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbLoadBalancerListenerStream],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerTls",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbLoadBalancerListenerTls:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbLoadBalancerListenerTls(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerTlsDefaultHandler",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbLoadBalancerListenerTlsDefaultHandler:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbLoadBalancerListenerTlsDefaultHandler(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerTlsDefaultHandlerHttpHandler",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbLoadBalancerListenerTlsDefaultHandlerHttpHandler:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbLoadBalancerListenerTlsDefaultHandlerHttpHandler(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2Options",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2Options:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2Options(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2OptionsList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2OptionsList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2OptionsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2OptionsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2OptionsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2OptionsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxConcurrentStreams")
    def max_concurrent_streams(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxConcurrentStreams"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2Options]:
        return typing.cast(typing.Optional[DataYandexAlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2Options], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2Options],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexAlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allowHttp10")
    def allow_http10(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "allowHttp10"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="http2Options")
    def http2_options(
        self,
    ) -> DataYandexAlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2OptionsList:
        return typing.cast(DataYandexAlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2OptionsList, jsii.get(self, "http2Options"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpRouterId")
    def http_router_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "httpRouterId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbLoadBalancerListenerTlsDefaultHandlerHttpHandler]:
        return typing.cast(typing.Optional[DataYandexAlbLoadBalancerListenerTlsDefaultHandlerHttpHandler], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbLoadBalancerListenerTlsDefaultHandlerHttpHandler],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexAlbLoadBalancerListenerTlsDefaultHandlerList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerTlsDefaultHandlerList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbLoadBalancerListenerTlsDefaultHandlerOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbLoadBalancerListenerTlsDefaultHandlerOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbLoadBalancerListenerTlsDefaultHandlerOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerTlsDefaultHandlerOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="certificateIds")
    def certificate_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "certificateIds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpHandler")
    def http_handler(
        self,
    ) -> DataYandexAlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerList:
        return typing.cast(DataYandexAlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerList, jsii.get(self, "httpHandler"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="streamHandler")
    def stream_handler(
        self,
    ) -> "DataYandexAlbLoadBalancerListenerTlsDefaultHandlerStreamHandlerList":
        return typing.cast("DataYandexAlbLoadBalancerListenerTlsDefaultHandlerStreamHandlerList", jsii.get(self, "streamHandler"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbLoadBalancerListenerTlsDefaultHandler]:
        return typing.cast(typing.Optional[DataYandexAlbLoadBalancerListenerTlsDefaultHandler], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbLoadBalancerListenerTlsDefaultHandler],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerTlsDefaultHandlerStreamHandler",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbLoadBalancerListenerTlsDefaultHandlerStreamHandler:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbLoadBalancerListenerTlsDefaultHandlerStreamHandler(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbLoadBalancerListenerTlsDefaultHandlerStreamHandlerList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerTlsDefaultHandlerStreamHandlerList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbLoadBalancerListenerTlsDefaultHandlerStreamHandlerOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbLoadBalancerListenerTlsDefaultHandlerStreamHandlerOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbLoadBalancerListenerTlsDefaultHandlerStreamHandlerOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerTlsDefaultHandlerStreamHandlerOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backendGroupId")
    def backend_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "backendGroupId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbLoadBalancerListenerTlsDefaultHandlerStreamHandler]:
        return typing.cast(typing.Optional[DataYandexAlbLoadBalancerListenerTlsDefaultHandlerStreamHandler], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbLoadBalancerListenerTlsDefaultHandlerStreamHandler],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexAlbLoadBalancerListenerTlsList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerTlsList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbLoadBalancerListenerTlsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbLoadBalancerListenerTlsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbLoadBalancerListenerTlsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerTlsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="defaultHandler")
    def default_handler(self) -> DataYandexAlbLoadBalancerListenerTlsDefaultHandlerList:
        return typing.cast(DataYandexAlbLoadBalancerListenerTlsDefaultHandlerList, jsii.get(self, "defaultHandler"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sniHandler")
    def sni_handler(self) -> "DataYandexAlbLoadBalancerListenerTlsSniHandlerList":
        return typing.cast("DataYandexAlbLoadBalancerListenerTlsSniHandlerList", jsii.get(self, "sniHandler"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexAlbLoadBalancerListenerTls]:
        return typing.cast(typing.Optional[DataYandexAlbLoadBalancerListenerTls], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbLoadBalancerListenerTls],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerTlsSniHandler",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbLoadBalancerListenerTlsSniHandler:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbLoadBalancerListenerTlsSniHandler(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerTlsSniHandlerHandler",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbLoadBalancerListenerTlsSniHandlerHandler:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbLoadBalancerListenerTlsSniHandlerHandler(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandler",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandler:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandler(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2Options",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2Options:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2Options(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2OptionsList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2OptionsList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2OptionsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2OptionsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2OptionsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2OptionsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxConcurrentStreams")
    def max_concurrent_streams(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxConcurrentStreams"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2Options]:
        return typing.cast(typing.Optional[DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2Options], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2Options],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allowHttp10")
    def allow_http10(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "allowHttp10"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="http2Options")
    def http2_options(
        self,
    ) -> DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2OptionsList:
        return typing.cast(DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2OptionsList, jsii.get(self, "http2Options"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpRouterId")
    def http_router_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "httpRouterId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandler]:
        return typing.cast(typing.Optional[DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandler], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandler],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="certificateIds")
    def certificate_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "certificateIds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpHandler")
    def http_handler(
        self,
    ) -> DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerList:
        return typing.cast(DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerList, jsii.get(self, "httpHandler"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="streamHandler")
    def stream_handler(
        self,
    ) -> "DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandlerList":
        return typing.cast("DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandlerList", jsii.get(self, "streamHandler"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbLoadBalancerListenerTlsSniHandlerHandler]:
        return typing.cast(typing.Optional[DataYandexAlbLoadBalancerListenerTlsSniHandlerHandler], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbLoadBalancerListenerTlsSniHandlerHandler],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandler",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandler:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandler(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandlerList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandlerList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandlerOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandlerOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandlerOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandlerOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backendGroupId")
    def backend_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "backendGroupId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandler]:
        return typing.cast(typing.Optional[DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandler], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandler],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexAlbLoadBalancerListenerTlsSniHandlerList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerTlsSniHandlerList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbLoadBalancerListenerTlsSniHandlerOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbLoadBalancerListenerTlsSniHandlerOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbLoadBalancerListenerTlsSniHandlerOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerListenerTlsSniHandlerOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="handler")
    def handler(self) -> DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerList:
        return typing.cast(DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerList, jsii.get(self, "handler"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serverNames")
    def server_names(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "serverNames"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbLoadBalancerListenerTlsSniHandler]:
        return typing.cast(typing.Optional[DataYandexAlbLoadBalancerListenerTlsSniHandler], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbLoadBalancerListenerTlsSniHandler],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class DataYandexAlbLoadBalancerTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_load_balancer#create DataYandexAlbLoadBalancer#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_load_balancer#delete DataYandexAlbLoadBalancer#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_load_balancer#update DataYandexAlbLoadBalancer#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_load_balancer#create DataYandexAlbLoadBalancer#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_load_balancer#delete DataYandexAlbLoadBalancer#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_load_balancer#update DataYandexAlbLoadBalancer#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbLoadBalancerTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbLoadBalancerTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbLoadBalancerTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, DataYandexAlbLoadBalancerTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, DataYandexAlbLoadBalancerTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, DataYandexAlbLoadBalancerTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexAlbTargetGroup(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbTargetGroup",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/alb_target_group yandex_alb_target_group}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        target_group_id: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/alb_target_group yandex_alb_target_group} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_target_group#description DataYandexAlbTargetGroup#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_target_group#folder_id DataYandexAlbTargetGroup#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_target_group#id DataYandexAlbTargetGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_target_group#name DataYandexAlbTargetGroup#name}.
        :param target_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_target_group#target_group_id DataYandexAlbTargetGroup#target_group_id}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexAlbTargetGroupConfig(
            description=description,
            folder_id=folder_id,
            id=id,
            name=name,
            target_group_id=target_group_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetTargetGroupId")
    def reset_target_group_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTargetGroupId", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="target")
    def target(self) -> "DataYandexAlbTargetGroupTargetList":
        return typing.cast("DataYandexAlbTargetGroupTargetList", jsii.get(self, "target"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupIdInput")
    def target_group_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "targetGroupIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupId")
    def target_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "targetGroupId"))

    @target_group_id.setter
    def target_group_id(self, value: builtins.str) -> None:
        jsii.set(self, "targetGroupId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbTargetGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "description": "description",
        "folder_id": "folderId",
        "id": "id",
        "name": "name",
        "target_group_id": "targetGroupId",
    },
)
class DataYandexAlbTargetGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        target_group_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_target_group#description DataYandexAlbTargetGroup#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_target_group#folder_id DataYandexAlbTargetGroup#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_target_group#id DataYandexAlbTargetGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_target_group#name DataYandexAlbTargetGroup#name}.
        :param target_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_target_group#target_group_id DataYandexAlbTargetGroup#target_group_id}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name
        if target_group_id is not None:
            self._values["target_group_id"] = target_group_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_target_group#description DataYandexAlbTargetGroup#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_target_group#folder_id DataYandexAlbTargetGroup#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_target_group#id DataYandexAlbTargetGroup#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_target_group#name DataYandexAlbTargetGroup#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def target_group_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_target_group#target_group_id DataYandexAlbTargetGroup#target_group_id}.'''
        result = self._values.get("target_group_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbTargetGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbTargetGroupTarget",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbTargetGroupTarget:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbTargetGroupTarget(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbTargetGroupTargetList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbTargetGroupTargetList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbTargetGroupTargetOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbTargetGroupTargetOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbTargetGroupTargetOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbTargetGroupTargetOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipAddress")
    def ip_address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ipAddress"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="privateIpv4Address")
    def private_ipv4_address(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "privateIpv4Address"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexAlbTargetGroupTarget]:
        return typing.cast(typing.Optional[DataYandexAlbTargetGroupTarget], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbTargetGroupTarget],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexAlbVirtualHost(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHost",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/alb_virtual_host yandex_alb_virtual_host}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        http_router_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        virtual_host_id: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/alb_virtual_host yandex_alb_virtual_host} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param http_router_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_virtual_host#http_router_id DataYandexAlbVirtualHost#http_router_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_virtual_host#id DataYandexAlbVirtualHost#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_virtual_host#name DataYandexAlbVirtualHost#name}.
        :param virtual_host_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_virtual_host#virtual_host_id DataYandexAlbVirtualHost#virtual_host_id}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexAlbVirtualHostConfig(
            http_router_id=http_router_id,
            id=id,
            name=name,
            virtual_host_id=virtual_host_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetHttpRouterId")
    def reset_http_router_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttpRouterId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetVirtualHostId")
    def reset_virtual_host_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetVirtualHostId", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="authority")
    def authority(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "authority"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="modifyRequestHeaders")
    def modify_request_headers(
        self,
    ) -> "DataYandexAlbVirtualHostModifyRequestHeadersList":
        return typing.cast("DataYandexAlbVirtualHostModifyRequestHeadersList", jsii.get(self, "modifyRequestHeaders"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="modifyResponseHeaders")
    def modify_response_headers(
        self,
    ) -> "DataYandexAlbVirtualHostModifyResponseHeadersList":
        return typing.cast("DataYandexAlbVirtualHostModifyResponseHeadersList", jsii.get(self, "modifyResponseHeaders"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="route")
    def route(self) -> "DataYandexAlbVirtualHostRouteList":
        return typing.cast("DataYandexAlbVirtualHostRouteList", jsii.get(self, "route"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpRouterIdInput")
    def http_router_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "httpRouterIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="virtualHostIdInput")
    def virtual_host_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "virtualHostIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpRouterId")
    def http_router_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "httpRouterId"))

    @http_router_id.setter
    def http_router_id(self, value: builtins.str) -> None:
        jsii.set(self, "httpRouterId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="virtualHostId")
    def virtual_host_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "virtualHostId"))

    @virtual_host_id.setter
    def virtual_host_id(self, value: builtins.str) -> None:
        jsii.set(self, "virtualHostId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "http_router_id": "httpRouterId",
        "id": "id",
        "name": "name",
        "virtual_host_id": "virtualHostId",
    },
)
class DataYandexAlbVirtualHostConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        http_router_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        virtual_host_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param http_router_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_virtual_host#http_router_id DataYandexAlbVirtualHost#http_router_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_virtual_host#id DataYandexAlbVirtualHost#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_virtual_host#name DataYandexAlbVirtualHost#name}.
        :param virtual_host_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_virtual_host#virtual_host_id DataYandexAlbVirtualHost#virtual_host_id}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if http_router_id is not None:
            self._values["http_router_id"] = http_router_id
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name
        if virtual_host_id is not None:
            self._values["virtual_host_id"] = virtual_host_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def http_router_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_virtual_host#http_router_id DataYandexAlbVirtualHost#http_router_id}.'''
        result = self._values.get("http_router_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_virtual_host#id DataYandexAlbVirtualHost#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_virtual_host#name DataYandexAlbVirtualHost#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def virtual_host_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/alb_virtual_host#virtual_host_id DataYandexAlbVirtualHost#virtual_host_id}.'''
        result = self._values.get("virtual_host_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbVirtualHostConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostModifyRequestHeaders",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbVirtualHostModifyRequestHeaders:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbVirtualHostModifyRequestHeaders(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbVirtualHostModifyRequestHeadersList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostModifyRequestHeadersList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbVirtualHostModifyRequestHeadersOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbVirtualHostModifyRequestHeadersOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbVirtualHostModifyRequestHeadersOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostModifyRequestHeadersOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="append")
    def append(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "append"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="remove")
    def remove(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "remove"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replace")
    def replace(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "replace"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbVirtualHostModifyRequestHeaders]:
        return typing.cast(typing.Optional[DataYandexAlbVirtualHostModifyRequestHeaders], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbVirtualHostModifyRequestHeaders],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostModifyResponseHeaders",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbVirtualHostModifyResponseHeaders:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbVirtualHostModifyResponseHeaders(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbVirtualHostModifyResponseHeadersList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostModifyResponseHeadersList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbVirtualHostModifyResponseHeadersOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbVirtualHostModifyResponseHeadersOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbVirtualHostModifyResponseHeadersOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostModifyResponseHeadersOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="append")
    def append(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "append"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="remove")
    def remove(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "remove"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replace")
    def replace(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "replace"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbVirtualHostModifyResponseHeaders]:
        return typing.cast(typing.Optional[DataYandexAlbVirtualHostModifyResponseHeaders], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbVirtualHostModifyResponseHeaders],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRoute",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbVirtualHostRoute:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbVirtualHostRoute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteGrpcRoute",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbVirtualHostRouteGrpcRoute:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbVirtualHostRouteGrpcRoute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteGrpcRouteGrpcMatch",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbVirtualHostRouteGrpcRouteGrpcMatch:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbVirtualHostRouteGrpcRouteGrpcMatch(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteGrpcRouteGrpcMatchFqmn",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbVirtualHostRouteGrpcRouteGrpcMatchFqmn:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbVirtualHostRouteGrpcRouteGrpcMatchFqmn(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbVirtualHostRouteGrpcRouteGrpcMatchFqmnList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteGrpcRouteGrpcMatchFqmnList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbVirtualHostRouteGrpcRouteGrpcMatchFqmnOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbVirtualHostRouteGrpcRouteGrpcMatchFqmnOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbVirtualHostRouteGrpcRouteGrpcMatchFqmnOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteGrpcRouteGrpcMatchFqmnOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="exact")
    def exact(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "exact"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="prefix")
    def prefix(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "prefix"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbVirtualHostRouteGrpcRouteGrpcMatchFqmn]:
        return typing.cast(typing.Optional[DataYandexAlbVirtualHostRouteGrpcRouteGrpcMatchFqmn], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbVirtualHostRouteGrpcRouteGrpcMatchFqmn],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexAlbVirtualHostRouteGrpcRouteGrpcMatchList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteGrpcRouteGrpcMatchList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbVirtualHostRouteGrpcRouteGrpcMatchOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbVirtualHostRouteGrpcRouteGrpcMatchOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbVirtualHostRouteGrpcRouteGrpcMatchOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteGrpcRouteGrpcMatchOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqmn")
    def fqmn(self) -> DataYandexAlbVirtualHostRouteGrpcRouteGrpcMatchFqmnList:
        return typing.cast(DataYandexAlbVirtualHostRouteGrpcRouteGrpcMatchFqmnList, jsii.get(self, "fqmn"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbVirtualHostRouteGrpcRouteGrpcMatch]:
        return typing.cast(typing.Optional[DataYandexAlbVirtualHostRouteGrpcRouteGrpcMatch], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbVirtualHostRouteGrpcRouteGrpcMatch],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteGrpcRouteGrpcRouteAction",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbVirtualHostRouteGrpcRouteGrpcRouteAction:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbVirtualHostRouteGrpcRouteGrpcRouteAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbVirtualHostRouteGrpcRouteGrpcRouteActionList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteGrpcRouteGrpcRouteActionList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbVirtualHostRouteGrpcRouteGrpcRouteActionOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbVirtualHostRouteGrpcRouteGrpcRouteActionOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbVirtualHostRouteGrpcRouteGrpcRouteActionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteGrpcRouteGrpcRouteActionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoHostRewrite")
    def auto_host_rewrite(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "autoHostRewrite"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backendGroupId")
    def backend_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "backendGroupId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostRewrite")
    def host_rewrite(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "hostRewrite"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idleTimeout")
    def idle_timeout(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "idleTimeout"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxTimeout")
    def max_timeout(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "maxTimeout"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbVirtualHostRouteGrpcRouteGrpcRouteAction]:
        return typing.cast(typing.Optional[DataYandexAlbVirtualHostRouteGrpcRouteGrpcRouteAction], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbVirtualHostRouteGrpcRouteGrpcRouteAction],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteGrpcRouteGrpcStatusResponseAction",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbVirtualHostRouteGrpcRouteGrpcStatusResponseAction:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbVirtualHostRouteGrpcRouteGrpcStatusResponseAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbVirtualHostRouteGrpcRouteGrpcStatusResponseActionList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteGrpcRouteGrpcStatusResponseActionList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbVirtualHostRouteGrpcRouteGrpcStatusResponseActionOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbVirtualHostRouteGrpcRouteGrpcStatusResponseActionOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbVirtualHostRouteGrpcRouteGrpcStatusResponseActionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteGrpcRouteGrpcStatusResponseActionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbVirtualHostRouteGrpcRouteGrpcStatusResponseAction]:
        return typing.cast(typing.Optional[DataYandexAlbVirtualHostRouteGrpcRouteGrpcStatusResponseAction], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbVirtualHostRouteGrpcRouteGrpcStatusResponseAction],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexAlbVirtualHostRouteGrpcRouteList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteGrpcRouteList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbVirtualHostRouteGrpcRouteOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbVirtualHostRouteGrpcRouteOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbVirtualHostRouteGrpcRouteOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteGrpcRouteOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="grpcMatch")
    def grpc_match(self) -> DataYandexAlbVirtualHostRouteGrpcRouteGrpcMatchList:
        return typing.cast(DataYandexAlbVirtualHostRouteGrpcRouteGrpcMatchList, jsii.get(self, "grpcMatch"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="grpcRouteAction")
    def grpc_route_action(
        self,
    ) -> DataYandexAlbVirtualHostRouteGrpcRouteGrpcRouteActionList:
        return typing.cast(DataYandexAlbVirtualHostRouteGrpcRouteGrpcRouteActionList, jsii.get(self, "grpcRouteAction"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="grpcStatusResponseAction")
    def grpc_status_response_action(
        self,
    ) -> DataYandexAlbVirtualHostRouteGrpcRouteGrpcStatusResponseActionList:
        return typing.cast(DataYandexAlbVirtualHostRouteGrpcRouteGrpcStatusResponseActionList, jsii.get(self, "grpcStatusResponseAction"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexAlbVirtualHostRouteGrpcRoute]:
        return typing.cast(typing.Optional[DataYandexAlbVirtualHostRouteGrpcRoute], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbVirtualHostRouteGrpcRoute],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteHttpRoute",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbVirtualHostRouteHttpRoute:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbVirtualHostRouteHttpRoute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteHttpRouteDirectResponseAction",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbVirtualHostRouteHttpRouteDirectResponseAction:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbVirtualHostRouteHttpRouteDirectResponseAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbVirtualHostRouteHttpRouteDirectResponseActionList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteHttpRouteDirectResponseActionList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbVirtualHostRouteHttpRouteDirectResponseActionOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbVirtualHostRouteHttpRouteDirectResponseActionOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbVirtualHostRouteHttpRouteDirectResponseActionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteHttpRouteDirectResponseActionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="body")
    def body(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "body"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbVirtualHostRouteHttpRouteDirectResponseAction]:
        return typing.cast(typing.Optional[DataYandexAlbVirtualHostRouteHttpRouteDirectResponseAction], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbVirtualHostRouteHttpRouteDirectResponseAction],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteHttpRouteHttpMatch",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbVirtualHostRouteHttpRouteHttpMatch:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbVirtualHostRouteHttpRouteHttpMatch(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbVirtualHostRouteHttpRouteHttpMatchList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteHttpRouteHttpMatchList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbVirtualHostRouteHttpRouteHttpMatchOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbVirtualHostRouteHttpRouteHttpMatchOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbVirtualHostRouteHttpRouteHttpMatchOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteHttpRouteHttpMatchOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpMethod")
    def http_method(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "httpMethod"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="path")
    def path(self) -> "DataYandexAlbVirtualHostRouteHttpRouteHttpMatchPathList":
        return typing.cast("DataYandexAlbVirtualHostRouteHttpRouteHttpMatchPathList", jsii.get(self, "path"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbVirtualHostRouteHttpRouteHttpMatch]:
        return typing.cast(typing.Optional[DataYandexAlbVirtualHostRouteHttpRouteHttpMatch], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbVirtualHostRouteHttpRouteHttpMatch],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteHttpRouteHttpMatchPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbVirtualHostRouteHttpRouteHttpMatchPath:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbVirtualHostRouteHttpRouteHttpMatchPath(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbVirtualHostRouteHttpRouteHttpMatchPathList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteHttpRouteHttpMatchPathList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbVirtualHostRouteHttpRouteHttpMatchPathOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbVirtualHostRouteHttpRouteHttpMatchPathOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbVirtualHostRouteHttpRouteHttpMatchPathOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteHttpRouteHttpMatchPathOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="exact")
    def exact(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "exact"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="prefix")
    def prefix(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "prefix"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbVirtualHostRouteHttpRouteHttpMatchPath]:
        return typing.cast(typing.Optional[DataYandexAlbVirtualHostRouteHttpRouteHttpMatchPath], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbVirtualHostRouteHttpRouteHttpMatchPath],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteHttpRouteHttpRouteAction",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbVirtualHostRouteHttpRouteHttpRouteAction:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbVirtualHostRouteHttpRouteHttpRouteAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbVirtualHostRouteHttpRouteHttpRouteActionList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteHttpRouteHttpRouteActionList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbVirtualHostRouteHttpRouteHttpRouteActionOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbVirtualHostRouteHttpRouteHttpRouteActionOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbVirtualHostRouteHttpRouteHttpRouteActionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteHttpRouteHttpRouteActionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoHostRewrite")
    def auto_host_rewrite(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "autoHostRewrite"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backendGroupId")
    def backend_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "backendGroupId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostRewrite")
    def host_rewrite(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "hostRewrite"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idleTimeout")
    def idle_timeout(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "idleTimeout"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="prefixRewrite")
    def prefix_rewrite(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "prefixRewrite"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeout")
    def timeout(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "timeout"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="upgradeTypes")
    def upgrade_types(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "upgradeTypes"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbVirtualHostRouteHttpRouteHttpRouteAction]:
        return typing.cast(typing.Optional[DataYandexAlbVirtualHostRouteHttpRouteHttpRouteAction], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbVirtualHostRouteHttpRouteHttpRouteAction],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexAlbVirtualHostRouteHttpRouteList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteHttpRouteList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbVirtualHostRouteHttpRouteOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbVirtualHostRouteHttpRouteOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbVirtualHostRouteHttpRouteOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteHttpRouteOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="directResponseAction")
    def direct_response_action(
        self,
    ) -> DataYandexAlbVirtualHostRouteHttpRouteDirectResponseActionList:
        return typing.cast(DataYandexAlbVirtualHostRouteHttpRouteDirectResponseActionList, jsii.get(self, "directResponseAction"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpMatch")
    def http_match(self) -> DataYandexAlbVirtualHostRouteHttpRouteHttpMatchList:
        return typing.cast(DataYandexAlbVirtualHostRouteHttpRouteHttpMatchList, jsii.get(self, "httpMatch"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpRouteAction")
    def http_route_action(
        self,
    ) -> DataYandexAlbVirtualHostRouteHttpRouteHttpRouteActionList:
        return typing.cast(DataYandexAlbVirtualHostRouteHttpRouteHttpRouteActionList, jsii.get(self, "httpRouteAction"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="redirectAction")
    def redirect_action(
        self,
    ) -> "DataYandexAlbVirtualHostRouteHttpRouteRedirectActionList":
        return typing.cast("DataYandexAlbVirtualHostRouteHttpRouteRedirectActionList", jsii.get(self, "redirectAction"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexAlbVirtualHostRouteHttpRoute]:
        return typing.cast(typing.Optional[DataYandexAlbVirtualHostRouteHttpRoute], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbVirtualHostRouteHttpRoute],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteHttpRouteRedirectAction",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexAlbVirtualHostRouteHttpRouteRedirectAction:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexAlbVirtualHostRouteHttpRouteRedirectAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexAlbVirtualHostRouteHttpRouteRedirectActionList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteHttpRouteRedirectActionList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexAlbVirtualHostRouteHttpRouteRedirectActionOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbVirtualHostRouteHttpRouteRedirectActionOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbVirtualHostRouteHttpRouteRedirectActionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteHttpRouteRedirectActionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="removeQuery")
    def remove_query(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "removeQuery"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replaceHost")
    def replace_host(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "replaceHost"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replacePath")
    def replace_path(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "replacePath"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replacePort")
    def replace_port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "replacePort"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replacePrefix")
    def replace_prefix(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "replacePrefix"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replaceScheme")
    def replace_scheme(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "replaceScheme"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="responseCode")
    def response_code(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "responseCode"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexAlbVirtualHostRouteHttpRouteRedirectAction]:
        return typing.cast(typing.Optional[DataYandexAlbVirtualHostRouteHttpRouteRedirectAction], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbVirtualHostRouteHttpRouteRedirectAction],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexAlbVirtualHostRouteList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "DataYandexAlbVirtualHostRouteOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexAlbVirtualHostRouteOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexAlbVirtualHostRouteOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexAlbVirtualHostRouteOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="grpcRoute")
    def grpc_route(self) -> DataYandexAlbVirtualHostRouteGrpcRouteList:
        return typing.cast(DataYandexAlbVirtualHostRouteGrpcRouteList, jsii.get(self, "grpcRoute"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpRoute")
    def http_route(self) -> DataYandexAlbVirtualHostRouteHttpRouteList:
        return typing.cast(DataYandexAlbVirtualHostRouteHttpRouteList, jsii.get(self, "httpRoute"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexAlbVirtualHostRoute]:
        return typing.cast(typing.Optional[DataYandexAlbVirtualHostRoute], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexAlbVirtualHostRoute],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexApiGateway(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexApiGateway",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/api_gateway yandex_api_gateway}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        api_gateway_id: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/api_gateway yandex_api_gateway} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param api_gateway_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/api_gateway#api_gateway_id DataYandexApiGateway#api_gateway_id}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/api_gateway#folder_id DataYandexApiGateway#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/api_gateway#id DataYandexApiGateway#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/api_gateway#name DataYandexApiGateway#name}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexApiGatewayConfig(
            api_gateway_id=api_gateway_id,
            folder_id=folder_id,
            id=id,
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetApiGatewayId")
    def reset_api_gateway_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApiGatewayId", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="domain")
    def domain(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "domain"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logGroupId")
    def log_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "logGroupId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="userDomains")
    def user_domains(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "userDomains"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="apiGatewayIdInput")
    def api_gateway_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "apiGatewayIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="apiGatewayId")
    def api_gateway_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "apiGatewayId"))

    @api_gateway_id.setter
    def api_gateway_id(self, value: builtins.str) -> None:
        jsii.set(self, "apiGatewayId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexApiGatewayConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_gateway_id": "apiGatewayId",
        "folder_id": "folderId",
        "id": "id",
        "name": "name",
    },
)
class DataYandexApiGatewayConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_gateway_id: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_gateway_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/api_gateway#api_gateway_id DataYandexApiGateway#api_gateway_id}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/api_gateway#folder_id DataYandexApiGateway#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/api_gateway#id DataYandexApiGateway#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/api_gateway#name DataYandexApiGateway#name}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if api_gateway_id is not None:
            self._values["api_gateway_id"] = api_gateway_id
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def api_gateway_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/api_gateway#api_gateway_id DataYandexApiGateway#api_gateway_id}.'''
        result = self._values.get("api_gateway_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/api_gateway#folder_id DataYandexApiGateway#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/api_gateway#id DataYandexApiGateway#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/api_gateway#name DataYandexApiGateway#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexApiGatewayConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexCdnOriginGroup(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexCdnOriginGroup",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/cdn_origin_group yandex_cdn_origin_group}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        origin_group_id: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/cdn_origin_group yandex_cdn_origin_group} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_origin_group#folder_id DataYandexCdnOriginGroup#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_origin_group#id DataYandexCdnOriginGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_origin_group#name DataYandexCdnOriginGroup#name}.
        :param origin_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_origin_group#origin_group_id DataYandexCdnOriginGroup#origin_group_id}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexCdnOriginGroupConfig(
            folder_id=folder_id,
            id=id,
            name=name,
            origin_group_id=origin_group_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetOriginGroupId")
    def reset_origin_group_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOriginGroupId", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="origin")
    def origin(self) -> "DataYandexCdnOriginGroupOriginList":
        return typing.cast("DataYandexCdnOriginGroupOriginList", jsii.get(self, "origin"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="useNext")
    def use_next(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "useNext"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="originGroupIdInput")
    def origin_group_id_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "originGroupIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="originGroupId")
    def origin_group_id(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "originGroupId"))

    @origin_group_id.setter
    def origin_group_id(self, value: jsii.Number) -> None:
        jsii.set(self, "originGroupId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexCdnOriginGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "folder_id": "folderId",
        "id": "id",
        "name": "name",
        "origin_group_id": "originGroupId",
    },
)
class DataYandexCdnOriginGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        origin_group_id: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_origin_group#folder_id DataYandexCdnOriginGroup#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_origin_group#id DataYandexCdnOriginGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_origin_group#name DataYandexCdnOriginGroup#name}.
        :param origin_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_origin_group#origin_group_id DataYandexCdnOriginGroup#origin_group_id}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name
        if origin_group_id is not None:
            self._values["origin_group_id"] = origin_group_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_origin_group#folder_id DataYandexCdnOriginGroup#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_origin_group#id DataYandexCdnOriginGroup#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_origin_group#name DataYandexCdnOriginGroup#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def origin_group_id(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_origin_group#origin_group_id DataYandexCdnOriginGroup#origin_group_id}.'''
        result = self._values.get("origin_group_id")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexCdnOriginGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexCdnOriginGroupOrigin",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexCdnOriginGroupOrigin:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexCdnOriginGroupOrigin(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexCdnOriginGroupOriginList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexCdnOriginGroupOriginList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexCdnOriginGroupOriginOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexCdnOriginGroupOriginOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexCdnOriginGroupOriginOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexCdnOriginGroupOriginOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backup")
    def backup(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "backup"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "enabled"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="originGroupId")
    def origin_group_id(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "originGroupId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="source")
    def source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "source"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexCdnOriginGroupOrigin]:
        return typing.cast(typing.Optional[DataYandexCdnOriginGroupOrigin], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexCdnOriginGroupOrigin],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexCdnResource(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexCdnResource",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource yandex_cdn_resource}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        active: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        cname: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        options: typing.Optional["DataYandexCdnResourceOptions"] = None,
        origin_group_id: typing.Optional[jsii.Number] = None,
        origin_group_name: typing.Optional[builtins.str] = None,
        origin_protocol: typing.Optional[builtins.str] = None,
        resource_id: typing.Optional[builtins.str] = None,
        secondary_hostnames: typing.Optional[typing.Sequence[builtins.str]] = None,
        ssl_certificate: typing.Optional["DataYandexCdnResourceSslCertificate"] = None,
        updated_at: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource yandex_cdn_resource} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param active: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#active DataYandexCdnResource#active}.
        :param cname: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#cname DataYandexCdnResource#cname}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#id DataYandexCdnResource#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param options: options block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#options DataYandexCdnResource#options}
        :param origin_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#origin_group_id DataYandexCdnResource#origin_group_id}.
        :param origin_group_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#origin_group_name DataYandexCdnResource#origin_group_name}.
        :param origin_protocol: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#origin_protocol DataYandexCdnResource#origin_protocol}.
        :param resource_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#resource_id DataYandexCdnResource#resource_id}.
        :param secondary_hostnames: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#secondary_hostnames DataYandexCdnResource#secondary_hostnames}.
        :param ssl_certificate: ssl_certificate block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#ssl_certificate DataYandexCdnResource#ssl_certificate}
        :param updated_at: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#updated_at DataYandexCdnResource#updated_at}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexCdnResourceConfig(
            active=active,
            cname=cname,
            id=id,
            options=options,
            origin_group_id=origin_group_id,
            origin_group_name=origin_group_name,
            origin_protocol=origin_protocol,
            resource_id=resource_id,
            secondary_hostnames=secondary_hostnames,
            ssl_certificate=ssl_certificate,
            updated_at=updated_at,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putOptions")
    def put_options(
        self,
        *,
        allowed_http_methods: typing.Optional[typing.Sequence[builtins.str]] = None,
        browser_cache_settings: typing.Optional[jsii.Number] = None,
        cache_http_headers: typing.Optional[typing.Sequence[builtins.str]] = None,
        cors: typing.Optional[typing.Sequence[builtins.str]] = None,
        custom_host_header: typing.Optional[builtins.str] = None,
        custom_server_name: typing.Optional[builtins.str] = None,
        disable_cache: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        disable_proxy_force_ranges: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        edge_cache_settings: typing.Optional[jsii.Number] = None,
        fetched_compressed: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        forward_host_header: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        gzip_on: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        ignore_cookie: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        ignore_query_params: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        proxy_cache_methods_set: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        query_params_blacklist: typing.Optional[typing.Sequence[builtins.str]] = None,
        query_params_whitelist: typing.Optional[typing.Sequence[builtins.str]] = None,
        redirect_https_to_http: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        redirect_http_to_https: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        slice: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        static_request_headers: typing.Optional[typing.Sequence[builtins.str]] = None,
        static_response_headers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
    ) -> None:
        '''
        :param allowed_http_methods: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#allowed_http_methods DataYandexCdnResource#allowed_http_methods}.
        :param browser_cache_settings: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#browser_cache_settings DataYandexCdnResource#browser_cache_settings}.
        :param cache_http_headers: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#cache_http_headers DataYandexCdnResource#cache_http_headers}.
        :param cors: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#cors DataYandexCdnResource#cors}.
        :param custom_host_header: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#custom_host_header DataYandexCdnResource#custom_host_header}.
        :param custom_server_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#custom_server_name DataYandexCdnResource#custom_server_name}.
        :param disable_cache: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#disable_cache DataYandexCdnResource#disable_cache}.
        :param disable_proxy_force_ranges: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#disable_proxy_force_ranges DataYandexCdnResource#disable_proxy_force_ranges}.
        :param edge_cache_settings: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#edge_cache_settings DataYandexCdnResource#edge_cache_settings}.
        :param fetched_compressed: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#fetched_compressed DataYandexCdnResource#fetched_compressed}.
        :param forward_host_header: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#forward_host_header DataYandexCdnResource#forward_host_header}.
        :param gzip_on: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#gzip_on DataYandexCdnResource#gzip_on}.
        :param ignore_cookie: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#ignore_cookie DataYandexCdnResource#ignore_cookie}.
        :param ignore_query_params: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#ignore_query_params DataYandexCdnResource#ignore_query_params}.
        :param proxy_cache_methods_set: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#proxy_cache_methods_set DataYandexCdnResource#proxy_cache_methods_set}.
        :param query_params_blacklist: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#query_params_blacklist DataYandexCdnResource#query_params_blacklist}.
        :param query_params_whitelist: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#query_params_whitelist DataYandexCdnResource#query_params_whitelist}.
        :param redirect_https_to_http: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#redirect_https_to_http DataYandexCdnResource#redirect_https_to_http}.
        :param redirect_http_to_https: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#redirect_http_to_https DataYandexCdnResource#redirect_http_to_https}.
        :param slice: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#slice DataYandexCdnResource#slice}.
        :param static_request_headers: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#static_request_headers DataYandexCdnResource#static_request_headers}.
        :param static_response_headers: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#static_response_headers DataYandexCdnResource#static_response_headers}.
        '''
        value = DataYandexCdnResourceOptions(
            allowed_http_methods=allowed_http_methods,
            browser_cache_settings=browser_cache_settings,
            cache_http_headers=cache_http_headers,
            cors=cors,
            custom_host_header=custom_host_header,
            custom_server_name=custom_server_name,
            disable_cache=disable_cache,
            disable_proxy_force_ranges=disable_proxy_force_ranges,
            edge_cache_settings=edge_cache_settings,
            fetched_compressed=fetched_compressed,
            forward_host_header=forward_host_header,
            gzip_on=gzip_on,
            ignore_cookie=ignore_cookie,
            ignore_query_params=ignore_query_params,
            proxy_cache_methods_set=proxy_cache_methods_set,
            query_params_blacklist=query_params_blacklist,
            query_params_whitelist=query_params_whitelist,
            redirect_https_to_http=redirect_https_to_http,
            redirect_http_to_https=redirect_http_to_https,
            slice=slice,
            static_request_headers=static_request_headers,
            static_response_headers=static_response_headers,
        )

        return typing.cast(None, jsii.invoke(self, "putOptions", [value]))

    @jsii.member(jsii_name="putSslCertificate")
    def put_ssl_certificate(
        self,
        *,
        type: builtins.str,
        certificate_manager_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#type DataYandexCdnResource#type}.
        :param certificate_manager_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#certificate_manager_id DataYandexCdnResource#certificate_manager_id}.
        '''
        value = DataYandexCdnResourceSslCertificate(
            type=type, certificate_manager_id=certificate_manager_id
        )

        return typing.cast(None, jsii.invoke(self, "putSslCertificate", [value]))

    @jsii.member(jsii_name="resetActive")
    def reset_active(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetActive", []))

    @jsii.member(jsii_name="resetCname")
    def reset_cname(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCname", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetOptions")
    def reset_options(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOptions", []))

    @jsii.member(jsii_name="resetOriginGroupId")
    def reset_origin_group_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOriginGroupId", []))

    @jsii.member(jsii_name="resetOriginGroupName")
    def reset_origin_group_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOriginGroupName", []))

    @jsii.member(jsii_name="resetOriginProtocol")
    def reset_origin_protocol(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOriginProtocol", []))

    @jsii.member(jsii_name="resetResourceId")
    def reset_resource_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetResourceId", []))

    @jsii.member(jsii_name="resetSecondaryHostnames")
    def reset_secondary_hostnames(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecondaryHostnames", []))

    @jsii.member(jsii_name="resetSslCertificate")
    def reset_ssl_certificate(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSslCertificate", []))

    @jsii.member(jsii_name="resetUpdatedAt")
    def reset_updated_at(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdatedAt", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="options")
    def options(self) -> "DataYandexCdnResourceOptionsOutputReference":
        return typing.cast("DataYandexCdnResourceOptionsOutputReference", jsii.get(self, "options"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sslCertificate")
    def ssl_certificate(self) -> "DataYandexCdnResourceSslCertificateOutputReference":
        return typing.cast("DataYandexCdnResourceSslCertificateOutputReference", jsii.get(self, "sslCertificate"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="activeInput")
    def active_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "activeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cnameInput")
    def cname_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "cnameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="optionsInput")
    def options_input(self) -> typing.Optional["DataYandexCdnResourceOptions"]:
        return typing.cast(typing.Optional["DataYandexCdnResourceOptions"], jsii.get(self, "optionsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="originGroupIdInput")
    def origin_group_id_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "originGroupIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="originGroupNameInput")
    def origin_group_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "originGroupNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="originProtocolInput")
    def origin_protocol_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "originProtocolInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourceIdInput")
    def resource_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourceIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="secondaryHostnamesInput")
    def secondary_hostnames_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "secondaryHostnamesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sslCertificateInput")
    def ssl_certificate_input(
        self,
    ) -> typing.Optional["DataYandexCdnResourceSslCertificate"]:
        return typing.cast(typing.Optional["DataYandexCdnResourceSslCertificate"], jsii.get(self, "sslCertificateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updatedAtInput")
    def updated_at_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updatedAtInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="active")
    def active(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "active"))

    @active.setter
    def active(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "active", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cname")
    def cname(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "cname"))

    @cname.setter
    def cname(self, value: builtins.str) -> None:
        jsii.set(self, "cname", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="originGroupId")
    def origin_group_id(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "originGroupId"))

    @origin_group_id.setter
    def origin_group_id(self, value: jsii.Number) -> None:
        jsii.set(self, "originGroupId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="originGroupName")
    def origin_group_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "originGroupName"))

    @origin_group_name.setter
    def origin_group_name(self, value: builtins.str) -> None:
        jsii.set(self, "originGroupName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="originProtocol")
    def origin_protocol(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "originProtocol"))

    @origin_protocol.setter
    def origin_protocol(self, value: builtins.str) -> None:
        jsii.set(self, "originProtocol", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourceId")
    def resource_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourceId"))

    @resource_id.setter
    def resource_id(self, value: builtins.str) -> None:
        jsii.set(self, "resourceId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="secondaryHostnames")
    def secondary_hostnames(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "secondaryHostnames"))

    @secondary_hostnames.setter
    def secondary_hostnames(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "secondaryHostnames", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updatedAt")
    def updated_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "updatedAt"))

    @updated_at.setter
    def updated_at(self, value: builtins.str) -> None:
        jsii.set(self, "updatedAt", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexCdnResourceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "active": "active",
        "cname": "cname",
        "id": "id",
        "options": "options",
        "origin_group_id": "originGroupId",
        "origin_group_name": "originGroupName",
        "origin_protocol": "originProtocol",
        "resource_id": "resourceId",
        "secondary_hostnames": "secondaryHostnames",
        "ssl_certificate": "sslCertificate",
        "updated_at": "updatedAt",
    },
)
class DataYandexCdnResourceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        active: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        cname: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        options: typing.Optional["DataYandexCdnResourceOptions"] = None,
        origin_group_id: typing.Optional[jsii.Number] = None,
        origin_group_name: typing.Optional[builtins.str] = None,
        origin_protocol: typing.Optional[builtins.str] = None,
        resource_id: typing.Optional[builtins.str] = None,
        secondary_hostnames: typing.Optional[typing.Sequence[builtins.str]] = None,
        ssl_certificate: typing.Optional["DataYandexCdnResourceSslCertificate"] = None,
        updated_at: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param active: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#active DataYandexCdnResource#active}.
        :param cname: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#cname DataYandexCdnResource#cname}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#id DataYandexCdnResource#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param options: options block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#options DataYandexCdnResource#options}
        :param origin_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#origin_group_id DataYandexCdnResource#origin_group_id}.
        :param origin_group_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#origin_group_name DataYandexCdnResource#origin_group_name}.
        :param origin_protocol: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#origin_protocol DataYandexCdnResource#origin_protocol}.
        :param resource_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#resource_id DataYandexCdnResource#resource_id}.
        :param secondary_hostnames: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#secondary_hostnames DataYandexCdnResource#secondary_hostnames}.
        :param ssl_certificate: ssl_certificate block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#ssl_certificate DataYandexCdnResource#ssl_certificate}
        :param updated_at: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#updated_at DataYandexCdnResource#updated_at}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(options, dict):
            options = DataYandexCdnResourceOptions(**options)
        if isinstance(ssl_certificate, dict):
            ssl_certificate = DataYandexCdnResourceSslCertificate(**ssl_certificate)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if active is not None:
            self._values["active"] = active
        if cname is not None:
            self._values["cname"] = cname
        if id is not None:
            self._values["id"] = id
        if options is not None:
            self._values["options"] = options
        if origin_group_id is not None:
            self._values["origin_group_id"] = origin_group_id
        if origin_group_name is not None:
            self._values["origin_group_name"] = origin_group_name
        if origin_protocol is not None:
            self._values["origin_protocol"] = origin_protocol
        if resource_id is not None:
            self._values["resource_id"] = resource_id
        if secondary_hostnames is not None:
            self._values["secondary_hostnames"] = secondary_hostnames
        if ssl_certificate is not None:
            self._values["ssl_certificate"] = ssl_certificate
        if updated_at is not None:
            self._values["updated_at"] = updated_at

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def active(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#active DataYandexCdnResource#active}.'''
        result = self._values.get("active")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def cname(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#cname DataYandexCdnResource#cname}.'''
        result = self._values.get("cname")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#id DataYandexCdnResource#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def options(self) -> typing.Optional["DataYandexCdnResourceOptions"]:
        '''options block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#options DataYandexCdnResource#options}
        '''
        result = self._values.get("options")
        return typing.cast(typing.Optional["DataYandexCdnResourceOptions"], result)

    @builtins.property
    def origin_group_id(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#origin_group_id DataYandexCdnResource#origin_group_id}.'''
        result = self._values.get("origin_group_id")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def origin_group_name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#origin_group_name DataYandexCdnResource#origin_group_name}.'''
        result = self._values.get("origin_group_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def origin_protocol(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#origin_protocol DataYandexCdnResource#origin_protocol}.'''
        result = self._values.get("origin_protocol")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def resource_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#resource_id DataYandexCdnResource#resource_id}.'''
        result = self._values.get("resource_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def secondary_hostnames(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#secondary_hostnames DataYandexCdnResource#secondary_hostnames}.'''
        result = self._values.get("secondary_hostnames")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def ssl_certificate(self) -> typing.Optional["DataYandexCdnResourceSslCertificate"]:
        '''ssl_certificate block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#ssl_certificate DataYandexCdnResource#ssl_certificate}
        '''
        result = self._values.get("ssl_certificate")
        return typing.cast(typing.Optional["DataYandexCdnResourceSslCertificate"], result)

    @builtins.property
    def updated_at(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#updated_at DataYandexCdnResource#updated_at}.'''
        result = self._values.get("updated_at")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexCdnResourceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexCdnResourceOptions",
    jsii_struct_bases=[],
    name_mapping={
        "allowed_http_methods": "allowedHttpMethods",
        "browser_cache_settings": "browserCacheSettings",
        "cache_http_headers": "cacheHttpHeaders",
        "cors": "cors",
        "custom_host_header": "customHostHeader",
        "custom_server_name": "customServerName",
        "disable_cache": "disableCache",
        "disable_proxy_force_ranges": "disableProxyForceRanges",
        "edge_cache_settings": "edgeCacheSettings",
        "fetched_compressed": "fetchedCompressed",
        "forward_host_header": "forwardHostHeader",
        "gzip_on": "gzipOn",
        "ignore_cookie": "ignoreCookie",
        "ignore_query_params": "ignoreQueryParams",
        "proxy_cache_methods_set": "proxyCacheMethodsSet",
        "query_params_blacklist": "queryParamsBlacklist",
        "query_params_whitelist": "queryParamsWhitelist",
        "redirect_https_to_http": "redirectHttpsToHttp",
        "redirect_http_to_https": "redirectHttpToHttps",
        "slice": "slice",
        "static_request_headers": "staticRequestHeaders",
        "static_response_headers": "staticResponseHeaders",
    },
)
class DataYandexCdnResourceOptions:
    def __init__(
        self,
        *,
        allowed_http_methods: typing.Optional[typing.Sequence[builtins.str]] = None,
        browser_cache_settings: typing.Optional[jsii.Number] = None,
        cache_http_headers: typing.Optional[typing.Sequence[builtins.str]] = None,
        cors: typing.Optional[typing.Sequence[builtins.str]] = None,
        custom_host_header: typing.Optional[builtins.str] = None,
        custom_server_name: typing.Optional[builtins.str] = None,
        disable_cache: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        disable_proxy_force_ranges: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        edge_cache_settings: typing.Optional[jsii.Number] = None,
        fetched_compressed: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        forward_host_header: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        gzip_on: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        ignore_cookie: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        ignore_query_params: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        proxy_cache_methods_set: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        query_params_blacklist: typing.Optional[typing.Sequence[builtins.str]] = None,
        query_params_whitelist: typing.Optional[typing.Sequence[builtins.str]] = None,
        redirect_https_to_http: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        redirect_http_to_https: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        slice: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        static_request_headers: typing.Optional[typing.Sequence[builtins.str]] = None,
        static_response_headers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
    ) -> None:
        '''
        :param allowed_http_methods: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#allowed_http_methods DataYandexCdnResource#allowed_http_methods}.
        :param browser_cache_settings: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#browser_cache_settings DataYandexCdnResource#browser_cache_settings}.
        :param cache_http_headers: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#cache_http_headers DataYandexCdnResource#cache_http_headers}.
        :param cors: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#cors DataYandexCdnResource#cors}.
        :param custom_host_header: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#custom_host_header DataYandexCdnResource#custom_host_header}.
        :param custom_server_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#custom_server_name DataYandexCdnResource#custom_server_name}.
        :param disable_cache: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#disable_cache DataYandexCdnResource#disable_cache}.
        :param disable_proxy_force_ranges: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#disable_proxy_force_ranges DataYandexCdnResource#disable_proxy_force_ranges}.
        :param edge_cache_settings: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#edge_cache_settings DataYandexCdnResource#edge_cache_settings}.
        :param fetched_compressed: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#fetched_compressed DataYandexCdnResource#fetched_compressed}.
        :param forward_host_header: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#forward_host_header DataYandexCdnResource#forward_host_header}.
        :param gzip_on: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#gzip_on DataYandexCdnResource#gzip_on}.
        :param ignore_cookie: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#ignore_cookie DataYandexCdnResource#ignore_cookie}.
        :param ignore_query_params: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#ignore_query_params DataYandexCdnResource#ignore_query_params}.
        :param proxy_cache_methods_set: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#proxy_cache_methods_set DataYandexCdnResource#proxy_cache_methods_set}.
        :param query_params_blacklist: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#query_params_blacklist DataYandexCdnResource#query_params_blacklist}.
        :param query_params_whitelist: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#query_params_whitelist DataYandexCdnResource#query_params_whitelist}.
        :param redirect_https_to_http: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#redirect_https_to_http DataYandexCdnResource#redirect_https_to_http}.
        :param redirect_http_to_https: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#redirect_http_to_https DataYandexCdnResource#redirect_http_to_https}.
        :param slice: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#slice DataYandexCdnResource#slice}.
        :param static_request_headers: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#static_request_headers DataYandexCdnResource#static_request_headers}.
        :param static_response_headers: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#static_response_headers DataYandexCdnResource#static_response_headers}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if allowed_http_methods is not None:
            self._values["allowed_http_methods"] = allowed_http_methods
        if browser_cache_settings is not None:
            self._values["browser_cache_settings"] = browser_cache_settings
        if cache_http_headers is not None:
            self._values["cache_http_headers"] = cache_http_headers
        if cors is not None:
            self._values["cors"] = cors
        if custom_host_header is not None:
            self._values["custom_host_header"] = custom_host_header
        if custom_server_name is not None:
            self._values["custom_server_name"] = custom_server_name
        if disable_cache is not None:
            self._values["disable_cache"] = disable_cache
        if disable_proxy_force_ranges is not None:
            self._values["disable_proxy_force_ranges"] = disable_proxy_force_ranges
        if edge_cache_settings is not None:
            self._values["edge_cache_settings"] = edge_cache_settings
        if fetched_compressed is not None:
            self._values["fetched_compressed"] = fetched_compressed
        if forward_host_header is not None:
            self._values["forward_host_header"] = forward_host_header
        if gzip_on is not None:
            self._values["gzip_on"] = gzip_on
        if ignore_cookie is not None:
            self._values["ignore_cookie"] = ignore_cookie
        if ignore_query_params is not None:
            self._values["ignore_query_params"] = ignore_query_params
        if proxy_cache_methods_set is not None:
            self._values["proxy_cache_methods_set"] = proxy_cache_methods_set
        if query_params_blacklist is not None:
            self._values["query_params_blacklist"] = query_params_blacklist
        if query_params_whitelist is not None:
            self._values["query_params_whitelist"] = query_params_whitelist
        if redirect_https_to_http is not None:
            self._values["redirect_https_to_http"] = redirect_https_to_http
        if redirect_http_to_https is not None:
            self._values["redirect_http_to_https"] = redirect_http_to_https
        if slice is not None:
            self._values["slice"] = slice
        if static_request_headers is not None:
            self._values["static_request_headers"] = static_request_headers
        if static_response_headers is not None:
            self._values["static_response_headers"] = static_response_headers

    @builtins.property
    def allowed_http_methods(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#allowed_http_methods DataYandexCdnResource#allowed_http_methods}.'''
        result = self._values.get("allowed_http_methods")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def browser_cache_settings(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#browser_cache_settings DataYandexCdnResource#browser_cache_settings}.'''
        result = self._values.get("browser_cache_settings")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def cache_http_headers(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#cache_http_headers DataYandexCdnResource#cache_http_headers}.'''
        result = self._values.get("cache_http_headers")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def cors(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#cors DataYandexCdnResource#cors}.'''
        result = self._values.get("cors")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def custom_host_header(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#custom_host_header DataYandexCdnResource#custom_host_header}.'''
        result = self._values.get("custom_host_header")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def custom_server_name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#custom_server_name DataYandexCdnResource#custom_server_name}.'''
        result = self._values.get("custom_server_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def disable_cache(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#disable_cache DataYandexCdnResource#disable_cache}.'''
        result = self._values.get("disable_cache")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def disable_proxy_force_ranges(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#disable_proxy_force_ranges DataYandexCdnResource#disable_proxy_force_ranges}.'''
        result = self._values.get("disable_proxy_force_ranges")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def edge_cache_settings(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#edge_cache_settings DataYandexCdnResource#edge_cache_settings}.'''
        result = self._values.get("edge_cache_settings")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fetched_compressed(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#fetched_compressed DataYandexCdnResource#fetched_compressed}.'''
        result = self._values.get("fetched_compressed")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def forward_host_header(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#forward_host_header DataYandexCdnResource#forward_host_header}.'''
        result = self._values.get("forward_host_header")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def gzip_on(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#gzip_on DataYandexCdnResource#gzip_on}.'''
        result = self._values.get("gzip_on")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def ignore_cookie(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#ignore_cookie DataYandexCdnResource#ignore_cookie}.'''
        result = self._values.get("ignore_cookie")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def ignore_query_params(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#ignore_query_params DataYandexCdnResource#ignore_query_params}.'''
        result = self._values.get("ignore_query_params")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def proxy_cache_methods_set(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#proxy_cache_methods_set DataYandexCdnResource#proxy_cache_methods_set}.'''
        result = self._values.get("proxy_cache_methods_set")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def query_params_blacklist(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#query_params_blacklist DataYandexCdnResource#query_params_blacklist}.'''
        result = self._values.get("query_params_blacklist")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def query_params_whitelist(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#query_params_whitelist DataYandexCdnResource#query_params_whitelist}.'''
        result = self._values.get("query_params_whitelist")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def redirect_https_to_http(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#redirect_https_to_http DataYandexCdnResource#redirect_https_to_http}.'''
        result = self._values.get("redirect_https_to_http")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def redirect_http_to_https(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#redirect_http_to_https DataYandexCdnResource#redirect_http_to_https}.'''
        result = self._values.get("redirect_http_to_https")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def slice(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#slice DataYandexCdnResource#slice}.'''
        result = self._values.get("slice")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def static_request_headers(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#static_request_headers DataYandexCdnResource#static_request_headers}.'''
        result = self._values.get("static_request_headers")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def static_response_headers(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#static_response_headers DataYandexCdnResource#static_response_headers}.'''
        result = self._values.get("static_response_headers")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexCdnResourceOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexCdnResourceOptionsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexCdnResourceOptionsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAllowedHttpMethods")
    def reset_allowed_http_methods(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAllowedHttpMethods", []))

    @jsii.member(jsii_name="resetBrowserCacheSettings")
    def reset_browser_cache_settings(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetBrowserCacheSettings", []))

    @jsii.member(jsii_name="resetCacheHttpHeaders")
    def reset_cache_http_headers(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCacheHttpHeaders", []))

    @jsii.member(jsii_name="resetCors")
    def reset_cors(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCors", []))

    @jsii.member(jsii_name="resetCustomHostHeader")
    def reset_custom_host_header(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomHostHeader", []))

    @jsii.member(jsii_name="resetCustomServerName")
    def reset_custom_server_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCustomServerName", []))

    @jsii.member(jsii_name="resetDisableCache")
    def reset_disable_cache(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDisableCache", []))

    @jsii.member(jsii_name="resetDisableProxyForceRanges")
    def reset_disable_proxy_force_ranges(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDisableProxyForceRanges", []))

    @jsii.member(jsii_name="resetEdgeCacheSettings")
    def reset_edge_cache_settings(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEdgeCacheSettings", []))

    @jsii.member(jsii_name="resetFetchedCompressed")
    def reset_fetched_compressed(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFetchedCompressed", []))

    @jsii.member(jsii_name="resetForwardHostHeader")
    def reset_forward_host_header(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetForwardHostHeader", []))

    @jsii.member(jsii_name="resetGzipOn")
    def reset_gzip_on(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGzipOn", []))

    @jsii.member(jsii_name="resetIgnoreCookie")
    def reset_ignore_cookie(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIgnoreCookie", []))

    @jsii.member(jsii_name="resetIgnoreQueryParams")
    def reset_ignore_query_params(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIgnoreQueryParams", []))

    @jsii.member(jsii_name="resetProxyCacheMethodsSet")
    def reset_proxy_cache_methods_set(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetProxyCacheMethodsSet", []))

    @jsii.member(jsii_name="resetQueryParamsBlacklist")
    def reset_query_params_blacklist(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQueryParamsBlacklist", []))

    @jsii.member(jsii_name="resetQueryParamsWhitelist")
    def reset_query_params_whitelist(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQueryParamsWhitelist", []))

    @jsii.member(jsii_name="resetRedirectHttpsToHttp")
    def reset_redirect_https_to_http(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRedirectHttpsToHttp", []))

    @jsii.member(jsii_name="resetRedirectHttpToHttps")
    def reset_redirect_http_to_https(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRedirectHttpToHttps", []))

    @jsii.member(jsii_name="resetSlice")
    def reset_slice(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSlice", []))

    @jsii.member(jsii_name="resetStaticRequestHeaders")
    def reset_static_request_headers(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStaticRequestHeaders", []))

    @jsii.member(jsii_name="resetStaticResponseHeaders")
    def reset_static_response_headers(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStaticResponseHeaders", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allowedHttpMethodsInput")
    def allowed_http_methods_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "allowedHttpMethodsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="browserCacheSettingsInput")
    def browser_cache_settings_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "browserCacheSettingsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cacheHttpHeadersInput")
    def cache_http_headers_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "cacheHttpHeadersInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="corsInput")
    def cors_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "corsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="customHostHeaderInput")
    def custom_host_header_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "customHostHeaderInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="customServerNameInput")
    def custom_server_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "customServerNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="disableCacheInput")
    def disable_cache_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "disableCacheInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="disableProxyForceRangesInput")
    def disable_proxy_force_ranges_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "disableProxyForceRangesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="edgeCacheSettingsInput")
    def edge_cache_settings_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "edgeCacheSettingsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fetchedCompressedInput")
    def fetched_compressed_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "fetchedCompressedInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="forwardHostHeaderInput")
    def forward_host_header_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "forwardHostHeaderInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="gzipOnInput")
    def gzip_on_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "gzipOnInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ignoreCookieInput")
    def ignore_cookie_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "ignoreCookieInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ignoreQueryParamsInput")
    def ignore_query_params_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "ignoreQueryParamsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="proxyCacheMethodsSetInput")
    def proxy_cache_methods_set_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "proxyCacheMethodsSetInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queryParamsBlacklistInput")
    def query_params_blacklist_input(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "queryParamsBlacklistInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queryParamsWhitelistInput")
    def query_params_whitelist_input(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "queryParamsWhitelistInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="redirectHttpsToHttpInput")
    def redirect_https_to_http_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "redirectHttpsToHttpInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="redirectHttpToHttpsInput")
    def redirect_http_to_https_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "redirectHttpToHttpsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sliceInput")
    def slice_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "sliceInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="staticRequestHeadersInput")
    def static_request_headers_input(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "staticRequestHeadersInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="staticResponseHeadersInput")
    def static_response_headers_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "staticResponseHeadersInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allowedHttpMethods")
    def allowed_http_methods(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "allowedHttpMethods"))

    @allowed_http_methods.setter
    def allowed_http_methods(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "allowedHttpMethods", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="browserCacheSettings")
    def browser_cache_settings(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "browserCacheSettings"))

    @browser_cache_settings.setter
    def browser_cache_settings(self, value: jsii.Number) -> None:
        jsii.set(self, "browserCacheSettings", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cacheHttpHeaders")
    def cache_http_headers(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "cacheHttpHeaders"))

    @cache_http_headers.setter
    def cache_http_headers(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "cacheHttpHeaders", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cors")
    def cors(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "cors"))

    @cors.setter
    def cors(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "cors", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="customHostHeader")
    def custom_host_header(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "customHostHeader"))

    @custom_host_header.setter
    def custom_host_header(self, value: builtins.str) -> None:
        jsii.set(self, "customHostHeader", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="customServerName")
    def custom_server_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "customServerName"))

    @custom_server_name.setter
    def custom_server_name(self, value: builtins.str) -> None:
        jsii.set(self, "customServerName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="disableCache")
    def disable_cache(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "disableCache"))

    @disable_cache.setter
    def disable_cache(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "disableCache", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="disableProxyForceRanges")
    def disable_proxy_force_ranges(
        self,
    ) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "disableProxyForceRanges"))

    @disable_proxy_force_ranges.setter
    def disable_proxy_force_ranges(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "disableProxyForceRanges", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="edgeCacheSettings")
    def edge_cache_settings(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "edgeCacheSettings"))

    @edge_cache_settings.setter
    def edge_cache_settings(self, value: jsii.Number) -> None:
        jsii.set(self, "edgeCacheSettings", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fetchedCompressed")
    def fetched_compressed(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "fetchedCompressed"))

    @fetched_compressed.setter
    def fetched_compressed(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "fetchedCompressed", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="forwardHostHeader")
    def forward_host_header(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "forwardHostHeader"))

    @forward_host_header.setter
    def forward_host_header(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "forwardHostHeader", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="gzipOn")
    def gzip_on(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "gzipOn"))

    @gzip_on.setter
    def gzip_on(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "gzipOn", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ignoreCookie")
    def ignore_cookie(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "ignoreCookie"))

    @ignore_cookie.setter
    def ignore_cookie(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "ignoreCookie", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ignoreQueryParams")
    def ignore_query_params(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "ignoreQueryParams"))

    @ignore_query_params.setter
    def ignore_query_params(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "ignoreQueryParams", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="proxyCacheMethodsSet")
    def proxy_cache_methods_set(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "proxyCacheMethodsSet"))

    @proxy_cache_methods_set.setter
    def proxy_cache_methods_set(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "proxyCacheMethodsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queryParamsBlacklist")
    def query_params_blacklist(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "queryParamsBlacklist"))

    @query_params_blacklist.setter
    def query_params_blacklist(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "queryParamsBlacklist", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queryParamsWhitelist")
    def query_params_whitelist(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "queryParamsWhitelist"))

    @query_params_whitelist.setter
    def query_params_whitelist(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "queryParamsWhitelist", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="redirectHttpsToHttp")
    def redirect_https_to_http(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "redirectHttpsToHttp"))

    @redirect_https_to_http.setter
    def redirect_https_to_http(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "redirectHttpsToHttp", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="redirectHttpToHttps")
    def redirect_http_to_https(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "redirectHttpToHttps"))

    @redirect_http_to_https.setter
    def redirect_http_to_https(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "redirectHttpToHttps", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="slice")
    def slice(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "slice"))

    @slice.setter
    def slice(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "slice", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="staticRequestHeaders")
    def static_request_headers(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "staticRequestHeaders"))

    @static_request_headers.setter
    def static_request_headers(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "staticRequestHeaders", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="staticResponseHeaders")
    def static_response_headers(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "staticResponseHeaders"))

    @static_response_headers.setter
    def static_response_headers(
        self,
        value: typing.Mapping[builtins.str, builtins.str],
    ) -> None:
        jsii.set(self, "staticResponseHeaders", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexCdnResourceOptions]:
        return typing.cast(typing.Optional[DataYandexCdnResourceOptions], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexCdnResourceOptions],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexCdnResourceSslCertificate",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "certificate_manager_id": "certificateManagerId"},
)
class DataYandexCdnResourceSslCertificate:
    def __init__(
        self,
        *,
        type: builtins.str,
        certificate_manager_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#type DataYandexCdnResource#type}.
        :param certificate_manager_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#certificate_manager_id DataYandexCdnResource#certificate_manager_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }
        if certificate_manager_id is not None:
            self._values["certificate_manager_id"] = certificate_manager_id

    @builtins.property
    def type(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#type DataYandexCdnResource#type}.'''
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def certificate_manager_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/cdn_resource#certificate_manager_id DataYandexCdnResource#certificate_manager_id}.'''
        result = self._values.get("certificate_manager_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexCdnResourceSslCertificate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexCdnResourceSslCertificateOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexCdnResourceSslCertificateOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCertificateManagerId")
    def reset_certificate_manager_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCertificateManagerId", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="certificateManagerIdInput")
    def certificate_manager_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "certificateManagerIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="typeInput")
    def type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "typeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="certificateManagerId")
    def certificate_manager_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "certificateManagerId"))

    @certificate_manager_id.setter
    def certificate_manager_id(self, value: builtins.str) -> None:
        jsii.set(self, "certificateManagerId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @type.setter
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexCdnResourceSslCertificate]:
        return typing.cast(typing.Optional[DataYandexCdnResourceSslCertificate], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexCdnResourceSslCertificate],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexClientConfig(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexClientConfig",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/client_config yandex_client_config}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        id: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/client_config yandex_client_config} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/client_config#id DataYandexClientConfig#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexClientConfigConfig(
            id=id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cloudId")
    def cloud_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "cloudId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="iamToken")
    def iam_token(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "iamToken"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zone")
    def zone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zone"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexClientConfigConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "id": "id",
    },
)
class DataYandexClientConfigConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/client_config#id DataYandexClientConfig#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if id is not None:
            self._values["id"] = id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/client_config#id DataYandexClientConfig#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexClientConfigConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeDisk(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeDisk",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk yandex_compute_disk}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        disk_id: typing.Optional[builtins.str] = None,
        disk_placement_policy: typing.Optional["DataYandexComputeDiskDiskPlacementPolicy"] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk yandex_compute_disk} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param disk_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk#disk_id DataYandexComputeDisk#disk_id}.
        :param disk_placement_policy: disk_placement_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk#disk_placement_policy DataYandexComputeDisk#disk_placement_policy}
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk#folder_id DataYandexComputeDisk#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk#id DataYandexComputeDisk#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk#name DataYandexComputeDisk#name}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexComputeDiskConfig(
            disk_id=disk_id,
            disk_placement_policy=disk_placement_policy,
            folder_id=folder_id,
            id=id,
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putDiskPlacementPolicy")
    def put_disk_placement_policy(
        self,
        *,
        disk_placement_group_id: builtins.str,
    ) -> None:
        '''
        :param disk_placement_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk#disk_placement_group_id DataYandexComputeDisk#disk_placement_group_id}.
        '''
        value = DataYandexComputeDiskDiskPlacementPolicy(
            disk_placement_group_id=disk_placement_group_id
        )

        return typing.cast(None, jsii.invoke(self, "putDiskPlacementPolicy", [value]))

    @jsii.member(jsii_name="resetDiskId")
    def reset_disk_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDiskId", []))

    @jsii.member(jsii_name="resetDiskPlacementPolicy")
    def reset_disk_placement_policy(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDiskPlacementPolicy", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="blockSize")
    def block_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "blockSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskPlacementPolicy")
    def disk_placement_policy(
        self,
    ) -> "DataYandexComputeDiskDiskPlacementPolicyOutputReference":
        return typing.cast("DataYandexComputeDiskDiskPlacementPolicyOutputReference", jsii.get(self, "diskPlacementPolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="imageId")
    def image_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "imageId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="instanceIds")
    def instance_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "instanceIds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="productIds")
    def product_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "productIds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="size")
    def size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "size"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="snapshotId")
    def snapshot_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "snapshotId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zone")
    def zone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zone"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskIdInput")
    def disk_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "diskIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskPlacementPolicyInput")
    def disk_placement_policy_input(
        self,
    ) -> typing.Optional["DataYandexComputeDiskDiskPlacementPolicy"]:
        return typing.cast(typing.Optional["DataYandexComputeDiskDiskPlacementPolicy"], jsii.get(self, "diskPlacementPolicyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskId")
    def disk_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskId"))

    @disk_id.setter
    def disk_id(self, value: builtins.str) -> None:
        jsii.set(self, "diskId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeDiskConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "disk_id": "diskId",
        "disk_placement_policy": "diskPlacementPolicy",
        "folder_id": "folderId",
        "id": "id",
        "name": "name",
    },
)
class DataYandexComputeDiskConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        disk_id: typing.Optional[builtins.str] = None,
        disk_placement_policy: typing.Optional["DataYandexComputeDiskDiskPlacementPolicy"] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param disk_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk#disk_id DataYandexComputeDisk#disk_id}.
        :param disk_placement_policy: disk_placement_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk#disk_placement_policy DataYandexComputeDisk#disk_placement_policy}
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk#folder_id DataYandexComputeDisk#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk#id DataYandexComputeDisk#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk#name DataYandexComputeDisk#name}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(disk_placement_policy, dict):
            disk_placement_policy = DataYandexComputeDiskDiskPlacementPolicy(**disk_placement_policy)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if disk_id is not None:
            self._values["disk_id"] = disk_id
        if disk_placement_policy is not None:
            self._values["disk_placement_policy"] = disk_placement_policy
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def disk_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk#disk_id DataYandexComputeDisk#disk_id}.'''
        result = self._values.get("disk_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def disk_placement_policy(
        self,
    ) -> typing.Optional["DataYandexComputeDiskDiskPlacementPolicy"]:
        '''disk_placement_policy block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk#disk_placement_policy DataYandexComputeDisk#disk_placement_policy}
        '''
        result = self._values.get("disk_placement_policy")
        return typing.cast(typing.Optional["DataYandexComputeDiskDiskPlacementPolicy"], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk#folder_id DataYandexComputeDisk#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk#id DataYandexComputeDisk#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk#name DataYandexComputeDisk#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeDiskConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeDiskDiskPlacementPolicy",
    jsii_struct_bases=[],
    name_mapping={"disk_placement_group_id": "diskPlacementGroupId"},
)
class DataYandexComputeDiskDiskPlacementPolicy:
    def __init__(self, *, disk_placement_group_id: builtins.str) -> None:
        '''
        :param disk_placement_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk#disk_placement_group_id DataYandexComputeDisk#disk_placement_group_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "disk_placement_group_id": disk_placement_group_id,
        }

    @builtins.property
    def disk_placement_group_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk#disk_placement_group_id DataYandexComputeDisk#disk_placement_group_id}.'''
        result = self._values.get("disk_placement_group_id")
        assert result is not None, "Required property 'disk_placement_group_id' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeDiskDiskPlacementPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeDiskDiskPlacementPolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeDiskDiskPlacementPolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskPlacementGroupIdInput")
    def disk_placement_group_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "diskPlacementGroupIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskPlacementGroupId")
    def disk_placement_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskPlacementGroupId"))

    @disk_placement_group_id.setter
    def disk_placement_group_id(self, value: builtins.str) -> None:
        jsii.set(self, "diskPlacementGroupId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeDiskDiskPlacementPolicy]:
        return typing.cast(typing.Optional[DataYandexComputeDiskDiskPlacementPolicy], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeDiskDiskPlacementPolicy],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexComputeDiskPlacementGroup(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeDiskPlacementGroup",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk_placement_group yandex_compute_disk_placement_group}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        group_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        zone: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk_placement_group yandex_compute_disk_placement_group} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk_placement_group#description DataYandexComputeDiskPlacementGroup#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk_placement_group#folder_id DataYandexComputeDiskPlacementGroup#folder_id}.
        :param group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk_placement_group#group_id DataYandexComputeDiskPlacementGroup#group_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk_placement_group#id DataYandexComputeDiskPlacementGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk_placement_group#labels DataYandexComputeDiskPlacementGroup#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk_placement_group#name DataYandexComputeDiskPlacementGroup#name}.
        :param zone: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk_placement_group#zone DataYandexComputeDiskPlacementGroup#zone}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexComputeDiskPlacementGroupConfig(
            description=description,
            folder_id=folder_id,
            group_id=group_id,
            id=id,
            labels=labels,
            name=name,
            zone=zone,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetGroupId")
    def reset_group_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetZone")
    def reset_zone(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetZone", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="groupIdInput")
    def group_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "groupIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneInput")
    def zone_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "zoneInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="groupId")
    def group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "groupId"))

    @group_id.setter
    def group_id(self, value: builtins.str) -> None:
        jsii.set(self, "groupId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zone")
    def zone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zone"))

    @zone.setter
    def zone(self, value: builtins.str) -> None:
        jsii.set(self, "zone", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeDiskPlacementGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "description": "description",
        "folder_id": "folderId",
        "group_id": "groupId",
        "id": "id",
        "labels": "labels",
        "name": "name",
        "zone": "zone",
    },
)
class DataYandexComputeDiskPlacementGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        group_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        zone: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk_placement_group#description DataYandexComputeDiskPlacementGroup#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk_placement_group#folder_id DataYandexComputeDiskPlacementGroup#folder_id}.
        :param group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk_placement_group#group_id DataYandexComputeDiskPlacementGroup#group_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk_placement_group#id DataYandexComputeDiskPlacementGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk_placement_group#labels DataYandexComputeDiskPlacementGroup#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk_placement_group#name DataYandexComputeDiskPlacementGroup#name}.
        :param zone: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk_placement_group#zone DataYandexComputeDiskPlacementGroup#zone}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if group_id is not None:
            self._values["group_id"] = group_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if name is not None:
            self._values["name"] = name
        if zone is not None:
            self._values["zone"] = zone

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk_placement_group#description DataYandexComputeDiskPlacementGroup#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk_placement_group#folder_id DataYandexComputeDiskPlacementGroup#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def group_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk_placement_group#group_id DataYandexComputeDiskPlacementGroup#group_id}.'''
        result = self._values.get("group_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk_placement_group#id DataYandexComputeDiskPlacementGroup#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk_placement_group#labels DataYandexComputeDiskPlacementGroup#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk_placement_group#name DataYandexComputeDiskPlacementGroup#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def zone(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_disk_placement_group#zone DataYandexComputeDiskPlacementGroup#zone}.'''
        result = self._values.get("zone")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeDiskPlacementGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeImage(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeImage",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/compute_image yandex_compute_image}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        family: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        image_id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/compute_image yandex_compute_image} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param family: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_image#family DataYandexComputeImage#family}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_image#folder_id DataYandexComputeImage#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_image#id DataYandexComputeImage#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param image_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_image#image_id DataYandexComputeImage#image_id}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_image#name DataYandexComputeImage#name}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexComputeImageConfig(
            family=family,
            folder_id=folder_id,
            id=id,
            image_id=image_id,
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetFamily")
    def reset_family(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFamily", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetImageId")
    def reset_image_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetImageId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minDiskSize")
    def min_disk_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minDiskSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="osType")
    def os_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "osType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="pooled")
    def pooled(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "pooled"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="productIds")
    def product_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "productIds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="size")
    def size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "size"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="familyInput")
    def family_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "familyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="imageIdInput")
    def image_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "imageIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="family")
    def family(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "family"))

    @family.setter
    def family(self, value: builtins.str) -> None:
        jsii.set(self, "family", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="imageId")
    def image_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "imageId"))

    @image_id.setter
    def image_id(self, value: builtins.str) -> None:
        jsii.set(self, "imageId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeImageConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "family": "family",
        "folder_id": "folderId",
        "id": "id",
        "image_id": "imageId",
        "name": "name",
    },
)
class DataYandexComputeImageConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        family: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        image_id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param family: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_image#family DataYandexComputeImage#family}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_image#folder_id DataYandexComputeImage#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_image#id DataYandexComputeImage#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param image_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_image#image_id DataYandexComputeImage#image_id}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_image#name DataYandexComputeImage#name}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if family is not None:
            self._values["family"] = family
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if image_id is not None:
            self._values["image_id"] = image_id
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def family(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_image#family DataYandexComputeImage#family}.'''
        result = self._values.get("family")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_image#folder_id DataYandexComputeImage#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_image#id DataYandexComputeImage#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def image_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_image#image_id DataYandexComputeImage#image_id}.'''
        result = self._values.get("image_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_image#name DataYandexComputeImage#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeImageConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeInstance(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstance",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance yandex_compute_instance}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        instance_id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        placement_policy: typing.Optional["DataYandexComputeInstancePlacementPolicy"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance yandex_compute_instance} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance#folder_id DataYandexComputeInstance#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance#id DataYandexComputeInstance#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param instance_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance#instance_id DataYandexComputeInstance#instance_id}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance#name DataYandexComputeInstance#name}.
        :param placement_policy: placement_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance#placement_policy DataYandexComputeInstance#placement_policy}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexComputeInstanceConfig(
            folder_id=folder_id,
            id=id,
            instance_id=instance_id,
            name=name,
            placement_policy=placement_policy,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putPlacementPolicy")
    def put_placement_policy(
        self,
        *,
        host_affinity_rules: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["DataYandexComputeInstancePlacementPolicyHostAffinityRules"]]] = None,
        placement_group_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param host_affinity_rules: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance#host_affinity_rules DataYandexComputeInstance#host_affinity_rules}.
        :param placement_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance#placement_group_id DataYandexComputeInstance#placement_group_id}.
        '''
        value = DataYandexComputeInstancePlacementPolicy(
            host_affinity_rules=host_affinity_rules,
            placement_group_id=placement_group_id,
        )

        return typing.cast(None, jsii.invoke(self, "putPlacementPolicy", [value]))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetInstanceId")
    def reset_instance_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInstanceId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetPlacementPolicy")
    def reset_placement_policy(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPlacementPolicy", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bootDisk")
    def boot_disk(self) -> "DataYandexComputeInstanceBootDiskList":
        return typing.cast("DataYandexComputeInstanceBootDiskList", jsii.get(self, "bootDisk"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fqdn"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metadata")
    def metadata(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "metadata"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkAccelerationType")
    def network_acceleration_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkAccelerationType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkInterface")
    def network_interface(self) -> "DataYandexComputeInstanceNetworkInterfaceList":
        return typing.cast("DataYandexComputeInstanceNetworkInterfaceList", jsii.get(self, "networkInterface"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="placementPolicy")
    def placement_policy(
        self,
    ) -> "DataYandexComputeInstancePlacementPolicyOutputReference":
        return typing.cast("DataYandexComputeInstancePlacementPolicyOutputReference", jsii.get(self, "placementPolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="platformId")
    def platform_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "platformId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resources")
    def resources(self) -> "DataYandexComputeInstanceResourcesList":
        return typing.cast("DataYandexComputeInstanceResourcesList", jsii.get(self, "resources"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="schedulingPolicy")
    def scheduling_policy(self) -> "DataYandexComputeInstanceSchedulingPolicyList":
        return typing.cast("DataYandexComputeInstanceSchedulingPolicyList", jsii.get(self, "schedulingPolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="secondaryDisk")
    def secondary_disk(self) -> "DataYandexComputeInstanceSecondaryDiskList":
        return typing.cast("DataYandexComputeInstanceSecondaryDiskList", jsii.get(self, "secondaryDisk"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountId")
    def service_account_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceAccountId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zone")
    def zone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zone"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="instanceIdInput")
    def instance_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "instanceIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="placementPolicyInput")
    def placement_policy_input(
        self,
    ) -> typing.Optional["DataYandexComputeInstancePlacementPolicy"]:
        return typing.cast(typing.Optional["DataYandexComputeInstancePlacementPolicy"], jsii.get(self, "placementPolicyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="instanceId")
    def instance_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "instanceId"))

    @instance_id.setter
    def instance_id(self, value: builtins.str) -> None:
        jsii.set(self, "instanceId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceBootDisk",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceBootDisk:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceBootDisk(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceBootDiskInitializeParams",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceBootDiskInitializeParams:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceBootDiskInitializeParams(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeInstanceBootDiskInitializeParamsList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceBootDiskInitializeParamsList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceBootDiskInitializeParamsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceBootDiskInitializeParamsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceBootDiskInitializeParamsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceBootDiskInitializeParamsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="blockSize")
    def block_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "blockSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="imageId")
    def image_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "imageId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="size")
    def size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "size"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="snapshotId")
    def snapshot_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "snapshotId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceBootDiskInitializeParams]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceBootDiskInitializeParams], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceBootDiskInitializeParams],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexComputeInstanceBootDiskList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceBootDiskList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceBootDiskOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceBootDiskOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceBootDiskOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceBootDiskOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoDelete")
    def auto_delete(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "autoDelete"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deviceName")
    def device_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "deviceName"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskId")
    def disk_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="initializeParams")
    def initialize_params(
        self,
    ) -> DataYandexComputeInstanceBootDiskInitializeParamsList:
        return typing.cast(DataYandexComputeInstanceBootDiskInitializeParamsList, jsii.get(self, "initializeParams"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mode")
    def mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "mode"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexComputeInstanceBootDisk]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceBootDisk], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceBootDisk],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "folder_id": "folderId",
        "id": "id",
        "instance_id": "instanceId",
        "name": "name",
        "placement_policy": "placementPolicy",
    },
)
class DataYandexComputeInstanceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        instance_id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        placement_policy: typing.Optional["DataYandexComputeInstancePlacementPolicy"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance#folder_id DataYandexComputeInstance#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance#id DataYandexComputeInstance#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param instance_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance#instance_id DataYandexComputeInstance#instance_id}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance#name DataYandexComputeInstance#name}.
        :param placement_policy: placement_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance#placement_policy DataYandexComputeInstance#placement_policy}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(placement_policy, dict):
            placement_policy = DataYandexComputeInstancePlacementPolicy(**placement_policy)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if instance_id is not None:
            self._values["instance_id"] = instance_id
        if name is not None:
            self._values["name"] = name
        if placement_policy is not None:
            self._values["placement_policy"] = placement_policy

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance#folder_id DataYandexComputeInstance#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance#id DataYandexComputeInstance#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def instance_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance#instance_id DataYandexComputeInstance#instance_id}.'''
        result = self._values.get("instance_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance#name DataYandexComputeInstance#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def placement_policy(
        self,
    ) -> typing.Optional["DataYandexComputeInstancePlacementPolicy"]:
        '''placement_policy block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance#placement_policy DataYandexComputeInstance#placement_policy}
        '''
        result = self._values.get("placement_policy")
        return typing.cast(typing.Optional["DataYandexComputeInstancePlacementPolicy"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeInstanceGroup(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroup",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance_group yandex_compute_instance_group}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        instance_group_id: builtins.str,
        id: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance_group yandex_compute_instance_group} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param instance_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance_group#instance_group_id DataYandexComputeInstanceGroup#instance_group_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance_group#id DataYandexComputeInstanceGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexComputeInstanceGroupConfig(
            instance_group_id=instance_group_id,
            id=id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allocationPolicy")
    def allocation_policy(self) -> "DataYandexComputeInstanceGroupAllocationPolicyList":
        return typing.cast("DataYandexComputeInstanceGroupAllocationPolicyList", jsii.get(self, "allocationPolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="applicationBalancerState")
    def application_balancer_state(
        self,
    ) -> "DataYandexComputeInstanceGroupApplicationBalancerStateList":
        return typing.cast("DataYandexComputeInstanceGroupApplicationBalancerStateList", jsii.get(self, "applicationBalancerState"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="applicationLoadBalancer")
    def application_load_balancer(
        self,
    ) -> "DataYandexComputeInstanceGroupApplicationLoadBalancerList":
        return typing.cast("DataYandexComputeInstanceGroupApplicationLoadBalancerList", jsii.get(self, "applicationLoadBalancer"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtection")
    def deletion_protection(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "deletionProtection"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deployPolicy")
    def deploy_policy(self) -> "DataYandexComputeInstanceGroupDeployPolicyList":
        return typing.cast("DataYandexComputeInstanceGroupDeployPolicyList", jsii.get(self, "deployPolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthCheck")
    def health_check(self) -> "DataYandexComputeInstanceGroupHealthCheckList":
        return typing.cast("DataYandexComputeInstanceGroupHealthCheckList", jsii.get(self, "healthCheck"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="instances")
    def instances(self) -> "DataYandexComputeInstanceGroupInstancesList":
        return typing.cast("DataYandexComputeInstanceGroupInstancesList", jsii.get(self, "instances"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="instanceTemplate")
    def instance_template(self) -> "DataYandexComputeInstanceGroupInstanceTemplateList":
        return typing.cast("DataYandexComputeInstanceGroupInstanceTemplateList", jsii.get(self, "instanceTemplate"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="loadBalancer")
    def load_balancer(self) -> "DataYandexComputeInstanceGroupLoadBalancerList":
        return typing.cast("DataYandexComputeInstanceGroupLoadBalancerList", jsii.get(self, "loadBalancer"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="loadBalancerState")
    def load_balancer_state(
        self,
    ) -> "DataYandexComputeInstanceGroupLoadBalancerStateList":
        return typing.cast("DataYandexComputeInstanceGroupLoadBalancerStateList", jsii.get(self, "loadBalancerState"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxCheckingHealthDuration")
    def max_checking_health_duration(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxCheckingHealthDuration"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="scalePolicy")
    def scale_policy(self) -> "DataYandexComputeInstanceGroupScalePolicyList":
        return typing.cast("DataYandexComputeInstanceGroupScalePolicyList", jsii.get(self, "scalePolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountId")
    def service_account_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceAccountId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="variables")
    def variables(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "variables"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="instanceGroupIdInput")
    def instance_group_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "instanceGroupIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="instanceGroupId")
    def instance_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "instanceGroupId"))

    @instance_group_id.setter
    def instance_group_id(self, value: builtins.str) -> None:
        jsii.set(self, "instanceGroupId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupAllocationPolicy",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceGroupAllocationPolicy:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceGroupAllocationPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeInstanceGroupAllocationPolicyList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupAllocationPolicyList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceGroupAllocationPolicyOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceGroupAllocationPolicyOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceGroupAllocationPolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupAllocationPolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zones")
    def zones(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "zones"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceGroupAllocationPolicy]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceGroupAllocationPolicy], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceGroupAllocationPolicy],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupApplicationBalancerState",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceGroupApplicationBalancerState:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceGroupApplicationBalancerState(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeInstanceGroupApplicationBalancerStateList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupApplicationBalancerStateList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceGroupApplicationBalancerStateOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceGroupApplicationBalancerStateOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceGroupApplicationBalancerStateOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupApplicationBalancerStateOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="statusMessage")
    def status_message(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "statusMessage"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupId")
    def target_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "targetGroupId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceGroupApplicationBalancerState]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceGroupApplicationBalancerState], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceGroupApplicationBalancerState],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupApplicationLoadBalancer",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceGroupApplicationLoadBalancer:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceGroupApplicationLoadBalancer(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeInstanceGroupApplicationLoadBalancerList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupApplicationLoadBalancerList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceGroupApplicationLoadBalancerOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceGroupApplicationLoadBalancerOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceGroupApplicationLoadBalancerOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupApplicationLoadBalancerOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxOpeningTrafficDuration")
    def max_opening_traffic_duration(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxOpeningTrafficDuration"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="statusMessage")
    def status_message(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "statusMessage"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupDescription")
    def target_group_description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "targetGroupDescription"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupId")
    def target_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "targetGroupId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupLabels")
    def target_group_labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "targetGroupLabels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupName")
    def target_group_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "targetGroupName"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceGroupApplicationLoadBalancer]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceGroupApplicationLoadBalancer], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceGroupApplicationLoadBalancer],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "instance_group_id": "instanceGroupId",
        "id": "id",
    },
)
class DataYandexComputeInstanceGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        instance_group_id: builtins.str,
        id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param instance_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance_group#instance_group_id DataYandexComputeInstanceGroup#instance_group_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance_group#id DataYandexComputeInstanceGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {
            "instance_group_id": instance_group_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if id is not None:
            self._values["id"] = id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def instance_group_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance_group#instance_group_id DataYandexComputeInstanceGroup#instance_group_id}.'''
        result = self._values.get("instance_group_id")
        assert result is not None, "Required property 'instance_group_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance_group#id DataYandexComputeInstanceGroup#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupDeployPolicy",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceGroupDeployPolicy:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceGroupDeployPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeInstanceGroupDeployPolicyList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupDeployPolicyList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceGroupDeployPolicyOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceGroupDeployPolicyOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceGroupDeployPolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupDeployPolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxCreating")
    def max_creating(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxCreating"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxDeleting")
    def max_deleting(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxDeleting"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxExpansion")
    def max_expansion(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxExpansion"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxUnavailable")
    def max_unavailable(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxUnavailable"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="startupDuration")
    def startup_duration(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "startupDuration"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="strategy")
    def strategy(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "strategy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceGroupDeployPolicy]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceGroupDeployPolicy], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceGroupDeployPolicy],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupHealthCheck",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceGroupHealthCheck:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceGroupHealthCheck(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupHealthCheckHttpOptions",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceGroupHealthCheckHttpOptions:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceGroupHealthCheckHttpOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeInstanceGroupHealthCheckHttpOptionsList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupHealthCheckHttpOptionsList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceGroupHealthCheckHttpOptionsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceGroupHealthCheckHttpOptionsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceGroupHealthCheckHttpOptionsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupHealthCheckHttpOptionsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="path")
    def path(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "path"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "port"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceGroupHealthCheckHttpOptions]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceGroupHealthCheckHttpOptions], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceGroupHealthCheckHttpOptions],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexComputeInstanceGroupHealthCheckList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupHealthCheckList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceGroupHealthCheckOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceGroupHealthCheckOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceGroupHealthCheckOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupHealthCheckOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthyThreshold")
    def healthy_threshold(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "healthyThreshold"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpOptions")
    def http_options(self) -> DataYandexComputeInstanceGroupHealthCheckHttpOptionsList:
        return typing.cast(DataYandexComputeInstanceGroupHealthCheckHttpOptionsList, jsii.get(self, "httpOptions"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tcpOptions")
    def tcp_options(self) -> "DataYandexComputeInstanceGroupHealthCheckTcpOptionsList":
        return typing.cast("DataYandexComputeInstanceGroupHealthCheckTcpOptionsList", jsii.get(self, "tcpOptions"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeout")
    def timeout(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "timeout"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="unhealthyThreshold")
    def unhealthy_threshold(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "unhealthyThreshold"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceGroupHealthCheck]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceGroupHealthCheck], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceGroupHealthCheck],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupHealthCheckTcpOptions",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceGroupHealthCheckTcpOptions:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceGroupHealthCheckTcpOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeInstanceGroupHealthCheckTcpOptionsList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupHealthCheckTcpOptionsList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceGroupHealthCheckTcpOptionsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceGroupHealthCheckTcpOptionsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceGroupHealthCheckTcpOptionsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupHealthCheckTcpOptionsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "port"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceGroupHealthCheckTcpOptions]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceGroupHealthCheckTcpOptions], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceGroupHealthCheckTcpOptions],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplate",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceGroupInstanceTemplate:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceGroupInstanceTemplate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateBootDisk",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceGroupInstanceTemplateBootDisk:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceGroupInstanceTemplateBootDisk(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateBootDiskInitializeParams",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceGroupInstanceTemplateBootDiskInitializeParams:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceGroupInstanceTemplateBootDiskInitializeParams(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeInstanceGroupInstanceTemplateBootDiskInitializeParamsList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateBootDiskInitializeParamsList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceGroupInstanceTemplateBootDiskInitializeParamsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceGroupInstanceTemplateBootDiskInitializeParamsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceGroupInstanceTemplateBootDiskInitializeParamsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateBootDiskInitializeParamsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="imageId")
    def image_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "imageId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="size")
    def size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "size"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="snapshotId")
    def snapshot_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "snapshotId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceGroupInstanceTemplateBootDiskInitializeParams]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceGroupInstanceTemplateBootDiskInitializeParams], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceGroupInstanceTemplateBootDiskInitializeParams],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexComputeInstanceGroupInstanceTemplateBootDiskList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateBootDiskList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceGroupInstanceTemplateBootDiskOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceGroupInstanceTemplateBootDiskOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceGroupInstanceTemplateBootDiskOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateBootDiskOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deviceName")
    def device_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "deviceName"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskId")
    def disk_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="initializeParams")
    def initialize_params(
        self,
    ) -> DataYandexComputeInstanceGroupInstanceTemplateBootDiskInitializeParamsList:
        return typing.cast(DataYandexComputeInstanceGroupInstanceTemplateBootDiskInitializeParamsList, jsii.get(self, "initializeParams"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mode")
    def mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "mode"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceGroupInstanceTemplateBootDisk]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceGroupInstanceTemplateBootDisk], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceGroupInstanceTemplateBootDisk],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexComputeInstanceGroupInstanceTemplateList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceGroupInstanceTemplateOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceGroupInstanceTemplateOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateNetworkInterface",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceGroupInstanceTemplateNetworkInterface:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceGroupInstanceTemplateNetworkInterface(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecord",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecord:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecord(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecordList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecordList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecordOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecordOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecordOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecordOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dnsZoneId")
    def dns_zone_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dnsZoneId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fqdn"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ptr")
    def ptr(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "ptr"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ttl")
    def ttl(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "ttl"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecord]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecord], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecord],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecord",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecord:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecord(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecordList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecordList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecordOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecordOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecordOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecordOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dnsZoneId")
    def dns_zone_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dnsZoneId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fqdn"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ptr")
    def ptr(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "ptr"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ttl")
    def ttl(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "ttl"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecord]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecord], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecord],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecord",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecord:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecord(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecordList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecordList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecordOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecordOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecordOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecordOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dnsZoneId")
    def dns_zone_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dnsZoneId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fqdn"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ptr")
    def ptr(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "ptr"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ttl")
    def ttl(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "ttl"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecord]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecord], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecord],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dnsRecord")
    def dns_record(
        self,
    ) -> DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecordList:
        return typing.cast(DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecordList, jsii.get(self, "dnsRecord"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipAddress")
    def ip_address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ipAddress"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv4")
    def ipv4(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "ipv4"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv6")
    def ipv6(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "ipv6"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv6Address")
    def ipv6_address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ipv6Address"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv6DnsRecord")
    def ipv6_dns_record(
        self,
    ) -> DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecordList:
        return typing.cast(DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecordList, jsii.get(self, "ipv6DnsRecord"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nat")
    def nat(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "nat"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="natDnsRecord")
    def nat_dns_record(
        self,
    ) -> DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecordList:
        return typing.cast(DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecordList, jsii.get(self, "natDnsRecord"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="natIpAddress")
    def nat_ip_address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "natIpAddress"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "securityGroupIds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "subnetIds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceGroupInstanceTemplateNetworkInterface]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceGroupInstanceTemplateNetworkInterface], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceGroupInstanceTemplateNetworkInterface],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateNetworkSettings",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceGroupInstanceTemplateNetworkSettings:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceGroupInstanceTemplateNetworkSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeInstanceGroupInstanceTemplateNetworkSettingsList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateNetworkSettingsList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceGroupInstanceTemplateNetworkSettingsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceGroupInstanceTemplateNetworkSettingsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceGroupInstanceTemplateNetworkSettingsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateNetworkSettingsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceGroupInstanceTemplateNetworkSettings]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceGroupInstanceTemplateNetworkSettings], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceGroupInstanceTemplateNetworkSettings],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexComputeInstanceGroupInstanceTemplateOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bootDisk")
    def boot_disk(self) -> DataYandexComputeInstanceGroupInstanceTemplateBootDiskList:
        return typing.cast(DataYandexComputeInstanceGroupInstanceTemplateBootDiskList, jsii.get(self, "bootDisk"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostname")
    def hostname(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "hostname"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metadata")
    def metadata(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "metadata"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkInterface")
    def network_interface(
        self,
    ) -> DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceList:
        return typing.cast(DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceList, jsii.get(self, "networkInterface"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkSettings")
    def network_settings(
        self,
    ) -> DataYandexComputeInstanceGroupInstanceTemplateNetworkSettingsList:
        return typing.cast(DataYandexComputeInstanceGroupInstanceTemplateNetworkSettingsList, jsii.get(self, "networkSettings"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="placementPolicy")
    def placement_policy(
        self,
    ) -> "DataYandexComputeInstanceGroupInstanceTemplatePlacementPolicyList":
        return typing.cast("DataYandexComputeInstanceGroupInstanceTemplatePlacementPolicyList", jsii.get(self, "placementPolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="platformId")
    def platform_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "platformId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resources")
    def resources(
        self,
    ) -> "DataYandexComputeInstanceGroupInstanceTemplateResourcesList":
        return typing.cast("DataYandexComputeInstanceGroupInstanceTemplateResourcesList", jsii.get(self, "resources"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="schedulingPolicy")
    def scheduling_policy(
        self,
    ) -> "DataYandexComputeInstanceGroupInstanceTemplateSchedulingPolicyList":
        return typing.cast("DataYandexComputeInstanceGroupInstanceTemplateSchedulingPolicyList", jsii.get(self, "schedulingPolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="secondaryDisk")
    def secondary_disk(
        self,
    ) -> "DataYandexComputeInstanceGroupInstanceTemplateSecondaryDiskList":
        return typing.cast("DataYandexComputeInstanceGroupInstanceTemplateSecondaryDiskList", jsii.get(self, "secondaryDisk"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountId")
    def service_account_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceAccountId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceGroupInstanceTemplate]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceGroupInstanceTemplate], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceGroupInstanceTemplate],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplatePlacementPolicy",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceGroupInstanceTemplatePlacementPolicy:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceGroupInstanceTemplatePlacementPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeInstanceGroupInstanceTemplatePlacementPolicyList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplatePlacementPolicyList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceGroupInstanceTemplatePlacementPolicyOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceGroupInstanceTemplatePlacementPolicyOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceGroupInstanceTemplatePlacementPolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplatePlacementPolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="placementGroupId")
    def placement_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "placementGroupId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceGroupInstanceTemplatePlacementPolicy]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceGroupInstanceTemplatePlacementPolicy], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceGroupInstanceTemplatePlacementPolicy],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateResources",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceGroupInstanceTemplateResources:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceGroupInstanceTemplateResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeInstanceGroupInstanceTemplateResourcesList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateResourcesList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceGroupInstanceTemplateResourcesOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceGroupInstanceTemplateResourcesOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceGroupInstanceTemplateResourcesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateResourcesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="coreFraction")
    def core_fraction(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "coreFraction"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cores")
    def cores(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "cores"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="gpus")
    def gpus(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "gpus"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="memory")
    def memory(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "memory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceGroupInstanceTemplateResources]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceGroupInstanceTemplateResources], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceGroupInstanceTemplateResources],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateSchedulingPolicy",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceGroupInstanceTemplateSchedulingPolicy:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceGroupInstanceTemplateSchedulingPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeInstanceGroupInstanceTemplateSchedulingPolicyList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateSchedulingPolicyList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceGroupInstanceTemplateSchedulingPolicyOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceGroupInstanceTemplateSchedulingPolicyOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceGroupInstanceTemplateSchedulingPolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateSchedulingPolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="preemptible")
    def preemptible(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "preemptible"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceGroupInstanceTemplateSchedulingPolicy]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceGroupInstanceTemplateSchedulingPolicy], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceGroupInstanceTemplateSchedulingPolicy],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateSecondaryDisk",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceGroupInstanceTemplateSecondaryDisk:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceGroupInstanceTemplateSecondaryDisk(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParams",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParams:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParams(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParamsList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParamsList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParamsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParamsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParamsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParamsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="imageId")
    def image_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "imageId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="size")
    def size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "size"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="snapshotId")
    def snapshot_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "snapshotId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParams]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParams], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParams],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexComputeInstanceGroupInstanceTemplateSecondaryDiskList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateSecondaryDiskList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceGroupInstanceTemplateSecondaryDiskOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceGroupInstanceTemplateSecondaryDiskOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceGroupInstanceTemplateSecondaryDiskOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstanceTemplateSecondaryDiskOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deviceName")
    def device_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "deviceName"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskId")
    def disk_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="initializeParams")
    def initialize_params(
        self,
    ) -> DataYandexComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParamsList:
        return typing.cast(DataYandexComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParamsList, jsii.get(self, "initializeParams"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mode")
    def mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "mode"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceGroupInstanceTemplateSecondaryDisk]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceGroupInstanceTemplateSecondaryDisk], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceGroupInstanceTemplateSecondaryDisk],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstances",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceGroupInstances:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceGroupInstances(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeInstanceGroupInstancesList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstancesList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceGroupInstancesOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceGroupInstancesOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstancesNetworkInterface",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceGroupInstancesNetworkInterface:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceGroupInstancesNetworkInterface(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeInstanceGroupInstancesNetworkInterfaceList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstancesNetworkInterfaceList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceGroupInstancesNetworkInterfaceOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceGroupInstancesNetworkInterfaceOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceGroupInstancesNetworkInterfaceOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstancesNetworkInterfaceOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="index")
    def index(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "index"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipAddress")
    def ip_address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ipAddress"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv4")
    def ipv4(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "ipv4"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv6")
    def ipv6(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "ipv6"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv6Address")
    def ipv6_address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ipv6Address"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="macAddress")
    def mac_address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "macAddress"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nat")
    def nat(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "nat"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="natIpAddress")
    def nat_ip_address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "natIpAddress"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="natIpVersion")
    def nat_ip_version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "natIpVersion"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceGroupInstancesNetworkInterface]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceGroupInstancesNetworkInterface], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceGroupInstancesNetworkInterface],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexComputeInstanceGroupInstancesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupInstancesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fqdn"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="instanceId")
    def instance_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "instanceId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkInterface")
    def network_interface(
        self,
    ) -> DataYandexComputeInstanceGroupInstancesNetworkInterfaceList:
        return typing.cast(DataYandexComputeInstanceGroupInstancesNetworkInterfaceList, jsii.get(self, "networkInterface"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="statusChangedAt")
    def status_changed_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "statusChangedAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="statusMessage")
    def status_message(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "statusMessage"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneId")
    def zone_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zoneId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceGroupInstances]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceGroupInstances], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceGroupInstances],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupLoadBalancer",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceGroupLoadBalancer:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceGroupLoadBalancer(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeInstanceGroupLoadBalancerList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupLoadBalancerList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceGroupLoadBalancerOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceGroupLoadBalancerOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceGroupLoadBalancerOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupLoadBalancerOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxOpeningTrafficDuration")
    def max_opening_traffic_duration(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxOpeningTrafficDuration"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="statusMessage")
    def status_message(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "statusMessage"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupDescription")
    def target_group_description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "targetGroupDescription"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupId")
    def target_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "targetGroupId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupLabels")
    def target_group_labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "targetGroupLabels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupName")
    def target_group_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "targetGroupName"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceGroupLoadBalancer]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceGroupLoadBalancer], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceGroupLoadBalancer],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupLoadBalancerState",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceGroupLoadBalancerState:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceGroupLoadBalancerState(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeInstanceGroupLoadBalancerStateList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupLoadBalancerStateList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceGroupLoadBalancerStateOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceGroupLoadBalancerStateOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceGroupLoadBalancerStateOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupLoadBalancerStateOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="statusMessage")
    def status_message(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "statusMessage"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupId")
    def target_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "targetGroupId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceGroupLoadBalancerState]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceGroupLoadBalancerState], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceGroupLoadBalancerState],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupScalePolicy",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceGroupScalePolicy:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceGroupScalePolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupScalePolicyAutoScale",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceGroupScalePolicyAutoScale:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceGroupScalePolicyAutoScale(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupScalePolicyAutoScaleCustomRule",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceGroupScalePolicyAutoScaleCustomRule:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceGroupScalePolicyAutoScaleCustomRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeInstanceGroupScalePolicyAutoScaleCustomRuleList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupScalePolicyAutoScaleCustomRuleList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceGroupScalePolicyAutoScaleCustomRuleOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceGroupScalePolicyAutoScaleCustomRuleOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceGroupScalePolicyAutoScaleCustomRuleOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupScalePolicyAutoScaleCustomRuleOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricName")
    def metric_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metricName"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricType")
    def metric_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metricType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ruleType")
    def rule_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ruleType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="service")
    def service(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "service"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="target")
    def target(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "target"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceGroupScalePolicyAutoScaleCustomRule]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceGroupScalePolicyAutoScaleCustomRule], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceGroupScalePolicyAutoScaleCustomRule],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexComputeInstanceGroupScalePolicyAutoScaleList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupScalePolicyAutoScaleList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceGroupScalePolicyAutoScaleOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceGroupScalePolicyAutoScaleOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceGroupScalePolicyAutoScaleOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupScalePolicyAutoScaleOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cpuUtilizationTarget")
    def cpu_utilization_target(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "cpuUtilizationTarget"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="customRule")
    def custom_rule(
        self,
    ) -> DataYandexComputeInstanceGroupScalePolicyAutoScaleCustomRuleList:
        return typing.cast(DataYandexComputeInstanceGroupScalePolicyAutoScaleCustomRuleList, jsii.get(self, "customRule"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="initialSize")
    def initial_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "initialSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxSize")
    def max_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="measurementDuration")
    def measurement_duration(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "measurementDuration"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minZoneSize")
    def min_zone_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minZoneSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="stabilizationDuration")
    def stabilization_duration(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "stabilizationDuration"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="warmupDuration")
    def warmup_duration(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "warmupDuration"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceGroupScalePolicyAutoScale]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceGroupScalePolicyAutoScale], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceGroupScalePolicyAutoScale],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupScalePolicyFixedScale",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceGroupScalePolicyFixedScale:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceGroupScalePolicyFixedScale(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeInstanceGroupScalePolicyFixedScaleList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupScalePolicyFixedScaleList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceGroupScalePolicyFixedScaleOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceGroupScalePolicyFixedScaleOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceGroupScalePolicyFixedScaleOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupScalePolicyFixedScaleOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="size")
    def size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "size"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceGroupScalePolicyFixedScale]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceGroupScalePolicyFixedScale], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceGroupScalePolicyFixedScale],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexComputeInstanceGroupScalePolicyList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupScalePolicyList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceGroupScalePolicyOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceGroupScalePolicyOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceGroupScalePolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupScalePolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoScale")
    def auto_scale(self) -> DataYandexComputeInstanceGroupScalePolicyAutoScaleList:
        return typing.cast(DataYandexComputeInstanceGroupScalePolicyAutoScaleList, jsii.get(self, "autoScale"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fixedScale")
    def fixed_scale(self) -> DataYandexComputeInstanceGroupScalePolicyFixedScaleList:
        return typing.cast(DataYandexComputeInstanceGroupScalePolicyFixedScaleList, jsii.get(self, "fixedScale"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="testAutoScale")
    def test_auto_scale(
        self,
    ) -> "DataYandexComputeInstanceGroupScalePolicyTestAutoScaleList":
        return typing.cast("DataYandexComputeInstanceGroupScalePolicyTestAutoScaleList", jsii.get(self, "testAutoScale"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceGroupScalePolicy]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceGroupScalePolicy], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceGroupScalePolicy],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupScalePolicyTestAutoScale",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceGroupScalePolicyTestAutoScale:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceGroupScalePolicyTestAutoScale(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupScalePolicyTestAutoScaleCustomRule",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceGroupScalePolicyTestAutoScaleCustomRule:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceGroupScalePolicyTestAutoScaleCustomRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeInstanceGroupScalePolicyTestAutoScaleCustomRuleList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupScalePolicyTestAutoScaleCustomRuleList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceGroupScalePolicyTestAutoScaleCustomRuleOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceGroupScalePolicyTestAutoScaleCustomRuleOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceGroupScalePolicyTestAutoScaleCustomRuleOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupScalePolicyTestAutoScaleCustomRuleOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricName")
    def metric_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metricName"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricType")
    def metric_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "metricType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ruleType")
    def rule_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ruleType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="service")
    def service(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "service"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="target")
    def target(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "target"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceGroupScalePolicyTestAutoScaleCustomRule]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceGroupScalePolicyTestAutoScaleCustomRule], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceGroupScalePolicyTestAutoScaleCustomRule],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexComputeInstanceGroupScalePolicyTestAutoScaleList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupScalePolicyTestAutoScaleList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceGroupScalePolicyTestAutoScaleOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceGroupScalePolicyTestAutoScaleOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceGroupScalePolicyTestAutoScaleOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceGroupScalePolicyTestAutoScaleOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cpuUtilizationTarget")
    def cpu_utilization_target(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "cpuUtilizationTarget"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="customRule")
    def custom_rule(
        self,
    ) -> DataYandexComputeInstanceGroupScalePolicyTestAutoScaleCustomRuleList:
        return typing.cast(DataYandexComputeInstanceGroupScalePolicyTestAutoScaleCustomRuleList, jsii.get(self, "customRule"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="initialSize")
    def initial_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "initialSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxSize")
    def max_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="measurementDuration")
    def measurement_duration(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "measurementDuration"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minZoneSize")
    def min_zone_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minZoneSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="stabilizationDuration")
    def stabilization_duration(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "stabilizationDuration"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="warmupDuration")
    def warmup_duration(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "warmupDuration"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceGroupScalePolicyTestAutoScale]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceGroupScalePolicyTestAutoScale], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceGroupScalePolicyTestAutoScale],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceNetworkInterface",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceNetworkInterface:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceNetworkInterface(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceNetworkInterfaceDnsRecord",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceNetworkInterfaceDnsRecord:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceNetworkInterfaceDnsRecord(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeInstanceNetworkInterfaceDnsRecordList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceNetworkInterfaceDnsRecordList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceNetworkInterfaceDnsRecordOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceNetworkInterfaceDnsRecordOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceNetworkInterfaceDnsRecordOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceNetworkInterfaceDnsRecordOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dnsZoneId")
    def dns_zone_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dnsZoneId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fqdn"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ptr")
    def ptr(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "ptr"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ttl")
    def ttl(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "ttl"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceNetworkInterfaceDnsRecord]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceNetworkInterfaceDnsRecord], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceNetworkInterfaceDnsRecord],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceNetworkInterfaceIpv6DnsRecord",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceNetworkInterfaceIpv6DnsRecord:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceNetworkInterfaceIpv6DnsRecord(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeInstanceNetworkInterfaceIpv6DnsRecordList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceNetworkInterfaceIpv6DnsRecordList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceNetworkInterfaceIpv6DnsRecordOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceNetworkInterfaceIpv6DnsRecordOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceNetworkInterfaceIpv6DnsRecordOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceNetworkInterfaceIpv6DnsRecordOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dnsZoneId")
    def dns_zone_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dnsZoneId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fqdn"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ptr")
    def ptr(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "ptr"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ttl")
    def ttl(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "ttl"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceNetworkInterfaceIpv6DnsRecord]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceNetworkInterfaceIpv6DnsRecord], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceNetworkInterfaceIpv6DnsRecord],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexComputeInstanceNetworkInterfaceList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceNetworkInterfaceList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceNetworkInterfaceOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceNetworkInterfaceOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceNetworkInterfaceNatDnsRecord",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceNetworkInterfaceNatDnsRecord:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceNetworkInterfaceNatDnsRecord(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeInstanceNetworkInterfaceNatDnsRecordList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceNetworkInterfaceNatDnsRecordList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceNetworkInterfaceNatDnsRecordOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceNetworkInterfaceNatDnsRecordOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceNetworkInterfaceNatDnsRecordOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceNetworkInterfaceNatDnsRecordOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dnsZoneId")
    def dns_zone_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dnsZoneId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fqdn"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ptr")
    def ptr(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "ptr"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ttl")
    def ttl(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "ttl"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceNetworkInterfaceNatDnsRecord]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceNetworkInterfaceNatDnsRecord], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceNetworkInterfaceNatDnsRecord],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexComputeInstanceNetworkInterfaceOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceNetworkInterfaceOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dnsRecord")
    def dns_record(self) -> DataYandexComputeInstanceNetworkInterfaceDnsRecordList:
        return typing.cast(DataYandexComputeInstanceNetworkInterfaceDnsRecordList, jsii.get(self, "dnsRecord"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="index")
    def index(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "index"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipAddress")
    def ip_address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ipAddress"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv4")
    def ipv4(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "ipv4"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv6")
    def ipv6(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "ipv6"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv6Address")
    def ipv6_address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ipv6Address"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv6DnsRecord")
    def ipv6_dns_record(
        self,
    ) -> DataYandexComputeInstanceNetworkInterfaceIpv6DnsRecordList:
        return typing.cast(DataYandexComputeInstanceNetworkInterfaceIpv6DnsRecordList, jsii.get(self, "ipv6DnsRecord"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="macAddress")
    def mac_address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "macAddress"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nat")
    def nat(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "nat"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="natDnsRecord")
    def nat_dns_record(
        self,
    ) -> DataYandexComputeInstanceNetworkInterfaceNatDnsRecordList:
        return typing.cast(DataYandexComputeInstanceNetworkInterfaceNatDnsRecordList, jsii.get(self, "natDnsRecord"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="natIpAddress")
    def nat_ip_address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "natIpAddress"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="natIpVersion")
    def nat_ip_version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "natIpVersion"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "securityGroupIds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceNetworkInterface]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceNetworkInterface], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceNetworkInterface],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstancePlacementPolicy",
    jsii_struct_bases=[],
    name_mapping={
        "host_affinity_rules": "hostAffinityRules",
        "placement_group_id": "placementGroupId",
    },
)
class DataYandexComputeInstancePlacementPolicy:
    def __init__(
        self,
        *,
        host_affinity_rules: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["DataYandexComputeInstancePlacementPolicyHostAffinityRules"]]] = None,
        placement_group_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param host_affinity_rules: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance#host_affinity_rules DataYandexComputeInstance#host_affinity_rules}.
        :param placement_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance#placement_group_id DataYandexComputeInstance#placement_group_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if host_affinity_rules is not None:
            self._values["host_affinity_rules"] = host_affinity_rules
        if placement_group_id is not None:
            self._values["placement_group_id"] = placement_group_id

    @builtins.property
    def host_affinity_rules(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataYandexComputeInstancePlacementPolicyHostAffinityRules"]]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance#host_affinity_rules DataYandexComputeInstance#host_affinity_rules}.'''
        result = self._values.get("host_affinity_rules")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataYandexComputeInstancePlacementPolicyHostAffinityRules"]]], result)

    @builtins.property
    def placement_group_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance#placement_group_id DataYandexComputeInstance#placement_group_id}.'''
        result = self._values.get("placement_group_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstancePlacementPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstancePlacementPolicyHostAffinityRules",
    jsii_struct_bases=[],
    name_mapping={"key": "key", "op": "op", "values": "values"},
)
class DataYandexComputeInstancePlacementPolicyHostAffinityRules:
    def __init__(
        self,
        *,
        key: typing.Optional[builtins.str] = None,
        op: typing.Optional[builtins.str] = None,
        values: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param key: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance#key DataYandexComputeInstance#key}.
        :param op: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance#op DataYandexComputeInstance#op}.
        :param values: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance#values DataYandexComputeInstance#values}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if key is not None:
            self._values["key"] = key
        if op is not None:
            self._values["op"] = op
        if values is not None:
            self._values["values"] = values

    @builtins.property
    def key(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance#key DataYandexComputeInstance#key}.'''
        result = self._values.get("key")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def op(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance#op DataYandexComputeInstance#op}.'''
        result = self._values.get("op")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def values(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_instance#values DataYandexComputeInstance#values}.'''
        result = self._values.get("values")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstancePlacementPolicyHostAffinityRules(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeInstancePlacementPolicyHostAffinityRulesList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstancePlacementPolicyHostAffinityRulesList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstancePlacementPolicyHostAffinityRulesOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstancePlacementPolicyHostAffinityRulesOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataYandexComputeInstancePlacementPolicyHostAffinityRules]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataYandexComputeInstancePlacementPolicyHostAffinityRules]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataYandexComputeInstancePlacementPolicyHostAffinityRules]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexComputeInstancePlacementPolicyHostAffinityRulesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstancePlacementPolicyHostAffinityRulesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetKey")
    def reset_key(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetKey", []))

    @jsii.member(jsii_name="resetOp")
    def reset_op(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOp", []))

    @jsii.member(jsii_name="resetValues")
    def reset_values(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetValues", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="keyInput")
    def key_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "keyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="opInput")
    def op_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "opInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="valuesInput")
    def values_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "valuesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="key")
    def key(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "key"))

    @key.setter
    def key(self, value: builtins.str) -> None:
        jsii.set(self, "key", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="op")
    def op(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "op"))

    @op.setter
    def op(self, value: builtins.str) -> None:
        jsii.set(self, "op", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="values")
    def values(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "values"))

    @values.setter
    def values(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "values", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, DataYandexComputeInstancePlacementPolicyHostAffinityRules]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, DataYandexComputeInstancePlacementPolicyHostAffinityRules]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, DataYandexComputeInstancePlacementPolicyHostAffinityRules]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexComputeInstancePlacementPolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstancePlacementPolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putHostAffinityRules")
    def put_host_affinity_rules(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence[DataYandexComputeInstancePlacementPolicyHostAffinityRules]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putHostAffinityRules", [value]))

    @jsii.member(jsii_name="resetHostAffinityRules")
    def reset_host_affinity_rules(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHostAffinityRules", []))

    @jsii.member(jsii_name="resetPlacementGroupId")
    def reset_placement_group_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPlacementGroupId", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostAffinityRules")
    def host_affinity_rules(
        self,
    ) -> DataYandexComputeInstancePlacementPolicyHostAffinityRulesList:
        return typing.cast(DataYandexComputeInstancePlacementPolicyHostAffinityRulesList, jsii.get(self, "hostAffinityRules"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostAffinityRulesInput")
    def host_affinity_rules_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataYandexComputeInstancePlacementPolicyHostAffinityRules]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataYandexComputeInstancePlacementPolicyHostAffinityRules]]], jsii.get(self, "hostAffinityRulesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="placementGroupIdInput")
    def placement_group_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "placementGroupIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="placementGroupId")
    def placement_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "placementGroupId"))

    @placement_group_id.setter
    def placement_group_id(self, value: builtins.str) -> None:
        jsii.set(self, "placementGroupId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstancePlacementPolicy]:
        return typing.cast(typing.Optional[DataYandexComputeInstancePlacementPolicy], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstancePlacementPolicy],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceResources",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceResources:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeInstanceResourcesList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceResourcesList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceResourcesOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceResourcesOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceResourcesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceResourcesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="coreFraction")
    def core_fraction(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "coreFraction"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cores")
    def cores(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "cores"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="gpus")
    def gpus(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "gpus"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="memory")
    def memory(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "memory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexComputeInstanceResources]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceResources], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceResources],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceSchedulingPolicy",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceSchedulingPolicy:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceSchedulingPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeInstanceSchedulingPolicyList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceSchedulingPolicyList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceSchedulingPolicyOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceSchedulingPolicyOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceSchedulingPolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceSchedulingPolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="preemptible")
    def preemptible(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "preemptible"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexComputeInstanceSchedulingPolicy]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceSchedulingPolicy], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceSchedulingPolicy],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceSecondaryDisk",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexComputeInstanceSecondaryDisk:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeInstanceSecondaryDisk(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeInstanceSecondaryDiskList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceSecondaryDiskList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexComputeInstanceSecondaryDiskOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexComputeInstanceSecondaryDiskOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexComputeInstanceSecondaryDiskOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeInstanceSecondaryDiskOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoDelete")
    def auto_delete(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "autoDelete"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deviceName")
    def device_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "deviceName"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskId")
    def disk_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mode")
    def mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "mode"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexComputeInstanceSecondaryDisk]:
        return typing.cast(typing.Optional[DataYandexComputeInstanceSecondaryDisk], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexComputeInstanceSecondaryDisk],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexComputePlacementGroup(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputePlacementGroup",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/compute_placement_group yandex_compute_placement_group}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        group_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/compute_placement_group yandex_compute_placement_group} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_placement_group#description DataYandexComputePlacementGroup#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_placement_group#folder_id DataYandexComputePlacementGroup#folder_id}.
        :param group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_placement_group#group_id DataYandexComputePlacementGroup#group_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_placement_group#id DataYandexComputePlacementGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_placement_group#labels DataYandexComputePlacementGroup#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_placement_group#name DataYandexComputePlacementGroup#name}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexComputePlacementGroupConfig(
            description=description,
            folder_id=folder_id,
            group_id=group_id,
            id=id,
            labels=labels,
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetGroupId")
    def reset_group_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="groupIdInput")
    def group_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "groupIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="groupId")
    def group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "groupId"))

    @group_id.setter
    def group_id(self, value: builtins.str) -> None:
        jsii.set(self, "groupId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputePlacementGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "description": "description",
        "folder_id": "folderId",
        "group_id": "groupId",
        "id": "id",
        "labels": "labels",
        "name": "name",
    },
)
class DataYandexComputePlacementGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        group_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_placement_group#description DataYandexComputePlacementGroup#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_placement_group#folder_id DataYandexComputePlacementGroup#folder_id}.
        :param group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_placement_group#group_id DataYandexComputePlacementGroup#group_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_placement_group#id DataYandexComputePlacementGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_placement_group#labels DataYandexComputePlacementGroup#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_placement_group#name DataYandexComputePlacementGroup#name}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if group_id is not None:
            self._values["group_id"] = group_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_placement_group#description DataYandexComputePlacementGroup#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_placement_group#folder_id DataYandexComputePlacementGroup#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def group_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_placement_group#group_id DataYandexComputePlacementGroup#group_id}.'''
        result = self._values.get("group_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_placement_group#id DataYandexComputePlacementGroup#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_placement_group#labels DataYandexComputePlacementGroup#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_placement_group#name DataYandexComputePlacementGroup#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputePlacementGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexComputeSnapshot(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexComputeSnapshot",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/compute_snapshot yandex_compute_snapshot}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        snapshot_id: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/compute_snapshot yandex_compute_snapshot} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_snapshot#folder_id DataYandexComputeSnapshot#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_snapshot#id DataYandexComputeSnapshot#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_snapshot#name DataYandexComputeSnapshot#name}.
        :param snapshot_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_snapshot#snapshot_id DataYandexComputeSnapshot#snapshot_id}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexComputeSnapshotConfig(
            folder_id=folder_id,
            id=id,
            name=name,
            snapshot_id=snapshot_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetSnapshotId")
    def reset_snapshot_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSnapshotId", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSize")
    def disk_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "diskSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="productIds")
    def product_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "productIds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sourceDiskId")
    def source_disk_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sourceDiskId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="storageSize")
    def storage_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "storageSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="snapshotIdInput")
    def snapshot_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "snapshotIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="snapshotId")
    def snapshot_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "snapshotId"))

    @snapshot_id.setter
    def snapshot_id(self, value: builtins.str) -> None:
        jsii.set(self, "snapshotId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexComputeSnapshotConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "folder_id": "folderId",
        "id": "id",
        "name": "name",
        "snapshot_id": "snapshotId",
    },
)
class DataYandexComputeSnapshotConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        snapshot_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_snapshot#folder_id DataYandexComputeSnapshot#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_snapshot#id DataYandexComputeSnapshot#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_snapshot#name DataYandexComputeSnapshot#name}.
        :param snapshot_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_snapshot#snapshot_id DataYandexComputeSnapshot#snapshot_id}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name
        if snapshot_id is not None:
            self._values["snapshot_id"] = snapshot_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_snapshot#folder_id DataYandexComputeSnapshot#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_snapshot#id DataYandexComputeSnapshot#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_snapshot#name DataYandexComputeSnapshot#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def snapshot_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/compute_snapshot#snapshot_id DataYandexComputeSnapshot#snapshot_id}.'''
        result = self._values.get("snapshot_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexComputeSnapshotConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexContainerRegistry(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexContainerRegistry",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/container_registry yandex_container_registry}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        registry_id: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/container_registry yandex_container_registry} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/container_registry#folder_id DataYandexContainerRegistry#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/container_registry#id DataYandexContainerRegistry#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/container_registry#labels DataYandexContainerRegistry#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/container_registry#name DataYandexContainerRegistry#name}.
        :param registry_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/container_registry#registry_id DataYandexContainerRegistry#registry_id}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexContainerRegistryConfig(
            folder_id=folder_id,
            id=id,
            labels=labels,
            name=name,
            registry_id=registry_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetRegistryId")
    def reset_registry_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRegistryId", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="registryIdInput")
    def registry_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "registryIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="registryId")
    def registry_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "registryId"))

    @registry_id.setter
    def registry_id(self, value: builtins.str) -> None:
        jsii.set(self, "registryId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexContainerRegistryConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "folder_id": "folderId",
        "id": "id",
        "labels": "labels",
        "name": "name",
        "registry_id": "registryId",
    },
)
class DataYandexContainerRegistryConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        registry_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/container_registry#folder_id DataYandexContainerRegistry#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/container_registry#id DataYandexContainerRegistry#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/container_registry#labels DataYandexContainerRegistry#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/container_registry#name DataYandexContainerRegistry#name}.
        :param registry_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/container_registry#registry_id DataYandexContainerRegistry#registry_id}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if name is not None:
            self._values["name"] = name
        if registry_id is not None:
            self._values["registry_id"] = registry_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/container_registry#folder_id DataYandexContainerRegistry#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/container_registry#id DataYandexContainerRegistry#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/container_registry#labels DataYandexContainerRegistry#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/container_registry#name DataYandexContainerRegistry#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def registry_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/container_registry#registry_id DataYandexContainerRegistry#registry_id}.'''
        result = self._values.get("registry_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexContainerRegistryConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexContainerRepository(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexContainerRepository",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/container_repository yandex_container_repository}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        repository_id: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/container_repository yandex_container_repository} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/container_repository#id DataYandexContainerRepository#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/container_repository#name DataYandexContainerRepository#name}.
        :param repository_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/container_repository#repository_id DataYandexContainerRepository#repository_id}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexContainerRepositoryConfig(
            id=id,
            name=name,
            repository_id=repository_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetRepositoryId")
    def reset_repository_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRepositoryId", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="repositoryIdInput")
    def repository_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "repositoryIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="repositoryId")
    def repository_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "repositoryId"))

    @repository_id.setter
    def repository_id(self, value: builtins.str) -> None:
        jsii.set(self, "repositoryId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexContainerRepositoryConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "id": "id",
        "name": "name",
        "repository_id": "repositoryId",
    },
)
class DataYandexContainerRepositoryConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        repository_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/container_repository#id DataYandexContainerRepository#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/container_repository#name DataYandexContainerRepository#name}.
        :param repository_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/container_repository#repository_id DataYandexContainerRepository#repository_id}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name
        if repository_id is not None:
            self._values["repository_id"] = repository_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/container_repository#id DataYandexContainerRepository#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/container_repository#name DataYandexContainerRepository#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def repository_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/container_repository#repository_id DataYandexContainerRepository#repository_id}.'''
        result = self._values.get("repository_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexContainerRepositoryConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexDataprocCluster(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexDataprocCluster",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/dataproc_cluster yandex_dataproc_cluster}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        cluster_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/dataproc_cluster yandex_dataproc_cluster} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/dataproc_cluster#cluster_id DataYandexDataprocCluster#cluster_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/dataproc_cluster#id DataYandexDataprocCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/dataproc_cluster#name DataYandexDataprocCluster#name}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexDataprocClusterConfig(
            cluster_id=cluster_id,
            id=id,
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetClusterId")
    def reset_cluster_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetClusterId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bucket")
    def bucket(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "bucket"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterConfig")
    def cluster_config(self) -> "DataYandexDataprocClusterClusterConfigList":
        return typing.cast("DataYandexDataprocClusterClusterConfigList", jsii.get(self, "clusterConfig"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtection")
    def deletion_protection(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "deletionProtection"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostGroupIds")
    def host_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "hostGroupIds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "securityGroupIds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountId")
    def service_account_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceAccountId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="uiProxy")
    def ui_proxy(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "uiProxy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneId")
    def zone_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zoneId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterIdInput")
    def cluster_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "clusterIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterId")
    def cluster_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "clusterId"))

    @cluster_id.setter
    def cluster_id(self, value: builtins.str) -> None:
        jsii.set(self, "clusterId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexDataprocClusterClusterConfig",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexDataprocClusterClusterConfig:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexDataprocClusterClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexDataprocClusterClusterConfigHadoop",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexDataprocClusterClusterConfigHadoop:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexDataprocClusterClusterConfigHadoop(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexDataprocClusterClusterConfigHadoopList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexDataprocClusterClusterConfigHadoopList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexDataprocClusterClusterConfigHadoopOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexDataprocClusterClusterConfigHadoopOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexDataprocClusterClusterConfigHadoopOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexDataprocClusterClusterConfigHadoopOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="properties")
    def properties(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "properties"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="services")
    def services(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "services"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sshPublicKeys")
    def ssh_public_keys(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "sshPublicKeys"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexDataprocClusterClusterConfigHadoop]:
        return typing.cast(typing.Optional[DataYandexDataprocClusterClusterConfigHadoop], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexDataprocClusterClusterConfigHadoop],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexDataprocClusterClusterConfigList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexDataprocClusterClusterConfigList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexDataprocClusterClusterConfigOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexDataprocClusterClusterConfigOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexDataprocClusterClusterConfigOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexDataprocClusterClusterConfigOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hadoop")
    def hadoop(self) -> DataYandexDataprocClusterClusterConfigHadoopList:
        return typing.cast(DataYandexDataprocClusterClusterConfigHadoopList, jsii.get(self, "hadoop"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subclusterSpec")
    def subcluster_spec(
        self,
    ) -> "DataYandexDataprocClusterClusterConfigSubclusterSpecList":
        return typing.cast("DataYandexDataprocClusterClusterConfigSubclusterSpecList", jsii.get(self, "subclusterSpec"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="versionId")
    def version_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "versionId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexDataprocClusterClusterConfig]:
        return typing.cast(typing.Optional[DataYandexDataprocClusterClusterConfig], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexDataprocClusterClusterConfig],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexDataprocClusterClusterConfigSubclusterSpec",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexDataprocClusterClusterConfigSubclusterSpec:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexDataprocClusterClusterConfigSubclusterSpec(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexDataprocClusterClusterConfigSubclusterSpecAutoscalingConfig",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexDataprocClusterClusterConfigSubclusterSpecAutoscalingConfig:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexDataprocClusterClusterConfigSubclusterSpecAutoscalingConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexDataprocClusterClusterConfigSubclusterSpecAutoscalingConfigList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexDataprocClusterClusterConfigSubclusterSpecAutoscalingConfigList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexDataprocClusterClusterConfigSubclusterSpecAutoscalingConfigOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexDataprocClusterClusterConfigSubclusterSpecAutoscalingConfigOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexDataprocClusterClusterConfigSubclusterSpecAutoscalingConfigOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexDataprocClusterClusterConfigSubclusterSpecAutoscalingConfigOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cpuUtilizationTarget")
    def cpu_utilization_target(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "cpuUtilizationTarget"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="decommissionTimeout")
    def decommission_timeout(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "decommissionTimeout"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxHostsCount")
    def max_hosts_count(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxHostsCount"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="measurementDuration")
    def measurement_duration(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "measurementDuration"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="preemptible")
    def preemptible(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "preemptible"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="stabilizationDuration")
    def stabilization_duration(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "stabilizationDuration"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="warmupDuration")
    def warmup_duration(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "warmupDuration"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexDataprocClusterClusterConfigSubclusterSpecAutoscalingConfig]:
        return typing.cast(typing.Optional[DataYandexDataprocClusterClusterConfigSubclusterSpecAutoscalingConfig], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexDataprocClusterClusterConfigSubclusterSpecAutoscalingConfig],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexDataprocClusterClusterConfigSubclusterSpecList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexDataprocClusterClusterConfigSubclusterSpecList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexDataprocClusterClusterConfigSubclusterSpecOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexDataprocClusterClusterConfigSubclusterSpecOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexDataprocClusterClusterConfigSubclusterSpecOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexDataprocClusterClusterConfigSubclusterSpecOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIp")
    def assign_public_ip(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "assignPublicIp"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoscalingConfig")
    def autoscaling_config(
        self,
    ) -> DataYandexDataprocClusterClusterConfigSubclusterSpecAutoscalingConfigList:
        return typing.cast(DataYandexDataprocClusterClusterConfigSubclusterSpecAutoscalingConfigList, jsii.get(self, "autoscalingConfig"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostsCount")
    def hosts_count(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "hostsCount"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resources")
    def resources(
        self,
    ) -> "DataYandexDataprocClusterClusterConfigSubclusterSpecResourcesList":
        return typing.cast("DataYandexDataprocClusterClusterConfigSubclusterSpecResourcesList", jsii.get(self, "resources"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="role")
    def role(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "role"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexDataprocClusterClusterConfigSubclusterSpec]:
        return typing.cast(typing.Optional[DataYandexDataprocClusterClusterConfigSubclusterSpec], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexDataprocClusterClusterConfigSubclusterSpec],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexDataprocClusterClusterConfigSubclusterSpecResources",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexDataprocClusterClusterConfigSubclusterSpecResources:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexDataprocClusterClusterConfigSubclusterSpecResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexDataprocClusterClusterConfigSubclusterSpecResourcesList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexDataprocClusterClusterConfigSubclusterSpecResourcesList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexDataprocClusterClusterConfigSubclusterSpecResourcesOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexDataprocClusterClusterConfigSubclusterSpecResourcesOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexDataprocClusterClusterConfigSubclusterSpecResourcesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexDataprocClusterClusterConfigSubclusterSpecResourcesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSize")
    def disk_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "diskSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeId")
    def disk_type_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskTypeId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetId")
    def resource_preset_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourcePresetId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexDataprocClusterClusterConfigSubclusterSpecResources]:
        return typing.cast(typing.Optional[DataYandexDataprocClusterClusterConfigSubclusterSpecResources], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexDataprocClusterClusterConfigSubclusterSpecResources],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexDataprocClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_id": "clusterId",
        "id": "id",
        "name": "name",
    },
)
class DataYandexDataprocClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/dataproc_cluster#cluster_id DataYandexDataprocCluster#cluster_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/dataproc_cluster#id DataYandexDataprocCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/dataproc_cluster#name DataYandexDataprocCluster#name}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if cluster_id is not None:
            self._values["cluster_id"] = cluster_id
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def cluster_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/dataproc_cluster#cluster_id DataYandexDataprocCluster#cluster_id}.'''
        result = self._values.get("cluster_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/dataproc_cluster#id DataYandexDataprocCluster#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/dataproc_cluster#name DataYandexDataprocCluster#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexDataprocClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexDnsZone(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexDnsZone",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/dns_zone yandex_dns_zone}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        dns_zone_id: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DataYandexDnsZoneTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/dns_zone yandex_dns_zone} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param dns_zone_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/dns_zone#dns_zone_id DataYandexDnsZone#dns_zone_id}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/dns_zone#folder_id DataYandexDnsZone#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/dns_zone#id DataYandexDnsZone#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/dns_zone#name DataYandexDnsZone#name}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/dns_zone#timeouts DataYandexDnsZone#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexDnsZoneConfig(
            dns_zone_id=dns_zone_id,
            folder_id=folder_id,
            id=id,
            name=name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/dns_zone#create DataYandexDnsZone#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/dns_zone#delete DataYandexDnsZone#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/dns_zone#update DataYandexDnsZone#update}.
        '''
        value = DataYandexDnsZoneTimeouts(create=create, delete=delete, update=update)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetDnsZoneId")
    def reset_dns_zone_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDnsZoneId", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="privateNetworks")
    def private_networks(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "privateNetworks"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="public")
    def public(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "public"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "DataYandexDnsZoneTimeoutsOutputReference":
        return typing.cast("DataYandexDnsZoneTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zone")
    def zone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zone"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dnsZoneIdInput")
    def dns_zone_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dnsZoneIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "DataYandexDnsZoneTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "DataYandexDnsZoneTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dnsZoneId")
    def dns_zone_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "dnsZoneId"))

    @dns_zone_id.setter
    def dns_zone_id(self, value: builtins.str) -> None:
        jsii.set(self, "dnsZoneId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexDnsZoneConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "dns_zone_id": "dnsZoneId",
        "folder_id": "folderId",
        "id": "id",
        "name": "name",
        "timeouts": "timeouts",
    },
)
class DataYandexDnsZoneConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        dns_zone_id: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DataYandexDnsZoneTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param dns_zone_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/dns_zone#dns_zone_id DataYandexDnsZone#dns_zone_id}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/dns_zone#folder_id DataYandexDnsZone#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/dns_zone#id DataYandexDnsZone#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/dns_zone#name DataYandexDnsZone#name}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/dns_zone#timeouts DataYandexDnsZone#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DataYandexDnsZoneTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if dns_zone_id is not None:
            self._values["dns_zone_id"] = dns_zone_id
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def dns_zone_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/dns_zone#dns_zone_id DataYandexDnsZone#dns_zone_id}.'''
        result = self._values.get("dns_zone_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/dns_zone#folder_id DataYandexDnsZone#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/dns_zone#id DataYandexDnsZone#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/dns_zone#name DataYandexDnsZone#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["DataYandexDnsZoneTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/dns_zone#timeouts DataYandexDnsZone#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["DataYandexDnsZoneTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexDnsZoneConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexDnsZoneTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class DataYandexDnsZoneTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/dns_zone#create DataYandexDnsZone#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/dns_zone#delete DataYandexDnsZone#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/dns_zone#update DataYandexDnsZone#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/dns_zone#create DataYandexDnsZone#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/dns_zone#delete DataYandexDnsZone#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/dns_zone#update DataYandexDnsZone#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexDnsZoneTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexDnsZoneTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexDnsZoneTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, DataYandexDnsZoneTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, DataYandexDnsZoneTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, DataYandexDnsZoneTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexFunction(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexFunction",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/function yandex_function}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        folder_id: typing.Optional[builtins.str] = None,
        function_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/function yandex_function} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function#folder_id DataYandexFunction#folder_id}.
        :param function_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function#function_id DataYandexFunction#function_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function#id DataYandexFunction#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function#name DataYandexFunction#name}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexFunctionConfig(
            folder_id=folder_id,
            function_id=function_id,
            id=id,
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetFunctionId")
    def reset_function_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFunctionId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="entrypoint")
    def entrypoint(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "entrypoint"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="environment")
    def environment(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "environment"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="executionTimeout")
    def execution_timeout(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "executionTimeout"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="imageSize")
    def image_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "imageSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="loggroupId")
    def loggroup_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "loggroupId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="memory")
    def memory(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "memory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="runtime")
    def runtime(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "runtime"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountId")
    def service_account_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceAccountId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "tags"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "version"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="functionIdInput")
    def function_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "functionIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="functionId")
    def function_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "functionId"))

    @function_id.setter
    def function_id(self, value: builtins.str) -> None:
        jsii.set(self, "functionId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexFunctionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "folder_id": "folderId",
        "function_id": "functionId",
        "id": "id",
        "name": "name",
    },
)
class DataYandexFunctionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        folder_id: typing.Optional[builtins.str] = None,
        function_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function#folder_id DataYandexFunction#folder_id}.
        :param function_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function#function_id DataYandexFunction#function_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function#id DataYandexFunction#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function#name DataYandexFunction#name}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if function_id is not None:
            self._values["function_id"] = function_id
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function#folder_id DataYandexFunction#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def function_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function#function_id DataYandexFunction#function_id}.'''
        result = self._values.get("function_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function#id DataYandexFunction#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function#name DataYandexFunction#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexFunctionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexFunctionScalingPolicy(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexFunctionScalingPolicy",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/function_scaling_policy yandex_function_scaling_policy}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        function_id: builtins.str,
        id: typing.Optional[builtins.str] = None,
        policy: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["DataYandexFunctionScalingPolicyPolicy"]]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/function_scaling_policy yandex_function_scaling_policy} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param function_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function_scaling_policy#function_id DataYandexFunctionScalingPolicy#function_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function_scaling_policy#id DataYandexFunctionScalingPolicy#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param policy: policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function_scaling_policy#policy DataYandexFunctionScalingPolicy#policy}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexFunctionScalingPolicyConfig(
            function_id=function_id,
            id=id,
            policy=policy,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putPolicy")
    def put_policy(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["DataYandexFunctionScalingPolicyPolicy"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putPolicy", [value]))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetPolicy")
    def reset_policy(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPolicy", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="policy")
    def policy(self) -> "DataYandexFunctionScalingPolicyPolicyList":
        return typing.cast("DataYandexFunctionScalingPolicyPolicyList", jsii.get(self, "policy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="functionIdInput")
    def function_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "functionIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="policyInput")
    def policy_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataYandexFunctionScalingPolicyPolicy"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataYandexFunctionScalingPolicyPolicy"]]], jsii.get(self, "policyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="functionId")
    def function_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "functionId"))

    @function_id.setter
    def function_id(self, value: builtins.str) -> None:
        jsii.set(self, "functionId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexFunctionScalingPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "function_id": "functionId",
        "id": "id",
        "policy": "policy",
    },
)
class DataYandexFunctionScalingPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        function_id: builtins.str,
        id: typing.Optional[builtins.str] = None,
        policy: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["DataYandexFunctionScalingPolicyPolicy"]]] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param function_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function_scaling_policy#function_id DataYandexFunctionScalingPolicy#function_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function_scaling_policy#id DataYandexFunctionScalingPolicy#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param policy: policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function_scaling_policy#policy DataYandexFunctionScalingPolicy#policy}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {
            "function_id": function_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if id is not None:
            self._values["id"] = id
        if policy is not None:
            self._values["policy"] = policy

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def function_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function_scaling_policy#function_id DataYandexFunctionScalingPolicy#function_id}.'''
        result = self._values.get("function_id")
        assert result is not None, "Required property 'function_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function_scaling_policy#id DataYandexFunctionScalingPolicy#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def policy(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataYandexFunctionScalingPolicyPolicy"]]]:
        '''policy block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function_scaling_policy#policy DataYandexFunctionScalingPolicy#policy}
        '''
        result = self._values.get("policy")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataYandexFunctionScalingPolicyPolicy"]]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexFunctionScalingPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexFunctionScalingPolicyPolicy",
    jsii_struct_bases=[],
    name_mapping={
        "zone_instances_limit": "zoneInstancesLimit",
        "zone_requests_limit": "zoneRequestsLimit",
    },
)
class DataYandexFunctionScalingPolicyPolicy:
    def __init__(
        self,
        *,
        zone_instances_limit: typing.Optional[jsii.Number] = None,
        zone_requests_limit: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param zone_instances_limit: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function_scaling_policy#zone_instances_limit DataYandexFunctionScalingPolicy#zone_instances_limit}.
        :param zone_requests_limit: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function_scaling_policy#zone_requests_limit DataYandexFunctionScalingPolicy#zone_requests_limit}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if zone_instances_limit is not None:
            self._values["zone_instances_limit"] = zone_instances_limit
        if zone_requests_limit is not None:
            self._values["zone_requests_limit"] = zone_requests_limit

    @builtins.property
    def zone_instances_limit(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function_scaling_policy#zone_instances_limit DataYandexFunctionScalingPolicy#zone_instances_limit}.'''
        result = self._values.get("zone_instances_limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def zone_requests_limit(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function_scaling_policy#zone_requests_limit DataYandexFunctionScalingPolicy#zone_requests_limit}.'''
        result = self._values.get("zone_requests_limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexFunctionScalingPolicyPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexFunctionScalingPolicyPolicyList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexFunctionScalingPolicyPolicyList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexFunctionScalingPolicyPolicyOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexFunctionScalingPolicyPolicyOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataYandexFunctionScalingPolicyPolicy]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataYandexFunctionScalingPolicyPolicy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataYandexFunctionScalingPolicyPolicy]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexFunctionScalingPolicyPolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexFunctionScalingPolicyPolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetZoneInstancesLimit")
    def reset_zone_instances_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetZoneInstancesLimit", []))

    @jsii.member(jsii_name="resetZoneRequestsLimit")
    def reset_zone_requests_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetZoneRequestsLimit", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tag")
    def tag(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "tag"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneInstancesLimitInput")
    def zone_instances_limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "zoneInstancesLimitInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneRequestsLimitInput")
    def zone_requests_limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "zoneRequestsLimitInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneInstancesLimit")
    def zone_instances_limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "zoneInstancesLimit"))

    @zone_instances_limit.setter
    def zone_instances_limit(self, value: jsii.Number) -> None:
        jsii.set(self, "zoneInstancesLimit", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneRequestsLimit")
    def zone_requests_limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "zoneRequestsLimit"))

    @zone_requests_limit.setter
    def zone_requests_limit(self, value: jsii.Number) -> None:
        jsii.set(self, "zoneRequestsLimit", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, DataYandexFunctionScalingPolicyPolicy]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, DataYandexFunctionScalingPolicyPolicy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, DataYandexFunctionScalingPolicyPolicy]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexFunctionTrigger(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexFunctionTrigger",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/function_trigger yandex_function_trigger}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        trigger_id: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/function_trigger yandex_function_trigger} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function_trigger#folder_id DataYandexFunctionTrigger#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function_trigger#id DataYandexFunctionTrigger#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function_trigger#name DataYandexFunctionTrigger#name}.
        :param trigger_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function_trigger#trigger_id DataYandexFunctionTrigger#trigger_id}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexFunctionTriggerConfig(
            folder_id=folder_id,
            id=id,
            name=name,
            trigger_id=trigger_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetTriggerId")
    def reset_trigger_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTriggerId", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dlq")
    def dlq(self) -> "DataYandexFunctionTriggerDlqList":
        return typing.cast("DataYandexFunctionTriggerDlqList", jsii.get(self, "dlq"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="function")
    def function(self) -> "DataYandexFunctionTriggerFunctionList":
        return typing.cast("DataYandexFunctionTriggerFunctionList", jsii.get(self, "function"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="iot")
    def iot(self) -> "DataYandexFunctionTriggerIotList":
        return typing.cast("DataYandexFunctionTriggerIotList", jsii.get(self, "iot"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logging")
    def logging(self) -> "DataYandexFunctionTriggerLoggingList":
        return typing.cast("DataYandexFunctionTriggerLoggingList", jsii.get(self, "logging"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logGroup")
    def log_group(self) -> "DataYandexFunctionTriggerLogGroupList":
        return typing.cast("DataYandexFunctionTriggerLogGroupList", jsii.get(self, "logGroup"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="messageQueue")
    def message_queue(self) -> "DataYandexFunctionTriggerMessageQueueList":
        return typing.cast("DataYandexFunctionTriggerMessageQueueList", jsii.get(self, "messageQueue"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="objectStorage")
    def object_storage(self) -> "DataYandexFunctionTriggerObjectStorageList":
        return typing.cast("DataYandexFunctionTriggerObjectStorageList", jsii.get(self, "objectStorage"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timer")
    def timer(self) -> "DataYandexFunctionTriggerTimerList":
        return typing.cast("DataYandexFunctionTriggerTimerList", jsii.get(self, "timer"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="triggerIdInput")
    def trigger_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "triggerIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="triggerId")
    def trigger_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "triggerId"))

    @trigger_id.setter
    def trigger_id(self, value: builtins.str) -> None:
        jsii.set(self, "triggerId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexFunctionTriggerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "folder_id": "folderId",
        "id": "id",
        "name": "name",
        "trigger_id": "triggerId",
    },
)
class DataYandexFunctionTriggerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        trigger_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function_trigger#folder_id DataYandexFunctionTrigger#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function_trigger#id DataYandexFunctionTrigger#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function_trigger#name DataYandexFunctionTrigger#name}.
        :param trigger_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function_trigger#trigger_id DataYandexFunctionTrigger#trigger_id}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name
        if trigger_id is not None:
            self._values["trigger_id"] = trigger_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function_trigger#folder_id DataYandexFunctionTrigger#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function_trigger#id DataYandexFunctionTrigger#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function_trigger#name DataYandexFunctionTrigger#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def trigger_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/function_trigger#trigger_id DataYandexFunctionTrigger#trigger_id}.'''
        result = self._values.get("trigger_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexFunctionTriggerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexFunctionTriggerDlq",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexFunctionTriggerDlq:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexFunctionTriggerDlq(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexFunctionTriggerDlqList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexFunctionTriggerDlqList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "DataYandexFunctionTriggerDlqOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexFunctionTriggerDlqOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexFunctionTriggerDlqOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexFunctionTriggerDlqOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queueId")
    def queue_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "queueId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountId")
    def service_account_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceAccountId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexFunctionTriggerDlq]:
        return typing.cast(typing.Optional[DataYandexFunctionTriggerDlq], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexFunctionTriggerDlq],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexFunctionTriggerFunction",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexFunctionTriggerFunction:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexFunctionTriggerFunction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexFunctionTriggerFunctionList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexFunctionTriggerFunctionList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexFunctionTriggerFunctionOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexFunctionTriggerFunctionOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexFunctionTriggerFunctionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexFunctionTriggerFunctionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="retryAttempts")
    def retry_attempts(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "retryAttempts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="retryInterval")
    def retry_interval(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "retryInterval"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountId")
    def service_account_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceAccountId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tag")
    def tag(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "tag"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexFunctionTriggerFunction]:
        return typing.cast(typing.Optional[DataYandexFunctionTriggerFunction], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexFunctionTriggerFunction],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexFunctionTriggerIot",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexFunctionTriggerIot:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexFunctionTriggerIot(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexFunctionTriggerIotList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexFunctionTriggerIotList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "DataYandexFunctionTriggerIotOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexFunctionTriggerIotOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexFunctionTriggerIotOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexFunctionTriggerIotOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deviceId")
    def device_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "deviceId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="registryId")
    def registry_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "registryId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="topic")
    def topic(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "topic"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexFunctionTriggerIot]:
        return typing.cast(typing.Optional[DataYandexFunctionTriggerIot], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexFunctionTriggerIot],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexFunctionTriggerLogGroup",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexFunctionTriggerLogGroup:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexFunctionTriggerLogGroup(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexFunctionTriggerLogGroupList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexFunctionTriggerLogGroupList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexFunctionTriggerLogGroupOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexFunctionTriggerLogGroupOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexFunctionTriggerLogGroupOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexFunctionTriggerLogGroupOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="batchCutoff")
    def batch_cutoff(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "batchCutoff"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="batchSize")
    def batch_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "batchSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logGroupIds")
    def log_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "logGroupIds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexFunctionTriggerLogGroup]:
        return typing.cast(typing.Optional[DataYandexFunctionTriggerLogGroup], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexFunctionTriggerLogGroup],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexFunctionTriggerLogging",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexFunctionTriggerLogging:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexFunctionTriggerLogging(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexFunctionTriggerLoggingList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexFunctionTriggerLoggingList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexFunctionTriggerLoggingOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexFunctionTriggerLoggingOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexFunctionTriggerLoggingOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexFunctionTriggerLoggingOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="batchCutoff")
    def batch_cutoff(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "batchCutoff"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="batchSize")
    def batch_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "batchSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="groupId")
    def group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "groupId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="levels")
    def levels(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "levels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourceIds")
    def resource_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "resourceIds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourceTypes")
    def resource_types(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "resourceTypes"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexFunctionTriggerLogging]:
        return typing.cast(typing.Optional[DataYandexFunctionTriggerLogging], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexFunctionTriggerLogging],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexFunctionTriggerMessageQueue",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexFunctionTriggerMessageQueue:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexFunctionTriggerMessageQueue(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexFunctionTriggerMessageQueueList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexFunctionTriggerMessageQueueList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexFunctionTriggerMessageQueueOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexFunctionTriggerMessageQueueOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexFunctionTriggerMessageQueueOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexFunctionTriggerMessageQueueOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="batchCutoff")
    def batch_cutoff(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "batchCutoff"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="batchSize")
    def batch_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "batchSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queueId")
    def queue_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "queueId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountId")
    def service_account_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceAccountId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="visibilityTimeout")
    def visibility_timeout(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "visibilityTimeout"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexFunctionTriggerMessageQueue]:
        return typing.cast(typing.Optional[DataYandexFunctionTriggerMessageQueue], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexFunctionTriggerMessageQueue],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexFunctionTriggerObjectStorage",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexFunctionTriggerObjectStorage:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexFunctionTriggerObjectStorage(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexFunctionTriggerObjectStorageList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexFunctionTriggerObjectStorageList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexFunctionTriggerObjectStorageOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexFunctionTriggerObjectStorageOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexFunctionTriggerObjectStorageOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexFunctionTriggerObjectStorageOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bucketId")
    def bucket_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "bucketId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "create"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "delete"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="prefix")
    def prefix(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "prefix"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="suffix")
    def suffix(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "suffix"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "update"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexFunctionTriggerObjectStorage]:
        return typing.cast(typing.Optional[DataYandexFunctionTriggerObjectStorage], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexFunctionTriggerObjectStorage],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexFunctionTriggerTimer",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexFunctionTriggerTimer:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexFunctionTriggerTimer(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexFunctionTriggerTimerList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexFunctionTriggerTimerList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexFunctionTriggerTimerOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexFunctionTriggerTimerOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexFunctionTriggerTimerOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexFunctionTriggerTimerOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cronExpression")
    def cron_expression(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "cronExpression"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexFunctionTriggerTimer]:
        return typing.cast(typing.Optional[DataYandexFunctionTriggerTimer], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexFunctionTriggerTimer],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexIamPolicy(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexIamPolicy",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/iam_policy yandex_iam_policy}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        binding: typing.Union[cdktf.IResolvable, typing.Sequence["DataYandexIamPolicyBinding"]],
        id: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/iam_policy yandex_iam_policy} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param binding: binding block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_policy#binding DataYandexIamPolicy#binding}
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_policy#id DataYandexIamPolicy#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexIamPolicyConfig(
            binding=binding,
            id=id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putBinding")
    def put_binding(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["DataYandexIamPolicyBinding"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putBinding", [value]))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="binding")
    def binding(self) -> "DataYandexIamPolicyBindingList":
        return typing.cast("DataYandexIamPolicyBindingList", jsii.get(self, "binding"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="policyData")
    def policy_data(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "policyData"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bindingInput")
    def binding_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataYandexIamPolicyBinding"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataYandexIamPolicyBinding"]]], jsii.get(self, "bindingInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexIamPolicyBinding",
    jsii_struct_bases=[],
    name_mapping={"members": "members", "role": "role"},
)
class DataYandexIamPolicyBinding:
    def __init__(
        self,
        *,
        members: typing.Sequence[builtins.str],
        role: builtins.str,
    ) -> None:
        '''
        :param members: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_policy#members DataYandexIamPolicy#members}.
        :param role: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_policy#role DataYandexIamPolicy#role}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "members": members,
            "role": role,
        }

    @builtins.property
    def members(self) -> typing.List[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_policy#members DataYandexIamPolicy#members}.'''
        result = self._values.get("members")
        assert result is not None, "Required property 'members' is missing"
        return typing.cast(typing.List[builtins.str], result)

    @builtins.property
    def role(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_policy#role DataYandexIamPolicy#role}.'''
        result = self._values.get("role")
        assert result is not None, "Required property 'role' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexIamPolicyBinding(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexIamPolicyBindingList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexIamPolicyBindingList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "DataYandexIamPolicyBindingOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexIamPolicyBindingOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataYandexIamPolicyBinding]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataYandexIamPolicyBinding]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataYandexIamPolicyBinding]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexIamPolicyBindingOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexIamPolicyBindingOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="membersInput")
    def members_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "membersInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="roleInput")
    def role_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "roleInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="members")
    def members(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "members"))

    @members.setter
    def members(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "members", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="role")
    def role(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "role"))

    @role.setter
    def role(self, value: builtins.str) -> None:
        jsii.set(self, "role", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, DataYandexIamPolicyBinding]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, DataYandexIamPolicyBinding]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, DataYandexIamPolicyBinding]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexIamPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "binding": "binding",
        "id": "id",
    },
)
class DataYandexIamPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        binding: typing.Union[cdktf.IResolvable, typing.Sequence[DataYandexIamPolicyBinding]],
        id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param binding: binding block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_policy#binding DataYandexIamPolicy#binding}
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_policy#id DataYandexIamPolicy#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {
            "binding": binding,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if id is not None:
            self._values["id"] = id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def binding(
        self,
    ) -> typing.Union[cdktf.IResolvable, typing.List[DataYandexIamPolicyBinding]]:
        '''binding block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_policy#binding DataYandexIamPolicy#binding}
        '''
        result = self._values.get("binding")
        assert result is not None, "Required property 'binding' is missing"
        return typing.cast(typing.Union[cdktf.IResolvable, typing.List[DataYandexIamPolicyBinding]], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_policy#id DataYandexIamPolicy#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexIamPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexIamRole(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexIamRole",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/iam_role yandex_iam_role}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        description: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        role_id: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/iam_role yandex_iam_role} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_role#description DataYandexIamRole#description}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_role#id DataYandexIamRole#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param role_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_role#role_id DataYandexIamRole#role_id}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexIamRoleConfig(
            description=description,
            id=id,
            role_id=role_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetRoleId")
    def reset_role_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRoleId", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="roleIdInput")
    def role_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "roleIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="roleId")
    def role_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "roleId"))

    @role_id.setter
    def role_id(self, value: builtins.str) -> None:
        jsii.set(self, "roleId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexIamRoleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "description": "description",
        "id": "id",
        "role_id": "roleId",
    },
)
class DataYandexIamRoleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        description: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        role_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_role#description DataYandexIamRole#description}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_role#id DataYandexIamRole#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param role_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_role#role_id DataYandexIamRole#role_id}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if id is not None:
            self._values["id"] = id
        if role_id is not None:
            self._values["role_id"] = role_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_role#description DataYandexIamRole#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_role#id DataYandexIamRole#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def role_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_role#role_id DataYandexIamRole#role_id}.'''
        result = self._values.get("role_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexIamRoleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexIamServiceAccount(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexIamServiceAccount",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/iam_service_account yandex_iam_service_account}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        service_account_id: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/iam_service_account yandex_iam_service_account} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_service_account#folder_id DataYandexIamServiceAccount#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_service_account#id DataYandexIamServiceAccount#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_service_account#name DataYandexIamServiceAccount#name}.
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_service_account#service_account_id DataYandexIamServiceAccount#service_account_id}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexIamServiceAccountConfig(
            folder_id=folder_id,
            id=id,
            name=name,
            service_account_id=service_account_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetServiceAccountId")
    def reset_service_account_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetServiceAccountId", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountIdInput")
    def service_account_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceAccountIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountId")
    def service_account_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceAccountId"))

    @service_account_id.setter
    def service_account_id(self, value: builtins.str) -> None:
        jsii.set(self, "serviceAccountId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexIamServiceAccountConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "folder_id": "folderId",
        "id": "id",
        "name": "name",
        "service_account_id": "serviceAccountId",
    },
)
class DataYandexIamServiceAccountConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        service_account_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_service_account#folder_id DataYandexIamServiceAccount#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_service_account#id DataYandexIamServiceAccount#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_service_account#name DataYandexIamServiceAccount#name}.
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_service_account#service_account_id DataYandexIamServiceAccount#service_account_id}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name
        if service_account_id is not None:
            self._values["service_account_id"] = service_account_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_service_account#folder_id DataYandexIamServiceAccount#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_service_account#id DataYandexIamServiceAccount#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_service_account#name DataYandexIamServiceAccount#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def service_account_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_service_account#service_account_id DataYandexIamServiceAccount#service_account_id}.'''
        result = self._values.get("service_account_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexIamServiceAccountConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexIamUser(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexIamUser",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/iam_user yandex_iam_user}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        id: typing.Optional[builtins.str] = None,
        login: typing.Optional[builtins.str] = None,
        user_id: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/iam_user yandex_iam_user} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_user#id DataYandexIamUser#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param login: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_user#login DataYandexIamUser#login}.
        :param user_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_user#user_id DataYandexIamUser#user_id}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexIamUserConfig(
            id=id,
            login=login,
            user_id=user_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLogin")
    def reset_login(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogin", []))

    @jsii.member(jsii_name="resetUserId")
    def reset_user_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUserId", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="defaultEmail")
    def default_email(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "defaultEmail"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="loginInput")
    def login_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "loginInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="userIdInput")
    def user_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "userIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="login")
    def login(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "login"))

    @login.setter
    def login(self, value: builtins.str) -> None:
        jsii.set(self, "login", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="userId")
    def user_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "userId"))

    @user_id.setter
    def user_id(self, value: builtins.str) -> None:
        jsii.set(self, "userId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexIamUserConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "id": "id",
        "login": "login",
        "user_id": "userId",
    },
)
class DataYandexIamUserConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        id: typing.Optional[builtins.str] = None,
        login: typing.Optional[builtins.str] = None,
        user_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_user#id DataYandexIamUser#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param login: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_user#login DataYandexIamUser#login}.
        :param user_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_user#user_id DataYandexIamUser#user_id}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if id is not None:
            self._values["id"] = id
        if login is not None:
            self._values["login"] = login
        if user_id is not None:
            self._values["user_id"] = user_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_user#id DataYandexIamUser#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def login(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_user#login DataYandexIamUser#login}.'''
        result = self._values.get("login")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def user_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iam_user#user_id DataYandexIamUser#user_id}.'''
        result = self._values.get("user_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexIamUserConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexIotCoreDevice(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexIotCoreDevice",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/iot_core_device yandex_iot_core_device}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        device_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/iot_core_device yandex_iot_core_device} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param device_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iot_core_device#device_id DataYandexIotCoreDevice#device_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iot_core_device#id DataYandexIotCoreDevice#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iot_core_device#name DataYandexIotCoreDevice#name}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexIotCoreDeviceConfig(
            device_id=device_id,
            id=id,
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetDeviceId")
    def reset_device_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDeviceId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="aliases")
    def aliases(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "aliases"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="certificates")
    def certificates(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "certificates"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="passwords")
    def passwords(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "passwords"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="registryId")
    def registry_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "registryId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deviceIdInput")
    def device_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deviceIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deviceId")
    def device_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "deviceId"))

    @device_id.setter
    def device_id(self, value: builtins.str) -> None:
        jsii.set(self, "deviceId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexIotCoreDeviceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "device_id": "deviceId",
        "id": "id",
        "name": "name",
    },
)
class DataYandexIotCoreDeviceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        device_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param device_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iot_core_device#device_id DataYandexIotCoreDevice#device_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iot_core_device#id DataYandexIotCoreDevice#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iot_core_device#name DataYandexIotCoreDevice#name}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if device_id is not None:
            self._values["device_id"] = device_id
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def device_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iot_core_device#device_id DataYandexIotCoreDevice#device_id}.'''
        result = self._values.get("device_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iot_core_device#id DataYandexIotCoreDevice#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iot_core_device#name DataYandexIotCoreDevice#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexIotCoreDeviceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexIotCoreRegistry(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexIotCoreRegistry",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/iot_core_registry yandex_iot_core_registry}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        registry_id: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/iot_core_registry yandex_iot_core_registry} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iot_core_registry#folder_id DataYandexIotCoreRegistry#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iot_core_registry#id DataYandexIotCoreRegistry#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iot_core_registry#name DataYandexIotCoreRegistry#name}.
        :param registry_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iot_core_registry#registry_id DataYandexIotCoreRegistry#registry_id}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexIotCoreRegistryConfig(
            folder_id=folder_id,
            id=id,
            name=name,
            registry_id=registry_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetRegistryId")
    def reset_registry_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRegistryId", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="certificates")
    def certificates(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "certificates"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="passwords")
    def passwords(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "passwords"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="registryIdInput")
    def registry_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "registryIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="registryId")
    def registry_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "registryId"))

    @registry_id.setter
    def registry_id(self, value: builtins.str) -> None:
        jsii.set(self, "registryId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexIotCoreRegistryConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "folder_id": "folderId",
        "id": "id",
        "name": "name",
        "registry_id": "registryId",
    },
)
class DataYandexIotCoreRegistryConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        registry_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iot_core_registry#folder_id DataYandexIotCoreRegistry#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iot_core_registry#id DataYandexIotCoreRegistry#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iot_core_registry#name DataYandexIotCoreRegistry#name}.
        :param registry_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iot_core_registry#registry_id DataYandexIotCoreRegistry#registry_id}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name
        if registry_id is not None:
            self._values["registry_id"] = registry_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iot_core_registry#folder_id DataYandexIotCoreRegistry#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iot_core_registry#id DataYandexIotCoreRegistry#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iot_core_registry#name DataYandexIotCoreRegistry#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def registry_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/iot_core_registry#registry_id DataYandexIotCoreRegistry#registry_id}.'''
        result = self._values.get("registry_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexIotCoreRegistryConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexKubernetesCluster(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesCluster",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/kubernetes_cluster yandex_kubernetes_cluster}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        cluster_id: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/kubernetes_cluster yandex_kubernetes_cluster} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/kubernetes_cluster#cluster_id DataYandexKubernetesCluster#cluster_id}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/kubernetes_cluster#folder_id DataYandexKubernetesCluster#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/kubernetes_cluster#id DataYandexKubernetesCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/kubernetes_cluster#name DataYandexKubernetesCluster#name}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexKubernetesClusterConfig(
            cluster_id=cluster_id,
            folder_id=folder_id,
            id=id,
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetClusterId")
    def reset_cluster_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetClusterId", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterIpv4Range")
    def cluster_ipv4_range(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "clusterIpv4Range"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterIpv6Range")
    def cluster_ipv6_range(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "clusterIpv6Range"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="health")
    def health(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "health"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="kmsProvider")
    def kms_provider(self) -> "DataYandexKubernetesClusterKmsProviderList":
        return typing.cast("DataYandexKubernetesClusterKmsProviderList", jsii.get(self, "kmsProvider"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logGroupId")
    def log_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "logGroupId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="master")
    def master(self) -> "DataYandexKubernetesClusterMasterList":
        return typing.cast("DataYandexKubernetesClusterMasterList", jsii.get(self, "master"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkImplementation")
    def network_implementation(
        self,
    ) -> "DataYandexKubernetesClusterNetworkImplementationList":
        return typing.cast("DataYandexKubernetesClusterNetworkImplementationList", jsii.get(self, "networkImplementation"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkPolicyProvider")
    def network_policy_provider(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkPolicyProvider"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nodeIpv4CidrMaskSize")
    def node_ipv4_cidr_mask_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "nodeIpv4CidrMaskSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nodeServiceAccountId")
    def node_service_account_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "nodeServiceAccountId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="releaseChannel")
    def release_channel(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "releaseChannel"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountId")
    def service_account_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceAccountId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceIpv4Range")
    def service_ipv4_range(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceIpv4Range"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceIpv6Range")
    def service_ipv6_range(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceIpv6Range"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterIdInput")
    def cluster_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "clusterIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterId")
    def cluster_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "clusterId"))

    @cluster_id.setter
    def cluster_id(self, value: builtins.str) -> None:
        jsii.set(self, "clusterId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_id": "clusterId",
        "folder_id": "folderId",
        "id": "id",
        "name": "name",
    },
)
class DataYandexKubernetesClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_id: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/kubernetes_cluster#cluster_id DataYandexKubernetesCluster#cluster_id}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/kubernetes_cluster#folder_id DataYandexKubernetesCluster#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/kubernetes_cluster#id DataYandexKubernetesCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/kubernetes_cluster#name DataYandexKubernetesCluster#name}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if cluster_id is not None:
            self._values["cluster_id"] = cluster_id
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def cluster_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/kubernetes_cluster#cluster_id DataYandexKubernetesCluster#cluster_id}.'''
        result = self._values.get("cluster_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/kubernetes_cluster#folder_id DataYandexKubernetesCluster#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/kubernetes_cluster#id DataYandexKubernetesCluster#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/kubernetes_cluster#name DataYandexKubernetesCluster#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexKubernetesClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesClusterKmsProvider",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexKubernetesClusterKmsProvider:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexKubernetesClusterKmsProvider(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexKubernetesClusterKmsProviderList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesClusterKmsProviderList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexKubernetesClusterKmsProviderOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexKubernetesClusterKmsProviderOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexKubernetesClusterKmsProviderOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesClusterKmsProviderOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="keyId")
    def key_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "keyId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexKubernetesClusterKmsProvider]:
        return typing.cast(typing.Optional[DataYandexKubernetesClusterKmsProvider], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexKubernetesClusterKmsProvider],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesClusterMaster",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexKubernetesClusterMaster:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexKubernetesClusterMaster(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexKubernetesClusterMasterList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesClusterMasterList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexKubernetesClusterMasterOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexKubernetesClusterMasterOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesClusterMasterMaintenancePolicy",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexKubernetesClusterMasterMaintenancePolicy:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexKubernetesClusterMasterMaintenancePolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexKubernetesClusterMasterMaintenancePolicyList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesClusterMasterMaintenancePolicyList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexKubernetesClusterMasterMaintenancePolicyOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexKubernetesClusterMasterMaintenancePolicyOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesClusterMasterMaintenancePolicyMaintenanceWindow",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexKubernetesClusterMasterMaintenancePolicyMaintenanceWindow:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexKubernetesClusterMasterMaintenancePolicyMaintenanceWindow(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexKubernetesClusterMasterMaintenancePolicyMaintenanceWindowList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesClusterMasterMaintenancePolicyMaintenanceWindowList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexKubernetesClusterMasterMaintenancePolicyMaintenanceWindowOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexKubernetesClusterMasterMaintenancePolicyMaintenanceWindowOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexKubernetesClusterMasterMaintenancePolicyMaintenanceWindowOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesClusterMasterMaintenancePolicyMaintenanceWindowOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="day")
    def day(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "day"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="duration")
    def duration(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "duration"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="startTime")
    def start_time(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "startTime"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexKubernetesClusterMasterMaintenancePolicyMaintenanceWindow]:
        return typing.cast(typing.Optional[DataYandexKubernetesClusterMasterMaintenancePolicyMaintenanceWindow], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexKubernetesClusterMasterMaintenancePolicyMaintenanceWindow],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexKubernetesClusterMasterMaintenancePolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesClusterMasterMaintenancePolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoUpgrade")
    def auto_upgrade(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "autoUpgrade"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maintenanceWindow")
    def maintenance_window(
        self,
    ) -> DataYandexKubernetesClusterMasterMaintenancePolicyMaintenanceWindowList:
        return typing.cast(DataYandexKubernetesClusterMasterMaintenancePolicyMaintenanceWindowList, jsii.get(self, "maintenanceWindow"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexKubernetesClusterMasterMaintenancePolicy]:
        return typing.cast(typing.Optional[DataYandexKubernetesClusterMasterMaintenancePolicy], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexKubernetesClusterMasterMaintenancePolicy],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexKubernetesClusterMasterOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesClusterMasterOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterCaCertificate")
    def cluster_ca_certificate(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "clusterCaCertificate"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="externalV4Address")
    def external_v4_address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "externalV4Address"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="externalV4Endpoint")
    def external_v4_endpoint(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "externalV4Endpoint"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalV4Address")
    def internal_v4_address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "internalV4Address"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalV4Endpoint")
    def internal_v4_endpoint(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "internalV4Endpoint"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maintenancePolicy")
    def maintenance_policy(
        self,
    ) -> DataYandexKubernetesClusterMasterMaintenancePolicyList:
        return typing.cast(DataYandexKubernetesClusterMasterMaintenancePolicyList, jsii.get(self, "maintenancePolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="publicIp")
    def public_ip(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "publicIp"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="regional")
    def regional(self) -> "DataYandexKubernetesClusterMasterRegionalList":
        return typing.cast("DataYandexKubernetesClusterMasterRegionalList", jsii.get(self, "regional"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "securityGroupIds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "version"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="versionInfo")
    def version_info(self) -> "DataYandexKubernetesClusterMasterVersionInfoList":
        return typing.cast("DataYandexKubernetesClusterMasterVersionInfoList", jsii.get(self, "versionInfo"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zonal")
    def zonal(self) -> "DataYandexKubernetesClusterMasterZonalList":
        return typing.cast("DataYandexKubernetesClusterMasterZonalList", jsii.get(self, "zonal"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexKubernetesClusterMaster]:
        return typing.cast(typing.Optional[DataYandexKubernetesClusterMaster], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexKubernetesClusterMaster],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesClusterMasterRegional",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexKubernetesClusterMasterRegional:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexKubernetesClusterMasterRegional(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexKubernetesClusterMasterRegionalList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesClusterMasterRegionalList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexKubernetesClusterMasterRegionalOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexKubernetesClusterMasterRegionalOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexKubernetesClusterMasterRegionalOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesClusterMasterRegionalOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="region")
    def region(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "region"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexKubernetesClusterMasterRegional]:
        return typing.cast(typing.Optional[DataYandexKubernetesClusterMasterRegional], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexKubernetesClusterMasterRegional],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesClusterMasterVersionInfo",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexKubernetesClusterMasterVersionInfo:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexKubernetesClusterMasterVersionInfo(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexKubernetesClusterMasterVersionInfoList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesClusterMasterVersionInfoList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexKubernetesClusterMasterVersionInfoOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexKubernetesClusterMasterVersionInfoOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexKubernetesClusterMasterVersionInfoOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesClusterMasterVersionInfoOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="currentVersion")
    def current_version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "currentVersion"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="newRevisionAvailable")
    def new_revision_available(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "newRevisionAvailable"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="newRevisionSummary")
    def new_revision_summary(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "newRevisionSummary"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="versionDeprecated")
    def version_deprecated(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "versionDeprecated"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexKubernetesClusterMasterVersionInfo]:
        return typing.cast(typing.Optional[DataYandexKubernetesClusterMasterVersionInfo], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexKubernetesClusterMasterVersionInfo],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesClusterMasterZonal",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexKubernetesClusterMasterZonal:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexKubernetesClusterMasterZonal(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexKubernetesClusterMasterZonalList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesClusterMasterZonalList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexKubernetesClusterMasterZonalOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexKubernetesClusterMasterZonalOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexKubernetesClusterMasterZonalOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesClusterMasterZonalOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zone")
    def zone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zone"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexKubernetesClusterMasterZonal]:
        return typing.cast(typing.Optional[DataYandexKubernetesClusterMasterZonal], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexKubernetesClusterMasterZonal],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesClusterNetworkImplementation",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexKubernetesClusterNetworkImplementation:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexKubernetesClusterNetworkImplementation(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesClusterNetworkImplementationCilium",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexKubernetesClusterNetworkImplementationCilium:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexKubernetesClusterNetworkImplementationCilium(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexKubernetesClusterNetworkImplementationCiliumList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesClusterNetworkImplementationCiliumList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexKubernetesClusterNetworkImplementationCiliumOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexKubernetesClusterNetworkImplementationCiliumOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexKubernetesClusterNetworkImplementationCiliumOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesClusterNetworkImplementationCiliumOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="routingMode")
    def routing_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "routingMode"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexKubernetesClusterNetworkImplementationCilium]:
        return typing.cast(typing.Optional[DataYandexKubernetesClusterNetworkImplementationCilium], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexKubernetesClusterNetworkImplementationCilium],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexKubernetesClusterNetworkImplementationList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesClusterNetworkImplementationList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexKubernetesClusterNetworkImplementationOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexKubernetesClusterNetworkImplementationOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexKubernetesClusterNetworkImplementationOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesClusterNetworkImplementationOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cilium")
    def cilium(self) -> DataYandexKubernetesClusterNetworkImplementationCiliumList:
        return typing.cast(DataYandexKubernetesClusterNetworkImplementationCiliumList, jsii.get(self, "cilium"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexKubernetesClusterNetworkImplementation]:
        return typing.cast(typing.Optional[DataYandexKubernetesClusterNetworkImplementation], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexKubernetesClusterNetworkImplementation],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexKubernetesNodeGroup(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroup",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/kubernetes_node_group yandex_kubernetes_node_group}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        node_group_id: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/kubernetes_node_group yandex_kubernetes_node_group} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/kubernetes_node_group#folder_id DataYandexKubernetesNodeGroup#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/kubernetes_node_group#id DataYandexKubernetesNodeGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/kubernetes_node_group#name DataYandexKubernetesNodeGroup#name}.
        :param node_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/kubernetes_node_group#node_group_id DataYandexKubernetesNodeGroup#node_group_id}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexKubernetesNodeGroupConfig(
            folder_id=folder_id,
            id=id,
            name=name,
            node_group_id=node_group_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetNodeGroupId")
    def reset_node_group_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNodeGroupId", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allocationPolicy")
    def allocation_policy(self) -> "DataYandexKubernetesNodeGroupAllocationPolicyList":
        return typing.cast("DataYandexKubernetesNodeGroupAllocationPolicyList", jsii.get(self, "allocationPolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allowedUnsafeSysctls")
    def allowed_unsafe_sysctls(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "allowedUnsafeSysctls"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterId")
    def cluster_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "clusterId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deployPolicy")
    def deploy_policy(self) -> "DataYandexKubernetesNodeGroupDeployPolicyList":
        return typing.cast("DataYandexKubernetesNodeGroupDeployPolicyList", jsii.get(self, "deployPolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="instanceGroupId")
    def instance_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "instanceGroupId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="instanceTemplate")
    def instance_template(self) -> "DataYandexKubernetesNodeGroupInstanceTemplateList":
        return typing.cast("DataYandexKubernetesNodeGroupInstanceTemplateList", jsii.get(self, "instanceTemplate"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maintenancePolicy")
    def maintenance_policy(
        self,
    ) -> "DataYandexKubernetesNodeGroupMaintenancePolicyList":
        return typing.cast("DataYandexKubernetesNodeGroupMaintenancePolicyList", jsii.get(self, "maintenancePolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nodeLabels")
    def node_labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "nodeLabels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nodeTaints")
    def node_taints(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "nodeTaints"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="scalePolicy")
    def scale_policy(self) -> "DataYandexKubernetesNodeGroupScalePolicyList":
        return typing.cast("DataYandexKubernetesNodeGroupScalePolicyList", jsii.get(self, "scalePolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="versionInfo")
    def version_info(self) -> "DataYandexKubernetesNodeGroupVersionInfoList":
        return typing.cast("DataYandexKubernetesNodeGroupVersionInfoList", jsii.get(self, "versionInfo"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nodeGroupIdInput")
    def node_group_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nodeGroupIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nodeGroupId")
    def node_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "nodeGroupId"))

    @node_group_id.setter
    def node_group_id(self, value: builtins.str) -> None:
        jsii.set(self, "nodeGroupId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupAllocationPolicy",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexKubernetesNodeGroupAllocationPolicy:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexKubernetesNodeGroupAllocationPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexKubernetesNodeGroupAllocationPolicyList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupAllocationPolicyList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexKubernetesNodeGroupAllocationPolicyOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexKubernetesNodeGroupAllocationPolicyOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupAllocationPolicyLocation",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexKubernetesNodeGroupAllocationPolicyLocation:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexKubernetesNodeGroupAllocationPolicyLocation(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexKubernetesNodeGroupAllocationPolicyLocationList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupAllocationPolicyLocationList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexKubernetesNodeGroupAllocationPolicyLocationOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexKubernetesNodeGroupAllocationPolicyLocationOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexKubernetesNodeGroupAllocationPolicyLocationOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupAllocationPolicyLocationOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zone")
    def zone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zone"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexKubernetesNodeGroupAllocationPolicyLocation]:
        return typing.cast(typing.Optional[DataYandexKubernetesNodeGroupAllocationPolicyLocation], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexKubernetesNodeGroupAllocationPolicyLocation],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexKubernetesNodeGroupAllocationPolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupAllocationPolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="location")
    def location(self) -> DataYandexKubernetesNodeGroupAllocationPolicyLocationList:
        return typing.cast(DataYandexKubernetesNodeGroupAllocationPolicyLocationList, jsii.get(self, "location"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexKubernetesNodeGroupAllocationPolicy]:
        return typing.cast(typing.Optional[DataYandexKubernetesNodeGroupAllocationPolicy], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexKubernetesNodeGroupAllocationPolicy],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "folder_id": "folderId",
        "id": "id",
        "name": "name",
        "node_group_id": "nodeGroupId",
    },
)
class DataYandexKubernetesNodeGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        node_group_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/kubernetes_node_group#folder_id DataYandexKubernetesNodeGroup#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/kubernetes_node_group#id DataYandexKubernetesNodeGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/kubernetes_node_group#name DataYandexKubernetesNodeGroup#name}.
        :param node_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/kubernetes_node_group#node_group_id DataYandexKubernetesNodeGroup#node_group_id}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name
        if node_group_id is not None:
            self._values["node_group_id"] = node_group_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/kubernetes_node_group#folder_id DataYandexKubernetesNodeGroup#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/kubernetes_node_group#id DataYandexKubernetesNodeGroup#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/kubernetes_node_group#name DataYandexKubernetesNodeGroup#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def node_group_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/kubernetes_node_group#node_group_id DataYandexKubernetesNodeGroup#node_group_id}.'''
        result = self._values.get("node_group_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexKubernetesNodeGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupDeployPolicy",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexKubernetesNodeGroupDeployPolicy:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexKubernetesNodeGroupDeployPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexKubernetesNodeGroupDeployPolicyList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupDeployPolicyList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexKubernetesNodeGroupDeployPolicyOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexKubernetesNodeGroupDeployPolicyOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexKubernetesNodeGroupDeployPolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupDeployPolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxExpansion")
    def max_expansion(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxExpansion"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxUnavailable")
    def max_unavailable(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxUnavailable"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexKubernetesNodeGroupDeployPolicy]:
        return typing.cast(typing.Optional[DataYandexKubernetesNodeGroupDeployPolicy], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexKubernetesNodeGroupDeployPolicy],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupInstanceTemplate",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexKubernetesNodeGroupInstanceTemplate:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexKubernetesNodeGroupInstanceTemplate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupInstanceTemplateBootDisk",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexKubernetesNodeGroupInstanceTemplateBootDisk:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexKubernetesNodeGroupInstanceTemplateBootDisk(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexKubernetesNodeGroupInstanceTemplateBootDiskList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupInstanceTemplateBootDiskList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexKubernetesNodeGroupInstanceTemplateBootDiskOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexKubernetesNodeGroupInstanceTemplateBootDiskOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexKubernetesNodeGroupInstanceTemplateBootDiskOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupInstanceTemplateBootDiskOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="size")
    def size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "size"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexKubernetesNodeGroupInstanceTemplateBootDisk]:
        return typing.cast(typing.Optional[DataYandexKubernetesNodeGroupInstanceTemplateBootDisk], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexKubernetesNodeGroupInstanceTemplateBootDisk],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupInstanceTemplateContainerRuntime",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexKubernetesNodeGroupInstanceTemplateContainerRuntime:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexKubernetesNodeGroupInstanceTemplateContainerRuntime(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexKubernetesNodeGroupInstanceTemplateContainerRuntimeList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupInstanceTemplateContainerRuntimeList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexKubernetesNodeGroupInstanceTemplateContainerRuntimeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexKubernetesNodeGroupInstanceTemplateContainerRuntimeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexKubernetesNodeGroupInstanceTemplateContainerRuntimeOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupInstanceTemplateContainerRuntimeOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexKubernetesNodeGroupInstanceTemplateContainerRuntime]:
        return typing.cast(typing.Optional[DataYandexKubernetesNodeGroupInstanceTemplateContainerRuntime], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexKubernetesNodeGroupInstanceTemplateContainerRuntime],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexKubernetesNodeGroupInstanceTemplateList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupInstanceTemplateList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexKubernetesNodeGroupInstanceTemplateOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexKubernetesNodeGroupInstanceTemplateOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupInstanceTemplateNetworkInterface",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexKubernetesNodeGroupInstanceTemplateNetworkInterface:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexKubernetesNodeGroupInstanceTemplateNetworkInterface(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexKubernetesNodeGroupInstanceTemplateNetworkInterfaceList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupInstanceTemplateNetworkInterfaceList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexKubernetesNodeGroupInstanceTemplateNetworkInterfaceOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexKubernetesNodeGroupInstanceTemplateNetworkInterfaceOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexKubernetesNodeGroupInstanceTemplateNetworkInterfaceOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupInstanceTemplateNetworkInterfaceOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv4")
    def ipv4(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "ipv4"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv6")
    def ipv6(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "ipv6"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nat")
    def nat(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "nat"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "securityGroupIds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "subnetIds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexKubernetesNodeGroupInstanceTemplateNetworkInterface]:
        return typing.cast(typing.Optional[DataYandexKubernetesNodeGroupInstanceTemplateNetworkInterface], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexKubernetesNodeGroupInstanceTemplateNetworkInterface],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexKubernetesNodeGroupInstanceTemplateOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupInstanceTemplateOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bootDisk")
    def boot_disk(self) -> DataYandexKubernetesNodeGroupInstanceTemplateBootDiskList:
        return typing.cast(DataYandexKubernetesNodeGroupInstanceTemplateBootDiskList, jsii.get(self, "bootDisk"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="containerRuntime")
    def container_runtime(
        self,
    ) -> DataYandexKubernetesNodeGroupInstanceTemplateContainerRuntimeList:
        return typing.cast(DataYandexKubernetesNodeGroupInstanceTemplateContainerRuntimeList, jsii.get(self, "containerRuntime"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metadata")
    def metadata(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "metadata"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nat")
    def nat(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "nat"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkAccelerationType")
    def network_acceleration_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkAccelerationType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkInterface")
    def network_interface(
        self,
    ) -> DataYandexKubernetesNodeGroupInstanceTemplateNetworkInterfaceList:
        return typing.cast(DataYandexKubernetesNodeGroupInstanceTemplateNetworkInterfaceList, jsii.get(self, "networkInterface"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="placementPolicy")
    def placement_policy(
        self,
    ) -> "DataYandexKubernetesNodeGroupInstanceTemplatePlacementPolicyList":
        return typing.cast("DataYandexKubernetesNodeGroupInstanceTemplatePlacementPolicyList", jsii.get(self, "placementPolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="platformId")
    def platform_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "platformId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resources")
    def resources(self) -> "DataYandexKubernetesNodeGroupInstanceTemplateResourcesList":
        return typing.cast("DataYandexKubernetesNodeGroupInstanceTemplateResourcesList", jsii.get(self, "resources"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="schedulingPolicy")
    def scheduling_policy(
        self,
    ) -> "DataYandexKubernetesNodeGroupInstanceTemplateSchedulingPolicyList":
        return typing.cast("DataYandexKubernetesNodeGroupInstanceTemplateSchedulingPolicyList", jsii.get(self, "schedulingPolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexKubernetesNodeGroupInstanceTemplate]:
        return typing.cast(typing.Optional[DataYandexKubernetesNodeGroupInstanceTemplate], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexKubernetesNodeGroupInstanceTemplate],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupInstanceTemplatePlacementPolicy",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexKubernetesNodeGroupInstanceTemplatePlacementPolicy:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexKubernetesNodeGroupInstanceTemplatePlacementPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexKubernetesNodeGroupInstanceTemplatePlacementPolicyList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupInstanceTemplatePlacementPolicyList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexKubernetesNodeGroupInstanceTemplatePlacementPolicyOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexKubernetesNodeGroupInstanceTemplatePlacementPolicyOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexKubernetesNodeGroupInstanceTemplatePlacementPolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupInstanceTemplatePlacementPolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="placementGroupId")
    def placement_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "placementGroupId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexKubernetesNodeGroupInstanceTemplatePlacementPolicy]:
        return typing.cast(typing.Optional[DataYandexKubernetesNodeGroupInstanceTemplatePlacementPolicy], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexKubernetesNodeGroupInstanceTemplatePlacementPolicy],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupInstanceTemplateResources",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexKubernetesNodeGroupInstanceTemplateResources:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexKubernetesNodeGroupInstanceTemplateResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexKubernetesNodeGroupInstanceTemplateResourcesList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupInstanceTemplateResourcesList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexKubernetesNodeGroupInstanceTemplateResourcesOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexKubernetesNodeGroupInstanceTemplateResourcesOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexKubernetesNodeGroupInstanceTemplateResourcesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupInstanceTemplateResourcesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="coreFraction")
    def core_fraction(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "coreFraction"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cores")
    def cores(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "cores"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="gpus")
    def gpus(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "gpus"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="memory")
    def memory(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "memory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexKubernetesNodeGroupInstanceTemplateResources]:
        return typing.cast(typing.Optional[DataYandexKubernetesNodeGroupInstanceTemplateResources], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexKubernetesNodeGroupInstanceTemplateResources],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupInstanceTemplateSchedulingPolicy",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexKubernetesNodeGroupInstanceTemplateSchedulingPolicy:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexKubernetesNodeGroupInstanceTemplateSchedulingPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexKubernetesNodeGroupInstanceTemplateSchedulingPolicyList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupInstanceTemplateSchedulingPolicyList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexKubernetesNodeGroupInstanceTemplateSchedulingPolicyOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexKubernetesNodeGroupInstanceTemplateSchedulingPolicyOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexKubernetesNodeGroupInstanceTemplateSchedulingPolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupInstanceTemplateSchedulingPolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="preemptible")
    def preemptible(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "preemptible"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexKubernetesNodeGroupInstanceTemplateSchedulingPolicy]:
        return typing.cast(typing.Optional[DataYandexKubernetesNodeGroupInstanceTemplateSchedulingPolicy], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexKubernetesNodeGroupInstanceTemplateSchedulingPolicy],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupMaintenancePolicy",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexKubernetesNodeGroupMaintenancePolicy:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexKubernetesNodeGroupMaintenancePolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexKubernetesNodeGroupMaintenancePolicyList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupMaintenancePolicyList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexKubernetesNodeGroupMaintenancePolicyOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexKubernetesNodeGroupMaintenancePolicyOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupMaintenancePolicyMaintenanceWindow",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexKubernetesNodeGroupMaintenancePolicyMaintenanceWindow:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexKubernetesNodeGroupMaintenancePolicyMaintenanceWindow(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexKubernetesNodeGroupMaintenancePolicyMaintenanceWindowList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupMaintenancePolicyMaintenanceWindowList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexKubernetesNodeGroupMaintenancePolicyMaintenanceWindowOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexKubernetesNodeGroupMaintenancePolicyMaintenanceWindowOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexKubernetesNodeGroupMaintenancePolicyMaintenanceWindowOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupMaintenancePolicyMaintenanceWindowOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="day")
    def day(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "day"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="duration")
    def duration(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "duration"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="startTime")
    def start_time(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "startTime"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexKubernetesNodeGroupMaintenancePolicyMaintenanceWindow]:
        return typing.cast(typing.Optional[DataYandexKubernetesNodeGroupMaintenancePolicyMaintenanceWindow], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexKubernetesNodeGroupMaintenancePolicyMaintenanceWindow],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexKubernetesNodeGroupMaintenancePolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupMaintenancePolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoRepair")
    def auto_repair(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "autoRepair"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoUpgrade")
    def auto_upgrade(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "autoUpgrade"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maintenanceWindow")
    def maintenance_window(
        self,
    ) -> DataYandexKubernetesNodeGroupMaintenancePolicyMaintenanceWindowList:
        return typing.cast(DataYandexKubernetesNodeGroupMaintenancePolicyMaintenanceWindowList, jsii.get(self, "maintenanceWindow"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexKubernetesNodeGroupMaintenancePolicy]:
        return typing.cast(typing.Optional[DataYandexKubernetesNodeGroupMaintenancePolicy], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexKubernetesNodeGroupMaintenancePolicy],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupScalePolicy",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexKubernetesNodeGroupScalePolicy:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexKubernetesNodeGroupScalePolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupScalePolicyAutoScale",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexKubernetesNodeGroupScalePolicyAutoScale:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexKubernetesNodeGroupScalePolicyAutoScale(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexKubernetesNodeGroupScalePolicyAutoScaleList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupScalePolicyAutoScaleList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexKubernetesNodeGroupScalePolicyAutoScaleOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexKubernetesNodeGroupScalePolicyAutoScaleOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexKubernetesNodeGroupScalePolicyAutoScaleOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupScalePolicyAutoScaleOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="initial")
    def initial(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "initial"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="max")
    def max(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "max"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="min")
    def min(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "min"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexKubernetesNodeGroupScalePolicyAutoScale]:
        return typing.cast(typing.Optional[DataYandexKubernetesNodeGroupScalePolicyAutoScale], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexKubernetesNodeGroupScalePolicyAutoScale],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupScalePolicyFixedScale",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexKubernetesNodeGroupScalePolicyFixedScale:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexKubernetesNodeGroupScalePolicyFixedScale(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexKubernetesNodeGroupScalePolicyFixedScaleList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupScalePolicyFixedScaleList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexKubernetesNodeGroupScalePolicyFixedScaleOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexKubernetesNodeGroupScalePolicyFixedScaleOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexKubernetesNodeGroupScalePolicyFixedScaleOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupScalePolicyFixedScaleOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="size")
    def size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "size"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexKubernetesNodeGroupScalePolicyFixedScale]:
        return typing.cast(typing.Optional[DataYandexKubernetesNodeGroupScalePolicyFixedScale], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexKubernetesNodeGroupScalePolicyFixedScale],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexKubernetesNodeGroupScalePolicyList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupScalePolicyList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexKubernetesNodeGroupScalePolicyOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexKubernetesNodeGroupScalePolicyOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexKubernetesNodeGroupScalePolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupScalePolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoScale")
    def auto_scale(self) -> DataYandexKubernetesNodeGroupScalePolicyAutoScaleList:
        return typing.cast(DataYandexKubernetesNodeGroupScalePolicyAutoScaleList, jsii.get(self, "autoScale"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fixedScale")
    def fixed_scale(self) -> DataYandexKubernetesNodeGroupScalePolicyFixedScaleList:
        return typing.cast(DataYandexKubernetesNodeGroupScalePolicyFixedScaleList, jsii.get(self, "fixedScale"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexKubernetesNodeGroupScalePolicy]:
        return typing.cast(typing.Optional[DataYandexKubernetesNodeGroupScalePolicy], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexKubernetesNodeGroupScalePolicy],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupVersionInfo",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexKubernetesNodeGroupVersionInfo:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexKubernetesNodeGroupVersionInfo(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexKubernetesNodeGroupVersionInfoList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupVersionInfoList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexKubernetesNodeGroupVersionInfoOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexKubernetesNodeGroupVersionInfoOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexKubernetesNodeGroupVersionInfoOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexKubernetesNodeGroupVersionInfoOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="currentVersion")
    def current_version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "currentVersion"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="newRevisionAvailable")
    def new_revision_available(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "newRevisionAvailable"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="newRevisionSummary")
    def new_revision_summary(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "newRevisionSummary"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="versionDeprecated")
    def version_deprecated(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "versionDeprecated"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexKubernetesNodeGroupVersionInfo]:
        return typing.cast(typing.Optional[DataYandexKubernetesNodeGroupVersionInfo], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexKubernetesNodeGroupVersionInfo],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexLbNetworkLoadBalancer(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexLbNetworkLoadBalancer",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/lb_network_load_balancer yandex_lb_network_load_balancer}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        network_load_balancer_id: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/lb_network_load_balancer yandex_lb_network_load_balancer} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/lb_network_load_balancer#folder_id DataYandexLbNetworkLoadBalancer#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/lb_network_load_balancer#id DataYandexLbNetworkLoadBalancer#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/lb_network_load_balancer#name DataYandexLbNetworkLoadBalancer#name}.
        :param network_load_balancer_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/lb_network_load_balancer#network_load_balancer_id DataYandexLbNetworkLoadBalancer#network_load_balancer_id}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexLbNetworkLoadBalancerConfig(
            folder_id=folder_id,
            id=id,
            name=name,
            network_load_balancer_id=network_load_balancer_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetNetworkLoadBalancerId")
    def reset_network_load_balancer_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNetworkLoadBalancerId", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="attachedTargetGroup")
    def attached_target_group(
        self,
    ) -> "DataYandexLbNetworkLoadBalancerAttachedTargetGroupList":
        return typing.cast("DataYandexLbNetworkLoadBalancerAttachedTargetGroupList", jsii.get(self, "attachedTargetGroup"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="listener")
    def listener(self) -> "DataYandexLbNetworkLoadBalancerListenerList":
        return typing.cast("DataYandexLbNetworkLoadBalancerListenerList", jsii.get(self, "listener"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="regionId")
    def region_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "regionId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkLoadBalancerIdInput")
    def network_load_balancer_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "networkLoadBalancerIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkLoadBalancerId")
    def network_load_balancer_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkLoadBalancerId"))

    @network_load_balancer_id.setter
    def network_load_balancer_id(self, value: builtins.str) -> None:
        jsii.set(self, "networkLoadBalancerId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexLbNetworkLoadBalancerAttachedTargetGroup",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexLbNetworkLoadBalancerAttachedTargetGroup:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexLbNetworkLoadBalancerAttachedTargetGroup(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheck",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheck:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheck(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptions",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptions:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptionsList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptionsList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptionsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptionsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptionsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptionsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="path")
    def path(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "path"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "port"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptions]:
        return typing.cast(typing.Optional[DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptions], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptions],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthyThreshold")
    def healthy_threshold(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "healthyThreshold"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpOptions")
    def http_options(
        self,
    ) -> DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptionsList:
        return typing.cast(DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptionsList, jsii.get(self, "httpOptions"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tcpOptions")
    def tcp_options(
        self,
    ) -> "DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptionsList":
        return typing.cast("DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptionsList", jsii.get(self, "tcpOptions"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeout")
    def timeout(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "timeout"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="unhealthyThreshold")
    def unhealthy_threshold(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "unhealthyThreshold"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheck]:
        return typing.cast(typing.Optional[DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheck], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheck],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptions",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptions:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptionsList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptionsList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptionsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptionsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptionsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptionsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "port"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptions]:
        return typing.cast(typing.Optional[DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptions], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptions],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexLbNetworkLoadBalancerAttachedTargetGroupList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexLbNetworkLoadBalancerAttachedTargetGroupList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexLbNetworkLoadBalancerAttachedTargetGroupOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexLbNetworkLoadBalancerAttachedTargetGroupOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexLbNetworkLoadBalancerAttachedTargetGroupOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexLbNetworkLoadBalancerAttachedTargetGroupOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthcheck")
    def healthcheck(
        self,
    ) -> DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckList:
        return typing.cast(DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckList, jsii.get(self, "healthcheck"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupId")
    def target_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "targetGroupId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexLbNetworkLoadBalancerAttachedTargetGroup]:
        return typing.cast(typing.Optional[DataYandexLbNetworkLoadBalancerAttachedTargetGroup], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexLbNetworkLoadBalancerAttachedTargetGroup],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexLbNetworkLoadBalancerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "folder_id": "folderId",
        "id": "id",
        "name": "name",
        "network_load_balancer_id": "networkLoadBalancerId",
    },
)
class DataYandexLbNetworkLoadBalancerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        network_load_balancer_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/lb_network_load_balancer#folder_id DataYandexLbNetworkLoadBalancer#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/lb_network_load_balancer#id DataYandexLbNetworkLoadBalancer#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/lb_network_load_balancer#name DataYandexLbNetworkLoadBalancer#name}.
        :param network_load_balancer_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/lb_network_load_balancer#network_load_balancer_id DataYandexLbNetworkLoadBalancer#network_load_balancer_id}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name
        if network_load_balancer_id is not None:
            self._values["network_load_balancer_id"] = network_load_balancer_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/lb_network_load_balancer#folder_id DataYandexLbNetworkLoadBalancer#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/lb_network_load_balancer#id DataYandexLbNetworkLoadBalancer#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/lb_network_load_balancer#name DataYandexLbNetworkLoadBalancer#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def network_load_balancer_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/lb_network_load_balancer#network_load_balancer_id DataYandexLbNetworkLoadBalancer#network_load_balancer_id}.'''
        result = self._values.get("network_load_balancer_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexLbNetworkLoadBalancerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexLbNetworkLoadBalancerListener",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexLbNetworkLoadBalancerListener:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexLbNetworkLoadBalancerListener(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexLbNetworkLoadBalancerListenerExternalAddressSpec",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexLbNetworkLoadBalancerListenerExternalAddressSpec:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexLbNetworkLoadBalancerListenerExternalAddressSpec(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexLbNetworkLoadBalancerListenerExternalAddressSpecList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexLbNetworkLoadBalancerListenerExternalAddressSpecList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexLbNetworkLoadBalancerListenerExternalAddressSpecOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexLbNetworkLoadBalancerListenerExternalAddressSpecOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexLbNetworkLoadBalancerListenerExternalAddressSpecOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexLbNetworkLoadBalancerListenerExternalAddressSpecOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="address")
    def address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "address"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipVersion")
    def ip_version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ipVersion"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexLbNetworkLoadBalancerListenerExternalAddressSpec]:
        return typing.cast(typing.Optional[DataYandexLbNetworkLoadBalancerListenerExternalAddressSpec], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexLbNetworkLoadBalancerListenerExternalAddressSpec],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexLbNetworkLoadBalancerListenerInternalAddressSpec",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexLbNetworkLoadBalancerListenerInternalAddressSpec:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexLbNetworkLoadBalancerListenerInternalAddressSpec(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexLbNetworkLoadBalancerListenerInternalAddressSpecList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexLbNetworkLoadBalancerListenerInternalAddressSpecList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexLbNetworkLoadBalancerListenerInternalAddressSpecOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexLbNetworkLoadBalancerListenerInternalAddressSpecOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexLbNetworkLoadBalancerListenerInternalAddressSpecOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexLbNetworkLoadBalancerListenerInternalAddressSpecOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="address")
    def address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "address"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipVersion")
    def ip_version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ipVersion"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexLbNetworkLoadBalancerListenerInternalAddressSpec]:
        return typing.cast(typing.Optional[DataYandexLbNetworkLoadBalancerListenerInternalAddressSpec], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexLbNetworkLoadBalancerListenerInternalAddressSpec],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexLbNetworkLoadBalancerListenerList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexLbNetworkLoadBalancerListenerList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexLbNetworkLoadBalancerListenerOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexLbNetworkLoadBalancerListenerOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexLbNetworkLoadBalancerListenerOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexLbNetworkLoadBalancerListenerOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="externalAddressSpec")
    def external_address_spec(
        self,
    ) -> DataYandexLbNetworkLoadBalancerListenerExternalAddressSpecList:
        return typing.cast(DataYandexLbNetworkLoadBalancerListenerExternalAddressSpecList, jsii.get(self, "externalAddressSpec"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalAddressSpec")
    def internal_address_spec(
        self,
    ) -> DataYandexLbNetworkLoadBalancerListenerInternalAddressSpecList:
        return typing.cast(DataYandexLbNetworkLoadBalancerListenerInternalAddressSpecList, jsii.get(self, "internalAddressSpec"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "port"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "protocol"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetPort")
    def target_port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "targetPort"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexLbNetworkLoadBalancerListener]:
        return typing.cast(typing.Optional[DataYandexLbNetworkLoadBalancerListener], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexLbNetworkLoadBalancerListener],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexLbTargetGroup(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexLbTargetGroup",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/lb_target_group yandex_lb_target_group}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        target_group_id: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/lb_target_group yandex_lb_target_group} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/lb_target_group#folder_id DataYandexLbTargetGroup#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/lb_target_group#id DataYandexLbTargetGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/lb_target_group#name DataYandexLbTargetGroup#name}.
        :param target_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/lb_target_group#target_group_id DataYandexLbTargetGroup#target_group_id}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexLbTargetGroupConfig(
            folder_id=folder_id,
            id=id,
            name=name,
            target_group_id=target_group_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetTargetGroupId")
    def reset_target_group_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTargetGroupId", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="target")
    def target(self) -> "DataYandexLbTargetGroupTargetList":
        return typing.cast("DataYandexLbTargetGroupTargetList", jsii.get(self, "target"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupIdInput")
    def target_group_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "targetGroupIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupId")
    def target_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "targetGroupId"))

    @target_group_id.setter
    def target_group_id(self, value: builtins.str) -> None:
        jsii.set(self, "targetGroupId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexLbTargetGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "folder_id": "folderId",
        "id": "id",
        "name": "name",
        "target_group_id": "targetGroupId",
    },
)
class DataYandexLbTargetGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        target_group_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/lb_target_group#folder_id DataYandexLbTargetGroup#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/lb_target_group#id DataYandexLbTargetGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/lb_target_group#name DataYandexLbTargetGroup#name}.
        :param target_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/lb_target_group#target_group_id DataYandexLbTargetGroup#target_group_id}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name
        if target_group_id is not None:
            self._values["target_group_id"] = target_group_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/lb_target_group#folder_id DataYandexLbTargetGroup#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/lb_target_group#id DataYandexLbTargetGroup#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/lb_target_group#name DataYandexLbTargetGroup#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def target_group_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/lb_target_group#target_group_id DataYandexLbTargetGroup#target_group_id}.'''
        result = self._values.get("target_group_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexLbTargetGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexLbTargetGroupTarget",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexLbTargetGroupTarget:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexLbTargetGroupTarget(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexLbTargetGroupTargetList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexLbTargetGroupTargetList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "DataYandexLbTargetGroupTargetOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexLbTargetGroupTargetOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexLbTargetGroupTargetOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexLbTargetGroupTargetOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="address")
    def address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "address"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexLbTargetGroupTarget]:
        return typing.cast(typing.Optional[DataYandexLbTargetGroupTarget], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexLbTargetGroupTarget],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexLoggingGroup(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexLoggingGroup",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/logging_group yandex_logging_group}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        folder_id: typing.Optional[builtins.str] = None,
        group_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/logging_group yandex_logging_group} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/logging_group#folder_id DataYandexLoggingGroup#folder_id}.
        :param group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/logging_group#group_id DataYandexLoggingGroup#group_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/logging_group#id DataYandexLoggingGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/logging_group#name DataYandexLoggingGroup#name}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexLoggingGroupConfig(
            folder_id=folder_id,
            group_id=group_id,
            id=id,
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetGroupId")
    def reset_group_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cloudId")
    def cloud_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "cloudId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="retentionPeriod")
    def retention_period(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "retentionPeriod"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="groupIdInput")
    def group_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "groupIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="groupId")
    def group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "groupId"))

    @group_id.setter
    def group_id(self, value: builtins.str) -> None:
        jsii.set(self, "groupId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexLoggingGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "folder_id": "folderId",
        "group_id": "groupId",
        "id": "id",
        "name": "name",
    },
)
class DataYandexLoggingGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        folder_id: typing.Optional[builtins.str] = None,
        group_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/logging_group#folder_id DataYandexLoggingGroup#folder_id}.
        :param group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/logging_group#group_id DataYandexLoggingGroup#group_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/logging_group#id DataYandexLoggingGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/logging_group#name DataYandexLoggingGroup#name}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if group_id is not None:
            self._values["group_id"] = group_id
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/logging_group#folder_id DataYandexLoggingGroup#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def group_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/logging_group#group_id DataYandexLoggingGroup#group_id}.'''
        result = self._values.get("group_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/logging_group#id DataYandexLoggingGroup#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/logging_group#name DataYandexLoggingGroup#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexLoggingGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbClickhouseCluster(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseCluster",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/mdb_clickhouse_cluster yandex_mdb_clickhouse_cluster}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        cloud_storage: typing.Optional["DataYandexMdbClickhouseClusterCloudStorage"] = None,
        cluster_id: typing.Optional[builtins.str] = None,
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        service_account_id: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/mdb_clickhouse_cluster yandex_mdb_clickhouse_cluster} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param cloud_storage: cloud_storage block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_clickhouse_cluster#cloud_storage DataYandexMdbClickhouseCluster#cloud_storage}
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_clickhouse_cluster#cluster_id DataYandexMdbClickhouseCluster#cluster_id}.
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_clickhouse_cluster#deletion_protection DataYandexMdbClickhouseCluster#deletion_protection}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_clickhouse_cluster#folder_id DataYandexMdbClickhouseCluster#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_clickhouse_cluster#id DataYandexMdbClickhouseCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_clickhouse_cluster#name DataYandexMdbClickhouseCluster#name}.
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_clickhouse_cluster#service_account_id DataYandexMdbClickhouseCluster#service_account_id}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexMdbClickhouseClusterConfig(
            cloud_storage=cloud_storage,
            cluster_id=cluster_id,
            deletion_protection=deletion_protection,
            folder_id=folder_id,
            id=id,
            name=name,
            service_account_id=service_account_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putCloudStorage")
    def put_cloud_storage(
        self,
        *,
        enabled: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        '''
        :param enabled: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_clickhouse_cluster#enabled DataYandexMdbClickhouseCluster#enabled}.
        '''
        value = DataYandexMdbClickhouseClusterCloudStorage(enabled=enabled)

        return typing.cast(None, jsii.invoke(self, "putCloudStorage", [value]))

    @jsii.member(jsii_name="resetCloudStorage")
    def reset_cloud_storage(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCloudStorage", []))

    @jsii.member(jsii_name="resetClusterId")
    def reset_cluster_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetClusterId", []))

    @jsii.member(jsii_name="resetDeletionProtection")
    def reset_deletion_protection(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDeletionProtection", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetServiceAccountId")
    def reset_service_account_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetServiceAccountId", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="access")
    def access(self) -> "DataYandexMdbClickhouseClusterAccessList":
        return typing.cast("DataYandexMdbClickhouseClusterAccessList", jsii.get(self, "access"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backupWindowStart")
    def backup_window_start(
        self,
    ) -> "DataYandexMdbClickhouseClusterBackupWindowStartList":
        return typing.cast("DataYandexMdbClickhouseClusterBackupWindowStartList", jsii.get(self, "backupWindowStart"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clickhouse")
    def clickhouse(self) -> "DataYandexMdbClickhouseClusterClickhouseList":
        return typing.cast("DataYandexMdbClickhouseClusterClickhouseList", jsii.get(self, "clickhouse"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cloudStorage")
    def cloud_storage(
        self,
    ) -> "DataYandexMdbClickhouseClusterCloudStorageOutputReference":
        return typing.cast("DataYandexMdbClickhouseClusterCloudStorageOutputReference", jsii.get(self, "cloudStorage"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="database")
    def database(self) -> "DataYandexMdbClickhouseClusterDatabaseList":
        return typing.cast("DataYandexMdbClickhouseClusterDatabaseList", jsii.get(self, "database"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="embeddedKeeper")
    def embedded_keeper(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "embeddedKeeper"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="environment")
    def environment(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "environment"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="formatSchema")
    def format_schema(self) -> "DataYandexMdbClickhouseClusterFormatSchemaList":
        return typing.cast("DataYandexMdbClickhouseClusterFormatSchemaList", jsii.get(self, "formatSchema"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="health")
    def health(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "health"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="host")
    def host(self) -> "DataYandexMdbClickhouseClusterHostList":
        return typing.cast("DataYandexMdbClickhouseClusterHostList", jsii.get(self, "host"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maintenanceWindow")
    def maintenance_window(
        self,
    ) -> "DataYandexMdbClickhouseClusterMaintenanceWindowList":
        return typing.cast("DataYandexMdbClickhouseClusterMaintenanceWindowList", jsii.get(self, "maintenanceWindow"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mlModel")
    def ml_model(self) -> "DataYandexMdbClickhouseClusterMlModelList":
        return typing.cast("DataYandexMdbClickhouseClusterMlModelList", jsii.get(self, "mlModel"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "securityGroupIds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="shardGroup")
    def shard_group(self) -> "DataYandexMdbClickhouseClusterShardGroupList":
        return typing.cast("DataYandexMdbClickhouseClusterShardGroupList", jsii.get(self, "shardGroup"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sqlDatabaseManagement")
    def sql_database_management(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "sqlDatabaseManagement"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sqlUserManagement")
    def sql_user_management(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "sqlUserManagement"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="user")
    def user(self) -> "DataYandexMdbClickhouseClusterUserList":
        return typing.cast("DataYandexMdbClickhouseClusterUserList", jsii.get(self, "user"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "version"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zookeeper")
    def zookeeper(self) -> "DataYandexMdbClickhouseClusterZookeeperList":
        return typing.cast("DataYandexMdbClickhouseClusterZookeeperList", jsii.get(self, "zookeeper"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cloudStorageInput")
    def cloud_storage_input(
        self,
    ) -> typing.Optional["DataYandexMdbClickhouseClusterCloudStorage"]:
        return typing.cast(typing.Optional["DataYandexMdbClickhouseClusterCloudStorage"], jsii.get(self, "cloudStorageInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterIdInput")
    def cluster_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "clusterIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtectionInput")
    def deletion_protection_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "deletionProtectionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountIdInput")
    def service_account_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceAccountIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterId")
    def cluster_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "clusterId"))

    @cluster_id.setter
    def cluster_id(self, value: builtins.str) -> None:
        jsii.set(self, "clusterId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtection")
    def deletion_protection(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "deletionProtection"))

    @deletion_protection.setter
    def deletion_protection(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "deletionProtection", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountId")
    def service_account_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceAccountId"))

    @service_account_id.setter
    def service_account_id(self, value: builtins.str) -> None:
        jsii.set(self, "serviceAccountId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterAccess",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbClickhouseClusterAccess:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbClickhouseClusterAccess(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbClickhouseClusterAccessList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterAccessList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbClickhouseClusterAccessOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbClickhouseClusterAccessOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbClickhouseClusterAccessOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterAccessOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dataLens")
    def data_lens(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "dataLens"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metrika")
    def metrika(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "metrika"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serverless")
    def serverless(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "serverless"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="webSql")
    def web_sql(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "webSql"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexMdbClickhouseClusterAccess]:
        return typing.cast(typing.Optional[DataYandexMdbClickhouseClusterAccess], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbClickhouseClusterAccess],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterBackupWindowStart",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbClickhouseClusterBackupWindowStart:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbClickhouseClusterBackupWindowStart(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbClickhouseClusterBackupWindowStartList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterBackupWindowStartList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbClickhouseClusterBackupWindowStartOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbClickhouseClusterBackupWindowStartOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbClickhouseClusterBackupWindowStartOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterBackupWindowStartOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hours")
    def hours(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "hours"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minutes")
    def minutes(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minutes"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbClickhouseClusterBackupWindowStart]:
        return typing.cast(typing.Optional[DataYandexMdbClickhouseClusterBackupWindowStart], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbClickhouseClusterBackupWindowStart],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouse",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbClickhouseClusterClickhouse:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbClickhouseClusterClickhouse(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseConfig",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbClickhouseClusterClickhouseConfig:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbClickhouseClusterClickhouseConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseConfigCompression",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbClickhouseClusterClickhouseConfigCompression:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbClickhouseClusterClickhouseConfigCompression(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbClickhouseClusterClickhouseConfigCompressionList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseConfigCompressionList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbClickhouseClusterClickhouseConfigCompressionOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbClickhouseClusterClickhouseConfigCompressionOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbClickhouseClusterClickhouseConfigCompressionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseConfigCompressionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="method")
    def method(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "method"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minPartSize")
    def min_part_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minPartSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minPartSizeRatio")
    def min_part_size_ratio(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minPartSizeRatio"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbClickhouseClusterClickhouseConfigCompression]:
        return typing.cast(typing.Optional[DataYandexMdbClickhouseClusterClickhouseConfigCompression], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbClickhouseClusterClickhouseConfigCompression],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollup",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollup:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollup(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="pattern")
    def pattern(
        self,
    ) -> "DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupPatternList":
        return typing.cast("DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupPatternList", jsii.get(self, "pattern"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollup]:
        return typing.cast(typing.Optional[DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollup], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollup],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupPattern",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupPattern:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupPattern(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupPatternList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupPatternList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupPatternOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupPatternOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupPatternOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupPatternOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="function")
    def function(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "function"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="regexp")
    def regexp(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "regexp"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="retention")
    def retention(
        self,
    ) -> "DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetentionList":
        return typing.cast("DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetentionList", jsii.get(self, "retention"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupPattern]:
        return typing.cast(typing.Optional[DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupPattern], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupPattern],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetention",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetention:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetention(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetentionList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetentionList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetentionOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetentionOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetentionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetentionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="age")
    def age(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "age"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="precision")
    def precision(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "precision"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetention]:
        return typing.cast(typing.Optional[DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetention], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetention],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseConfigKafka",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbClickhouseClusterClickhouseConfigKafka:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbClickhouseClusterClickhouseConfigKafka(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbClickhouseClusterClickhouseConfigKafkaList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseConfigKafkaList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbClickhouseClusterClickhouseConfigKafkaOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbClickhouseClusterClickhouseConfigKafkaOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbClickhouseClusterClickhouseConfigKafkaOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseConfigKafkaOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslMechanism")
    def sasl_mechanism(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "saslMechanism"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslPassword")
    def sasl_password(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "saslPassword"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslUsername")
    def sasl_username(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "saslUsername"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityProtocol")
    def security_protocol(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "securityProtocol"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbClickhouseClusterClickhouseConfigKafka]:
        return typing.cast(typing.Optional[DataYandexMdbClickhouseClusterClickhouseConfigKafka], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbClickhouseClusterClickhouseConfigKafka],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseConfigKafkaTopic",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbClickhouseClusterClickhouseConfigKafkaTopic:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbClickhouseClusterClickhouseConfigKafkaTopic(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbClickhouseClusterClickhouseConfigKafkaTopicList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseConfigKafkaTopicList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbClickhouseClusterClickhouseConfigKafkaTopicOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbClickhouseClusterClickhouseConfigKafkaTopicOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbClickhouseClusterClickhouseConfigKafkaTopicOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseConfigKafkaTopicOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="settings")
    def settings(
        self,
    ) -> "DataYandexMdbClickhouseClusterClickhouseConfigKafkaTopicSettingsList":
        return typing.cast("DataYandexMdbClickhouseClusterClickhouseConfigKafkaTopicSettingsList", jsii.get(self, "settings"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbClickhouseClusterClickhouseConfigKafkaTopic]:
        return typing.cast(typing.Optional[DataYandexMdbClickhouseClusterClickhouseConfigKafkaTopic], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbClickhouseClusterClickhouseConfigKafkaTopic],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseConfigKafkaTopicSettings",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbClickhouseClusterClickhouseConfigKafkaTopicSettings:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbClickhouseClusterClickhouseConfigKafkaTopicSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbClickhouseClusterClickhouseConfigKafkaTopicSettingsList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseConfigKafkaTopicSettingsList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbClickhouseClusterClickhouseConfigKafkaTopicSettingsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbClickhouseClusterClickhouseConfigKafkaTopicSettingsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbClickhouseClusterClickhouseConfigKafkaTopicSettingsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseConfigKafkaTopicSettingsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslMechanism")
    def sasl_mechanism(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "saslMechanism"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslPassword")
    def sasl_password(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "saslPassword"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslUsername")
    def sasl_username(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "saslUsername"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityProtocol")
    def security_protocol(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "securityProtocol"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbClickhouseClusterClickhouseConfigKafkaTopicSettings]:
        return typing.cast(typing.Optional[DataYandexMdbClickhouseClusterClickhouseConfigKafkaTopicSettings], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbClickhouseClusterClickhouseConfigKafkaTopicSettings],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexMdbClickhouseClusterClickhouseConfigList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseConfigList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbClickhouseClusterClickhouseConfigOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbClickhouseClusterClickhouseConfigOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseConfigMergeTree",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbClickhouseClusterClickhouseConfigMergeTree:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbClickhouseClusterClickhouseConfigMergeTree(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbClickhouseClusterClickhouseConfigMergeTreeList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseConfigMergeTreeList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbClickhouseClusterClickhouseConfigMergeTreeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbClickhouseClusterClickhouseConfigMergeTreeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbClickhouseClusterClickhouseConfigMergeTreeOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseConfigMergeTreeOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxBytesToMergeAtMinSpaceInPool")
    def max_bytes_to_merge_at_min_space_in_pool(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxBytesToMergeAtMinSpaceInPool"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxReplicatedMergesInQueue")
    def max_replicated_merges_in_queue(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxReplicatedMergesInQueue"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="numberOfFreeEntriesInPoolToLowerMaxSizeOfMerge")
    def number_of_free_entries_in_pool_to_lower_max_size_of_merge(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "numberOfFreeEntriesInPoolToLowerMaxSizeOfMerge"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="partsToDelayInsert")
    def parts_to_delay_insert(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "partsToDelayInsert"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="partsToThrowInsert")
    def parts_to_throw_insert(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "partsToThrowInsert"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replicatedDeduplicationWindow")
    def replicated_deduplication_window(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "replicatedDeduplicationWindow"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replicatedDeduplicationWindowSeconds")
    def replicated_deduplication_window_seconds(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "replicatedDeduplicationWindowSeconds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbClickhouseClusterClickhouseConfigMergeTree]:
        return typing.cast(typing.Optional[DataYandexMdbClickhouseClusterClickhouseConfigMergeTree], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbClickhouseClusterClickhouseConfigMergeTree],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexMdbClickhouseClusterClickhouseConfigOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseConfigOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backgroundPoolSize")
    def background_pool_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "backgroundPoolSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backgroundSchedulePoolSize")
    def background_schedule_pool_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "backgroundSchedulePoolSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="compression")
    def compression(
        self,
    ) -> DataYandexMdbClickhouseClusterClickhouseConfigCompressionList:
        return typing.cast(DataYandexMdbClickhouseClusterClickhouseConfigCompressionList, jsii.get(self, "compression"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="geobaseUri")
    def geobase_uri(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "geobaseUri"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="graphiteRollup")
    def graphite_rollup(
        self,
    ) -> DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupList:
        return typing.cast(DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupList, jsii.get(self, "graphiteRollup"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="kafka")
    def kafka(self) -> DataYandexMdbClickhouseClusterClickhouseConfigKafkaList:
        return typing.cast(DataYandexMdbClickhouseClusterClickhouseConfigKafkaList, jsii.get(self, "kafka"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="kafkaTopic")
    def kafka_topic(
        self,
    ) -> DataYandexMdbClickhouseClusterClickhouseConfigKafkaTopicList:
        return typing.cast(DataYandexMdbClickhouseClusterClickhouseConfigKafkaTopicList, jsii.get(self, "kafkaTopic"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="keepAliveTimeout")
    def keep_alive_timeout(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "keepAliveTimeout"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logLevel")
    def log_level(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "logLevel"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="markCacheSize")
    def mark_cache_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "markCacheSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxConcurrentQueries")
    def max_concurrent_queries(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxConcurrentQueries"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxConnections")
    def max_connections(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxConnections"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxPartitionSizeToDrop")
    def max_partition_size_to_drop(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxPartitionSizeToDrop"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxTableSizeToDrop")
    def max_table_size_to_drop(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxTableSizeToDrop"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mergeTree")
    def merge_tree(self) -> DataYandexMdbClickhouseClusterClickhouseConfigMergeTreeList:
        return typing.cast(DataYandexMdbClickhouseClusterClickhouseConfigMergeTreeList, jsii.get(self, "mergeTree"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricLogEnabled")
    def metric_log_enabled(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "metricLogEnabled"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricLogRetentionSize")
    def metric_log_retention_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "metricLogRetentionSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricLogRetentionTime")
    def metric_log_retention_time(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "metricLogRetentionTime"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="partLogRetentionSize")
    def part_log_retention_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "partLogRetentionSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="partLogRetentionTime")
    def part_log_retention_time(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "partLogRetentionTime"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queryLogRetentionSize")
    def query_log_retention_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "queryLogRetentionSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queryLogRetentionTime")
    def query_log_retention_time(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "queryLogRetentionTime"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queryThreadLogEnabled")
    def query_thread_log_enabled(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "queryThreadLogEnabled"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queryThreadLogRetentionSize")
    def query_thread_log_retention_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "queryThreadLogRetentionSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queryThreadLogRetentionTime")
    def query_thread_log_retention_time(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "queryThreadLogRetentionTime"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="rabbitmq")
    def rabbitmq(self) -> "DataYandexMdbClickhouseClusterClickhouseConfigRabbitmqList":
        return typing.cast("DataYandexMdbClickhouseClusterClickhouseConfigRabbitmqList", jsii.get(self, "rabbitmq"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="textLogEnabled")
    def text_log_enabled(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "textLogEnabled"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="textLogLevel")
    def text_log_level(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "textLogLevel"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="textLogRetentionSize")
    def text_log_retention_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "textLogRetentionSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="textLogRetentionTime")
    def text_log_retention_time(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "textLogRetentionTime"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timezone")
    def timezone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "timezone"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="traceLogEnabled")
    def trace_log_enabled(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "traceLogEnabled"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="traceLogRetentionSize")
    def trace_log_retention_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "traceLogRetentionSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="traceLogRetentionTime")
    def trace_log_retention_time(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "traceLogRetentionTime"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="uncompressedCacheSize")
    def uncompressed_cache_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "uncompressedCacheSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbClickhouseClusterClickhouseConfig]:
        return typing.cast(typing.Optional[DataYandexMdbClickhouseClusterClickhouseConfig], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbClickhouseClusterClickhouseConfig],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseConfigRabbitmq",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbClickhouseClusterClickhouseConfigRabbitmq:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbClickhouseClusterClickhouseConfigRabbitmq(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbClickhouseClusterClickhouseConfigRabbitmqList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseConfigRabbitmqList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbClickhouseClusterClickhouseConfigRabbitmqOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbClickhouseClusterClickhouseConfigRabbitmqOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbClickhouseClusterClickhouseConfigRabbitmqOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseConfigRabbitmqOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="password")
    def password(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "password"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="username")
    def username(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "username"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbClickhouseClusterClickhouseConfigRabbitmq]:
        return typing.cast(typing.Optional[DataYandexMdbClickhouseClusterClickhouseConfigRabbitmq], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbClickhouseClusterClickhouseConfigRabbitmq],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexMdbClickhouseClusterClickhouseList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbClickhouseClusterClickhouseOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbClickhouseClusterClickhouseOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbClickhouseClusterClickhouseOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="config")
    def config(self) -> DataYandexMdbClickhouseClusterClickhouseConfigList:
        return typing.cast(DataYandexMdbClickhouseClusterClickhouseConfigList, jsii.get(self, "config"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resources")
    def resources(self) -> "DataYandexMdbClickhouseClusterClickhouseResourcesList":
        return typing.cast("DataYandexMdbClickhouseClusterClickhouseResourcesList", jsii.get(self, "resources"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbClickhouseClusterClickhouse]:
        return typing.cast(typing.Optional[DataYandexMdbClickhouseClusterClickhouse], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbClickhouseClusterClickhouse],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseResources",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbClickhouseClusterClickhouseResources:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbClickhouseClusterClickhouseResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbClickhouseClusterClickhouseResourcesList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseResourcesList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbClickhouseClusterClickhouseResourcesOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbClickhouseClusterClickhouseResourcesOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbClickhouseClusterClickhouseResourcesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterClickhouseResourcesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSize")
    def disk_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "diskSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeId")
    def disk_type_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskTypeId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetId")
    def resource_preset_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourcePresetId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbClickhouseClusterClickhouseResources]:
        return typing.cast(typing.Optional[DataYandexMdbClickhouseClusterClickhouseResources], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbClickhouseClusterClickhouseResources],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterCloudStorage",
    jsii_struct_bases=[],
    name_mapping={"enabled": "enabled"},
)
class DataYandexMdbClickhouseClusterCloudStorage:
    def __init__(
        self,
        *,
        enabled: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        '''
        :param enabled: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_clickhouse_cluster#enabled DataYandexMdbClickhouseCluster#enabled}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
        }

    @builtins.property
    def enabled(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_clickhouse_cluster#enabled DataYandexMdbClickhouseCluster#enabled}.'''
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbClickhouseClusterCloudStorage(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbClickhouseClusterCloudStorageOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterCloudStorageOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="enabledInput")
    def enabled_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "enabledInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "enabled"))

    @enabled.setter
    def enabled(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbClickhouseClusterCloudStorage]:
        return typing.cast(typing.Optional[DataYandexMdbClickhouseClusterCloudStorage], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbClickhouseClusterCloudStorage],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cloud_storage": "cloudStorage",
        "cluster_id": "clusterId",
        "deletion_protection": "deletionProtection",
        "folder_id": "folderId",
        "id": "id",
        "name": "name",
        "service_account_id": "serviceAccountId",
    },
)
class DataYandexMdbClickhouseClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cloud_storage: typing.Optional[DataYandexMdbClickhouseClusterCloudStorage] = None,
        cluster_id: typing.Optional[builtins.str] = None,
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        service_account_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cloud_storage: cloud_storage block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_clickhouse_cluster#cloud_storage DataYandexMdbClickhouseCluster#cloud_storage}
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_clickhouse_cluster#cluster_id DataYandexMdbClickhouseCluster#cluster_id}.
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_clickhouse_cluster#deletion_protection DataYandexMdbClickhouseCluster#deletion_protection}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_clickhouse_cluster#folder_id DataYandexMdbClickhouseCluster#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_clickhouse_cluster#id DataYandexMdbClickhouseCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_clickhouse_cluster#name DataYandexMdbClickhouseCluster#name}.
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_clickhouse_cluster#service_account_id DataYandexMdbClickhouseCluster#service_account_id}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(cloud_storage, dict):
            cloud_storage = DataYandexMdbClickhouseClusterCloudStorage(**cloud_storage)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if cloud_storage is not None:
            self._values["cloud_storage"] = cloud_storage
        if cluster_id is not None:
            self._values["cluster_id"] = cluster_id
        if deletion_protection is not None:
            self._values["deletion_protection"] = deletion_protection
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name
        if service_account_id is not None:
            self._values["service_account_id"] = service_account_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def cloud_storage(
        self,
    ) -> typing.Optional[DataYandexMdbClickhouseClusterCloudStorage]:
        '''cloud_storage block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_clickhouse_cluster#cloud_storage DataYandexMdbClickhouseCluster#cloud_storage}
        '''
        result = self._values.get("cloud_storage")
        return typing.cast(typing.Optional[DataYandexMdbClickhouseClusterCloudStorage], result)

    @builtins.property
    def cluster_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_clickhouse_cluster#cluster_id DataYandexMdbClickhouseCluster#cluster_id}.'''
        result = self._values.get("cluster_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def deletion_protection(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_clickhouse_cluster#deletion_protection DataYandexMdbClickhouseCluster#deletion_protection}.'''
        result = self._values.get("deletion_protection")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_clickhouse_cluster#folder_id DataYandexMdbClickhouseCluster#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_clickhouse_cluster#id DataYandexMdbClickhouseCluster#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_clickhouse_cluster#name DataYandexMdbClickhouseCluster#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def service_account_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_clickhouse_cluster#service_account_id DataYandexMdbClickhouseCluster#service_account_id}.'''
        result = self._values.get("service_account_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbClickhouseClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterDatabase",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbClickhouseClusterDatabase:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbClickhouseClusterDatabase(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbClickhouseClusterDatabaseList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterDatabaseList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbClickhouseClusterDatabaseOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbClickhouseClusterDatabaseOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbClickhouseClusterDatabaseOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterDatabaseOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexMdbClickhouseClusterDatabase]:
        return typing.cast(typing.Optional[DataYandexMdbClickhouseClusterDatabase], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbClickhouseClusterDatabase],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterFormatSchema",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbClickhouseClusterFormatSchema:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbClickhouseClusterFormatSchema(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbClickhouseClusterFormatSchemaList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterFormatSchemaList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbClickhouseClusterFormatSchemaOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbClickhouseClusterFormatSchemaOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbClickhouseClusterFormatSchemaOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterFormatSchemaOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="uri")
    def uri(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "uri"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbClickhouseClusterFormatSchema]:
        return typing.cast(typing.Optional[DataYandexMdbClickhouseClusterFormatSchema], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbClickhouseClusterFormatSchema],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterHost",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbClickhouseClusterHost:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbClickhouseClusterHost(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbClickhouseClusterHostList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterHostList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbClickhouseClusterHostOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbClickhouseClusterHostOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbClickhouseClusterHostOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterHostOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIp")
    def assign_public_ip(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "assignPublicIp"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fqdn"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="shardName")
    def shard_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "shardName"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zone")
    def zone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zone"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexMdbClickhouseClusterHost]:
        return typing.cast(typing.Optional[DataYandexMdbClickhouseClusterHost], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbClickhouseClusterHost],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterMaintenanceWindow",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbClickhouseClusterMaintenanceWindow:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbClickhouseClusterMaintenanceWindow(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbClickhouseClusterMaintenanceWindowList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterMaintenanceWindowList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbClickhouseClusterMaintenanceWindowOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbClickhouseClusterMaintenanceWindowOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbClickhouseClusterMaintenanceWindowOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterMaintenanceWindowOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="day")
    def day(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "day"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hour")
    def hour(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "hour"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbClickhouseClusterMaintenanceWindow]:
        return typing.cast(typing.Optional[DataYandexMdbClickhouseClusterMaintenanceWindow], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbClickhouseClusterMaintenanceWindow],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterMlModel",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbClickhouseClusterMlModel:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbClickhouseClusterMlModel(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbClickhouseClusterMlModelList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterMlModelList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbClickhouseClusterMlModelOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbClickhouseClusterMlModelOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbClickhouseClusterMlModelOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterMlModelOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="uri")
    def uri(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "uri"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexMdbClickhouseClusterMlModel]:
        return typing.cast(typing.Optional[DataYandexMdbClickhouseClusterMlModel], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbClickhouseClusterMlModel],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterShardGroup",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbClickhouseClusterShardGroup:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbClickhouseClusterShardGroup(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbClickhouseClusterShardGroupList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterShardGroupList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbClickhouseClusterShardGroupOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbClickhouseClusterShardGroupOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbClickhouseClusterShardGroupOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterShardGroupOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="shardNames")
    def shard_names(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "shardNames"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbClickhouseClusterShardGroup]:
        return typing.cast(typing.Optional[DataYandexMdbClickhouseClusterShardGroup], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbClickhouseClusterShardGroup],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterUser",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbClickhouseClusterUser:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbClickhouseClusterUser(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbClickhouseClusterUserList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterUserList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbClickhouseClusterUserOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbClickhouseClusterUserOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbClickhouseClusterUserOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterUserOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="permission")
    def permission(self) -> "DataYandexMdbClickhouseClusterUserPermissionList":
        return typing.cast("DataYandexMdbClickhouseClusterUserPermissionList", jsii.get(self, "permission"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="quota")
    def quota(self) -> "DataYandexMdbClickhouseClusterUserQuotaList":
        return typing.cast("DataYandexMdbClickhouseClusterUserQuotaList", jsii.get(self, "quota"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="settings")
    def settings(self) -> "DataYandexMdbClickhouseClusterUserSettingsList":
        return typing.cast("DataYandexMdbClickhouseClusterUserSettingsList", jsii.get(self, "settings"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexMdbClickhouseClusterUser]:
        return typing.cast(typing.Optional[DataYandexMdbClickhouseClusterUser], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbClickhouseClusterUser],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterUserPermission",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbClickhouseClusterUserPermission:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbClickhouseClusterUserPermission(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbClickhouseClusterUserPermissionList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterUserPermissionList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbClickhouseClusterUserPermissionOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbClickhouseClusterUserPermissionOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbClickhouseClusterUserPermissionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterUserPermissionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databaseName")
    def database_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "databaseName"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbClickhouseClusterUserPermission]:
        return typing.cast(typing.Optional[DataYandexMdbClickhouseClusterUserPermission], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbClickhouseClusterUserPermission],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterUserQuota",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbClickhouseClusterUserQuota:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbClickhouseClusterUserQuota(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbClickhouseClusterUserQuotaList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterUserQuotaList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbClickhouseClusterUserQuotaOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbClickhouseClusterUserQuotaOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbClickhouseClusterUserQuotaOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterUserQuotaOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errors")
    def errors(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "errors"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="executionTime")
    def execution_time(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "executionTime"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="intervalDuration")
    def interval_duration(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "intervalDuration"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queries")
    def queries(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "queries"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="readRows")
    def read_rows(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "readRows"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resultRows")
    def result_rows(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "resultRows"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbClickhouseClusterUserQuota]:
        return typing.cast(typing.Optional[DataYandexMdbClickhouseClusterUserQuota], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbClickhouseClusterUserQuota],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterUserSettings",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbClickhouseClusterUserSettings:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbClickhouseClusterUserSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbClickhouseClusterUserSettingsList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterUserSettingsList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbClickhouseClusterUserSettingsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbClickhouseClusterUserSettingsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbClickhouseClusterUserSettingsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterUserSettingsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="addHttpCorsHeader")
    def add_http_cors_header(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "addHttpCorsHeader"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allowDdl")
    def allow_ddl(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "allowDdl"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="compile")
    def compile(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "compile"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="compileExpressions")
    def compile_expressions(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "compileExpressions"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="connectTimeout")
    def connect_timeout(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "connectTimeout"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="countDistinctImplementation")
    def count_distinct_implementation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "countDistinctImplementation"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="distinctOverflowMode")
    def distinct_overflow_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "distinctOverflowMode"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="distributedAggregationMemoryEfficient")
    def distributed_aggregation_memory_efficient(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "distributedAggregationMemoryEfficient"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="distributedDdlTaskTimeout")
    def distributed_ddl_task_timeout(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "distributedDdlTaskTimeout"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="distributedProductMode")
    def distributed_product_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "distributedProductMode"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="emptyResultForAggregationByEmptySet")
    def empty_result_for_aggregation_by_empty_set(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "emptyResultForAggregationByEmptySet"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="enableHttpCompression")
    def enable_http_compression(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "enableHttpCompression"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fallbackToStaleReplicasForDistributedQueries")
    def fallback_to_stale_replicas_for_distributed_queries(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "fallbackToStaleReplicasForDistributedQueries"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="forceIndexByDate")
    def force_index_by_date(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "forceIndexByDate"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="forcePrimaryKey")
    def force_primary_key(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "forcePrimaryKey"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="groupByOverflowMode")
    def group_by_overflow_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "groupByOverflowMode"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="groupByTwoLevelThreshold")
    def group_by_two_level_threshold(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "groupByTwoLevelThreshold"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="groupByTwoLevelThresholdBytes")
    def group_by_two_level_threshold_bytes(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "groupByTwoLevelThresholdBytes"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpConnectionTimeout")
    def http_connection_timeout(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "httpConnectionTimeout"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpHeadersProgressInterval")
    def http_headers_progress_interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "httpHeadersProgressInterval"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpReceiveTimeout")
    def http_receive_timeout(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "httpReceiveTimeout"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpSendTimeout")
    def http_send_timeout(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "httpSendTimeout"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="inputFormatDefaultsForOmittedFields")
    def input_format_defaults_for_omitted_fields(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "inputFormatDefaultsForOmittedFields"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="inputFormatValuesInterpretExpressions")
    def input_format_values_interpret_expressions(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "inputFormatValuesInterpretExpressions"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="insertQuorum")
    def insert_quorum(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "insertQuorum"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="insertQuorumTimeout")
    def insert_quorum_timeout(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "insertQuorumTimeout"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="joinedSubqueryRequiresAlias")
    def joined_subquery_requires_alias(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "joinedSubqueryRequiresAlias"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="joinOverflowMode")
    def join_overflow_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "joinOverflowMode"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="joinUseNulls")
    def join_use_nulls(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "joinUseNulls"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="lowCardinalityAllowInNativeFormat")
    def low_cardinality_allow_in_native_format(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "lowCardinalityAllowInNativeFormat"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxAstDepth")
    def max_ast_depth(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxAstDepth"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxAstElements")
    def max_ast_elements(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxAstElements"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxBlockSize")
    def max_block_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxBlockSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxBytesBeforeExternalGroupBy")
    def max_bytes_before_external_group_by(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxBytesBeforeExternalGroupBy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxBytesBeforeExternalSort")
    def max_bytes_before_external_sort(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxBytesBeforeExternalSort"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxBytesInDistinct")
    def max_bytes_in_distinct(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxBytesInDistinct"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxBytesInJoin")
    def max_bytes_in_join(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxBytesInJoin"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxBytesInSet")
    def max_bytes_in_set(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxBytesInSet"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxBytesToRead")
    def max_bytes_to_read(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxBytesToRead"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxBytesToSort")
    def max_bytes_to_sort(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxBytesToSort"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxBytesToTransfer")
    def max_bytes_to_transfer(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxBytesToTransfer"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxColumnsToRead")
    def max_columns_to_read(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxColumnsToRead"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxExecutionTime")
    def max_execution_time(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxExecutionTime"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxExpandedAstElements")
    def max_expanded_ast_elements(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxExpandedAstElements"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxInsertBlockSize")
    def max_insert_block_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxInsertBlockSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxMemoryUsage")
    def max_memory_usage(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxMemoryUsage"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxMemoryUsageForUser")
    def max_memory_usage_for_user(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxMemoryUsageForUser"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxNetworkBandwidth")
    def max_network_bandwidth(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxNetworkBandwidth"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxNetworkBandwidthForUser")
    def max_network_bandwidth_for_user(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxNetworkBandwidthForUser"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxQuerySize")
    def max_query_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxQuerySize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxReplicaDelayForDistributedQueries")
    def max_replica_delay_for_distributed_queries(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxReplicaDelayForDistributedQueries"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxResultBytes")
    def max_result_bytes(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxResultBytes"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxResultRows")
    def max_result_rows(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxResultRows"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxRowsInDistinct")
    def max_rows_in_distinct(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxRowsInDistinct"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxRowsInJoin")
    def max_rows_in_join(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxRowsInJoin"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxRowsInSet")
    def max_rows_in_set(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxRowsInSet"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxRowsToGroupBy")
    def max_rows_to_group_by(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxRowsToGroupBy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxRowsToRead")
    def max_rows_to_read(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxRowsToRead"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxRowsToSort")
    def max_rows_to_sort(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxRowsToSort"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxRowsToTransfer")
    def max_rows_to_transfer(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxRowsToTransfer"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxTemporaryColumns")
    def max_temporary_columns(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxTemporaryColumns"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxTemporaryNonConstColumns")
    def max_temporary_non_const_columns(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxTemporaryNonConstColumns"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxThreads")
    def max_threads(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxThreads"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mergeTreeMaxBytesToUseCache")
    def merge_tree_max_bytes_to_use_cache(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "mergeTreeMaxBytesToUseCache"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mergeTreeMaxRowsToUseCache")
    def merge_tree_max_rows_to_use_cache(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "mergeTreeMaxRowsToUseCache"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mergeTreeMinBytesForConcurrentRead")
    def merge_tree_min_bytes_for_concurrent_read(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "mergeTreeMinBytesForConcurrentRead"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mergeTreeMinRowsForConcurrentRead")
    def merge_tree_min_rows_for_concurrent_read(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "mergeTreeMinRowsForConcurrentRead"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minBytesToUseDirectIo")
    def min_bytes_to_use_direct_io(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minBytesToUseDirectIo"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minCountToCompile")
    def min_count_to_compile(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minCountToCompile"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minCountToCompileExpression")
    def min_count_to_compile_expression(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minCountToCompileExpression"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minExecutionSpeed")
    def min_execution_speed(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minExecutionSpeed"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minExecutionSpeedBytes")
    def min_execution_speed_bytes(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minExecutionSpeedBytes"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minInsertBlockSizeBytes")
    def min_insert_block_size_bytes(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minInsertBlockSizeBytes"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minInsertBlockSizeRows")
    def min_insert_block_size_rows(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minInsertBlockSizeRows"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="outputFormatJsonQuote64BitIntegers")
    def output_format_json_quote64_bit_integers(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "outputFormatJsonQuote64BitIntegers"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="outputFormatJsonQuoteDenormals")
    def output_format_json_quote_denormals(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "outputFormatJsonQuoteDenormals"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="priority")
    def priority(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "priority"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="quotaMode")
    def quota_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "quotaMode"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="readonly")
    def readonly(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "readonly"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="readOverflowMode")
    def read_overflow_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "readOverflowMode"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="receiveTimeout")
    def receive_timeout(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "receiveTimeout"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replicationAlterPartitionsSync")
    def replication_alter_partitions_sync(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "replicationAlterPartitionsSync"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resultOverflowMode")
    def result_overflow_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resultOverflowMode"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="selectSequentialConsistency")
    def select_sequential_consistency(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "selectSequentialConsistency"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sendProgressInHttpHeaders")
    def send_progress_in_http_headers(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "sendProgressInHttpHeaders"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sendTimeout")
    def send_timeout(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "sendTimeout"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="setOverflowMode")
    def set_overflow_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "setOverflowMode"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="skipUnavailableShards")
    def skip_unavailable_shards(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "skipUnavailableShards"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sortOverflowMode")
    def sort_overflow_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sortOverflowMode"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutOverflowMode")
    def timeout_overflow_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "timeoutOverflowMode"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="transferOverflowMode")
    def transfer_overflow_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "transferOverflowMode"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="transformNullIn")
    def transform_null_in(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "transformNullIn"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="useUncompressedCache")
    def use_uncompressed_cache(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "useUncompressedCache"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbClickhouseClusterUserSettings]:
        return typing.cast(typing.Optional[DataYandexMdbClickhouseClusterUserSettings], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbClickhouseClusterUserSettings],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterZookeeper",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbClickhouseClusterZookeeper:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbClickhouseClusterZookeeper(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbClickhouseClusterZookeeperList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterZookeeperList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbClickhouseClusterZookeeperOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbClickhouseClusterZookeeperOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbClickhouseClusterZookeeperOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterZookeeperOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resources")
    def resources(self) -> "DataYandexMdbClickhouseClusterZookeeperResourcesList":
        return typing.cast("DataYandexMdbClickhouseClusterZookeeperResourcesList", jsii.get(self, "resources"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbClickhouseClusterZookeeper]:
        return typing.cast(typing.Optional[DataYandexMdbClickhouseClusterZookeeper], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbClickhouseClusterZookeeper],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterZookeeperResources",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbClickhouseClusterZookeeperResources:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbClickhouseClusterZookeeperResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbClickhouseClusterZookeeperResourcesList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterZookeeperResourcesList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbClickhouseClusterZookeeperResourcesOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbClickhouseClusterZookeeperResourcesOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbClickhouseClusterZookeeperResourcesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbClickhouseClusterZookeeperResourcesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSize")
    def disk_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "diskSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeId")
    def disk_type_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskTypeId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetId")
    def resource_preset_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourcePresetId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbClickhouseClusterZookeeperResources]:
        return typing.cast(typing.Optional[DataYandexMdbClickhouseClusterZookeeperResources], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbClickhouseClusterZookeeperResources],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexMdbElasticsearchCluster(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbElasticsearchCluster",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/mdb_elasticsearch_cluster yandex_mdb_elasticsearch_cluster}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        cluster_id: typing.Optional[builtins.str] = None,
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        service_account_id: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/mdb_elasticsearch_cluster yandex_mdb_elasticsearch_cluster} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_elasticsearch_cluster#cluster_id DataYandexMdbElasticsearchCluster#cluster_id}.
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_elasticsearch_cluster#deletion_protection DataYandexMdbElasticsearchCluster#deletion_protection}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_elasticsearch_cluster#description DataYandexMdbElasticsearchCluster#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_elasticsearch_cluster#folder_id DataYandexMdbElasticsearchCluster#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_elasticsearch_cluster#id DataYandexMdbElasticsearchCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_elasticsearch_cluster#labels DataYandexMdbElasticsearchCluster#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_elasticsearch_cluster#name DataYandexMdbElasticsearchCluster#name}.
        :param security_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_elasticsearch_cluster#security_group_ids DataYandexMdbElasticsearchCluster#security_group_ids}.
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_elasticsearch_cluster#service_account_id DataYandexMdbElasticsearchCluster#service_account_id}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexMdbElasticsearchClusterConfig(
            cluster_id=cluster_id,
            deletion_protection=deletion_protection,
            description=description,
            folder_id=folder_id,
            id=id,
            labels=labels,
            name=name,
            security_group_ids=security_group_ids,
            service_account_id=service_account_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetClusterId")
    def reset_cluster_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetClusterId", []))

    @jsii.member(jsii_name="resetDeletionProtection")
    def reset_deletion_protection(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDeletionProtection", []))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetSecurityGroupIds")
    def reset_security_group_ids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityGroupIds", []))

    @jsii.member(jsii_name="resetServiceAccountId")
    def reset_service_account_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetServiceAccountId", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="config")
    def config(self) -> "DataYandexMdbElasticsearchClusterConfigAList":
        return typing.cast("DataYandexMdbElasticsearchClusterConfigAList", jsii.get(self, "config"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="environment")
    def environment(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "environment"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="health")
    def health(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "health"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="host")
    def host(self) -> "DataYandexMdbElasticsearchClusterHostList":
        return typing.cast("DataYandexMdbElasticsearchClusterHostList", jsii.get(self, "host"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maintenanceWindow")
    def maintenance_window(
        self,
    ) -> "DataYandexMdbElasticsearchClusterMaintenanceWindowList":
        return typing.cast("DataYandexMdbElasticsearchClusterMaintenanceWindowList", jsii.get(self, "maintenanceWindow"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterIdInput")
    def cluster_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "clusterIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtectionInput")
    def deletion_protection_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "deletionProtectionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIdsInput")
    def security_group_ids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "securityGroupIdsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountIdInput")
    def service_account_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceAccountIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterId")
    def cluster_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "clusterId"))

    @cluster_id.setter
    def cluster_id(self, value: builtins.str) -> None:
        jsii.set(self, "clusterId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtection")
    def deletion_protection(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "deletionProtection"))

    @deletion_protection.setter
    def deletion_protection(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "deletionProtection", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "securityGroupIds"))

    @security_group_ids.setter
    def security_group_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "securityGroupIds", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountId")
    def service_account_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceAccountId"))

    @service_account_id.setter
    def service_account_id(self, value: builtins.str) -> None:
        jsii.set(self, "serviceAccountId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbElasticsearchClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_id": "clusterId",
        "deletion_protection": "deletionProtection",
        "description": "description",
        "folder_id": "folderId",
        "id": "id",
        "labels": "labels",
        "name": "name",
        "security_group_ids": "securityGroupIds",
        "service_account_id": "serviceAccountId",
    },
)
class DataYandexMdbElasticsearchClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_id: typing.Optional[builtins.str] = None,
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        service_account_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_elasticsearch_cluster#cluster_id DataYandexMdbElasticsearchCluster#cluster_id}.
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_elasticsearch_cluster#deletion_protection DataYandexMdbElasticsearchCluster#deletion_protection}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_elasticsearch_cluster#description DataYandexMdbElasticsearchCluster#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_elasticsearch_cluster#folder_id DataYandexMdbElasticsearchCluster#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_elasticsearch_cluster#id DataYandexMdbElasticsearchCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_elasticsearch_cluster#labels DataYandexMdbElasticsearchCluster#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_elasticsearch_cluster#name DataYandexMdbElasticsearchCluster#name}.
        :param security_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_elasticsearch_cluster#security_group_ids DataYandexMdbElasticsearchCluster#security_group_ids}.
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_elasticsearch_cluster#service_account_id DataYandexMdbElasticsearchCluster#service_account_id}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if cluster_id is not None:
            self._values["cluster_id"] = cluster_id
        if deletion_protection is not None:
            self._values["deletion_protection"] = deletion_protection
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if name is not None:
            self._values["name"] = name
        if security_group_ids is not None:
            self._values["security_group_ids"] = security_group_ids
        if service_account_id is not None:
            self._values["service_account_id"] = service_account_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def cluster_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_elasticsearch_cluster#cluster_id DataYandexMdbElasticsearchCluster#cluster_id}.'''
        result = self._values.get("cluster_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def deletion_protection(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_elasticsearch_cluster#deletion_protection DataYandexMdbElasticsearchCluster#deletion_protection}.'''
        result = self._values.get("deletion_protection")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_elasticsearch_cluster#description DataYandexMdbElasticsearchCluster#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_elasticsearch_cluster#folder_id DataYandexMdbElasticsearchCluster#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_elasticsearch_cluster#id DataYandexMdbElasticsearchCluster#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_elasticsearch_cluster#labels DataYandexMdbElasticsearchCluster#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_elasticsearch_cluster#name DataYandexMdbElasticsearchCluster#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def security_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_elasticsearch_cluster#security_group_ids DataYandexMdbElasticsearchCluster#security_group_ids}.'''
        result = self._values.get("security_group_ids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def service_account_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_elasticsearch_cluster#service_account_id DataYandexMdbElasticsearchCluster#service_account_id}.'''
        result = self._values.get("service_account_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbElasticsearchClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbElasticsearchClusterConfigA",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbElasticsearchClusterConfigA:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbElasticsearchClusterConfigA(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbElasticsearchClusterConfigAList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbElasticsearchClusterConfigAList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbElasticsearchClusterConfigAOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbElasticsearchClusterConfigAOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbElasticsearchClusterConfigAOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbElasticsearchClusterConfigAOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="adminPassword")
    def admin_password(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "adminPassword"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dataNode")
    def data_node(self) -> "DataYandexMdbElasticsearchClusterConfigDataNodeList":
        return typing.cast("DataYandexMdbElasticsearchClusterConfigDataNodeList", jsii.get(self, "dataNode"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="edition")
    def edition(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "edition"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="masterNode")
    def master_node(self) -> "DataYandexMdbElasticsearchClusterConfigMasterNodeList":
        return typing.cast("DataYandexMdbElasticsearchClusterConfigMasterNodeList", jsii.get(self, "masterNode"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="plugins")
    def plugins(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "plugins"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "version"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbElasticsearchClusterConfigA]:
        return typing.cast(typing.Optional[DataYandexMdbElasticsearchClusterConfigA], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbElasticsearchClusterConfigA],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbElasticsearchClusterConfigDataNode",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbElasticsearchClusterConfigDataNode:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbElasticsearchClusterConfigDataNode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbElasticsearchClusterConfigDataNodeList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbElasticsearchClusterConfigDataNodeList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbElasticsearchClusterConfigDataNodeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbElasticsearchClusterConfigDataNodeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbElasticsearchClusterConfigDataNodeOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbElasticsearchClusterConfigDataNodeOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resources")
    def resources(
        self,
    ) -> "DataYandexMdbElasticsearchClusterConfigDataNodeResourcesList":
        return typing.cast("DataYandexMdbElasticsearchClusterConfigDataNodeResourcesList", jsii.get(self, "resources"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbElasticsearchClusterConfigDataNode]:
        return typing.cast(typing.Optional[DataYandexMdbElasticsearchClusterConfigDataNode], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbElasticsearchClusterConfigDataNode],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbElasticsearchClusterConfigDataNodeResources",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbElasticsearchClusterConfigDataNodeResources:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbElasticsearchClusterConfigDataNodeResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbElasticsearchClusterConfigDataNodeResourcesList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbElasticsearchClusterConfigDataNodeResourcesList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbElasticsearchClusterConfigDataNodeResourcesOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbElasticsearchClusterConfigDataNodeResourcesOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbElasticsearchClusterConfigDataNodeResourcesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbElasticsearchClusterConfigDataNodeResourcesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSize")
    def disk_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "diskSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeId")
    def disk_type_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskTypeId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetId")
    def resource_preset_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourcePresetId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbElasticsearchClusterConfigDataNodeResources]:
        return typing.cast(typing.Optional[DataYandexMdbElasticsearchClusterConfigDataNodeResources], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbElasticsearchClusterConfigDataNodeResources],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbElasticsearchClusterConfigMasterNode",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbElasticsearchClusterConfigMasterNode:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbElasticsearchClusterConfigMasterNode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbElasticsearchClusterConfigMasterNodeList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbElasticsearchClusterConfigMasterNodeList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbElasticsearchClusterConfigMasterNodeOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbElasticsearchClusterConfigMasterNodeOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbElasticsearchClusterConfigMasterNodeOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbElasticsearchClusterConfigMasterNodeOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resources")
    def resources(
        self,
    ) -> "DataYandexMdbElasticsearchClusterConfigMasterNodeResourcesList":
        return typing.cast("DataYandexMdbElasticsearchClusterConfigMasterNodeResourcesList", jsii.get(self, "resources"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbElasticsearchClusterConfigMasterNode]:
        return typing.cast(typing.Optional[DataYandexMdbElasticsearchClusterConfigMasterNode], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbElasticsearchClusterConfigMasterNode],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbElasticsearchClusterConfigMasterNodeResources",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbElasticsearchClusterConfigMasterNodeResources:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbElasticsearchClusterConfigMasterNodeResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbElasticsearchClusterConfigMasterNodeResourcesList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbElasticsearchClusterConfigMasterNodeResourcesList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbElasticsearchClusterConfigMasterNodeResourcesOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbElasticsearchClusterConfigMasterNodeResourcesOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbElasticsearchClusterConfigMasterNodeResourcesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbElasticsearchClusterConfigMasterNodeResourcesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSize")
    def disk_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "diskSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeId")
    def disk_type_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskTypeId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetId")
    def resource_preset_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourcePresetId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbElasticsearchClusterConfigMasterNodeResources]:
        return typing.cast(typing.Optional[DataYandexMdbElasticsearchClusterConfigMasterNodeResources], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbElasticsearchClusterConfigMasterNodeResources],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbElasticsearchClusterHost",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbElasticsearchClusterHost:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbElasticsearchClusterHost(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbElasticsearchClusterHostList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbElasticsearchClusterHostList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbElasticsearchClusterHostOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbElasticsearchClusterHostOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbElasticsearchClusterHostOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbElasticsearchClusterHostOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIp")
    def assign_public_ip(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "assignPublicIp"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fqdn"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zone")
    def zone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zone"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexMdbElasticsearchClusterHost]:
        return typing.cast(typing.Optional[DataYandexMdbElasticsearchClusterHost], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbElasticsearchClusterHost],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbElasticsearchClusterMaintenanceWindow",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbElasticsearchClusterMaintenanceWindow:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbElasticsearchClusterMaintenanceWindow(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbElasticsearchClusterMaintenanceWindowList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbElasticsearchClusterMaintenanceWindowList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbElasticsearchClusterMaintenanceWindowOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbElasticsearchClusterMaintenanceWindowOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbElasticsearchClusterMaintenanceWindowOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbElasticsearchClusterMaintenanceWindowOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="day")
    def day(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "day"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hour")
    def hour(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "hour"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbElasticsearchClusterMaintenanceWindow]:
        return typing.cast(typing.Optional[DataYandexMdbElasticsearchClusterMaintenanceWindow], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbElasticsearchClusterMaintenanceWindow],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexMdbGreenplumCluster(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbGreenplumCluster",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/mdb_greenplum_cluster yandex_mdb_greenplum_cluster}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        cluster_id: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/mdb_greenplum_cluster yandex_mdb_greenplum_cluster} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_greenplum_cluster#cluster_id DataYandexMdbGreenplumCluster#cluster_id}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_greenplum_cluster#folder_id DataYandexMdbGreenplumCluster#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_greenplum_cluster#id DataYandexMdbGreenplumCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_greenplum_cluster#name DataYandexMdbGreenplumCluster#name}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexMdbGreenplumClusterConfig(
            cluster_id=cluster_id,
            folder_id=folder_id,
            id=id,
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetClusterId")
    def reset_cluster_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetClusterId", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="access")
    def access(self) -> "DataYandexMdbGreenplumClusterAccessList":
        return typing.cast("DataYandexMdbGreenplumClusterAccessList", jsii.get(self, "access"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIp")
    def assign_public_ip(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "assignPublicIp"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backupWindowStart")
    def backup_window_start(
        self,
    ) -> "DataYandexMdbGreenplumClusterBackupWindowStartList":
        return typing.cast("DataYandexMdbGreenplumClusterBackupWindowStartList", jsii.get(self, "backupWindowStart"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtection")
    def deletion_protection(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "deletionProtection"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="environment")
    def environment(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "environment"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="health")
    def health(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "health"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="masterHostCount")
    def master_host_count(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "masterHostCount"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="masterHosts")
    def master_hosts(self) -> "DataYandexMdbGreenplumClusterMasterHostsList":
        return typing.cast("DataYandexMdbGreenplumClusterMasterHostsList", jsii.get(self, "masterHosts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="masterSubcluster")
    def master_subcluster(self) -> "DataYandexMdbGreenplumClusterMasterSubclusterList":
        return typing.cast("DataYandexMdbGreenplumClusterMasterSubclusterList", jsii.get(self, "masterSubcluster"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "securityGroupIds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="segmentHostCount")
    def segment_host_count(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "segmentHostCount"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="segmentHosts")
    def segment_hosts(self) -> "DataYandexMdbGreenplumClusterSegmentHostsList":
        return typing.cast("DataYandexMdbGreenplumClusterSegmentHostsList", jsii.get(self, "segmentHosts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="segmentInHost")
    def segment_in_host(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "segmentInHost"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="segmentSubcluster")
    def segment_subcluster(
        self,
    ) -> "DataYandexMdbGreenplumClusterSegmentSubclusterList":
        return typing.cast("DataYandexMdbGreenplumClusterSegmentSubclusterList", jsii.get(self, "segmentSubcluster"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="userName")
    def user_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "userName"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "version"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zone")
    def zone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zone"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterIdInput")
    def cluster_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "clusterIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterId")
    def cluster_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "clusterId"))

    @cluster_id.setter
    def cluster_id(self, value: builtins.str) -> None:
        jsii.set(self, "clusterId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbGreenplumClusterAccess",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbGreenplumClusterAccess:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbGreenplumClusterAccess(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbGreenplumClusterAccessList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbGreenplumClusterAccessList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbGreenplumClusterAccessOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbGreenplumClusterAccessOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbGreenplumClusterAccessOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbGreenplumClusterAccessOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dataLens")
    def data_lens(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "dataLens"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="webSql")
    def web_sql(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "webSql"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexMdbGreenplumClusterAccess]:
        return typing.cast(typing.Optional[DataYandexMdbGreenplumClusterAccess], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbGreenplumClusterAccess],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbGreenplumClusterBackupWindowStart",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbGreenplumClusterBackupWindowStart:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbGreenplumClusterBackupWindowStart(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbGreenplumClusterBackupWindowStartList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbGreenplumClusterBackupWindowStartList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbGreenplumClusterBackupWindowStartOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbGreenplumClusterBackupWindowStartOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbGreenplumClusterBackupWindowStartOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbGreenplumClusterBackupWindowStartOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hours")
    def hours(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "hours"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minutes")
    def minutes(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minutes"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbGreenplumClusterBackupWindowStart]:
        return typing.cast(typing.Optional[DataYandexMdbGreenplumClusterBackupWindowStart], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbGreenplumClusterBackupWindowStart],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbGreenplumClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_id": "clusterId",
        "folder_id": "folderId",
        "id": "id",
        "name": "name",
    },
)
class DataYandexMdbGreenplumClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_id: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_greenplum_cluster#cluster_id DataYandexMdbGreenplumCluster#cluster_id}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_greenplum_cluster#folder_id DataYandexMdbGreenplumCluster#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_greenplum_cluster#id DataYandexMdbGreenplumCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_greenplum_cluster#name DataYandexMdbGreenplumCluster#name}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if cluster_id is not None:
            self._values["cluster_id"] = cluster_id
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def cluster_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_greenplum_cluster#cluster_id DataYandexMdbGreenplumCluster#cluster_id}.'''
        result = self._values.get("cluster_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_greenplum_cluster#folder_id DataYandexMdbGreenplumCluster#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_greenplum_cluster#id DataYandexMdbGreenplumCluster#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_greenplum_cluster#name DataYandexMdbGreenplumCluster#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbGreenplumClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbGreenplumClusterMasterHosts",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbGreenplumClusterMasterHosts:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbGreenplumClusterMasterHosts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbGreenplumClusterMasterHostsList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbGreenplumClusterMasterHostsList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbGreenplumClusterMasterHostsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbGreenplumClusterMasterHostsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbGreenplumClusterMasterHostsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbGreenplumClusterMasterHostsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIp")
    def assign_public_ip(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "assignPublicIp"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fqdn"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbGreenplumClusterMasterHosts]:
        return typing.cast(typing.Optional[DataYandexMdbGreenplumClusterMasterHosts], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbGreenplumClusterMasterHosts],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbGreenplumClusterMasterSubcluster",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbGreenplumClusterMasterSubcluster:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbGreenplumClusterMasterSubcluster(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbGreenplumClusterMasterSubclusterList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbGreenplumClusterMasterSubclusterList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbGreenplumClusterMasterSubclusterOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbGreenplumClusterMasterSubclusterOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbGreenplumClusterMasterSubclusterOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbGreenplumClusterMasterSubclusterOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resources")
    def resources(self) -> "DataYandexMdbGreenplumClusterMasterSubclusterResourcesList":
        return typing.cast("DataYandexMdbGreenplumClusterMasterSubclusterResourcesList", jsii.get(self, "resources"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbGreenplumClusterMasterSubcluster]:
        return typing.cast(typing.Optional[DataYandexMdbGreenplumClusterMasterSubcluster], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbGreenplumClusterMasterSubcluster],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbGreenplumClusterMasterSubclusterResources",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbGreenplumClusterMasterSubclusterResources:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbGreenplumClusterMasterSubclusterResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbGreenplumClusterMasterSubclusterResourcesList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbGreenplumClusterMasterSubclusterResourcesList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbGreenplumClusterMasterSubclusterResourcesOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbGreenplumClusterMasterSubclusterResourcesOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbGreenplumClusterMasterSubclusterResourcesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbGreenplumClusterMasterSubclusterResourcesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSize")
    def disk_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "diskSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeId")
    def disk_type_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskTypeId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetId")
    def resource_preset_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourcePresetId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbGreenplumClusterMasterSubclusterResources]:
        return typing.cast(typing.Optional[DataYandexMdbGreenplumClusterMasterSubclusterResources], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbGreenplumClusterMasterSubclusterResources],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbGreenplumClusterSegmentHosts",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbGreenplumClusterSegmentHosts:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbGreenplumClusterSegmentHosts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbGreenplumClusterSegmentHostsList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbGreenplumClusterSegmentHostsList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbGreenplumClusterSegmentHostsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbGreenplumClusterSegmentHostsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbGreenplumClusterSegmentHostsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbGreenplumClusterSegmentHostsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fqdn"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbGreenplumClusterSegmentHosts]:
        return typing.cast(typing.Optional[DataYandexMdbGreenplumClusterSegmentHosts], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbGreenplumClusterSegmentHosts],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbGreenplumClusterSegmentSubcluster",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbGreenplumClusterSegmentSubcluster:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbGreenplumClusterSegmentSubcluster(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbGreenplumClusterSegmentSubclusterList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbGreenplumClusterSegmentSubclusterList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbGreenplumClusterSegmentSubclusterOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbGreenplumClusterSegmentSubclusterOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbGreenplumClusterSegmentSubclusterOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbGreenplumClusterSegmentSubclusterOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resources")
    def resources(
        self,
    ) -> "DataYandexMdbGreenplumClusterSegmentSubclusterResourcesList":
        return typing.cast("DataYandexMdbGreenplumClusterSegmentSubclusterResourcesList", jsii.get(self, "resources"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbGreenplumClusterSegmentSubcluster]:
        return typing.cast(typing.Optional[DataYandexMdbGreenplumClusterSegmentSubcluster], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbGreenplumClusterSegmentSubcluster],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbGreenplumClusterSegmentSubclusterResources",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbGreenplumClusterSegmentSubclusterResources:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbGreenplumClusterSegmentSubclusterResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbGreenplumClusterSegmentSubclusterResourcesList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbGreenplumClusterSegmentSubclusterResourcesList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbGreenplumClusterSegmentSubclusterResourcesOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbGreenplumClusterSegmentSubclusterResourcesOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbGreenplumClusterSegmentSubclusterResourcesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbGreenplumClusterSegmentSubclusterResourcesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSize")
    def disk_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "diskSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeId")
    def disk_type_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskTypeId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetId")
    def resource_preset_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourcePresetId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbGreenplumClusterSegmentSubclusterResources]:
        return typing.cast(typing.Optional[DataYandexMdbGreenplumClusterSegmentSubclusterResources], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbGreenplumClusterSegmentSubclusterResources],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexMdbKafkaCluster(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaCluster",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster yandex_mdb_kafka_cluster}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        cluster_id: typing.Optional[builtins.str] = None,
        config: typing.Optional["DataYandexMdbKafkaClusterConfigA"] = None,
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        subnet_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        topic: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["DataYandexMdbKafkaClusterTopic"]]] = None,
        user: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["DataYandexMdbKafkaClusterUser"]]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster yandex_mdb_kafka_cluster} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#cluster_id DataYandexMdbKafkaCluster#cluster_id}.
        :param config: config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#config DataYandexMdbKafkaCluster#config}
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#deletion_protection DataYandexMdbKafkaCluster#deletion_protection}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#folder_id DataYandexMdbKafkaCluster#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#id DataYandexMdbKafkaCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#name DataYandexMdbKafkaCluster#name}.
        :param subnet_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#subnet_ids DataYandexMdbKafkaCluster#subnet_ids}.
        :param topic: topic block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#topic DataYandexMdbKafkaCluster#topic}
        :param user: user block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#user DataYandexMdbKafkaCluster#user}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config_ = DataYandexMdbKafkaClusterConfig(
            cluster_id=cluster_id,
            config=config,
            deletion_protection=deletion_protection,
            folder_id=folder_id,
            id=id,
            name=name,
            subnet_ids=subnet_ids,
            topic=topic,
            user=user,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config_])

    @jsii.member(jsii_name="putConfig")
    def put_config(
        self,
        *,
        kafka: "DataYandexMdbKafkaClusterConfigKafka",
        version: builtins.str,
        zones: typing.Sequence[builtins.str],
        assign_public_ip: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        brokers_count: typing.Optional[jsii.Number] = None,
        schema_registry: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        unmanaged_topics: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        zookeeper: typing.Optional["DataYandexMdbKafkaClusterConfigZookeeper"] = None,
    ) -> None:
        '''
        :param kafka: kafka block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#kafka DataYandexMdbKafkaCluster#kafka}
        :param version: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#version DataYandexMdbKafkaCluster#version}.
        :param zones: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#zones DataYandexMdbKafkaCluster#zones}.
        :param assign_public_ip: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#assign_public_ip DataYandexMdbKafkaCluster#assign_public_ip}.
        :param brokers_count: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#brokers_count DataYandexMdbKafkaCluster#brokers_count}.
        :param schema_registry: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#schema_registry DataYandexMdbKafkaCluster#schema_registry}.
        :param unmanaged_topics: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#unmanaged_topics DataYandexMdbKafkaCluster#unmanaged_topics}.
        :param zookeeper: zookeeper block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#zookeeper DataYandexMdbKafkaCluster#zookeeper}
        '''
        value = DataYandexMdbKafkaClusterConfigA(
            kafka=kafka,
            version=version,
            zones=zones,
            assign_public_ip=assign_public_ip,
            brokers_count=brokers_count,
            schema_registry=schema_registry,
            unmanaged_topics=unmanaged_topics,
            zookeeper=zookeeper,
        )

        return typing.cast(None, jsii.invoke(self, "putConfig", [value]))

    @jsii.member(jsii_name="putTopic")
    def put_topic(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["DataYandexMdbKafkaClusterTopic"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putTopic", [value]))

    @jsii.member(jsii_name="putUser")
    def put_user(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["DataYandexMdbKafkaClusterUser"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putUser", [value]))

    @jsii.member(jsii_name="resetClusterId")
    def reset_cluster_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetClusterId", []))

    @jsii.member(jsii_name="resetConfig")
    def reset_config(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetConfig", []))

    @jsii.member(jsii_name="resetDeletionProtection")
    def reset_deletion_protection(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDeletionProtection", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetSubnetIds")
    def reset_subnet_ids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSubnetIds", []))

    @jsii.member(jsii_name="resetTopic")
    def reset_topic(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTopic", []))

    @jsii.member(jsii_name="resetUser")
    def reset_user(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUser", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="config")
    def config(self) -> "DataYandexMdbKafkaClusterConfigAOutputReference":
        return typing.cast("DataYandexMdbKafkaClusterConfigAOutputReference", jsii.get(self, "config"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="environment")
    def environment(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "environment"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="health")
    def health(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "health"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="host")
    def host(self) -> "DataYandexMdbKafkaClusterHostList":
        return typing.cast("DataYandexMdbKafkaClusterHostList", jsii.get(self, "host"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostGroupIds")
    def host_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "hostGroupIds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maintenanceWindow")
    def maintenance_window(self) -> "DataYandexMdbKafkaClusterMaintenanceWindowList":
        return typing.cast("DataYandexMdbKafkaClusterMaintenanceWindowList", jsii.get(self, "maintenanceWindow"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "securityGroupIds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="topic")
    def topic(self) -> "DataYandexMdbKafkaClusterTopicList":
        return typing.cast("DataYandexMdbKafkaClusterTopicList", jsii.get(self, "topic"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="user")
    def user(self) -> "DataYandexMdbKafkaClusterUserList":
        return typing.cast("DataYandexMdbKafkaClusterUserList", jsii.get(self, "user"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterIdInput")
    def cluster_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "clusterIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="configInput")
    def config_input(self) -> typing.Optional["DataYandexMdbKafkaClusterConfigA"]:
        return typing.cast(typing.Optional["DataYandexMdbKafkaClusterConfigA"], jsii.get(self, "configInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtectionInput")
    def deletion_protection_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "deletionProtectionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIdsInput")
    def subnet_ids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "subnetIdsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="topicInput")
    def topic_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataYandexMdbKafkaClusterTopic"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataYandexMdbKafkaClusterTopic"]]], jsii.get(self, "topicInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="userInput")
    def user_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataYandexMdbKafkaClusterUser"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataYandexMdbKafkaClusterUser"]]], jsii.get(self, "userInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterId")
    def cluster_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "clusterId"))

    @cluster_id.setter
    def cluster_id(self, value: builtins.str) -> None:
        jsii.set(self, "clusterId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtection")
    def deletion_protection(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "deletionProtection"))

    @deletion_protection.setter
    def deletion_protection(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "deletionProtection", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "subnetIds"))

    @subnet_ids.setter
    def subnet_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "subnetIds", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_id": "clusterId",
        "config": "config",
        "deletion_protection": "deletionProtection",
        "folder_id": "folderId",
        "id": "id",
        "name": "name",
        "subnet_ids": "subnetIds",
        "topic": "topic",
        "user": "user",
    },
)
class DataYandexMdbKafkaClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_id: typing.Optional[builtins.str] = None,
        config: typing.Optional["DataYandexMdbKafkaClusterConfigA"] = None,
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        subnet_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        topic: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["DataYandexMdbKafkaClusterTopic"]]] = None,
        user: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["DataYandexMdbKafkaClusterUser"]]] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#cluster_id DataYandexMdbKafkaCluster#cluster_id}.
        :param config: config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#config DataYandexMdbKafkaCluster#config}
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#deletion_protection DataYandexMdbKafkaCluster#deletion_protection}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#folder_id DataYandexMdbKafkaCluster#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#id DataYandexMdbKafkaCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#name DataYandexMdbKafkaCluster#name}.
        :param subnet_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#subnet_ids DataYandexMdbKafkaCluster#subnet_ids}.
        :param topic: topic block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#topic DataYandexMdbKafkaCluster#topic}
        :param user: user block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#user DataYandexMdbKafkaCluster#user}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(config, dict):
            config = DataYandexMdbKafkaClusterConfigA(**config)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if cluster_id is not None:
            self._values["cluster_id"] = cluster_id
        if config is not None:
            self._values["config"] = config
        if deletion_protection is not None:
            self._values["deletion_protection"] = deletion_protection
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name
        if subnet_ids is not None:
            self._values["subnet_ids"] = subnet_ids
        if topic is not None:
            self._values["topic"] = topic
        if user is not None:
            self._values["user"] = user

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def cluster_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#cluster_id DataYandexMdbKafkaCluster#cluster_id}.'''
        result = self._values.get("cluster_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def config(self) -> typing.Optional["DataYandexMdbKafkaClusterConfigA"]:
        '''config block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#config DataYandexMdbKafkaCluster#config}
        '''
        result = self._values.get("config")
        return typing.cast(typing.Optional["DataYandexMdbKafkaClusterConfigA"], result)

    @builtins.property
    def deletion_protection(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#deletion_protection DataYandexMdbKafkaCluster#deletion_protection}.'''
        result = self._values.get("deletion_protection")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#folder_id DataYandexMdbKafkaCluster#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#id DataYandexMdbKafkaCluster#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#name DataYandexMdbKafkaCluster#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def subnet_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#subnet_ids DataYandexMdbKafkaCluster#subnet_ids}.'''
        result = self._values.get("subnet_ids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def topic(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataYandexMdbKafkaClusterTopic"]]]:
        '''topic block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#topic DataYandexMdbKafkaCluster#topic}
        '''
        result = self._values.get("topic")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataYandexMdbKafkaClusterTopic"]]], result)

    @builtins.property
    def user(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataYandexMdbKafkaClusterUser"]]]:
        '''user block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#user DataYandexMdbKafkaCluster#user}
        '''
        result = self._values.get("user")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataYandexMdbKafkaClusterUser"]]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbKafkaClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaClusterConfigA",
    jsii_struct_bases=[],
    name_mapping={
        "kafka": "kafka",
        "version": "version",
        "zones": "zones",
        "assign_public_ip": "assignPublicIp",
        "brokers_count": "brokersCount",
        "schema_registry": "schemaRegistry",
        "unmanaged_topics": "unmanagedTopics",
        "zookeeper": "zookeeper",
    },
)
class DataYandexMdbKafkaClusterConfigA:
    def __init__(
        self,
        *,
        kafka: "DataYandexMdbKafkaClusterConfigKafka",
        version: builtins.str,
        zones: typing.Sequence[builtins.str],
        assign_public_ip: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        brokers_count: typing.Optional[jsii.Number] = None,
        schema_registry: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        unmanaged_topics: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        zookeeper: typing.Optional["DataYandexMdbKafkaClusterConfigZookeeper"] = None,
    ) -> None:
        '''
        :param kafka: kafka block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#kafka DataYandexMdbKafkaCluster#kafka}
        :param version: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#version DataYandexMdbKafkaCluster#version}.
        :param zones: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#zones DataYandexMdbKafkaCluster#zones}.
        :param assign_public_ip: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#assign_public_ip DataYandexMdbKafkaCluster#assign_public_ip}.
        :param brokers_count: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#brokers_count DataYandexMdbKafkaCluster#brokers_count}.
        :param schema_registry: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#schema_registry DataYandexMdbKafkaCluster#schema_registry}.
        :param unmanaged_topics: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#unmanaged_topics DataYandexMdbKafkaCluster#unmanaged_topics}.
        :param zookeeper: zookeeper block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#zookeeper DataYandexMdbKafkaCluster#zookeeper}
        '''
        if isinstance(kafka, dict):
            kafka = DataYandexMdbKafkaClusterConfigKafka(**kafka)
        if isinstance(zookeeper, dict):
            zookeeper = DataYandexMdbKafkaClusterConfigZookeeper(**zookeeper)
        self._values: typing.Dict[str, typing.Any] = {
            "kafka": kafka,
            "version": version,
            "zones": zones,
        }
        if assign_public_ip is not None:
            self._values["assign_public_ip"] = assign_public_ip
        if brokers_count is not None:
            self._values["brokers_count"] = brokers_count
        if schema_registry is not None:
            self._values["schema_registry"] = schema_registry
        if unmanaged_topics is not None:
            self._values["unmanaged_topics"] = unmanaged_topics
        if zookeeper is not None:
            self._values["zookeeper"] = zookeeper

    @builtins.property
    def kafka(self) -> "DataYandexMdbKafkaClusterConfigKafka":
        '''kafka block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#kafka DataYandexMdbKafkaCluster#kafka}
        '''
        result = self._values.get("kafka")
        assert result is not None, "Required property 'kafka' is missing"
        return typing.cast("DataYandexMdbKafkaClusterConfigKafka", result)

    @builtins.property
    def version(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#version DataYandexMdbKafkaCluster#version}.'''
        result = self._values.get("version")
        assert result is not None, "Required property 'version' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def zones(self) -> typing.List[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#zones DataYandexMdbKafkaCluster#zones}.'''
        result = self._values.get("zones")
        assert result is not None, "Required property 'zones' is missing"
        return typing.cast(typing.List[builtins.str], result)

    @builtins.property
    def assign_public_ip(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#assign_public_ip DataYandexMdbKafkaCluster#assign_public_ip}.'''
        result = self._values.get("assign_public_ip")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def brokers_count(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#brokers_count DataYandexMdbKafkaCluster#brokers_count}.'''
        result = self._values.get("brokers_count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def schema_registry(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#schema_registry DataYandexMdbKafkaCluster#schema_registry}.'''
        result = self._values.get("schema_registry")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def unmanaged_topics(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#unmanaged_topics DataYandexMdbKafkaCluster#unmanaged_topics}.'''
        result = self._values.get("unmanaged_topics")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def zookeeper(self) -> typing.Optional["DataYandexMdbKafkaClusterConfigZookeeper"]:
        '''zookeeper block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#zookeeper DataYandexMdbKafkaCluster#zookeeper}
        '''
        result = self._values.get("zookeeper")
        return typing.cast(typing.Optional["DataYandexMdbKafkaClusterConfigZookeeper"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbKafkaClusterConfigA(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbKafkaClusterConfigAOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaClusterConfigAOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putKafka")
    def put_kafka(
        self,
        *,
        resources: "DataYandexMdbKafkaClusterConfigKafkaResources",
        kafka_config: typing.Optional["DataYandexMdbKafkaClusterConfigKafkaKafkaConfig"] = None,
    ) -> None:
        '''
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#resources DataYandexMdbKafkaCluster#resources}
        :param kafka_config: kafka_config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#kafka_config DataYandexMdbKafkaCluster#kafka_config}
        '''
        value = DataYandexMdbKafkaClusterConfigKafka(
            resources=resources, kafka_config=kafka_config
        )

        return typing.cast(None, jsii.invoke(self, "putKafka", [value]))

    @jsii.member(jsii_name="putZookeeper")
    def put_zookeeper(
        self,
        *,
        resources: typing.Optional["DataYandexMdbKafkaClusterConfigZookeeperResources"] = None,
    ) -> None:
        '''
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#resources DataYandexMdbKafkaCluster#resources}
        '''
        value = DataYandexMdbKafkaClusterConfigZookeeper(resources=resources)

        return typing.cast(None, jsii.invoke(self, "putZookeeper", [value]))

    @jsii.member(jsii_name="resetAssignPublicIp")
    def reset_assign_public_ip(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAssignPublicIp", []))

    @jsii.member(jsii_name="resetBrokersCount")
    def reset_brokers_count(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetBrokersCount", []))

    @jsii.member(jsii_name="resetSchemaRegistry")
    def reset_schema_registry(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSchemaRegistry", []))

    @jsii.member(jsii_name="resetUnmanagedTopics")
    def reset_unmanaged_topics(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUnmanagedTopics", []))

    @jsii.member(jsii_name="resetZookeeper")
    def reset_zookeeper(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetZookeeper", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="kafka")
    def kafka(self) -> "DataYandexMdbKafkaClusterConfigKafkaOutputReference":
        return typing.cast("DataYandexMdbKafkaClusterConfigKafkaOutputReference", jsii.get(self, "kafka"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zookeeper")
    def zookeeper(self) -> "DataYandexMdbKafkaClusterConfigZookeeperOutputReference":
        return typing.cast("DataYandexMdbKafkaClusterConfigZookeeperOutputReference", jsii.get(self, "zookeeper"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIpInput")
    def assign_public_ip_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "assignPublicIpInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="brokersCountInput")
    def brokers_count_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "brokersCountInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="kafkaInput")
    def kafka_input(self) -> typing.Optional["DataYandexMdbKafkaClusterConfigKafka"]:
        return typing.cast(typing.Optional["DataYandexMdbKafkaClusterConfigKafka"], jsii.get(self, "kafkaInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="schemaRegistryInput")
    def schema_registry_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "schemaRegistryInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="unmanagedTopicsInput")
    def unmanaged_topics_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "unmanagedTopicsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="versionInput")
    def version_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "versionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zonesInput")
    def zones_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "zonesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zookeeperInput")
    def zookeeper_input(
        self,
    ) -> typing.Optional["DataYandexMdbKafkaClusterConfigZookeeper"]:
        return typing.cast(typing.Optional["DataYandexMdbKafkaClusterConfigZookeeper"], jsii.get(self, "zookeeperInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIp")
    def assign_public_ip(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "assignPublicIp"))

    @assign_public_ip.setter
    def assign_public_ip(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "assignPublicIp", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="brokersCount")
    def brokers_count(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "brokersCount"))

    @brokers_count.setter
    def brokers_count(self, value: jsii.Number) -> None:
        jsii.set(self, "brokersCount", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="schemaRegistry")
    def schema_registry(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "schemaRegistry"))

    @schema_registry.setter
    def schema_registry(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "schemaRegistry", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="unmanagedTopics")
    def unmanaged_topics(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "unmanagedTopics"))

    @unmanaged_topics.setter
    def unmanaged_topics(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "unmanagedTopics", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "version"))

    @version.setter
    def version(self, value: builtins.str) -> None:
        jsii.set(self, "version", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zones")
    def zones(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "zones"))

    @zones.setter
    def zones(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "zones", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexMdbKafkaClusterConfigA]:
        return typing.cast(typing.Optional[DataYandexMdbKafkaClusterConfigA], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbKafkaClusterConfigA],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaClusterConfigKafka",
    jsii_struct_bases=[],
    name_mapping={"resources": "resources", "kafka_config": "kafkaConfig"},
)
class DataYandexMdbKafkaClusterConfigKafka:
    def __init__(
        self,
        *,
        resources: "DataYandexMdbKafkaClusterConfigKafkaResources",
        kafka_config: typing.Optional["DataYandexMdbKafkaClusterConfigKafkaKafkaConfig"] = None,
    ) -> None:
        '''
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#resources DataYandexMdbKafkaCluster#resources}
        :param kafka_config: kafka_config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#kafka_config DataYandexMdbKafkaCluster#kafka_config}
        '''
        if isinstance(resources, dict):
            resources = DataYandexMdbKafkaClusterConfigKafkaResources(**resources)
        if isinstance(kafka_config, dict):
            kafka_config = DataYandexMdbKafkaClusterConfigKafkaKafkaConfig(**kafka_config)
        self._values: typing.Dict[str, typing.Any] = {
            "resources": resources,
        }
        if kafka_config is not None:
            self._values["kafka_config"] = kafka_config

    @builtins.property
    def resources(self) -> "DataYandexMdbKafkaClusterConfigKafkaResources":
        '''resources block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#resources DataYandexMdbKafkaCluster#resources}
        '''
        result = self._values.get("resources")
        assert result is not None, "Required property 'resources' is missing"
        return typing.cast("DataYandexMdbKafkaClusterConfigKafkaResources", result)

    @builtins.property
    def kafka_config(
        self,
    ) -> typing.Optional["DataYandexMdbKafkaClusterConfigKafkaKafkaConfig"]:
        '''kafka_config block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#kafka_config DataYandexMdbKafkaCluster#kafka_config}
        '''
        result = self._values.get("kafka_config")
        return typing.cast(typing.Optional["DataYandexMdbKafkaClusterConfigKafkaKafkaConfig"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbKafkaClusterConfigKafka(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaClusterConfigKafkaKafkaConfig",
    jsii_struct_bases=[],
    name_mapping={
        "auto_create_topics_enable": "autoCreateTopicsEnable",
        "compression_type": "compressionType",
        "default_replication_factor": "defaultReplicationFactor",
        "log_flush_interval_messages": "logFlushIntervalMessages",
        "log_flush_interval_ms": "logFlushIntervalMs",
        "log_flush_scheduler_interval_ms": "logFlushSchedulerIntervalMs",
        "log_preallocate": "logPreallocate",
        "log_retention_bytes": "logRetentionBytes",
        "log_retention_hours": "logRetentionHours",
        "log_retention_minutes": "logRetentionMinutes",
        "log_retention_ms": "logRetentionMs",
        "log_segment_bytes": "logSegmentBytes",
        "num_partitions": "numPartitions",
        "socket_receive_buffer_bytes": "socketReceiveBufferBytes",
        "socket_send_buffer_bytes": "socketSendBufferBytes",
    },
)
class DataYandexMdbKafkaClusterConfigKafkaKafkaConfig:
    def __init__(
        self,
        *,
        auto_create_topics_enable: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        compression_type: typing.Optional[builtins.str] = None,
        default_replication_factor: typing.Optional[builtins.str] = None,
        log_flush_interval_messages: typing.Optional[builtins.str] = None,
        log_flush_interval_ms: typing.Optional[builtins.str] = None,
        log_flush_scheduler_interval_ms: typing.Optional[builtins.str] = None,
        log_preallocate: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        log_retention_bytes: typing.Optional[builtins.str] = None,
        log_retention_hours: typing.Optional[builtins.str] = None,
        log_retention_minutes: typing.Optional[builtins.str] = None,
        log_retention_ms: typing.Optional[builtins.str] = None,
        log_segment_bytes: typing.Optional[builtins.str] = None,
        num_partitions: typing.Optional[builtins.str] = None,
        socket_receive_buffer_bytes: typing.Optional[builtins.str] = None,
        socket_send_buffer_bytes: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param auto_create_topics_enable: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#auto_create_topics_enable DataYandexMdbKafkaCluster#auto_create_topics_enable}.
        :param compression_type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#compression_type DataYandexMdbKafkaCluster#compression_type}.
        :param default_replication_factor: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#default_replication_factor DataYandexMdbKafkaCluster#default_replication_factor}.
        :param log_flush_interval_messages: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#log_flush_interval_messages DataYandexMdbKafkaCluster#log_flush_interval_messages}.
        :param log_flush_interval_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#log_flush_interval_ms DataYandexMdbKafkaCluster#log_flush_interval_ms}.
        :param log_flush_scheduler_interval_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#log_flush_scheduler_interval_ms DataYandexMdbKafkaCluster#log_flush_scheduler_interval_ms}.
        :param log_preallocate: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#log_preallocate DataYandexMdbKafkaCluster#log_preallocate}.
        :param log_retention_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#log_retention_bytes DataYandexMdbKafkaCluster#log_retention_bytes}.
        :param log_retention_hours: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#log_retention_hours DataYandexMdbKafkaCluster#log_retention_hours}.
        :param log_retention_minutes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#log_retention_minutes DataYandexMdbKafkaCluster#log_retention_minutes}.
        :param log_retention_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#log_retention_ms DataYandexMdbKafkaCluster#log_retention_ms}.
        :param log_segment_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#log_segment_bytes DataYandexMdbKafkaCluster#log_segment_bytes}.
        :param num_partitions: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#num_partitions DataYandexMdbKafkaCluster#num_partitions}.
        :param socket_receive_buffer_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#socket_receive_buffer_bytes DataYandexMdbKafkaCluster#socket_receive_buffer_bytes}.
        :param socket_send_buffer_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#socket_send_buffer_bytes DataYandexMdbKafkaCluster#socket_send_buffer_bytes}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if auto_create_topics_enable is not None:
            self._values["auto_create_topics_enable"] = auto_create_topics_enable
        if compression_type is not None:
            self._values["compression_type"] = compression_type
        if default_replication_factor is not None:
            self._values["default_replication_factor"] = default_replication_factor
        if log_flush_interval_messages is not None:
            self._values["log_flush_interval_messages"] = log_flush_interval_messages
        if log_flush_interval_ms is not None:
            self._values["log_flush_interval_ms"] = log_flush_interval_ms
        if log_flush_scheduler_interval_ms is not None:
            self._values["log_flush_scheduler_interval_ms"] = log_flush_scheduler_interval_ms
        if log_preallocate is not None:
            self._values["log_preallocate"] = log_preallocate
        if log_retention_bytes is not None:
            self._values["log_retention_bytes"] = log_retention_bytes
        if log_retention_hours is not None:
            self._values["log_retention_hours"] = log_retention_hours
        if log_retention_minutes is not None:
            self._values["log_retention_minutes"] = log_retention_minutes
        if log_retention_ms is not None:
            self._values["log_retention_ms"] = log_retention_ms
        if log_segment_bytes is not None:
            self._values["log_segment_bytes"] = log_segment_bytes
        if num_partitions is not None:
            self._values["num_partitions"] = num_partitions
        if socket_receive_buffer_bytes is not None:
            self._values["socket_receive_buffer_bytes"] = socket_receive_buffer_bytes
        if socket_send_buffer_bytes is not None:
            self._values["socket_send_buffer_bytes"] = socket_send_buffer_bytes

    @builtins.property
    def auto_create_topics_enable(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#auto_create_topics_enable DataYandexMdbKafkaCluster#auto_create_topics_enable}.'''
        result = self._values.get("auto_create_topics_enable")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def compression_type(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#compression_type DataYandexMdbKafkaCluster#compression_type}.'''
        result = self._values.get("compression_type")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def default_replication_factor(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#default_replication_factor DataYandexMdbKafkaCluster#default_replication_factor}.'''
        result = self._values.get("default_replication_factor")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def log_flush_interval_messages(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#log_flush_interval_messages DataYandexMdbKafkaCluster#log_flush_interval_messages}.'''
        result = self._values.get("log_flush_interval_messages")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def log_flush_interval_ms(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#log_flush_interval_ms DataYandexMdbKafkaCluster#log_flush_interval_ms}.'''
        result = self._values.get("log_flush_interval_ms")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def log_flush_scheduler_interval_ms(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#log_flush_scheduler_interval_ms DataYandexMdbKafkaCluster#log_flush_scheduler_interval_ms}.'''
        result = self._values.get("log_flush_scheduler_interval_ms")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def log_preallocate(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#log_preallocate DataYandexMdbKafkaCluster#log_preallocate}.'''
        result = self._values.get("log_preallocate")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def log_retention_bytes(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#log_retention_bytes DataYandexMdbKafkaCluster#log_retention_bytes}.'''
        result = self._values.get("log_retention_bytes")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def log_retention_hours(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#log_retention_hours DataYandexMdbKafkaCluster#log_retention_hours}.'''
        result = self._values.get("log_retention_hours")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def log_retention_minutes(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#log_retention_minutes DataYandexMdbKafkaCluster#log_retention_minutes}.'''
        result = self._values.get("log_retention_minutes")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def log_retention_ms(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#log_retention_ms DataYandexMdbKafkaCluster#log_retention_ms}.'''
        result = self._values.get("log_retention_ms")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def log_segment_bytes(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#log_segment_bytes DataYandexMdbKafkaCluster#log_segment_bytes}.'''
        result = self._values.get("log_segment_bytes")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def num_partitions(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#num_partitions DataYandexMdbKafkaCluster#num_partitions}.'''
        result = self._values.get("num_partitions")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def socket_receive_buffer_bytes(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#socket_receive_buffer_bytes DataYandexMdbKafkaCluster#socket_receive_buffer_bytes}.'''
        result = self._values.get("socket_receive_buffer_bytes")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def socket_send_buffer_bytes(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#socket_send_buffer_bytes DataYandexMdbKafkaCluster#socket_send_buffer_bytes}.'''
        result = self._values.get("socket_send_buffer_bytes")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbKafkaClusterConfigKafkaKafkaConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbKafkaClusterConfigKafkaKafkaConfigOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaClusterConfigKafkaKafkaConfigOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAutoCreateTopicsEnable")
    def reset_auto_create_topics_enable(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAutoCreateTopicsEnable", []))

    @jsii.member(jsii_name="resetCompressionType")
    def reset_compression_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCompressionType", []))

    @jsii.member(jsii_name="resetDefaultReplicationFactor")
    def reset_default_replication_factor(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDefaultReplicationFactor", []))

    @jsii.member(jsii_name="resetLogFlushIntervalMessages")
    def reset_log_flush_interval_messages(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogFlushIntervalMessages", []))

    @jsii.member(jsii_name="resetLogFlushIntervalMs")
    def reset_log_flush_interval_ms(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogFlushIntervalMs", []))

    @jsii.member(jsii_name="resetLogFlushSchedulerIntervalMs")
    def reset_log_flush_scheduler_interval_ms(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogFlushSchedulerIntervalMs", []))

    @jsii.member(jsii_name="resetLogPreallocate")
    def reset_log_preallocate(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogPreallocate", []))

    @jsii.member(jsii_name="resetLogRetentionBytes")
    def reset_log_retention_bytes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogRetentionBytes", []))

    @jsii.member(jsii_name="resetLogRetentionHours")
    def reset_log_retention_hours(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogRetentionHours", []))

    @jsii.member(jsii_name="resetLogRetentionMinutes")
    def reset_log_retention_minutes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogRetentionMinutes", []))

    @jsii.member(jsii_name="resetLogRetentionMs")
    def reset_log_retention_ms(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogRetentionMs", []))

    @jsii.member(jsii_name="resetLogSegmentBytes")
    def reset_log_segment_bytes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogSegmentBytes", []))

    @jsii.member(jsii_name="resetNumPartitions")
    def reset_num_partitions(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNumPartitions", []))

    @jsii.member(jsii_name="resetSocketReceiveBufferBytes")
    def reset_socket_receive_buffer_bytes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSocketReceiveBufferBytes", []))

    @jsii.member(jsii_name="resetSocketSendBufferBytes")
    def reset_socket_send_buffer_bytes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSocketSendBufferBytes", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoCreateTopicsEnableInput")
    def auto_create_topics_enable_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "autoCreateTopicsEnableInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="compressionTypeInput")
    def compression_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "compressionTypeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="defaultReplicationFactorInput")
    def default_replication_factor_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "defaultReplicationFactorInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logFlushIntervalMessagesInput")
    def log_flush_interval_messages_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "logFlushIntervalMessagesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logFlushIntervalMsInput")
    def log_flush_interval_ms_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "logFlushIntervalMsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logFlushSchedulerIntervalMsInput")
    def log_flush_scheduler_interval_ms_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "logFlushSchedulerIntervalMsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logPreallocateInput")
    def log_preallocate_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "logPreallocateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logRetentionBytesInput")
    def log_retention_bytes_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "logRetentionBytesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logRetentionHoursInput")
    def log_retention_hours_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "logRetentionHoursInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logRetentionMinutesInput")
    def log_retention_minutes_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "logRetentionMinutesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logRetentionMsInput")
    def log_retention_ms_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "logRetentionMsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logSegmentBytesInput")
    def log_segment_bytes_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "logSegmentBytesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="numPartitionsInput")
    def num_partitions_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "numPartitionsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="socketReceiveBufferBytesInput")
    def socket_receive_buffer_bytes_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "socketReceiveBufferBytesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="socketSendBufferBytesInput")
    def socket_send_buffer_bytes_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "socketSendBufferBytesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoCreateTopicsEnable")
    def auto_create_topics_enable(
        self,
    ) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "autoCreateTopicsEnable"))

    @auto_create_topics_enable.setter
    def auto_create_topics_enable(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "autoCreateTopicsEnable", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="compressionType")
    def compression_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "compressionType"))

    @compression_type.setter
    def compression_type(self, value: builtins.str) -> None:
        jsii.set(self, "compressionType", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="defaultReplicationFactor")
    def default_replication_factor(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "defaultReplicationFactor"))

    @default_replication_factor.setter
    def default_replication_factor(self, value: builtins.str) -> None:
        jsii.set(self, "defaultReplicationFactor", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logFlushIntervalMessages")
    def log_flush_interval_messages(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "logFlushIntervalMessages"))

    @log_flush_interval_messages.setter
    def log_flush_interval_messages(self, value: builtins.str) -> None:
        jsii.set(self, "logFlushIntervalMessages", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logFlushIntervalMs")
    def log_flush_interval_ms(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "logFlushIntervalMs"))

    @log_flush_interval_ms.setter
    def log_flush_interval_ms(self, value: builtins.str) -> None:
        jsii.set(self, "logFlushIntervalMs", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logFlushSchedulerIntervalMs")
    def log_flush_scheduler_interval_ms(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "logFlushSchedulerIntervalMs"))

    @log_flush_scheduler_interval_ms.setter
    def log_flush_scheduler_interval_ms(self, value: builtins.str) -> None:
        jsii.set(self, "logFlushSchedulerIntervalMs", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logPreallocate")
    def log_preallocate(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "logPreallocate"))

    @log_preallocate.setter
    def log_preallocate(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "logPreallocate", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logRetentionBytes")
    def log_retention_bytes(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "logRetentionBytes"))

    @log_retention_bytes.setter
    def log_retention_bytes(self, value: builtins.str) -> None:
        jsii.set(self, "logRetentionBytes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logRetentionHours")
    def log_retention_hours(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "logRetentionHours"))

    @log_retention_hours.setter
    def log_retention_hours(self, value: builtins.str) -> None:
        jsii.set(self, "logRetentionHours", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logRetentionMinutes")
    def log_retention_minutes(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "logRetentionMinutes"))

    @log_retention_minutes.setter
    def log_retention_minutes(self, value: builtins.str) -> None:
        jsii.set(self, "logRetentionMinutes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logRetentionMs")
    def log_retention_ms(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "logRetentionMs"))

    @log_retention_ms.setter
    def log_retention_ms(self, value: builtins.str) -> None:
        jsii.set(self, "logRetentionMs", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logSegmentBytes")
    def log_segment_bytes(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "logSegmentBytes"))

    @log_segment_bytes.setter
    def log_segment_bytes(self, value: builtins.str) -> None:
        jsii.set(self, "logSegmentBytes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="numPartitions")
    def num_partitions(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "numPartitions"))

    @num_partitions.setter
    def num_partitions(self, value: builtins.str) -> None:
        jsii.set(self, "numPartitions", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="socketReceiveBufferBytes")
    def socket_receive_buffer_bytes(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "socketReceiveBufferBytes"))

    @socket_receive_buffer_bytes.setter
    def socket_receive_buffer_bytes(self, value: builtins.str) -> None:
        jsii.set(self, "socketReceiveBufferBytes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="socketSendBufferBytes")
    def socket_send_buffer_bytes(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "socketSendBufferBytes"))

    @socket_send_buffer_bytes.setter
    def socket_send_buffer_bytes(self, value: builtins.str) -> None:
        jsii.set(self, "socketSendBufferBytes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbKafkaClusterConfigKafkaKafkaConfig]:
        return typing.cast(typing.Optional[DataYandexMdbKafkaClusterConfigKafkaKafkaConfig], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbKafkaClusterConfigKafkaKafkaConfig],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexMdbKafkaClusterConfigKafkaOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaClusterConfigKafkaOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putKafkaConfig")
    def put_kafka_config(
        self,
        *,
        auto_create_topics_enable: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        compression_type: typing.Optional[builtins.str] = None,
        default_replication_factor: typing.Optional[builtins.str] = None,
        log_flush_interval_messages: typing.Optional[builtins.str] = None,
        log_flush_interval_ms: typing.Optional[builtins.str] = None,
        log_flush_scheduler_interval_ms: typing.Optional[builtins.str] = None,
        log_preallocate: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        log_retention_bytes: typing.Optional[builtins.str] = None,
        log_retention_hours: typing.Optional[builtins.str] = None,
        log_retention_minutes: typing.Optional[builtins.str] = None,
        log_retention_ms: typing.Optional[builtins.str] = None,
        log_segment_bytes: typing.Optional[builtins.str] = None,
        num_partitions: typing.Optional[builtins.str] = None,
        socket_receive_buffer_bytes: typing.Optional[builtins.str] = None,
        socket_send_buffer_bytes: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param auto_create_topics_enable: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#auto_create_topics_enable DataYandexMdbKafkaCluster#auto_create_topics_enable}.
        :param compression_type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#compression_type DataYandexMdbKafkaCluster#compression_type}.
        :param default_replication_factor: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#default_replication_factor DataYandexMdbKafkaCluster#default_replication_factor}.
        :param log_flush_interval_messages: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#log_flush_interval_messages DataYandexMdbKafkaCluster#log_flush_interval_messages}.
        :param log_flush_interval_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#log_flush_interval_ms DataYandexMdbKafkaCluster#log_flush_interval_ms}.
        :param log_flush_scheduler_interval_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#log_flush_scheduler_interval_ms DataYandexMdbKafkaCluster#log_flush_scheduler_interval_ms}.
        :param log_preallocate: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#log_preallocate DataYandexMdbKafkaCluster#log_preallocate}.
        :param log_retention_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#log_retention_bytes DataYandexMdbKafkaCluster#log_retention_bytes}.
        :param log_retention_hours: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#log_retention_hours DataYandexMdbKafkaCluster#log_retention_hours}.
        :param log_retention_minutes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#log_retention_minutes DataYandexMdbKafkaCluster#log_retention_minutes}.
        :param log_retention_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#log_retention_ms DataYandexMdbKafkaCluster#log_retention_ms}.
        :param log_segment_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#log_segment_bytes DataYandexMdbKafkaCluster#log_segment_bytes}.
        :param num_partitions: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#num_partitions DataYandexMdbKafkaCluster#num_partitions}.
        :param socket_receive_buffer_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#socket_receive_buffer_bytes DataYandexMdbKafkaCluster#socket_receive_buffer_bytes}.
        :param socket_send_buffer_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#socket_send_buffer_bytes DataYandexMdbKafkaCluster#socket_send_buffer_bytes}.
        '''
        value = DataYandexMdbKafkaClusterConfigKafkaKafkaConfig(
            auto_create_topics_enable=auto_create_topics_enable,
            compression_type=compression_type,
            default_replication_factor=default_replication_factor,
            log_flush_interval_messages=log_flush_interval_messages,
            log_flush_interval_ms=log_flush_interval_ms,
            log_flush_scheduler_interval_ms=log_flush_scheduler_interval_ms,
            log_preallocate=log_preallocate,
            log_retention_bytes=log_retention_bytes,
            log_retention_hours=log_retention_hours,
            log_retention_minutes=log_retention_minutes,
            log_retention_ms=log_retention_ms,
            log_segment_bytes=log_segment_bytes,
            num_partitions=num_partitions,
            socket_receive_buffer_bytes=socket_receive_buffer_bytes,
            socket_send_buffer_bytes=socket_send_buffer_bytes,
        )

        return typing.cast(None, jsii.invoke(self, "putKafkaConfig", [value]))

    @jsii.member(jsii_name="putResources")
    def put_resources(
        self,
        *,
        disk_size: jsii.Number,
        disk_type_id: builtins.str,
        resource_preset_id: builtins.str,
    ) -> None:
        '''
        :param disk_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#disk_size DataYandexMdbKafkaCluster#disk_size}.
        :param disk_type_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#disk_type_id DataYandexMdbKafkaCluster#disk_type_id}.
        :param resource_preset_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#resource_preset_id DataYandexMdbKafkaCluster#resource_preset_id}.
        '''
        value = DataYandexMdbKafkaClusterConfigKafkaResources(
            disk_size=disk_size,
            disk_type_id=disk_type_id,
            resource_preset_id=resource_preset_id,
        )

        return typing.cast(None, jsii.invoke(self, "putResources", [value]))

    @jsii.member(jsii_name="resetKafkaConfig")
    def reset_kafka_config(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetKafkaConfig", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="kafkaConfig")
    def kafka_config(
        self,
    ) -> DataYandexMdbKafkaClusterConfigKafkaKafkaConfigOutputReference:
        return typing.cast(DataYandexMdbKafkaClusterConfigKafkaKafkaConfigOutputReference, jsii.get(self, "kafkaConfig"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resources")
    def resources(
        self,
    ) -> "DataYandexMdbKafkaClusterConfigKafkaResourcesOutputReference":
        return typing.cast("DataYandexMdbKafkaClusterConfigKafkaResourcesOutputReference", jsii.get(self, "resources"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="kafkaConfigInput")
    def kafka_config_input(
        self,
    ) -> typing.Optional[DataYandexMdbKafkaClusterConfigKafkaKafkaConfig]:
        return typing.cast(typing.Optional[DataYandexMdbKafkaClusterConfigKafkaKafkaConfig], jsii.get(self, "kafkaConfigInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcesInput")
    def resources_input(
        self,
    ) -> typing.Optional["DataYandexMdbKafkaClusterConfigKafkaResources"]:
        return typing.cast(typing.Optional["DataYandexMdbKafkaClusterConfigKafkaResources"], jsii.get(self, "resourcesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexMdbKafkaClusterConfigKafka]:
        return typing.cast(typing.Optional[DataYandexMdbKafkaClusterConfigKafka], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbKafkaClusterConfigKafka],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaClusterConfigKafkaResources",
    jsii_struct_bases=[],
    name_mapping={
        "disk_size": "diskSize",
        "disk_type_id": "diskTypeId",
        "resource_preset_id": "resourcePresetId",
    },
)
class DataYandexMdbKafkaClusterConfigKafkaResources:
    def __init__(
        self,
        *,
        disk_size: jsii.Number,
        disk_type_id: builtins.str,
        resource_preset_id: builtins.str,
    ) -> None:
        '''
        :param disk_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#disk_size DataYandexMdbKafkaCluster#disk_size}.
        :param disk_type_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#disk_type_id DataYandexMdbKafkaCluster#disk_type_id}.
        :param resource_preset_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#resource_preset_id DataYandexMdbKafkaCluster#resource_preset_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "disk_size": disk_size,
            "disk_type_id": disk_type_id,
            "resource_preset_id": resource_preset_id,
        }

    @builtins.property
    def disk_size(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#disk_size DataYandexMdbKafkaCluster#disk_size}.'''
        result = self._values.get("disk_size")
        assert result is not None, "Required property 'disk_size' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def disk_type_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#disk_type_id DataYandexMdbKafkaCluster#disk_type_id}.'''
        result = self._values.get("disk_type_id")
        assert result is not None, "Required property 'disk_type_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def resource_preset_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#resource_preset_id DataYandexMdbKafkaCluster#resource_preset_id}.'''
        result = self._values.get("resource_preset_id")
        assert result is not None, "Required property 'resource_preset_id' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbKafkaClusterConfigKafkaResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbKafkaClusterConfigKafkaResourcesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaClusterConfigKafkaResourcesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSizeInput")
    def disk_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "diskSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeIdInput")
    def disk_type_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "diskTypeIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetIdInput")
    def resource_preset_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourcePresetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSize")
    def disk_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "diskSize"))

    @disk_size.setter
    def disk_size(self, value: jsii.Number) -> None:
        jsii.set(self, "diskSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeId")
    def disk_type_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskTypeId"))

    @disk_type_id.setter
    def disk_type_id(self, value: builtins.str) -> None:
        jsii.set(self, "diskTypeId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetId")
    def resource_preset_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourcePresetId"))

    @resource_preset_id.setter
    def resource_preset_id(self, value: builtins.str) -> None:
        jsii.set(self, "resourcePresetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbKafkaClusterConfigKafkaResources]:
        return typing.cast(typing.Optional[DataYandexMdbKafkaClusterConfigKafkaResources], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbKafkaClusterConfigKafkaResources],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaClusterConfigZookeeper",
    jsii_struct_bases=[],
    name_mapping={"resources": "resources"},
)
class DataYandexMdbKafkaClusterConfigZookeeper:
    def __init__(
        self,
        *,
        resources: typing.Optional["DataYandexMdbKafkaClusterConfigZookeeperResources"] = None,
    ) -> None:
        '''
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#resources DataYandexMdbKafkaCluster#resources}
        '''
        if isinstance(resources, dict):
            resources = DataYandexMdbKafkaClusterConfigZookeeperResources(**resources)
        self._values: typing.Dict[str, typing.Any] = {}
        if resources is not None:
            self._values["resources"] = resources

    @builtins.property
    def resources(
        self,
    ) -> typing.Optional["DataYandexMdbKafkaClusterConfigZookeeperResources"]:
        '''resources block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#resources DataYandexMdbKafkaCluster#resources}
        '''
        result = self._values.get("resources")
        return typing.cast(typing.Optional["DataYandexMdbKafkaClusterConfigZookeeperResources"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbKafkaClusterConfigZookeeper(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbKafkaClusterConfigZookeeperOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaClusterConfigZookeeperOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putResources")
    def put_resources(
        self,
        *,
        disk_size: typing.Optional[jsii.Number] = None,
        disk_type_id: typing.Optional[builtins.str] = None,
        resource_preset_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param disk_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#disk_size DataYandexMdbKafkaCluster#disk_size}.
        :param disk_type_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#disk_type_id DataYandexMdbKafkaCluster#disk_type_id}.
        :param resource_preset_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#resource_preset_id DataYandexMdbKafkaCluster#resource_preset_id}.
        '''
        value = DataYandexMdbKafkaClusterConfigZookeeperResources(
            disk_size=disk_size,
            disk_type_id=disk_type_id,
            resource_preset_id=resource_preset_id,
        )

        return typing.cast(None, jsii.invoke(self, "putResources", [value]))

    @jsii.member(jsii_name="resetResources")
    def reset_resources(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetResources", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resources")
    def resources(
        self,
    ) -> "DataYandexMdbKafkaClusterConfigZookeeperResourcesOutputReference":
        return typing.cast("DataYandexMdbKafkaClusterConfigZookeeperResourcesOutputReference", jsii.get(self, "resources"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcesInput")
    def resources_input(
        self,
    ) -> typing.Optional["DataYandexMdbKafkaClusterConfigZookeeperResources"]:
        return typing.cast(typing.Optional["DataYandexMdbKafkaClusterConfigZookeeperResources"], jsii.get(self, "resourcesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbKafkaClusterConfigZookeeper]:
        return typing.cast(typing.Optional[DataYandexMdbKafkaClusterConfigZookeeper], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbKafkaClusterConfigZookeeper],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaClusterConfigZookeeperResources",
    jsii_struct_bases=[],
    name_mapping={
        "disk_size": "diskSize",
        "disk_type_id": "diskTypeId",
        "resource_preset_id": "resourcePresetId",
    },
)
class DataYandexMdbKafkaClusterConfigZookeeperResources:
    def __init__(
        self,
        *,
        disk_size: typing.Optional[jsii.Number] = None,
        disk_type_id: typing.Optional[builtins.str] = None,
        resource_preset_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param disk_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#disk_size DataYandexMdbKafkaCluster#disk_size}.
        :param disk_type_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#disk_type_id DataYandexMdbKafkaCluster#disk_type_id}.
        :param resource_preset_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#resource_preset_id DataYandexMdbKafkaCluster#resource_preset_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if disk_size is not None:
            self._values["disk_size"] = disk_size
        if disk_type_id is not None:
            self._values["disk_type_id"] = disk_type_id
        if resource_preset_id is not None:
            self._values["resource_preset_id"] = resource_preset_id

    @builtins.property
    def disk_size(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#disk_size DataYandexMdbKafkaCluster#disk_size}.'''
        result = self._values.get("disk_size")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def disk_type_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#disk_type_id DataYandexMdbKafkaCluster#disk_type_id}.'''
        result = self._values.get("disk_type_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def resource_preset_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#resource_preset_id DataYandexMdbKafkaCluster#resource_preset_id}.'''
        result = self._values.get("resource_preset_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbKafkaClusterConfigZookeeperResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbKafkaClusterConfigZookeeperResourcesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaClusterConfigZookeeperResourcesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetDiskSize")
    def reset_disk_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDiskSize", []))

    @jsii.member(jsii_name="resetDiskTypeId")
    def reset_disk_type_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDiskTypeId", []))

    @jsii.member(jsii_name="resetResourcePresetId")
    def reset_resource_preset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetResourcePresetId", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSizeInput")
    def disk_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "diskSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeIdInput")
    def disk_type_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "diskTypeIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetIdInput")
    def resource_preset_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourcePresetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSize")
    def disk_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "diskSize"))

    @disk_size.setter
    def disk_size(self, value: jsii.Number) -> None:
        jsii.set(self, "diskSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeId")
    def disk_type_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskTypeId"))

    @disk_type_id.setter
    def disk_type_id(self, value: builtins.str) -> None:
        jsii.set(self, "diskTypeId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetId")
    def resource_preset_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourcePresetId"))

    @resource_preset_id.setter
    def resource_preset_id(self, value: builtins.str) -> None:
        jsii.set(self, "resourcePresetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbKafkaClusterConfigZookeeperResources]:
        return typing.cast(typing.Optional[DataYandexMdbKafkaClusterConfigZookeeperResources], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbKafkaClusterConfigZookeeperResources],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaClusterHost",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbKafkaClusterHost:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbKafkaClusterHost(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbKafkaClusterHostList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaClusterHostList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "DataYandexMdbKafkaClusterHostOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbKafkaClusterHostOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbKafkaClusterHostOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaClusterHostOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIp")
    def assign_public_ip(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "assignPublicIp"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="health")
    def health(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "health"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="role")
    def role(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "role"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneId")
    def zone_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zoneId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexMdbKafkaClusterHost]:
        return typing.cast(typing.Optional[DataYandexMdbKafkaClusterHost], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbKafkaClusterHost],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaClusterMaintenanceWindow",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbKafkaClusterMaintenanceWindow:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbKafkaClusterMaintenanceWindow(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbKafkaClusterMaintenanceWindowList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaClusterMaintenanceWindowList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbKafkaClusterMaintenanceWindowOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbKafkaClusterMaintenanceWindowOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbKafkaClusterMaintenanceWindowOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaClusterMaintenanceWindowOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="day")
    def day(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "day"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hour")
    def hour(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "hour"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbKafkaClusterMaintenanceWindow]:
        return typing.cast(typing.Optional[DataYandexMdbKafkaClusterMaintenanceWindow], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbKafkaClusterMaintenanceWindow],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaClusterTopic",
    jsii_struct_bases=[],
    name_mapping={
        "cluster_id": "clusterId",
        "name": "name",
        "partitions": "partitions",
        "replication_factor": "replicationFactor",
        "topic_config": "topicConfig",
    },
)
class DataYandexMdbKafkaClusterTopic:
    def __init__(
        self,
        *,
        cluster_id: builtins.str,
        name: builtins.str,
        partitions: jsii.Number,
        replication_factor: jsii.Number,
        topic_config: typing.Optional["DataYandexMdbKafkaClusterTopicTopicConfig"] = None,
    ) -> None:
        '''
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#cluster_id DataYandexMdbKafkaCluster#cluster_id}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#name DataYandexMdbKafkaCluster#name}.
        :param partitions: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#partitions DataYandexMdbKafkaCluster#partitions}.
        :param replication_factor: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#replication_factor DataYandexMdbKafkaCluster#replication_factor}.
        :param topic_config: topic_config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#topic_config DataYandexMdbKafkaCluster#topic_config}
        '''
        if isinstance(topic_config, dict):
            topic_config = DataYandexMdbKafkaClusterTopicTopicConfig(**topic_config)
        self._values: typing.Dict[str, typing.Any] = {
            "cluster_id": cluster_id,
            "name": name,
            "partitions": partitions,
            "replication_factor": replication_factor,
        }
        if topic_config is not None:
            self._values["topic_config"] = topic_config

    @builtins.property
    def cluster_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#cluster_id DataYandexMdbKafkaCluster#cluster_id}.'''
        result = self._values.get("cluster_id")
        assert result is not None, "Required property 'cluster_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#name DataYandexMdbKafkaCluster#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def partitions(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#partitions DataYandexMdbKafkaCluster#partitions}.'''
        result = self._values.get("partitions")
        assert result is not None, "Required property 'partitions' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def replication_factor(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#replication_factor DataYandexMdbKafkaCluster#replication_factor}.'''
        result = self._values.get("replication_factor")
        assert result is not None, "Required property 'replication_factor' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def topic_config(
        self,
    ) -> typing.Optional["DataYandexMdbKafkaClusterTopicTopicConfig"]:
        '''topic_config block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#topic_config DataYandexMdbKafkaCluster#topic_config}
        '''
        result = self._values.get("topic_config")
        return typing.cast(typing.Optional["DataYandexMdbKafkaClusterTopicTopicConfig"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbKafkaClusterTopic(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbKafkaClusterTopicList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaClusterTopicList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbKafkaClusterTopicOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbKafkaClusterTopicOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataYandexMdbKafkaClusterTopic]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataYandexMdbKafkaClusterTopic]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataYandexMdbKafkaClusterTopic]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexMdbKafkaClusterTopicOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaClusterTopicOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putTopicConfig")
    def put_topic_config(
        self,
        *,
        cleanup_policy: typing.Optional[builtins.str] = None,
        compression_type: typing.Optional[builtins.str] = None,
        delete_retention_ms: typing.Optional[builtins.str] = None,
        file_delete_delay_ms: typing.Optional[builtins.str] = None,
        flush_messages: typing.Optional[builtins.str] = None,
        flush_ms: typing.Optional[builtins.str] = None,
        max_message_bytes: typing.Optional[builtins.str] = None,
        min_compaction_lag_ms: typing.Optional[builtins.str] = None,
        min_insync_replicas: typing.Optional[builtins.str] = None,
        preallocate: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        retention_bytes: typing.Optional[builtins.str] = None,
        retention_ms: typing.Optional[builtins.str] = None,
        segment_bytes: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param cleanup_policy: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#cleanup_policy DataYandexMdbKafkaCluster#cleanup_policy}.
        :param compression_type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#compression_type DataYandexMdbKafkaCluster#compression_type}.
        :param delete_retention_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#delete_retention_ms DataYandexMdbKafkaCluster#delete_retention_ms}.
        :param file_delete_delay_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#file_delete_delay_ms DataYandexMdbKafkaCluster#file_delete_delay_ms}.
        :param flush_messages: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#flush_messages DataYandexMdbKafkaCluster#flush_messages}.
        :param flush_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#flush_ms DataYandexMdbKafkaCluster#flush_ms}.
        :param max_message_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#max_message_bytes DataYandexMdbKafkaCluster#max_message_bytes}.
        :param min_compaction_lag_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#min_compaction_lag_ms DataYandexMdbKafkaCluster#min_compaction_lag_ms}.
        :param min_insync_replicas: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#min_insync_replicas DataYandexMdbKafkaCluster#min_insync_replicas}.
        :param preallocate: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#preallocate DataYandexMdbKafkaCluster#preallocate}.
        :param retention_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#retention_bytes DataYandexMdbKafkaCluster#retention_bytes}.
        :param retention_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#retention_ms DataYandexMdbKafkaCluster#retention_ms}.
        :param segment_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#segment_bytes DataYandexMdbKafkaCluster#segment_bytes}.
        '''
        value = DataYandexMdbKafkaClusterTopicTopicConfig(
            cleanup_policy=cleanup_policy,
            compression_type=compression_type,
            delete_retention_ms=delete_retention_ms,
            file_delete_delay_ms=file_delete_delay_ms,
            flush_messages=flush_messages,
            flush_ms=flush_ms,
            max_message_bytes=max_message_bytes,
            min_compaction_lag_ms=min_compaction_lag_ms,
            min_insync_replicas=min_insync_replicas,
            preallocate=preallocate,
            retention_bytes=retention_bytes,
            retention_ms=retention_ms,
            segment_bytes=segment_bytes,
        )

        return typing.cast(None, jsii.invoke(self, "putTopicConfig", [value]))

    @jsii.member(jsii_name="resetTopicConfig")
    def reset_topic_config(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTopicConfig", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="topicConfig")
    def topic_config(
        self,
    ) -> "DataYandexMdbKafkaClusterTopicTopicConfigOutputReference":
        return typing.cast("DataYandexMdbKafkaClusterTopicTopicConfigOutputReference", jsii.get(self, "topicConfig"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterIdInput")
    def cluster_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "clusterIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="partitionsInput")
    def partitions_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "partitionsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replicationFactorInput")
    def replication_factor_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "replicationFactorInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="topicConfigInput")
    def topic_config_input(
        self,
    ) -> typing.Optional["DataYandexMdbKafkaClusterTopicTopicConfig"]:
        return typing.cast(typing.Optional["DataYandexMdbKafkaClusterTopicTopicConfig"], jsii.get(self, "topicConfigInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterId")
    def cluster_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "clusterId"))

    @cluster_id.setter
    def cluster_id(self, value: builtins.str) -> None:
        jsii.set(self, "clusterId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="partitions")
    def partitions(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "partitions"))

    @partitions.setter
    def partitions(self, value: jsii.Number) -> None:
        jsii.set(self, "partitions", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replicationFactor")
    def replication_factor(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "replicationFactor"))

    @replication_factor.setter
    def replication_factor(self, value: jsii.Number) -> None:
        jsii.set(self, "replicationFactor", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, DataYandexMdbKafkaClusterTopic]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, DataYandexMdbKafkaClusterTopic]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, DataYandexMdbKafkaClusterTopic]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaClusterTopicTopicConfig",
    jsii_struct_bases=[],
    name_mapping={
        "cleanup_policy": "cleanupPolicy",
        "compression_type": "compressionType",
        "delete_retention_ms": "deleteRetentionMs",
        "file_delete_delay_ms": "fileDeleteDelayMs",
        "flush_messages": "flushMessages",
        "flush_ms": "flushMs",
        "max_message_bytes": "maxMessageBytes",
        "min_compaction_lag_ms": "minCompactionLagMs",
        "min_insync_replicas": "minInsyncReplicas",
        "preallocate": "preallocate",
        "retention_bytes": "retentionBytes",
        "retention_ms": "retentionMs",
        "segment_bytes": "segmentBytes",
    },
)
class DataYandexMdbKafkaClusterTopicTopicConfig:
    def __init__(
        self,
        *,
        cleanup_policy: typing.Optional[builtins.str] = None,
        compression_type: typing.Optional[builtins.str] = None,
        delete_retention_ms: typing.Optional[builtins.str] = None,
        file_delete_delay_ms: typing.Optional[builtins.str] = None,
        flush_messages: typing.Optional[builtins.str] = None,
        flush_ms: typing.Optional[builtins.str] = None,
        max_message_bytes: typing.Optional[builtins.str] = None,
        min_compaction_lag_ms: typing.Optional[builtins.str] = None,
        min_insync_replicas: typing.Optional[builtins.str] = None,
        preallocate: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        retention_bytes: typing.Optional[builtins.str] = None,
        retention_ms: typing.Optional[builtins.str] = None,
        segment_bytes: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param cleanup_policy: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#cleanup_policy DataYandexMdbKafkaCluster#cleanup_policy}.
        :param compression_type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#compression_type DataYandexMdbKafkaCluster#compression_type}.
        :param delete_retention_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#delete_retention_ms DataYandexMdbKafkaCluster#delete_retention_ms}.
        :param file_delete_delay_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#file_delete_delay_ms DataYandexMdbKafkaCluster#file_delete_delay_ms}.
        :param flush_messages: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#flush_messages DataYandexMdbKafkaCluster#flush_messages}.
        :param flush_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#flush_ms DataYandexMdbKafkaCluster#flush_ms}.
        :param max_message_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#max_message_bytes DataYandexMdbKafkaCluster#max_message_bytes}.
        :param min_compaction_lag_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#min_compaction_lag_ms DataYandexMdbKafkaCluster#min_compaction_lag_ms}.
        :param min_insync_replicas: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#min_insync_replicas DataYandexMdbKafkaCluster#min_insync_replicas}.
        :param preallocate: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#preallocate DataYandexMdbKafkaCluster#preallocate}.
        :param retention_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#retention_bytes DataYandexMdbKafkaCluster#retention_bytes}.
        :param retention_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#retention_ms DataYandexMdbKafkaCluster#retention_ms}.
        :param segment_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#segment_bytes DataYandexMdbKafkaCluster#segment_bytes}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if cleanup_policy is not None:
            self._values["cleanup_policy"] = cleanup_policy
        if compression_type is not None:
            self._values["compression_type"] = compression_type
        if delete_retention_ms is not None:
            self._values["delete_retention_ms"] = delete_retention_ms
        if file_delete_delay_ms is not None:
            self._values["file_delete_delay_ms"] = file_delete_delay_ms
        if flush_messages is not None:
            self._values["flush_messages"] = flush_messages
        if flush_ms is not None:
            self._values["flush_ms"] = flush_ms
        if max_message_bytes is not None:
            self._values["max_message_bytes"] = max_message_bytes
        if min_compaction_lag_ms is not None:
            self._values["min_compaction_lag_ms"] = min_compaction_lag_ms
        if min_insync_replicas is not None:
            self._values["min_insync_replicas"] = min_insync_replicas
        if preallocate is not None:
            self._values["preallocate"] = preallocate
        if retention_bytes is not None:
            self._values["retention_bytes"] = retention_bytes
        if retention_ms is not None:
            self._values["retention_ms"] = retention_ms
        if segment_bytes is not None:
            self._values["segment_bytes"] = segment_bytes

    @builtins.property
    def cleanup_policy(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#cleanup_policy DataYandexMdbKafkaCluster#cleanup_policy}.'''
        result = self._values.get("cleanup_policy")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def compression_type(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#compression_type DataYandexMdbKafkaCluster#compression_type}.'''
        result = self._values.get("compression_type")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete_retention_ms(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#delete_retention_ms DataYandexMdbKafkaCluster#delete_retention_ms}.'''
        result = self._values.get("delete_retention_ms")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def file_delete_delay_ms(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#file_delete_delay_ms DataYandexMdbKafkaCluster#file_delete_delay_ms}.'''
        result = self._values.get("file_delete_delay_ms")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def flush_messages(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#flush_messages DataYandexMdbKafkaCluster#flush_messages}.'''
        result = self._values.get("flush_messages")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def flush_ms(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#flush_ms DataYandexMdbKafkaCluster#flush_ms}.'''
        result = self._values.get("flush_ms")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def max_message_bytes(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#max_message_bytes DataYandexMdbKafkaCluster#max_message_bytes}.'''
        result = self._values.get("max_message_bytes")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def min_compaction_lag_ms(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#min_compaction_lag_ms DataYandexMdbKafkaCluster#min_compaction_lag_ms}.'''
        result = self._values.get("min_compaction_lag_ms")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def min_insync_replicas(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#min_insync_replicas DataYandexMdbKafkaCluster#min_insync_replicas}.'''
        result = self._values.get("min_insync_replicas")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def preallocate(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#preallocate DataYandexMdbKafkaCluster#preallocate}.'''
        result = self._values.get("preallocate")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def retention_bytes(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#retention_bytes DataYandexMdbKafkaCluster#retention_bytes}.'''
        result = self._values.get("retention_bytes")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def retention_ms(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#retention_ms DataYandexMdbKafkaCluster#retention_ms}.'''
        result = self._values.get("retention_ms")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def segment_bytes(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#segment_bytes DataYandexMdbKafkaCluster#segment_bytes}.'''
        result = self._values.get("segment_bytes")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbKafkaClusterTopicTopicConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbKafkaClusterTopicTopicConfigOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaClusterTopicTopicConfigOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCleanupPolicy")
    def reset_cleanup_policy(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCleanupPolicy", []))

    @jsii.member(jsii_name="resetCompressionType")
    def reset_compression_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCompressionType", []))

    @jsii.member(jsii_name="resetDeleteRetentionMs")
    def reset_delete_retention_ms(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDeleteRetentionMs", []))

    @jsii.member(jsii_name="resetFileDeleteDelayMs")
    def reset_file_delete_delay_ms(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFileDeleteDelayMs", []))

    @jsii.member(jsii_name="resetFlushMessages")
    def reset_flush_messages(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFlushMessages", []))

    @jsii.member(jsii_name="resetFlushMs")
    def reset_flush_ms(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFlushMs", []))

    @jsii.member(jsii_name="resetMaxMessageBytes")
    def reset_max_message_bytes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxMessageBytes", []))

    @jsii.member(jsii_name="resetMinCompactionLagMs")
    def reset_min_compaction_lag_ms(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMinCompactionLagMs", []))

    @jsii.member(jsii_name="resetMinInsyncReplicas")
    def reset_min_insync_replicas(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMinInsyncReplicas", []))

    @jsii.member(jsii_name="resetPreallocate")
    def reset_preallocate(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPreallocate", []))

    @jsii.member(jsii_name="resetRetentionBytes")
    def reset_retention_bytes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRetentionBytes", []))

    @jsii.member(jsii_name="resetRetentionMs")
    def reset_retention_ms(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRetentionMs", []))

    @jsii.member(jsii_name="resetSegmentBytes")
    def reset_segment_bytes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSegmentBytes", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cleanupPolicyInput")
    def cleanup_policy_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "cleanupPolicyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="compressionTypeInput")
    def compression_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "compressionTypeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteRetentionMsInput")
    def delete_retention_ms_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteRetentionMsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fileDeleteDelayMsInput")
    def file_delete_delay_ms_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "fileDeleteDelayMsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="flushMessagesInput")
    def flush_messages_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "flushMessagesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="flushMsInput")
    def flush_ms_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "flushMsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxMessageBytesInput")
    def max_message_bytes_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "maxMessageBytesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minCompactionLagMsInput")
    def min_compaction_lag_ms_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "minCompactionLagMsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minInsyncReplicasInput")
    def min_insync_replicas_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "minInsyncReplicasInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="preallocateInput")
    def preallocate_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "preallocateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="retentionBytesInput")
    def retention_bytes_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "retentionBytesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="retentionMsInput")
    def retention_ms_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "retentionMsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="segmentBytesInput")
    def segment_bytes_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "segmentBytesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cleanupPolicy")
    def cleanup_policy(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "cleanupPolicy"))

    @cleanup_policy.setter
    def cleanup_policy(self, value: builtins.str) -> None:
        jsii.set(self, "cleanupPolicy", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="compressionType")
    def compression_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "compressionType"))

    @compression_type.setter
    def compression_type(self, value: builtins.str) -> None:
        jsii.set(self, "compressionType", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteRetentionMs")
    def delete_retention_ms(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "deleteRetentionMs"))

    @delete_retention_ms.setter
    def delete_retention_ms(self, value: builtins.str) -> None:
        jsii.set(self, "deleteRetentionMs", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fileDeleteDelayMs")
    def file_delete_delay_ms(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fileDeleteDelayMs"))

    @file_delete_delay_ms.setter
    def file_delete_delay_ms(self, value: builtins.str) -> None:
        jsii.set(self, "fileDeleteDelayMs", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="flushMessages")
    def flush_messages(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "flushMessages"))

    @flush_messages.setter
    def flush_messages(self, value: builtins.str) -> None:
        jsii.set(self, "flushMessages", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="flushMs")
    def flush_ms(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "flushMs"))

    @flush_ms.setter
    def flush_ms(self, value: builtins.str) -> None:
        jsii.set(self, "flushMs", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxMessageBytes")
    def max_message_bytes(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "maxMessageBytes"))

    @max_message_bytes.setter
    def max_message_bytes(self, value: builtins.str) -> None:
        jsii.set(self, "maxMessageBytes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minCompactionLagMs")
    def min_compaction_lag_ms(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "minCompactionLagMs"))

    @min_compaction_lag_ms.setter
    def min_compaction_lag_ms(self, value: builtins.str) -> None:
        jsii.set(self, "minCompactionLagMs", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minInsyncReplicas")
    def min_insync_replicas(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "minInsyncReplicas"))

    @min_insync_replicas.setter
    def min_insync_replicas(self, value: builtins.str) -> None:
        jsii.set(self, "minInsyncReplicas", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="preallocate")
    def preallocate(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "preallocate"))

    @preallocate.setter
    def preallocate(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "preallocate", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="retentionBytes")
    def retention_bytes(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "retentionBytes"))

    @retention_bytes.setter
    def retention_bytes(self, value: builtins.str) -> None:
        jsii.set(self, "retentionBytes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="retentionMs")
    def retention_ms(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "retentionMs"))

    @retention_ms.setter
    def retention_ms(self, value: builtins.str) -> None:
        jsii.set(self, "retentionMs", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="segmentBytes")
    def segment_bytes(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "segmentBytes"))

    @segment_bytes.setter
    def segment_bytes(self, value: builtins.str) -> None:
        jsii.set(self, "segmentBytes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbKafkaClusterTopicTopicConfig]:
        return typing.cast(typing.Optional[DataYandexMdbKafkaClusterTopicTopicConfig], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbKafkaClusterTopicTopicConfig],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaClusterUser",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "password": "password", "permission": "permission"},
)
class DataYandexMdbKafkaClusterUser:
    def __init__(
        self,
        *,
        name: builtins.str,
        password: builtins.str,
        permission: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["DataYandexMdbKafkaClusterUserPermission"]]] = None,
    ) -> None:
        '''
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#name DataYandexMdbKafkaCluster#name}.
        :param password: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#password DataYandexMdbKafkaCluster#password}.
        :param permission: permission block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#permission DataYandexMdbKafkaCluster#permission}
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "password": password,
        }
        if permission is not None:
            self._values["permission"] = permission

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#name DataYandexMdbKafkaCluster#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def password(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#password DataYandexMdbKafkaCluster#password}.'''
        result = self._values.get("password")
        assert result is not None, "Required property 'password' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def permission(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataYandexMdbKafkaClusterUserPermission"]]]:
        '''permission block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#permission DataYandexMdbKafkaCluster#permission}
        '''
        result = self._values.get("permission")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataYandexMdbKafkaClusterUserPermission"]]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbKafkaClusterUser(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbKafkaClusterUserList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaClusterUserList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "DataYandexMdbKafkaClusterUserOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbKafkaClusterUserOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataYandexMdbKafkaClusterUser]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataYandexMdbKafkaClusterUser]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataYandexMdbKafkaClusterUser]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexMdbKafkaClusterUserOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaClusterUserOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putPermission")
    def put_permission(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["DataYandexMdbKafkaClusterUserPermission"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putPermission", [value]))

    @jsii.member(jsii_name="resetPermission")
    def reset_permission(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPermission", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="permission")
    def permission(self) -> "DataYandexMdbKafkaClusterUserPermissionList":
        return typing.cast("DataYandexMdbKafkaClusterUserPermissionList", jsii.get(self, "permission"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="passwordInput")
    def password_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "passwordInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="permissionInput")
    def permission_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataYandexMdbKafkaClusterUserPermission"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataYandexMdbKafkaClusterUserPermission"]]], jsii.get(self, "permissionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="password")
    def password(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "password"))

    @password.setter
    def password(self, value: builtins.str) -> None:
        jsii.set(self, "password", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, DataYandexMdbKafkaClusterUser]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, DataYandexMdbKafkaClusterUser]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, DataYandexMdbKafkaClusterUser]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaClusterUserPermission",
    jsii_struct_bases=[],
    name_mapping={"role": "role", "topic_name": "topicName"},
)
class DataYandexMdbKafkaClusterUserPermission:
    def __init__(self, *, role: builtins.str, topic_name: builtins.str) -> None:
        '''
        :param role: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#role DataYandexMdbKafkaCluster#role}.
        :param topic_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#topic_name DataYandexMdbKafkaCluster#topic_name}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "role": role,
            "topic_name": topic_name,
        }

    @builtins.property
    def role(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#role DataYandexMdbKafkaCluster#role}.'''
        result = self._values.get("role")
        assert result is not None, "Required property 'role' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def topic_name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_cluster#topic_name DataYandexMdbKafkaCluster#topic_name}.'''
        result = self._values.get("topic_name")
        assert result is not None, "Required property 'topic_name' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbKafkaClusterUserPermission(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbKafkaClusterUserPermissionList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaClusterUserPermissionList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbKafkaClusterUserPermissionOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbKafkaClusterUserPermissionOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataYandexMdbKafkaClusterUserPermission]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataYandexMdbKafkaClusterUserPermission]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataYandexMdbKafkaClusterUserPermission]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexMdbKafkaClusterUserPermissionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaClusterUserPermissionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="roleInput")
    def role_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "roleInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="topicNameInput")
    def topic_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "topicNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="role")
    def role(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "role"))

    @role.setter
    def role(self, value: builtins.str) -> None:
        jsii.set(self, "role", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="topicName")
    def topic_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "topicName"))

    @topic_name.setter
    def topic_name(self, value: builtins.str) -> None:
        jsii.set(self, "topicName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, DataYandexMdbKafkaClusterUserPermission]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, DataYandexMdbKafkaClusterUserPermission]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, DataYandexMdbKafkaClusterUserPermission]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexMdbKafkaConnector(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaConnector",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_connector yandex_mdb_kafka_connector}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        cluster_id: builtins.str,
        name: builtins.str,
        id: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_connector yandex_mdb_kafka_connector} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_connector#cluster_id DataYandexMdbKafkaConnector#cluster_id}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_connector#name DataYandexMdbKafkaConnector#name}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_connector#id DataYandexMdbKafkaConnector#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexMdbKafkaConnectorConfig(
            cluster_id=cluster_id,
            name=name,
            id=id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="connectorConfigMirrormaker")
    def connector_config_mirrormaker(
        self,
    ) -> "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerList":
        return typing.cast("DataYandexMdbKafkaConnectorConnectorConfigMirrormakerList", jsii.get(self, "connectorConfigMirrormaker"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="properties")
    def properties(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "properties"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tasksMax")
    def tasks_max(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "tasksMax"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterIdInput")
    def cluster_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "clusterIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterId")
    def cluster_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "clusterId"))

    @cluster_id.setter
    def cluster_id(self, value: builtins.str) -> None:
        jsii.set(self, "clusterId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaConnectorConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_id": "clusterId",
        "name": "name",
        "id": "id",
    },
)
class DataYandexMdbKafkaConnectorConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_id: builtins.str,
        name: builtins.str,
        id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_connector#cluster_id DataYandexMdbKafkaConnector#cluster_id}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_connector#name DataYandexMdbKafkaConnector#name}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_connector#id DataYandexMdbKafkaConnector#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {
            "cluster_id": cluster_id,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if id is not None:
            self._values["id"] = id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def cluster_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_connector#cluster_id DataYandexMdbKafkaConnector#cluster_id}.'''
        result = self._values.get("cluster_id")
        assert result is not None, "Required property 'cluster_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_connector#name DataYandexMdbKafkaConnector#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_connector#id DataYandexMdbKafkaConnector#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbKafkaConnectorConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaConnectorConnectorConfigMirrormaker",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbKafkaConnectorConnectorConfigMirrormaker:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbKafkaConnectorConnectorConfigMirrormaker(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbKafkaConnectorConnectorConfigMirrormakerList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaConnectorConnectorConfigMirrormakerList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbKafkaConnectorConnectorConfigMirrormakerOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbKafkaConnectorConnectorConfigMirrormakerOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaConnectorConnectorConfigMirrormakerOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replicationFactor")
    def replication_factor(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "replicationFactor"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sourceCluster")
    def source_cluster(
        self,
    ) -> "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterList":
        return typing.cast("DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterList", jsii.get(self, "sourceCluster"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetCluster")
    def target_cluster(
        self,
    ) -> "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterList":
        return typing.cast("DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterList", jsii.get(self, "targetCluster"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="topics")
    def topics(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "topics"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbKafkaConnectorConnectorConfigMirrormaker]:
        return typing.cast(typing.Optional[DataYandexMdbKafkaConnectorConnectorConfigMirrormaker], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbKafkaConnectorConnectorConfigMirrormaker],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceCluster",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceCluster:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceCluster(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalCluster",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalCluster:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalCluster(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalClusterList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalClusterList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalClusterOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalClusterOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalClusterOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalClusterOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bootstrapServers")
    def bootstrap_servers(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "bootstrapServers"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslMechanism")
    def sasl_mechanism(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "saslMechanism"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslPassword")
    def sasl_password(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "saslPassword"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslUsername")
    def sasl_username(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "saslUsername"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityProtocol")
    def security_protocol(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "securityProtocol"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalCluster]:
        return typing.cast(typing.Optional[DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalCluster], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalCluster],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="alias")
    def alias(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "alias"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="externalCluster")
    def external_cluster(
        self,
    ) -> DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalClusterList:
        return typing.cast(DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalClusterList, jsii.get(self, "externalCluster"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="thisCluster")
    def this_cluster(
        self,
    ) -> "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisClusterList":
        return typing.cast("DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisClusterList", jsii.get(self, "thisCluster"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceCluster]:
        return typing.cast(typing.Optional[DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceCluster], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceCluster],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisCluster",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisCluster:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisCluster(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisClusterList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisClusterList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisClusterOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisClusterOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisClusterOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisClusterOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisCluster]:
        return typing.cast(typing.Optional[DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisCluster], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisCluster],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetCluster",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetCluster:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetCluster(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalCluster",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalCluster:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalCluster(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalClusterList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalClusterList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalClusterOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalClusterOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalClusterOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalClusterOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bootstrapServers")
    def bootstrap_servers(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "bootstrapServers"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslMechanism")
    def sasl_mechanism(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "saslMechanism"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslPassword")
    def sasl_password(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "saslPassword"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslUsername")
    def sasl_username(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "saslUsername"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityProtocol")
    def security_protocol(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "securityProtocol"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalCluster]:
        return typing.cast(typing.Optional[DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalCluster], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalCluster],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="alias")
    def alias(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "alias"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="externalCluster")
    def external_cluster(
        self,
    ) -> DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalClusterList:
        return typing.cast(DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalClusterList, jsii.get(self, "externalCluster"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="thisCluster")
    def this_cluster(
        self,
    ) -> "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisClusterList":
        return typing.cast("DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisClusterList", jsii.get(self, "thisCluster"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetCluster]:
        return typing.cast(typing.Optional[DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetCluster], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetCluster],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisCluster",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisCluster:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisCluster(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisClusterList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisClusterList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisClusterOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisClusterOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisClusterOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisClusterOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisCluster]:
        return typing.cast(typing.Optional[DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisCluster], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisCluster],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexMdbKafkaTopic(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaTopic",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_topic yandex_mdb_kafka_topic}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        cluster_id: builtins.str,
        name: builtins.str,
        id: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_topic yandex_mdb_kafka_topic} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_topic#cluster_id DataYandexMdbKafkaTopic#cluster_id}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_topic#name DataYandexMdbKafkaTopic#name}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_topic#id DataYandexMdbKafkaTopic#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexMdbKafkaTopicConfig(
            cluster_id=cluster_id,
            name=name,
            id=id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="partitions")
    def partitions(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "partitions"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replicationFactor")
    def replication_factor(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "replicationFactor"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="topicConfig")
    def topic_config(self) -> "DataYandexMdbKafkaTopicTopicConfigList":
        return typing.cast("DataYandexMdbKafkaTopicTopicConfigList", jsii.get(self, "topicConfig"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterIdInput")
    def cluster_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "clusterIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterId")
    def cluster_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "clusterId"))

    @cluster_id.setter
    def cluster_id(self, value: builtins.str) -> None:
        jsii.set(self, "clusterId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaTopicConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_id": "clusterId",
        "name": "name",
        "id": "id",
    },
)
class DataYandexMdbKafkaTopicConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_id: builtins.str,
        name: builtins.str,
        id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_topic#cluster_id DataYandexMdbKafkaTopic#cluster_id}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_topic#name DataYandexMdbKafkaTopic#name}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_topic#id DataYandexMdbKafkaTopic#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {
            "cluster_id": cluster_id,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if id is not None:
            self._values["id"] = id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def cluster_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_topic#cluster_id DataYandexMdbKafkaTopic#cluster_id}.'''
        result = self._values.get("cluster_id")
        assert result is not None, "Required property 'cluster_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_topic#name DataYandexMdbKafkaTopic#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_kafka_topic#id DataYandexMdbKafkaTopic#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbKafkaTopicConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaTopicTopicConfig",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbKafkaTopicTopicConfig:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbKafkaTopicTopicConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbKafkaTopicTopicConfigList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaTopicTopicConfigList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbKafkaTopicTopicConfigOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbKafkaTopicTopicConfigOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbKafkaTopicTopicConfigOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbKafkaTopicTopicConfigOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cleanupPolicy")
    def cleanup_policy(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "cleanupPolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="compressionType")
    def compression_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "compressionType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteRetentionMs")
    def delete_retention_ms(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "deleteRetentionMs"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fileDeleteDelayMs")
    def file_delete_delay_ms(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fileDeleteDelayMs"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="flushMessages")
    def flush_messages(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "flushMessages"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="flushMs")
    def flush_ms(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "flushMs"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxMessageBytes")
    def max_message_bytes(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "maxMessageBytes"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minCompactionLagMs")
    def min_compaction_lag_ms(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "minCompactionLagMs"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minInsyncReplicas")
    def min_insync_replicas(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "minInsyncReplicas"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="preallocate")
    def preallocate(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "preallocate"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="retentionBytes")
    def retention_bytes(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "retentionBytes"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="retentionMs")
    def retention_ms(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "retentionMs"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="segmentBytes")
    def segment_bytes(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "segmentBytes"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexMdbKafkaTopicTopicConfig]:
        return typing.cast(typing.Optional[DataYandexMdbKafkaTopicTopicConfig], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbKafkaTopicTopicConfig],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexMdbMongodbCluster(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMongodbCluster",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mongodb_cluster yandex_mdb_mongodb_cluster}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        cluster_id: typing.Optional[builtins.str] = None,
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mongodb_cluster yandex_mdb_mongodb_cluster} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mongodb_cluster#cluster_id DataYandexMdbMongodbCluster#cluster_id}.
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mongodb_cluster#deletion_protection DataYandexMdbMongodbCluster#deletion_protection}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mongodb_cluster#folder_id DataYandexMdbMongodbCluster#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mongodb_cluster#id DataYandexMdbMongodbCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mongodb_cluster#name DataYandexMdbMongodbCluster#name}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexMdbMongodbClusterConfig(
            cluster_id=cluster_id,
            deletion_protection=deletion_protection,
            folder_id=folder_id,
            id=id,
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetClusterId")
    def reset_cluster_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetClusterId", []))

    @jsii.member(jsii_name="resetDeletionProtection")
    def reset_deletion_protection(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDeletionProtection", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterConfig")
    def cluster_config(self) -> "DataYandexMdbMongodbClusterClusterConfigList":
        return typing.cast("DataYandexMdbMongodbClusterClusterConfigList", jsii.get(self, "clusterConfig"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="database")
    def database(self) -> "DataYandexMdbMongodbClusterDatabaseList":
        return typing.cast("DataYandexMdbMongodbClusterDatabaseList", jsii.get(self, "database"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="environment")
    def environment(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "environment"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="health")
    def health(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "health"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="host")
    def host(self) -> "DataYandexMdbMongodbClusterHostList":
        return typing.cast("DataYandexMdbMongodbClusterHostList", jsii.get(self, "host"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maintenanceWindow")
    def maintenance_window(self) -> "DataYandexMdbMongodbClusterMaintenanceWindowList":
        return typing.cast("DataYandexMdbMongodbClusterMaintenanceWindowList", jsii.get(self, "maintenanceWindow"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resources")
    def resources(self) -> "DataYandexMdbMongodbClusterResourcesList":
        return typing.cast("DataYandexMdbMongodbClusterResourcesList", jsii.get(self, "resources"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "securityGroupIds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sharded")
    def sharded(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "sharded"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="user")
    def user(self) -> "DataYandexMdbMongodbClusterUserList":
        return typing.cast("DataYandexMdbMongodbClusterUserList", jsii.get(self, "user"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterIdInput")
    def cluster_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "clusterIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtectionInput")
    def deletion_protection_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "deletionProtectionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterId")
    def cluster_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "clusterId"))

    @cluster_id.setter
    def cluster_id(self, value: builtins.str) -> None:
        jsii.set(self, "clusterId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtection")
    def deletion_protection(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "deletionProtection"))

    @deletion_protection.setter
    def deletion_protection(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "deletionProtection", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMongodbClusterClusterConfig",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbMongodbClusterClusterConfig:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbMongodbClusterClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMongodbClusterClusterConfigAccess",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbMongodbClusterClusterConfigAccess:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbMongodbClusterClusterConfigAccess(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbMongodbClusterClusterConfigAccessList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMongodbClusterClusterConfigAccessList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbMongodbClusterClusterConfigAccessOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbMongodbClusterClusterConfigAccessOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbMongodbClusterClusterConfigAccessOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMongodbClusterClusterConfigAccessOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dataLens")
    def data_lens(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "dataLens"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbMongodbClusterClusterConfigAccess]:
        return typing.cast(typing.Optional[DataYandexMdbMongodbClusterClusterConfigAccess], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbMongodbClusterClusterConfigAccess],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMongodbClusterClusterConfigBackupWindowStart",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbMongodbClusterClusterConfigBackupWindowStart:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbMongodbClusterClusterConfigBackupWindowStart(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbMongodbClusterClusterConfigBackupWindowStartList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMongodbClusterClusterConfigBackupWindowStartList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbMongodbClusterClusterConfigBackupWindowStartOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbMongodbClusterClusterConfigBackupWindowStartOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbMongodbClusterClusterConfigBackupWindowStartOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMongodbClusterClusterConfigBackupWindowStartOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hours")
    def hours(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "hours"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minutes")
    def minutes(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minutes"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbMongodbClusterClusterConfigBackupWindowStart]:
        return typing.cast(typing.Optional[DataYandexMdbMongodbClusterClusterConfigBackupWindowStart], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbMongodbClusterClusterConfigBackupWindowStart],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexMdbMongodbClusterClusterConfigList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMongodbClusterClusterConfigList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbMongodbClusterClusterConfigOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbMongodbClusterClusterConfigOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbMongodbClusterClusterConfigOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMongodbClusterClusterConfigOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="access")
    def access(self) -> DataYandexMdbMongodbClusterClusterConfigAccessList:
        return typing.cast(DataYandexMdbMongodbClusterClusterConfigAccessList, jsii.get(self, "access"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backupWindowStart")
    def backup_window_start(
        self,
    ) -> DataYandexMdbMongodbClusterClusterConfigBackupWindowStartList:
        return typing.cast(DataYandexMdbMongodbClusterClusterConfigBackupWindowStartList, jsii.get(self, "backupWindowStart"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="featureCompatibilityVersion")
    def feature_compatibility_version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "featureCompatibilityVersion"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "version"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbMongodbClusterClusterConfig]:
        return typing.cast(typing.Optional[DataYandexMdbMongodbClusterClusterConfig], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbMongodbClusterClusterConfig],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMongodbClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_id": "clusterId",
        "deletion_protection": "deletionProtection",
        "folder_id": "folderId",
        "id": "id",
        "name": "name",
    },
)
class DataYandexMdbMongodbClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_id: typing.Optional[builtins.str] = None,
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mongodb_cluster#cluster_id DataYandexMdbMongodbCluster#cluster_id}.
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mongodb_cluster#deletion_protection DataYandexMdbMongodbCluster#deletion_protection}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mongodb_cluster#folder_id DataYandexMdbMongodbCluster#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mongodb_cluster#id DataYandexMdbMongodbCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mongodb_cluster#name DataYandexMdbMongodbCluster#name}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if cluster_id is not None:
            self._values["cluster_id"] = cluster_id
        if deletion_protection is not None:
            self._values["deletion_protection"] = deletion_protection
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def cluster_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mongodb_cluster#cluster_id DataYandexMdbMongodbCluster#cluster_id}.'''
        result = self._values.get("cluster_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def deletion_protection(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mongodb_cluster#deletion_protection DataYandexMdbMongodbCluster#deletion_protection}.'''
        result = self._values.get("deletion_protection")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mongodb_cluster#folder_id DataYandexMdbMongodbCluster#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mongodb_cluster#id DataYandexMdbMongodbCluster#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mongodb_cluster#name DataYandexMdbMongodbCluster#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbMongodbClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMongodbClusterDatabase",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbMongodbClusterDatabase:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbMongodbClusterDatabase(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbMongodbClusterDatabaseList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMongodbClusterDatabaseList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbMongodbClusterDatabaseOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbMongodbClusterDatabaseOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbMongodbClusterDatabaseOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMongodbClusterDatabaseOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexMdbMongodbClusterDatabase]:
        return typing.cast(typing.Optional[DataYandexMdbMongodbClusterDatabase], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbMongodbClusterDatabase],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMongodbClusterHost",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbMongodbClusterHost:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbMongodbClusterHost(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbMongodbClusterHostList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMongodbClusterHostList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbMongodbClusterHostOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbMongodbClusterHostOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbMongodbClusterHostOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMongodbClusterHostOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIp")
    def assign_public_ip(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "assignPublicIp"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="health")
    def health(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "health"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="role")
    def role(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "role"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="shardName")
    def shard_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "shardName"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneId")
    def zone_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zoneId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexMdbMongodbClusterHost]:
        return typing.cast(typing.Optional[DataYandexMdbMongodbClusterHost], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbMongodbClusterHost],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMongodbClusterMaintenanceWindow",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbMongodbClusterMaintenanceWindow:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbMongodbClusterMaintenanceWindow(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbMongodbClusterMaintenanceWindowList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMongodbClusterMaintenanceWindowList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbMongodbClusterMaintenanceWindowOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbMongodbClusterMaintenanceWindowOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbMongodbClusterMaintenanceWindowOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMongodbClusterMaintenanceWindowOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="day")
    def day(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "day"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hour")
    def hour(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "hour"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbMongodbClusterMaintenanceWindow]:
        return typing.cast(typing.Optional[DataYandexMdbMongodbClusterMaintenanceWindow], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbMongodbClusterMaintenanceWindow],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMongodbClusterResources",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbMongodbClusterResources:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbMongodbClusterResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbMongodbClusterResourcesList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMongodbClusterResourcesList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbMongodbClusterResourcesOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbMongodbClusterResourcesOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbMongodbClusterResourcesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMongodbClusterResourcesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSize")
    def disk_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "diskSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeId")
    def disk_type_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskTypeId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetId")
    def resource_preset_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourcePresetId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexMdbMongodbClusterResources]:
        return typing.cast(typing.Optional[DataYandexMdbMongodbClusterResources], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbMongodbClusterResources],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMongodbClusterUser",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbMongodbClusterUser:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbMongodbClusterUser(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbMongodbClusterUserList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMongodbClusterUserList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbMongodbClusterUserOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbMongodbClusterUserOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbMongodbClusterUserOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMongodbClusterUserOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="permission")
    def permission(self) -> "DataYandexMdbMongodbClusterUserPermissionList":
        return typing.cast("DataYandexMdbMongodbClusterUserPermissionList", jsii.get(self, "permission"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexMdbMongodbClusterUser]:
        return typing.cast(typing.Optional[DataYandexMdbMongodbClusterUser], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbMongodbClusterUser],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMongodbClusterUserPermission",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbMongodbClusterUserPermission:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbMongodbClusterUserPermission(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbMongodbClusterUserPermissionList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMongodbClusterUserPermissionList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbMongodbClusterUserPermissionOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbMongodbClusterUserPermissionOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbMongodbClusterUserPermissionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMongodbClusterUserPermissionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databaseName")
    def database_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "databaseName"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="roles")
    def roles(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "roles"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbMongodbClusterUserPermission]:
        return typing.cast(typing.Optional[DataYandexMdbMongodbClusterUserPermission], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbMongodbClusterUserPermission],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexMdbMysqlCluster(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMysqlCluster",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mysql_cluster yandex_mdb_mysql_cluster}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        access: typing.Optional["DataYandexMdbMysqlClusterAccess"] = None,
        cluster_id: typing.Optional[builtins.str] = None,
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        mysql_config: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mysql_cluster yandex_mdb_mysql_cluster} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param access: access block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mysql_cluster#access DataYandexMdbMysqlCluster#access}
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mysql_cluster#cluster_id DataYandexMdbMysqlCluster#cluster_id}.
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mysql_cluster#deletion_protection DataYandexMdbMysqlCluster#deletion_protection}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mysql_cluster#description DataYandexMdbMysqlCluster#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mysql_cluster#folder_id DataYandexMdbMysqlCluster#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mysql_cluster#id DataYandexMdbMysqlCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mysql_cluster#labels DataYandexMdbMysqlCluster#labels}.
        :param mysql_config: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mysql_cluster#mysql_config DataYandexMdbMysqlCluster#mysql_config}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mysql_cluster#name DataYandexMdbMysqlCluster#name}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexMdbMysqlClusterConfig(
            access=access,
            cluster_id=cluster_id,
            deletion_protection=deletion_protection,
            description=description,
            folder_id=folder_id,
            id=id,
            labels=labels,
            mysql_config=mysql_config,
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putAccess")
    def put_access(self) -> None:
        value = DataYandexMdbMysqlClusterAccess()

        return typing.cast(None, jsii.invoke(self, "putAccess", [value]))

    @jsii.member(jsii_name="resetAccess")
    def reset_access(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAccess", []))

    @jsii.member(jsii_name="resetClusterId")
    def reset_cluster_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetClusterId", []))

    @jsii.member(jsii_name="resetDeletionProtection")
    def reset_deletion_protection(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDeletionProtection", []))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetMysqlConfig")
    def reset_mysql_config(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMysqlConfig", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="access")
    def access(self) -> "DataYandexMdbMysqlClusterAccessOutputReference":
        return typing.cast("DataYandexMdbMysqlClusterAccessOutputReference", jsii.get(self, "access"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backupWindowStart")
    def backup_window_start(self) -> "DataYandexMdbMysqlClusterBackupWindowStartList":
        return typing.cast("DataYandexMdbMysqlClusterBackupWindowStartList", jsii.get(self, "backupWindowStart"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="database")
    def database(self) -> "DataYandexMdbMysqlClusterDatabaseList":
        return typing.cast("DataYandexMdbMysqlClusterDatabaseList", jsii.get(self, "database"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="environment")
    def environment(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "environment"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="health")
    def health(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "health"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="host")
    def host(self) -> "DataYandexMdbMysqlClusterHostList":
        return typing.cast("DataYandexMdbMysqlClusterHostList", jsii.get(self, "host"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maintenanceWindow")
    def maintenance_window(self) -> "DataYandexMdbMysqlClusterMaintenanceWindowList":
        return typing.cast("DataYandexMdbMysqlClusterMaintenanceWindowList", jsii.get(self, "maintenanceWindow"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resources")
    def resources(self) -> "DataYandexMdbMysqlClusterResourcesList":
        return typing.cast("DataYandexMdbMysqlClusterResourcesList", jsii.get(self, "resources"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "securityGroupIds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="user")
    def user(self) -> "DataYandexMdbMysqlClusterUserList":
        return typing.cast("DataYandexMdbMysqlClusterUserList", jsii.get(self, "user"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "version"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="accessInput")
    def access_input(self) -> typing.Optional["DataYandexMdbMysqlClusterAccess"]:
        return typing.cast(typing.Optional["DataYandexMdbMysqlClusterAccess"], jsii.get(self, "accessInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterIdInput")
    def cluster_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "clusterIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtectionInput")
    def deletion_protection_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "deletionProtectionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mysqlConfigInput")
    def mysql_config_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "mysqlConfigInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterId")
    def cluster_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "clusterId"))

    @cluster_id.setter
    def cluster_id(self, value: builtins.str) -> None:
        jsii.set(self, "clusterId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtection")
    def deletion_protection(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "deletionProtection"))

    @deletion_protection.setter
    def deletion_protection(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "deletionProtection", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mysqlConfig")
    def mysql_config(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "mysqlConfig"))

    @mysql_config.setter
    def mysql_config(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "mysqlConfig", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMysqlClusterAccess",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbMysqlClusterAccess:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbMysqlClusterAccess(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbMysqlClusterAccessOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMysqlClusterAccessOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dataLens")
    def data_lens(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "dataLens"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="webSql")
    def web_sql(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "webSql"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexMdbMysqlClusterAccess]:
        return typing.cast(typing.Optional[DataYandexMdbMysqlClusterAccess], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbMysqlClusterAccess],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMysqlClusterBackupWindowStart",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbMysqlClusterBackupWindowStart:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbMysqlClusterBackupWindowStart(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbMysqlClusterBackupWindowStartList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMysqlClusterBackupWindowStartList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbMysqlClusterBackupWindowStartOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbMysqlClusterBackupWindowStartOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbMysqlClusterBackupWindowStartOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMysqlClusterBackupWindowStartOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hours")
    def hours(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "hours"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minutes")
    def minutes(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minutes"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbMysqlClusterBackupWindowStart]:
        return typing.cast(typing.Optional[DataYandexMdbMysqlClusterBackupWindowStart], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbMysqlClusterBackupWindowStart],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMysqlClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "access": "access",
        "cluster_id": "clusterId",
        "deletion_protection": "deletionProtection",
        "description": "description",
        "folder_id": "folderId",
        "id": "id",
        "labels": "labels",
        "mysql_config": "mysqlConfig",
        "name": "name",
    },
)
class DataYandexMdbMysqlClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        access: typing.Optional[DataYandexMdbMysqlClusterAccess] = None,
        cluster_id: typing.Optional[builtins.str] = None,
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        mysql_config: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param access: access block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mysql_cluster#access DataYandexMdbMysqlCluster#access}
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mysql_cluster#cluster_id DataYandexMdbMysqlCluster#cluster_id}.
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mysql_cluster#deletion_protection DataYandexMdbMysqlCluster#deletion_protection}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mysql_cluster#description DataYandexMdbMysqlCluster#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mysql_cluster#folder_id DataYandexMdbMysqlCluster#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mysql_cluster#id DataYandexMdbMysqlCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mysql_cluster#labels DataYandexMdbMysqlCluster#labels}.
        :param mysql_config: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mysql_cluster#mysql_config DataYandexMdbMysqlCluster#mysql_config}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mysql_cluster#name DataYandexMdbMysqlCluster#name}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(access, dict):
            access = DataYandexMdbMysqlClusterAccess(**access)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if access is not None:
            self._values["access"] = access
        if cluster_id is not None:
            self._values["cluster_id"] = cluster_id
        if deletion_protection is not None:
            self._values["deletion_protection"] = deletion_protection
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if mysql_config is not None:
            self._values["mysql_config"] = mysql_config
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def access(self) -> typing.Optional[DataYandexMdbMysqlClusterAccess]:
        '''access block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mysql_cluster#access DataYandexMdbMysqlCluster#access}
        '''
        result = self._values.get("access")
        return typing.cast(typing.Optional[DataYandexMdbMysqlClusterAccess], result)

    @builtins.property
    def cluster_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mysql_cluster#cluster_id DataYandexMdbMysqlCluster#cluster_id}.'''
        result = self._values.get("cluster_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def deletion_protection(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mysql_cluster#deletion_protection DataYandexMdbMysqlCluster#deletion_protection}.'''
        result = self._values.get("deletion_protection")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mysql_cluster#description DataYandexMdbMysqlCluster#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mysql_cluster#folder_id DataYandexMdbMysqlCluster#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mysql_cluster#id DataYandexMdbMysqlCluster#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mysql_cluster#labels DataYandexMdbMysqlCluster#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def mysql_config(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mysql_cluster#mysql_config DataYandexMdbMysqlCluster#mysql_config}.'''
        result = self._values.get("mysql_config")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_mysql_cluster#name DataYandexMdbMysqlCluster#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbMysqlClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMysqlClusterDatabase",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbMysqlClusterDatabase:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbMysqlClusterDatabase(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbMysqlClusterDatabaseList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMysqlClusterDatabaseList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbMysqlClusterDatabaseOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbMysqlClusterDatabaseOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbMysqlClusterDatabaseOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMysqlClusterDatabaseOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexMdbMysqlClusterDatabase]:
        return typing.cast(typing.Optional[DataYandexMdbMysqlClusterDatabase], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbMysqlClusterDatabase],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMysqlClusterHost",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbMysqlClusterHost:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbMysqlClusterHost(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbMysqlClusterHostList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMysqlClusterHostList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "DataYandexMdbMysqlClusterHostOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbMysqlClusterHostOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbMysqlClusterHostOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMysqlClusterHostOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIp")
    def assign_public_ip(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "assignPublicIp"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backupPriority")
    def backup_priority(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "backupPriority"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fqdn"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="priority")
    def priority(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "priority"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replicationSource")
    def replication_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "replicationSource"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zone")
    def zone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zone"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexMdbMysqlClusterHost]:
        return typing.cast(typing.Optional[DataYandexMdbMysqlClusterHost], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbMysqlClusterHost],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMysqlClusterMaintenanceWindow",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbMysqlClusterMaintenanceWindow:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbMysqlClusterMaintenanceWindow(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbMysqlClusterMaintenanceWindowList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMysqlClusterMaintenanceWindowList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbMysqlClusterMaintenanceWindowOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbMysqlClusterMaintenanceWindowOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbMysqlClusterMaintenanceWindowOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMysqlClusterMaintenanceWindowOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="day")
    def day(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "day"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hour")
    def hour(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "hour"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbMysqlClusterMaintenanceWindow]:
        return typing.cast(typing.Optional[DataYandexMdbMysqlClusterMaintenanceWindow], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbMysqlClusterMaintenanceWindow],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMysqlClusterResources",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbMysqlClusterResources:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbMysqlClusterResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbMysqlClusterResourcesList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMysqlClusterResourcesList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbMysqlClusterResourcesOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbMysqlClusterResourcesOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbMysqlClusterResourcesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMysqlClusterResourcesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSize")
    def disk_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "diskSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeId")
    def disk_type_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskTypeId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetId")
    def resource_preset_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourcePresetId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexMdbMysqlClusterResources]:
        return typing.cast(typing.Optional[DataYandexMdbMysqlClusterResources], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbMysqlClusterResources],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMysqlClusterUser",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbMysqlClusterUser:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbMysqlClusterUser(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMysqlClusterUserConnectionLimits",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbMysqlClusterUserConnectionLimits:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbMysqlClusterUserConnectionLimits(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbMysqlClusterUserConnectionLimitsList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMysqlClusterUserConnectionLimitsList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbMysqlClusterUserConnectionLimitsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbMysqlClusterUserConnectionLimitsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbMysqlClusterUserConnectionLimitsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMysqlClusterUserConnectionLimitsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxConnectionsPerHour")
    def max_connections_per_hour(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxConnectionsPerHour"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxQuestionsPerHour")
    def max_questions_per_hour(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxQuestionsPerHour"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxUpdatesPerHour")
    def max_updates_per_hour(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxUpdatesPerHour"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxUserConnections")
    def max_user_connections(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxUserConnections"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbMysqlClusterUserConnectionLimits]:
        return typing.cast(typing.Optional[DataYandexMdbMysqlClusterUserConnectionLimits], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbMysqlClusterUserConnectionLimits],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexMdbMysqlClusterUserList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMysqlClusterUserList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "DataYandexMdbMysqlClusterUserOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbMysqlClusterUserOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbMysqlClusterUserOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMysqlClusterUserOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="authenticationPlugin")
    def authentication_plugin(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "authenticationPlugin"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="connectionLimits")
    def connection_limits(self) -> DataYandexMdbMysqlClusterUserConnectionLimitsList:
        return typing.cast(DataYandexMdbMysqlClusterUserConnectionLimitsList, jsii.get(self, "connectionLimits"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="globalPermissions")
    def global_permissions(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "globalPermissions"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="password")
    def password(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "password"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="permission")
    def permission(self) -> "DataYandexMdbMysqlClusterUserPermissionList":
        return typing.cast("DataYandexMdbMysqlClusterUserPermissionList", jsii.get(self, "permission"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexMdbMysqlClusterUser]:
        return typing.cast(typing.Optional[DataYandexMdbMysqlClusterUser], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbMysqlClusterUser],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMysqlClusterUserPermission",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbMysqlClusterUserPermission:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbMysqlClusterUserPermission(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbMysqlClusterUserPermissionList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMysqlClusterUserPermissionList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbMysqlClusterUserPermissionOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbMysqlClusterUserPermissionOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbMysqlClusterUserPermissionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbMysqlClusterUserPermissionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databaseName")
    def database_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "databaseName"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="roles")
    def roles(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "roles"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbMysqlClusterUserPermission]:
        return typing.cast(typing.Optional[DataYandexMdbMysqlClusterUserPermission], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbMysqlClusterUserPermission],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexMdbPostgresqlCluster(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlCluster",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/mdb_postgresql_cluster yandex_mdb_postgresql_cluster}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        cluster_id: typing.Optional[builtins.str] = None,
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/mdb_postgresql_cluster yandex_mdb_postgresql_cluster} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_postgresql_cluster#cluster_id DataYandexMdbPostgresqlCluster#cluster_id}.
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_postgresql_cluster#deletion_protection DataYandexMdbPostgresqlCluster#deletion_protection}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_postgresql_cluster#description DataYandexMdbPostgresqlCluster#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_postgresql_cluster#folder_id DataYandexMdbPostgresqlCluster#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_postgresql_cluster#id DataYandexMdbPostgresqlCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_postgresql_cluster#name DataYandexMdbPostgresqlCluster#name}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexMdbPostgresqlClusterConfig(
            cluster_id=cluster_id,
            deletion_protection=deletion_protection,
            description=description,
            folder_id=folder_id,
            id=id,
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetClusterId")
    def reset_cluster_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetClusterId", []))

    @jsii.member(jsii_name="resetDeletionProtection")
    def reset_deletion_protection(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDeletionProtection", []))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="config")
    def config(self) -> "DataYandexMdbPostgresqlClusterConfigAList":
        return typing.cast("DataYandexMdbPostgresqlClusterConfigAList", jsii.get(self, "config"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="database")
    def database(self) -> "DataYandexMdbPostgresqlClusterDatabaseList":
        return typing.cast("DataYandexMdbPostgresqlClusterDatabaseList", jsii.get(self, "database"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="environment")
    def environment(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "environment"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="health")
    def health(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "health"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="host")
    def host(self) -> "DataYandexMdbPostgresqlClusterHostList":
        return typing.cast("DataYandexMdbPostgresqlClusterHostList", jsii.get(self, "host"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maintenanceWindow")
    def maintenance_window(
        self,
    ) -> "DataYandexMdbPostgresqlClusterMaintenanceWindowList":
        return typing.cast("DataYandexMdbPostgresqlClusterMaintenanceWindowList", jsii.get(self, "maintenanceWindow"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "securityGroupIds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="user")
    def user(self) -> "DataYandexMdbPostgresqlClusterUserList":
        return typing.cast("DataYandexMdbPostgresqlClusterUserList", jsii.get(self, "user"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterIdInput")
    def cluster_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "clusterIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtectionInput")
    def deletion_protection_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "deletionProtectionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterId")
    def cluster_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "clusterId"))

    @cluster_id.setter
    def cluster_id(self, value: builtins.str) -> None:
        jsii.set(self, "clusterId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtection")
    def deletion_protection(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "deletionProtection"))

    @deletion_protection.setter
    def deletion_protection(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "deletionProtection", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_id": "clusterId",
        "deletion_protection": "deletionProtection",
        "description": "description",
        "folder_id": "folderId",
        "id": "id",
        "name": "name",
    },
)
class DataYandexMdbPostgresqlClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_id: typing.Optional[builtins.str] = None,
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_postgresql_cluster#cluster_id DataYandexMdbPostgresqlCluster#cluster_id}.
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_postgresql_cluster#deletion_protection DataYandexMdbPostgresqlCluster#deletion_protection}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_postgresql_cluster#description DataYandexMdbPostgresqlCluster#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_postgresql_cluster#folder_id DataYandexMdbPostgresqlCluster#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_postgresql_cluster#id DataYandexMdbPostgresqlCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_postgresql_cluster#name DataYandexMdbPostgresqlCluster#name}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if cluster_id is not None:
            self._values["cluster_id"] = cluster_id
        if deletion_protection is not None:
            self._values["deletion_protection"] = deletion_protection
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def cluster_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_postgresql_cluster#cluster_id DataYandexMdbPostgresqlCluster#cluster_id}.'''
        result = self._values.get("cluster_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def deletion_protection(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_postgresql_cluster#deletion_protection DataYandexMdbPostgresqlCluster#deletion_protection}.'''
        result = self._values.get("deletion_protection")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_postgresql_cluster#description DataYandexMdbPostgresqlCluster#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_postgresql_cluster#folder_id DataYandexMdbPostgresqlCluster#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_postgresql_cluster#id DataYandexMdbPostgresqlCluster#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_postgresql_cluster#name DataYandexMdbPostgresqlCluster#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbPostgresqlClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterConfigA",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbPostgresqlClusterConfigA:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbPostgresqlClusterConfigA(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbPostgresqlClusterConfigAList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterConfigAList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbPostgresqlClusterConfigAOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbPostgresqlClusterConfigAOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbPostgresqlClusterConfigAOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterConfigAOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="access")
    def access(self) -> "DataYandexMdbPostgresqlClusterConfigAccessList":
        return typing.cast("DataYandexMdbPostgresqlClusterConfigAccessList", jsii.get(self, "access"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autofailover")
    def autofailover(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "autofailover"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backupRetainPeriodDays")
    def backup_retain_period_days(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "backupRetainPeriodDays"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backupWindowStart")
    def backup_window_start(
        self,
    ) -> "DataYandexMdbPostgresqlClusterConfigBackupWindowStartList":
        return typing.cast("DataYandexMdbPostgresqlClusterConfigBackupWindowStartList", jsii.get(self, "backupWindowStart"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="performanceDiagnostics")
    def performance_diagnostics(
        self,
    ) -> "DataYandexMdbPostgresqlClusterConfigPerformanceDiagnosticsList":
        return typing.cast("DataYandexMdbPostgresqlClusterConfigPerformanceDiagnosticsList", jsii.get(self, "performanceDiagnostics"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="poolerConfig")
    def pooler_config(self) -> "DataYandexMdbPostgresqlClusterConfigPoolerConfigList":
        return typing.cast("DataYandexMdbPostgresqlClusterConfigPoolerConfigList", jsii.get(self, "poolerConfig"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="postgresqlConfig")
    def postgresql_config(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "postgresqlConfig"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resources")
    def resources(self) -> "DataYandexMdbPostgresqlClusterConfigResourcesList":
        return typing.cast("DataYandexMdbPostgresqlClusterConfigResourcesList", jsii.get(self, "resources"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "version"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexMdbPostgresqlClusterConfigA]:
        return typing.cast(typing.Optional[DataYandexMdbPostgresqlClusterConfigA], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbPostgresqlClusterConfigA],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterConfigAccess",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbPostgresqlClusterConfigAccess:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbPostgresqlClusterConfigAccess(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbPostgresqlClusterConfigAccessList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterConfigAccessList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbPostgresqlClusterConfigAccessOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbPostgresqlClusterConfigAccessOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbPostgresqlClusterConfigAccessOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterConfigAccessOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dataLens")
    def data_lens(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "dataLens"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serverless")
    def serverless(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "serverless"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="webSql")
    def web_sql(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "webSql"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbPostgresqlClusterConfigAccess]:
        return typing.cast(typing.Optional[DataYandexMdbPostgresqlClusterConfigAccess], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbPostgresqlClusterConfigAccess],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterConfigBackupWindowStart",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbPostgresqlClusterConfigBackupWindowStart:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbPostgresqlClusterConfigBackupWindowStart(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbPostgresqlClusterConfigBackupWindowStartList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterConfigBackupWindowStartList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbPostgresqlClusterConfigBackupWindowStartOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbPostgresqlClusterConfigBackupWindowStartOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbPostgresqlClusterConfigBackupWindowStartOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterConfigBackupWindowStartOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hours")
    def hours(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "hours"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minutes")
    def minutes(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minutes"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbPostgresqlClusterConfigBackupWindowStart]:
        return typing.cast(typing.Optional[DataYandexMdbPostgresqlClusterConfigBackupWindowStart], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbPostgresqlClusterConfigBackupWindowStart],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterConfigPerformanceDiagnostics",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbPostgresqlClusterConfigPerformanceDiagnostics:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbPostgresqlClusterConfigPerformanceDiagnostics(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbPostgresqlClusterConfigPerformanceDiagnosticsList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterConfigPerformanceDiagnosticsList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbPostgresqlClusterConfigPerformanceDiagnosticsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbPostgresqlClusterConfigPerformanceDiagnosticsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbPostgresqlClusterConfigPerformanceDiagnosticsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterConfigPerformanceDiagnosticsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "enabled"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sessionsSamplingInterval")
    def sessions_sampling_interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "sessionsSamplingInterval"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="statementsSamplingInterval")
    def statements_sampling_interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "statementsSamplingInterval"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbPostgresqlClusterConfigPerformanceDiagnostics]:
        return typing.cast(typing.Optional[DataYandexMdbPostgresqlClusterConfigPerformanceDiagnostics], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbPostgresqlClusterConfigPerformanceDiagnostics],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterConfigPoolerConfig",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbPostgresqlClusterConfigPoolerConfig:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbPostgresqlClusterConfigPoolerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbPostgresqlClusterConfigPoolerConfigList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterConfigPoolerConfigList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbPostgresqlClusterConfigPoolerConfigOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbPostgresqlClusterConfigPoolerConfigOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbPostgresqlClusterConfigPoolerConfigOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterConfigPoolerConfigOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="poolDiscard")
    def pool_discard(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "poolDiscard"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="poolingMode")
    def pooling_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "poolingMode"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbPostgresqlClusterConfigPoolerConfig]:
        return typing.cast(typing.Optional[DataYandexMdbPostgresqlClusterConfigPoolerConfig], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbPostgresqlClusterConfigPoolerConfig],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterConfigResources",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbPostgresqlClusterConfigResources:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbPostgresqlClusterConfigResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbPostgresqlClusterConfigResourcesList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterConfigResourcesList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbPostgresqlClusterConfigResourcesOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbPostgresqlClusterConfigResourcesOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbPostgresqlClusterConfigResourcesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterConfigResourcesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSize")
    def disk_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "diskSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeId")
    def disk_type_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskTypeId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetId")
    def resource_preset_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourcePresetId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbPostgresqlClusterConfigResources]:
        return typing.cast(typing.Optional[DataYandexMdbPostgresqlClusterConfigResources], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbPostgresqlClusterConfigResources],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterDatabase",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbPostgresqlClusterDatabase:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbPostgresqlClusterDatabase(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterDatabaseExtension",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbPostgresqlClusterDatabaseExtension:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbPostgresqlClusterDatabaseExtension(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbPostgresqlClusterDatabaseExtensionList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterDatabaseExtensionList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbPostgresqlClusterDatabaseExtensionOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbPostgresqlClusterDatabaseExtensionOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbPostgresqlClusterDatabaseExtensionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterDatabaseExtensionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "version"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbPostgresqlClusterDatabaseExtension]:
        return typing.cast(typing.Optional[DataYandexMdbPostgresqlClusterDatabaseExtension], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbPostgresqlClusterDatabaseExtension],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexMdbPostgresqlClusterDatabaseList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterDatabaseList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbPostgresqlClusterDatabaseOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbPostgresqlClusterDatabaseOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbPostgresqlClusterDatabaseOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterDatabaseOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="extension")
    def extension(self) -> DataYandexMdbPostgresqlClusterDatabaseExtensionList:
        return typing.cast(DataYandexMdbPostgresqlClusterDatabaseExtensionList, jsii.get(self, "extension"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="lcCollate")
    def lc_collate(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "lcCollate"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="lcType")
    def lc_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "lcType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="owner")
    def owner(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "owner"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexMdbPostgresqlClusterDatabase]:
        return typing.cast(typing.Optional[DataYandexMdbPostgresqlClusterDatabase], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbPostgresqlClusterDatabase],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterHost",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbPostgresqlClusterHost:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbPostgresqlClusterHost(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbPostgresqlClusterHostList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterHostList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbPostgresqlClusterHostOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbPostgresqlClusterHostOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbPostgresqlClusterHostOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterHostOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIp")
    def assign_public_ip(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "assignPublicIp"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fqdn"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="priority")
    def priority(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "priority"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replicationSource")
    def replication_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "replicationSource"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="role")
    def role(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "role"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zone")
    def zone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zone"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexMdbPostgresqlClusterHost]:
        return typing.cast(typing.Optional[DataYandexMdbPostgresqlClusterHost], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbPostgresqlClusterHost],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterMaintenanceWindow",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbPostgresqlClusterMaintenanceWindow:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbPostgresqlClusterMaintenanceWindow(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbPostgresqlClusterMaintenanceWindowList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterMaintenanceWindowList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbPostgresqlClusterMaintenanceWindowOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbPostgresqlClusterMaintenanceWindowOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbPostgresqlClusterMaintenanceWindowOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterMaintenanceWindowOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="day")
    def day(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "day"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hour")
    def hour(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "hour"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbPostgresqlClusterMaintenanceWindow]:
        return typing.cast(typing.Optional[DataYandexMdbPostgresqlClusterMaintenanceWindow], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbPostgresqlClusterMaintenanceWindow],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterUser",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbPostgresqlClusterUser:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbPostgresqlClusterUser(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbPostgresqlClusterUserList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterUserList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbPostgresqlClusterUserOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbPostgresqlClusterUserOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbPostgresqlClusterUserOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterUserOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="connLimit")
    def conn_limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "connLimit"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="grants")
    def grants(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "grants"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="login")
    def login(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "login"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="password")
    def password(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "password"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="permission")
    def permission(self) -> "DataYandexMdbPostgresqlClusterUserPermissionList":
        return typing.cast("DataYandexMdbPostgresqlClusterUserPermissionList", jsii.get(self, "permission"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="settings")
    def settings(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "settings"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexMdbPostgresqlClusterUser]:
        return typing.cast(typing.Optional[DataYandexMdbPostgresqlClusterUser], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbPostgresqlClusterUser],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterUserPermission",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbPostgresqlClusterUserPermission:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbPostgresqlClusterUserPermission(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbPostgresqlClusterUserPermissionList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterUserPermissionList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbPostgresqlClusterUserPermissionOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbPostgresqlClusterUserPermissionOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbPostgresqlClusterUserPermissionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbPostgresqlClusterUserPermissionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databaseName")
    def database_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "databaseName"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbPostgresqlClusterUserPermission]:
        return typing.cast(typing.Optional[DataYandexMdbPostgresqlClusterUserPermission], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbPostgresqlClusterUserPermission],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexMdbRedisCluster(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbRedisCluster",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/mdb_redis_cluster yandex_mdb_redis_cluster}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        cluster_id: typing.Optional[builtins.str] = None,
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/mdb_redis_cluster yandex_mdb_redis_cluster} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_redis_cluster#cluster_id DataYandexMdbRedisCluster#cluster_id}.
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_redis_cluster#deletion_protection DataYandexMdbRedisCluster#deletion_protection}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_redis_cluster#folder_id DataYandexMdbRedisCluster#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_redis_cluster#id DataYandexMdbRedisCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_redis_cluster#name DataYandexMdbRedisCluster#name}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexMdbRedisClusterConfig(
            cluster_id=cluster_id,
            deletion_protection=deletion_protection,
            folder_id=folder_id,
            id=id,
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetClusterId")
    def reset_cluster_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetClusterId", []))

    @jsii.member(jsii_name="resetDeletionProtection")
    def reset_deletion_protection(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDeletionProtection", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="config")
    def config(self) -> "DataYandexMdbRedisClusterConfigAList":
        return typing.cast("DataYandexMdbRedisClusterConfigAList", jsii.get(self, "config"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="environment")
    def environment(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "environment"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="health")
    def health(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "health"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="host")
    def host(self) -> "DataYandexMdbRedisClusterHostList":
        return typing.cast("DataYandexMdbRedisClusterHostList", jsii.get(self, "host"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maintenanceWindow")
    def maintenance_window(self) -> "DataYandexMdbRedisClusterMaintenanceWindowList":
        return typing.cast("DataYandexMdbRedisClusterMaintenanceWindowList", jsii.get(self, "maintenanceWindow"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="persistenceMode")
    def persistence_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "persistenceMode"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resources")
    def resources(self) -> "DataYandexMdbRedisClusterResourcesList":
        return typing.cast("DataYandexMdbRedisClusterResourcesList", jsii.get(self, "resources"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "securityGroupIds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sharded")
    def sharded(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "sharded"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tlsEnabled")
    def tls_enabled(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "tlsEnabled"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterIdInput")
    def cluster_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "clusterIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtectionInput")
    def deletion_protection_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "deletionProtectionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterId")
    def cluster_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "clusterId"))

    @cluster_id.setter
    def cluster_id(self, value: builtins.str) -> None:
        jsii.set(self, "clusterId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtection")
    def deletion_protection(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "deletionProtection"))

    @deletion_protection.setter
    def deletion_protection(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "deletionProtection", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbRedisClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_id": "clusterId",
        "deletion_protection": "deletionProtection",
        "folder_id": "folderId",
        "id": "id",
        "name": "name",
    },
)
class DataYandexMdbRedisClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_id: typing.Optional[builtins.str] = None,
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_redis_cluster#cluster_id DataYandexMdbRedisCluster#cluster_id}.
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_redis_cluster#deletion_protection DataYandexMdbRedisCluster#deletion_protection}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_redis_cluster#folder_id DataYandexMdbRedisCluster#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_redis_cluster#id DataYandexMdbRedisCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_redis_cluster#name DataYandexMdbRedisCluster#name}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if cluster_id is not None:
            self._values["cluster_id"] = cluster_id
        if deletion_protection is not None:
            self._values["deletion_protection"] = deletion_protection
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def cluster_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_redis_cluster#cluster_id DataYandexMdbRedisCluster#cluster_id}.'''
        result = self._values.get("cluster_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def deletion_protection(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_redis_cluster#deletion_protection DataYandexMdbRedisCluster#deletion_protection}.'''
        result = self._values.get("deletion_protection")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_redis_cluster#folder_id DataYandexMdbRedisCluster#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_redis_cluster#id DataYandexMdbRedisCluster#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_redis_cluster#name DataYandexMdbRedisCluster#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbRedisClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbRedisClusterConfigA",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbRedisClusterConfigA:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbRedisClusterConfigA(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbRedisClusterConfigAList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbRedisClusterConfigAList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbRedisClusterConfigAOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbRedisClusterConfigAOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbRedisClusterConfigAOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbRedisClusterConfigAOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databases")
    def databases(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "databases"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxmemoryPolicy")
    def maxmemory_policy(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "maxmemoryPolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="notifyKeyspaceEvents")
    def notify_keyspace_events(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "notifyKeyspaceEvents"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="slowlogLogSlowerThan")
    def slowlog_log_slower_than(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "slowlogLogSlowerThan"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="slowlogMaxLen")
    def slowlog_max_len(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "slowlogMaxLen"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeout")
    def timeout(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "timeout"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "version"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexMdbRedisClusterConfigA]:
        return typing.cast(typing.Optional[DataYandexMdbRedisClusterConfigA], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbRedisClusterConfigA],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbRedisClusterHost",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbRedisClusterHost:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbRedisClusterHost(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbRedisClusterHostList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbRedisClusterHostList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "DataYandexMdbRedisClusterHostOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbRedisClusterHostOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbRedisClusterHostOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbRedisClusterHostOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fqdn"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="shardName")
    def shard_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "shardName"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zone")
    def zone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zone"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexMdbRedisClusterHost]:
        return typing.cast(typing.Optional[DataYandexMdbRedisClusterHost], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbRedisClusterHost],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbRedisClusterMaintenanceWindow",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbRedisClusterMaintenanceWindow:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbRedisClusterMaintenanceWindow(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbRedisClusterMaintenanceWindowList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbRedisClusterMaintenanceWindowList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbRedisClusterMaintenanceWindowOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbRedisClusterMaintenanceWindowOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbRedisClusterMaintenanceWindowOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbRedisClusterMaintenanceWindowOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="day")
    def day(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "day"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hour")
    def hour(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "hour"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbRedisClusterMaintenanceWindow]:
        return typing.cast(typing.Optional[DataYandexMdbRedisClusterMaintenanceWindow], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbRedisClusterMaintenanceWindow],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbRedisClusterResources",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbRedisClusterResources:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbRedisClusterResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbRedisClusterResourcesList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbRedisClusterResourcesList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbRedisClusterResourcesOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbRedisClusterResourcesOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbRedisClusterResourcesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbRedisClusterResourcesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSize")
    def disk_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "diskSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeId")
    def disk_type_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskTypeId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetId")
    def resource_preset_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourcePresetId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexMdbRedisClusterResources]:
        return typing.cast(typing.Optional[DataYandexMdbRedisClusterResources], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbRedisClusterResources],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexMdbSqlserverCluster(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbSqlserverCluster",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/mdb_sqlserver_cluster yandex_mdb_sqlserver_cluster}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        cluster_id: typing.Optional[builtins.str] = None,
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        sqlserver_config: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/mdb_sqlserver_cluster yandex_mdb_sqlserver_cluster} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_sqlserver_cluster#cluster_id DataYandexMdbSqlserverCluster#cluster_id}.
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_sqlserver_cluster#deletion_protection DataYandexMdbSqlserverCluster#deletion_protection}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_sqlserver_cluster#folder_id DataYandexMdbSqlserverCluster#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_sqlserver_cluster#id DataYandexMdbSqlserverCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_sqlserver_cluster#name DataYandexMdbSqlserverCluster#name}.
        :param sqlserver_config: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_sqlserver_cluster#sqlserver_config DataYandexMdbSqlserverCluster#sqlserver_config}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexMdbSqlserverClusterConfig(
            cluster_id=cluster_id,
            deletion_protection=deletion_protection,
            folder_id=folder_id,
            id=id,
            name=name,
            sqlserver_config=sqlserver_config,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetClusterId")
    def reset_cluster_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetClusterId", []))

    @jsii.member(jsii_name="resetDeletionProtection")
    def reset_deletion_protection(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDeletionProtection", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetSqlserverConfig")
    def reset_sqlserver_config(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSqlserverConfig", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backupWindowStart")
    def backup_window_start(
        self,
    ) -> "DataYandexMdbSqlserverClusterBackupWindowStartList":
        return typing.cast("DataYandexMdbSqlserverClusterBackupWindowStartList", jsii.get(self, "backupWindowStart"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="database")
    def database(self) -> "DataYandexMdbSqlserverClusterDatabaseList":
        return typing.cast("DataYandexMdbSqlserverClusterDatabaseList", jsii.get(self, "database"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="environment")
    def environment(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "environment"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="health")
    def health(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "health"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="host")
    def host(self) -> "DataYandexMdbSqlserverClusterHostList":
        return typing.cast("DataYandexMdbSqlserverClusterHostList", jsii.get(self, "host"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostGroupIds")
    def host_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "hostGroupIds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resources")
    def resources(self) -> "DataYandexMdbSqlserverClusterResourcesList":
        return typing.cast("DataYandexMdbSqlserverClusterResourcesList", jsii.get(self, "resources"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "securityGroupIds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="user")
    def user(self) -> "DataYandexMdbSqlserverClusterUserList":
        return typing.cast("DataYandexMdbSqlserverClusterUserList", jsii.get(self, "user"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "version"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterIdInput")
    def cluster_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "clusterIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtectionInput")
    def deletion_protection_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "deletionProtectionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sqlserverConfigInput")
    def sqlserver_config_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "sqlserverConfigInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterId")
    def cluster_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "clusterId"))

    @cluster_id.setter
    def cluster_id(self, value: builtins.str) -> None:
        jsii.set(self, "clusterId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtection")
    def deletion_protection(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "deletionProtection"))

    @deletion_protection.setter
    def deletion_protection(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "deletionProtection", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sqlserverConfig")
    def sqlserver_config(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "sqlserverConfig"))

    @sqlserver_config.setter
    def sqlserver_config(
        self,
        value: typing.Mapping[builtins.str, builtins.str],
    ) -> None:
        jsii.set(self, "sqlserverConfig", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbSqlserverClusterBackupWindowStart",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbSqlserverClusterBackupWindowStart:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbSqlserverClusterBackupWindowStart(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbSqlserverClusterBackupWindowStartList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbSqlserverClusterBackupWindowStartList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbSqlserverClusterBackupWindowStartOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbSqlserverClusterBackupWindowStartOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbSqlserverClusterBackupWindowStartOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbSqlserverClusterBackupWindowStartOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hours")
    def hours(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "hours"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minutes")
    def minutes(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minutes"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbSqlserverClusterBackupWindowStart]:
        return typing.cast(typing.Optional[DataYandexMdbSqlserverClusterBackupWindowStart], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbSqlserverClusterBackupWindowStart],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbSqlserverClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_id": "clusterId",
        "deletion_protection": "deletionProtection",
        "folder_id": "folderId",
        "id": "id",
        "name": "name",
        "sqlserver_config": "sqlserverConfig",
    },
)
class DataYandexMdbSqlserverClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_id: typing.Optional[builtins.str] = None,
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        sqlserver_config: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_sqlserver_cluster#cluster_id DataYandexMdbSqlserverCluster#cluster_id}.
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_sqlserver_cluster#deletion_protection DataYandexMdbSqlserverCluster#deletion_protection}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_sqlserver_cluster#folder_id DataYandexMdbSqlserverCluster#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_sqlserver_cluster#id DataYandexMdbSqlserverCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_sqlserver_cluster#name DataYandexMdbSqlserverCluster#name}.
        :param sqlserver_config: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_sqlserver_cluster#sqlserver_config DataYandexMdbSqlserverCluster#sqlserver_config}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if cluster_id is not None:
            self._values["cluster_id"] = cluster_id
        if deletion_protection is not None:
            self._values["deletion_protection"] = deletion_protection
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name
        if sqlserver_config is not None:
            self._values["sqlserver_config"] = sqlserver_config

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def cluster_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_sqlserver_cluster#cluster_id DataYandexMdbSqlserverCluster#cluster_id}.'''
        result = self._values.get("cluster_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def deletion_protection(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_sqlserver_cluster#deletion_protection DataYandexMdbSqlserverCluster#deletion_protection}.'''
        result = self._values.get("deletion_protection")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_sqlserver_cluster#folder_id DataYandexMdbSqlserverCluster#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_sqlserver_cluster#id DataYandexMdbSqlserverCluster#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_sqlserver_cluster#name DataYandexMdbSqlserverCluster#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def sqlserver_config(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/mdb_sqlserver_cluster#sqlserver_config DataYandexMdbSqlserverCluster#sqlserver_config}.'''
        result = self._values.get("sqlserver_config")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbSqlserverClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbSqlserverClusterDatabase",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbSqlserverClusterDatabase:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbSqlserverClusterDatabase(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbSqlserverClusterDatabaseList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbSqlserverClusterDatabaseList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbSqlserverClusterDatabaseOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbSqlserverClusterDatabaseOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbSqlserverClusterDatabaseOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbSqlserverClusterDatabaseOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexMdbSqlserverClusterDatabase]:
        return typing.cast(typing.Optional[DataYandexMdbSqlserverClusterDatabase], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbSqlserverClusterDatabase],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbSqlserverClusterHost",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbSqlserverClusterHost:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbSqlserverClusterHost(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbSqlserverClusterHostList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbSqlserverClusterHostList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbSqlserverClusterHostOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbSqlserverClusterHostOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbSqlserverClusterHostOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbSqlserverClusterHostOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIp")
    def assign_public_ip(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "assignPublicIp"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fqdn"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zone")
    def zone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zone"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexMdbSqlserverClusterHost]:
        return typing.cast(typing.Optional[DataYandexMdbSqlserverClusterHost], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbSqlserverClusterHost],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbSqlserverClusterResources",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbSqlserverClusterResources:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbSqlserverClusterResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbSqlserverClusterResourcesList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbSqlserverClusterResourcesList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbSqlserverClusterResourcesOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbSqlserverClusterResourcesOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbSqlserverClusterResourcesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbSqlserverClusterResourcesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSize")
    def disk_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "diskSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeId")
    def disk_type_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskTypeId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetId")
    def resource_preset_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourcePresetId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexMdbSqlserverClusterResources]:
        return typing.cast(typing.Optional[DataYandexMdbSqlserverClusterResources], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbSqlserverClusterResources],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbSqlserverClusterUser",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbSqlserverClusterUser:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbSqlserverClusterUser(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbSqlserverClusterUserList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbSqlserverClusterUserList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbSqlserverClusterUserOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbSqlserverClusterUserOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbSqlserverClusterUserOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbSqlserverClusterUserOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="password")
    def password(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "password"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="permission")
    def permission(self) -> "DataYandexMdbSqlserverClusterUserPermissionList":
        return typing.cast("DataYandexMdbSqlserverClusterUserPermissionList", jsii.get(self, "permission"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexMdbSqlserverClusterUser]:
        return typing.cast(typing.Optional[DataYandexMdbSqlserverClusterUser], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbSqlserverClusterUser],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMdbSqlserverClusterUserPermission",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexMdbSqlserverClusterUserPermission:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMdbSqlserverClusterUserPermission(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexMdbSqlserverClusterUserPermissionList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbSqlserverClusterUserPermissionList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexMdbSqlserverClusterUserPermissionOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexMdbSqlserverClusterUserPermissionOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexMdbSqlserverClusterUserPermissionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMdbSqlserverClusterUserPermissionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databaseName")
    def database_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "databaseName"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="roles")
    def roles(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "roles"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexMdbSqlserverClusterUserPermission]:
        return typing.cast(typing.Optional[DataYandexMdbSqlserverClusterUserPermission], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexMdbSqlserverClusterUserPermission],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexMessageQueue(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexMessageQueue",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/message_queue yandex_message_queue}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        name: builtins.str,
        access_key: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        secret_key: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/message_queue yandex_message_queue} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/message_queue#name DataYandexMessageQueue#name}.
        :param access_key: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/message_queue#access_key DataYandexMessageQueue#access_key}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/message_queue#id DataYandexMessageQueue#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param secret_key: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/message_queue#secret_key DataYandexMessageQueue#secret_key}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexMessageQueueConfig(
            name=name,
            access_key=access_key,
            id=id,
            secret_key=secret_key,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetAccessKey")
    def reset_access_key(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAccessKey", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetSecretKey")
    def reset_secret_key(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecretKey", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="arn")
    def arn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "arn"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="url")
    def url(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "url"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="accessKeyInput")
    def access_key_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "accessKeyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="secretKeyInput")
    def secret_key_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "secretKeyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="accessKey")
    def access_key(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "accessKey"))

    @access_key.setter
    def access_key(self, value: builtins.str) -> None:
        jsii.set(self, "accessKey", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="secretKey")
    def secret_key(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "secretKey"))

    @secret_key.setter
    def secret_key(self, value: builtins.str) -> None:
        jsii.set(self, "secretKey", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexMessageQueueConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "access_key": "accessKey",
        "id": "id",
        "secret_key": "secretKey",
    },
)
class DataYandexMessageQueueConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        access_key: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        secret_key: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/message_queue#name DataYandexMessageQueue#name}.
        :param access_key: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/message_queue#access_key DataYandexMessageQueue#access_key}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/message_queue#id DataYandexMessageQueue#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param secret_key: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/message_queue#secret_key DataYandexMessageQueue#secret_key}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if access_key is not None:
            self._values["access_key"] = access_key
        if id is not None:
            self._values["id"] = id
        if secret_key is not None:
            self._values["secret_key"] = secret_key

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/message_queue#name DataYandexMessageQueue#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def access_key(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/message_queue#access_key DataYandexMessageQueue#access_key}.'''
        result = self._values.get("access_key")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/message_queue#id DataYandexMessageQueue#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def secret_key(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/message_queue#secret_key DataYandexMessageQueue#secret_key}.'''
        result = self._values.get("secret_key")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexMessageQueueConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexOrganizationmanagerSamlFederation(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexOrganizationmanagerSamlFederation",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/organizationmanager_saml_federation yandex_organizationmanager_saml_federation}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        federation_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        organization_id: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/organizationmanager_saml_federation yandex_organizationmanager_saml_federation} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param federation_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/organizationmanager_saml_federation#federation_id DataYandexOrganizationmanagerSamlFederation#federation_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/organizationmanager_saml_federation#id DataYandexOrganizationmanagerSamlFederation#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/organizationmanager_saml_federation#labels DataYandexOrganizationmanagerSamlFederation#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/organizationmanager_saml_federation#name DataYandexOrganizationmanagerSamlFederation#name}.
        :param organization_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/organizationmanager_saml_federation#organization_id DataYandexOrganizationmanagerSamlFederation#organization_id}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexOrganizationmanagerSamlFederationConfig(
            federation_id=federation_id,
            id=id,
            labels=labels,
            name=name,
            organization_id=organization_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetFederationId")
    def reset_federation_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFederationId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetOrganizationId")
    def reset_organization_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOrganizationId", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoCreateAccountOnLogin")
    def auto_create_account_on_login(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "autoCreateAccountOnLogin"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="caseInsensitiveNameIds")
    def case_insensitive_name_ids(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "caseInsensitiveNameIds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cookieMaxAge")
    def cookie_max_age(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "cookieMaxAge"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="issuer")
    def issuer(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "issuer"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securitySettings")
    def security_settings(
        self,
    ) -> "DataYandexOrganizationmanagerSamlFederationSecuritySettingsList":
        return typing.cast("DataYandexOrganizationmanagerSamlFederationSecuritySettingsList", jsii.get(self, "securitySettings"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ssoBinding")
    def sso_binding(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ssoBinding"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ssoUrl")
    def sso_url(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ssoUrl"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="federationIdInput")
    def federation_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "federationIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="organizationIdInput")
    def organization_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "organizationIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="federationId")
    def federation_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "federationId"))

    @federation_id.setter
    def federation_id(self, value: builtins.str) -> None:
        jsii.set(self, "federationId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="organizationId")
    def organization_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "organizationId"))

    @organization_id.setter
    def organization_id(self, value: builtins.str) -> None:
        jsii.set(self, "organizationId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexOrganizationmanagerSamlFederationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "federation_id": "federationId",
        "id": "id",
        "labels": "labels",
        "name": "name",
        "organization_id": "organizationId",
    },
)
class DataYandexOrganizationmanagerSamlFederationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        federation_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        organization_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param federation_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/organizationmanager_saml_federation#federation_id DataYandexOrganizationmanagerSamlFederation#federation_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/organizationmanager_saml_federation#id DataYandexOrganizationmanagerSamlFederation#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/organizationmanager_saml_federation#labels DataYandexOrganizationmanagerSamlFederation#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/organizationmanager_saml_federation#name DataYandexOrganizationmanagerSamlFederation#name}.
        :param organization_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/organizationmanager_saml_federation#organization_id DataYandexOrganizationmanagerSamlFederation#organization_id}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if federation_id is not None:
            self._values["federation_id"] = federation_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if name is not None:
            self._values["name"] = name
        if organization_id is not None:
            self._values["organization_id"] = organization_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def federation_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/organizationmanager_saml_federation#federation_id DataYandexOrganizationmanagerSamlFederation#federation_id}.'''
        result = self._values.get("federation_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/organizationmanager_saml_federation#id DataYandexOrganizationmanagerSamlFederation#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/organizationmanager_saml_federation#labels DataYandexOrganizationmanagerSamlFederation#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/organizationmanager_saml_federation#name DataYandexOrganizationmanagerSamlFederation#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def organization_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/organizationmanager_saml_federation#organization_id DataYandexOrganizationmanagerSamlFederation#organization_id}.'''
        result = self._values.get("organization_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexOrganizationmanagerSamlFederationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexOrganizationmanagerSamlFederationSecuritySettings",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexOrganizationmanagerSamlFederationSecuritySettings:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexOrganizationmanagerSamlFederationSecuritySettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexOrganizationmanagerSamlFederationSecuritySettingsList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexOrganizationmanagerSamlFederationSecuritySettingsList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexOrganizationmanagerSamlFederationSecuritySettingsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexOrganizationmanagerSamlFederationSecuritySettingsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexOrganizationmanagerSamlFederationSecuritySettingsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexOrganizationmanagerSamlFederationSecuritySettingsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="encryptedAssertions")
    def encrypted_assertions(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "encryptedAssertions"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexOrganizationmanagerSamlFederationSecuritySettings]:
        return typing.cast(typing.Optional[DataYandexOrganizationmanagerSamlFederationSecuritySettings], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexOrganizationmanagerSamlFederationSecuritySettings],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexOrganizationmanagerSamlFederationUserAccount(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexOrganizationmanagerSamlFederationUserAccount",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/organizationmanager_saml_federation_user_account yandex_organizationmanager_saml_federation_user_account}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        federation_id: builtins.str,
        name_id: builtins.str,
        id: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/organizationmanager_saml_federation_user_account yandex_organizationmanager_saml_federation_user_account} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param federation_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/organizationmanager_saml_federation_user_account#federation_id DataYandexOrganizationmanagerSamlFederationUserAccount#federation_id}.
        :param name_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/organizationmanager_saml_federation_user_account#name_id DataYandexOrganizationmanagerSamlFederationUserAccount#name_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/organizationmanager_saml_federation_user_account#id DataYandexOrganizationmanagerSamlFederationUserAccount#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexOrganizationmanagerSamlFederationUserAccountConfig(
            federation_id=federation_id,
            name_id=name_id,
            id=id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="federationIdInput")
    def federation_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "federationIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameIdInput")
    def name_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="federationId")
    def federation_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "federationId"))

    @federation_id.setter
    def federation_id(self, value: builtins.str) -> None:
        jsii.set(self, "federationId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameId")
    def name_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "nameId"))

    @name_id.setter
    def name_id(self, value: builtins.str) -> None:
        jsii.set(self, "nameId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexOrganizationmanagerSamlFederationUserAccountConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "federation_id": "federationId",
        "name_id": "nameId",
        "id": "id",
    },
)
class DataYandexOrganizationmanagerSamlFederationUserAccountConfig(
    cdktf.TerraformMetaArguments,
):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        federation_id: builtins.str,
        name_id: builtins.str,
        id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param federation_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/organizationmanager_saml_federation_user_account#federation_id DataYandexOrganizationmanagerSamlFederationUserAccount#federation_id}.
        :param name_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/organizationmanager_saml_federation_user_account#name_id DataYandexOrganizationmanagerSamlFederationUserAccount#name_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/organizationmanager_saml_federation_user_account#id DataYandexOrganizationmanagerSamlFederationUserAccount#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {
            "federation_id": federation_id,
            "name_id": name_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if id is not None:
            self._values["id"] = id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def federation_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/organizationmanager_saml_federation_user_account#federation_id DataYandexOrganizationmanagerSamlFederationUserAccount#federation_id}.'''
        result = self._values.get("federation_id")
        assert result is not None, "Required property 'federation_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/organizationmanager_saml_federation_user_account#name_id DataYandexOrganizationmanagerSamlFederationUserAccount#name_id}.'''
        result = self._values.get("name_id")
        assert result is not None, "Required property 'name_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/organizationmanager_saml_federation_user_account#id DataYandexOrganizationmanagerSamlFederationUserAccount#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexOrganizationmanagerSamlFederationUserAccountConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexResourcemanagerCloud(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexResourcemanagerCloud",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/resourcemanager_cloud yandex_resourcemanager_cloud}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        cloud_id: typing.Optional[builtins.str] = None,
        description: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/resourcemanager_cloud yandex_resourcemanager_cloud} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param cloud_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/resourcemanager_cloud#cloud_id DataYandexResourcemanagerCloud#cloud_id}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/resourcemanager_cloud#description DataYandexResourcemanagerCloud#description}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/resourcemanager_cloud#id DataYandexResourcemanagerCloud#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/resourcemanager_cloud#name DataYandexResourcemanagerCloud#name}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexResourcemanagerCloudConfig(
            cloud_id=cloud_id,
            description=description,
            id=id,
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetCloudId")
    def reset_cloud_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCloudId", []))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cloudIdInput")
    def cloud_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "cloudIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cloudId")
    def cloud_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "cloudId"))

    @cloud_id.setter
    def cloud_id(self, value: builtins.str) -> None:
        jsii.set(self, "cloudId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexResourcemanagerCloudConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cloud_id": "cloudId",
        "description": "description",
        "id": "id",
        "name": "name",
    },
)
class DataYandexResourcemanagerCloudConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cloud_id: typing.Optional[builtins.str] = None,
        description: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cloud_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/resourcemanager_cloud#cloud_id DataYandexResourcemanagerCloud#cloud_id}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/resourcemanager_cloud#description DataYandexResourcemanagerCloud#description}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/resourcemanager_cloud#id DataYandexResourcemanagerCloud#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/resourcemanager_cloud#name DataYandexResourcemanagerCloud#name}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if cloud_id is not None:
            self._values["cloud_id"] = cloud_id
        if description is not None:
            self._values["description"] = description
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def cloud_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/resourcemanager_cloud#cloud_id DataYandexResourcemanagerCloud#cloud_id}.'''
        result = self._values.get("cloud_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/resourcemanager_cloud#description DataYandexResourcemanagerCloud#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/resourcemanager_cloud#id DataYandexResourcemanagerCloud#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/resourcemanager_cloud#name DataYandexResourcemanagerCloud#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexResourcemanagerCloudConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexResourcemanagerFolder(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexResourcemanagerFolder",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/resourcemanager_folder yandex_resourcemanager_folder}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        cloud_id: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/resourcemanager_folder yandex_resourcemanager_folder} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param cloud_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/resourcemanager_folder#cloud_id DataYandexResourcemanagerFolder#cloud_id}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/resourcemanager_folder#folder_id DataYandexResourcemanagerFolder#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/resourcemanager_folder#id DataYandexResourcemanagerFolder#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/resourcemanager_folder#labels DataYandexResourcemanagerFolder#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/resourcemanager_folder#name DataYandexResourcemanagerFolder#name}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexResourcemanagerFolderConfig(
            cloud_id=cloud_id,
            folder_id=folder_id,
            id=id,
            labels=labels,
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetCloudId")
    def reset_cloud_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCloudId", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cloudIdInput")
    def cloud_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "cloudIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cloudId")
    def cloud_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "cloudId"))

    @cloud_id.setter
    def cloud_id(self, value: builtins.str) -> None:
        jsii.set(self, "cloudId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexResourcemanagerFolderConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cloud_id": "cloudId",
        "folder_id": "folderId",
        "id": "id",
        "labels": "labels",
        "name": "name",
    },
)
class DataYandexResourcemanagerFolderConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cloud_id: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cloud_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/resourcemanager_folder#cloud_id DataYandexResourcemanagerFolder#cloud_id}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/resourcemanager_folder#folder_id DataYandexResourcemanagerFolder#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/resourcemanager_folder#id DataYandexResourcemanagerFolder#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/resourcemanager_folder#labels DataYandexResourcemanagerFolder#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/resourcemanager_folder#name DataYandexResourcemanagerFolder#name}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if cloud_id is not None:
            self._values["cloud_id"] = cloud_id
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def cloud_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/resourcemanager_folder#cloud_id DataYandexResourcemanagerFolder#cloud_id}.'''
        result = self._values.get("cloud_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/resourcemanager_folder#folder_id DataYandexResourcemanagerFolder#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/resourcemanager_folder#id DataYandexResourcemanagerFolder#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/resourcemanager_folder#labels DataYandexResourcemanagerFolder#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/resourcemanager_folder#name DataYandexResourcemanagerFolder#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexResourcemanagerFolderConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexServerlessContainer(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexServerlessContainer",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/serverless_container yandex_serverless_container}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        container_id: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/serverless_container yandex_serverless_container} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param container_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/serverless_container#container_id DataYandexServerlessContainer#container_id}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/serverless_container#folder_id DataYandexServerlessContainer#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/serverless_container#id DataYandexServerlessContainer#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/serverless_container#name DataYandexServerlessContainer#name}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexServerlessContainerConfig(
            container_id=container_id,
            folder_id=folder_id,
            id=id,
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetContainerId")
    def reset_container_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetContainerId", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="concurrency")
    def concurrency(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "concurrency"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="coreFraction")
    def core_fraction(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "coreFraction"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cores")
    def cores(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "cores"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="executionTimeout")
    def execution_timeout(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "executionTimeout"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="image")
    def image(self) -> "DataYandexServerlessContainerImageList":
        return typing.cast("DataYandexServerlessContainerImageList", jsii.get(self, "image"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="memory")
    def memory(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "memory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="revisionId")
    def revision_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "revisionId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountId")
    def service_account_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceAccountId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="url")
    def url(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "url"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="containerIdInput")
    def container_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "containerIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="containerId")
    def container_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "containerId"))

    @container_id.setter
    def container_id(self, value: builtins.str) -> None:
        jsii.set(self, "containerId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexServerlessContainerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "container_id": "containerId",
        "folder_id": "folderId",
        "id": "id",
        "name": "name",
    },
)
class DataYandexServerlessContainerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        container_id: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param container_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/serverless_container#container_id DataYandexServerlessContainer#container_id}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/serverless_container#folder_id DataYandexServerlessContainer#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/serverless_container#id DataYandexServerlessContainer#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/serverless_container#name DataYandexServerlessContainer#name}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if container_id is not None:
            self._values["container_id"] = container_id
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def container_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/serverless_container#container_id DataYandexServerlessContainer#container_id}.'''
        result = self._values.get("container_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/serverless_container#folder_id DataYandexServerlessContainer#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/serverless_container#id DataYandexServerlessContainer#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/serverless_container#name DataYandexServerlessContainer#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexServerlessContainerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexServerlessContainerImage",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexServerlessContainerImage:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexServerlessContainerImage(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexServerlessContainerImageList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexServerlessContainerImageList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexServerlessContainerImageOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexServerlessContainerImageOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexServerlessContainerImageOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexServerlessContainerImageOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="args")
    def args(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "args"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="command")
    def command(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "command"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="digest")
    def digest(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "digest"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="environment")
    def environment(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "environment"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="url")
    def url(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "url"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="workDir")
    def work_dir(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "workDir"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexServerlessContainerImage]:
        return typing.cast(typing.Optional[DataYandexServerlessContainerImage], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexServerlessContainerImage],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexVpcAddress(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexVpcAddress",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/vpc_address yandex_vpc_address}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        address_id: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/vpc_address yandex_vpc_address} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param address_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_address#address_id DataYandexVpcAddress#address_id}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_address#folder_id DataYandexVpcAddress#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_address#id DataYandexVpcAddress#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_address#name DataYandexVpcAddress#name}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexVpcAddressConfig(
            address_id=address_id,
            folder_id=folder_id,
            id=id,
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetAddressId")
    def reset_address_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAddressId", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="externalIpv4Address")
    def external_ipv4_address(self) -> "DataYandexVpcAddressExternalIpv4AddressList":
        return typing.cast("DataYandexVpcAddressExternalIpv4AddressList", jsii.get(self, "externalIpv4Address"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="reserved")
    def reserved(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "reserved"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="used")
    def used(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "used"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="addressIdInput")
    def address_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "addressIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="addressId")
    def address_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "addressId"))

    @address_id.setter
    def address_id(self, value: builtins.str) -> None:
        jsii.set(self, "addressId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexVpcAddressConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "address_id": "addressId",
        "folder_id": "folderId",
        "id": "id",
        "name": "name",
    },
)
class DataYandexVpcAddressConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        address_id: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param address_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_address#address_id DataYandexVpcAddress#address_id}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_address#folder_id DataYandexVpcAddress#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_address#id DataYandexVpcAddress#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_address#name DataYandexVpcAddress#name}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if address_id is not None:
            self._values["address_id"] = address_id
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def address_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_address#address_id DataYandexVpcAddress#address_id}.'''
        result = self._values.get("address_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_address#folder_id DataYandexVpcAddress#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_address#id DataYandexVpcAddress#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_address#name DataYandexVpcAddress#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexVpcAddressConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexVpcAddressExternalIpv4Address",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexVpcAddressExternalIpv4Address:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexVpcAddressExternalIpv4Address(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexVpcAddressExternalIpv4AddressList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexVpcAddressExternalIpv4AddressList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexVpcAddressExternalIpv4AddressOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexVpcAddressExternalIpv4AddressOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexVpcAddressExternalIpv4AddressOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexVpcAddressExternalIpv4AddressOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="address")
    def address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "address"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ddosProtectionProvider")
    def ddos_protection_provider(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ddosProtectionProvider"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="outgoingSmtpCapability")
    def outgoing_smtp_capability(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "outgoingSmtpCapability"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneId")
    def zone_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zoneId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexVpcAddressExternalIpv4Address]:
        return typing.cast(typing.Optional[DataYandexVpcAddressExternalIpv4Address], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexVpcAddressExternalIpv4Address],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexVpcNetwork(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexVpcNetwork",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/vpc_network yandex_vpc_network}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        network_id: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/vpc_network yandex_vpc_network} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_network#folder_id DataYandexVpcNetwork#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_network#id DataYandexVpcNetwork#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_network#name DataYandexVpcNetwork#name}.
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_network#network_id DataYandexVpcNetwork#network_id}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexVpcNetworkConfig(
            folder_id=folder_id,
            id=id,
            name=name,
            network_id=network_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetNetworkId")
    def reset_network_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNetworkId", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="defaultSecurityGroupId")
    def default_security_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "defaultSecurityGroupId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "subnetIds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkIdInput")
    def network_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "networkIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @network_id.setter
    def network_id(self, value: builtins.str) -> None:
        jsii.set(self, "networkId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexVpcNetworkConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "folder_id": "folderId",
        "id": "id",
        "name": "name",
        "network_id": "networkId",
    },
)
class DataYandexVpcNetworkConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        network_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_network#folder_id DataYandexVpcNetwork#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_network#id DataYandexVpcNetwork#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_network#name DataYandexVpcNetwork#name}.
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_network#network_id DataYandexVpcNetwork#network_id}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name
        if network_id is not None:
            self._values["network_id"] = network_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_network#folder_id DataYandexVpcNetwork#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_network#id DataYandexVpcNetwork#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_network#name DataYandexVpcNetwork#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def network_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_network#network_id DataYandexVpcNetwork#network_id}.'''
        result = self._values.get("network_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexVpcNetworkConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexVpcRouteTable(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexVpcRouteTable",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/vpc_route_table yandex_vpc_route_table}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        route_table_id: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/vpc_route_table yandex_vpc_route_table} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_route_table#folder_id DataYandexVpcRouteTable#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_route_table#id DataYandexVpcRouteTable#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_route_table#name DataYandexVpcRouteTable#name}.
        :param route_table_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_route_table#route_table_id DataYandexVpcRouteTable#route_table_id}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexVpcRouteTableConfig(
            folder_id=folder_id,
            id=id,
            name=name,
            route_table_id=route_table_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetRouteTableId")
    def reset_route_table_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRouteTableId", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="staticRoute")
    def static_route(self) -> "DataYandexVpcRouteTableStaticRouteList":
        return typing.cast("DataYandexVpcRouteTableStaticRouteList", jsii.get(self, "staticRoute"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="routeTableIdInput")
    def route_table_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "routeTableIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="routeTableId")
    def route_table_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "routeTableId"))

    @route_table_id.setter
    def route_table_id(self, value: builtins.str) -> None:
        jsii.set(self, "routeTableId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexVpcRouteTableConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "folder_id": "folderId",
        "id": "id",
        "name": "name",
        "route_table_id": "routeTableId",
    },
)
class DataYandexVpcRouteTableConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        route_table_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_route_table#folder_id DataYandexVpcRouteTable#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_route_table#id DataYandexVpcRouteTable#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_route_table#name DataYandexVpcRouteTable#name}.
        :param route_table_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_route_table#route_table_id DataYandexVpcRouteTable#route_table_id}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name
        if route_table_id is not None:
            self._values["route_table_id"] = route_table_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_route_table#folder_id DataYandexVpcRouteTable#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_route_table#id DataYandexVpcRouteTable#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_route_table#name DataYandexVpcRouteTable#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def route_table_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_route_table#route_table_id DataYandexVpcRouteTable#route_table_id}.'''
        result = self._values.get("route_table_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexVpcRouteTableConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexVpcRouteTableStaticRoute",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexVpcRouteTableStaticRoute:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexVpcRouteTableStaticRoute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexVpcRouteTableStaticRouteList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexVpcRouteTableStaticRouteList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexVpcRouteTableStaticRouteOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexVpcRouteTableStaticRouteOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexVpcRouteTableStaticRouteOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexVpcRouteTableStaticRouteOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="destinationPrefix")
    def destination_prefix(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "destinationPrefix"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nextHopAddress")
    def next_hop_address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "nextHopAddress"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexVpcRouteTableStaticRoute]:
        return typing.cast(typing.Optional[DataYandexVpcRouteTableStaticRoute], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexVpcRouteTableStaticRoute],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexVpcSecurityGroup(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexVpcSecurityGroup",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/vpc_security_group yandex_vpc_security_group}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        security_group_id: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/vpc_security_group yandex_vpc_security_group} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_security_group#folder_id DataYandexVpcSecurityGroup#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_security_group#id DataYandexVpcSecurityGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_security_group#name DataYandexVpcSecurityGroup#name}.
        :param security_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_security_group#security_group_id DataYandexVpcSecurityGroup#security_group_id}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexVpcSecurityGroupConfig(
            folder_id=folder_id,
            id=id,
            name=name,
            security_group_id=security_group_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetSecurityGroupId")
    def reset_security_group_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityGroupId", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="egress")
    def egress(self) -> "DataYandexVpcSecurityGroupEgressList":
        return typing.cast("DataYandexVpcSecurityGroupEgressList", jsii.get(self, "egress"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ingress")
    def ingress(self) -> "DataYandexVpcSecurityGroupIngressList":
        return typing.cast("DataYandexVpcSecurityGroupIngressList", jsii.get(self, "ingress"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIdInput")
    def security_group_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "securityGroupIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupId")
    def security_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "securityGroupId"))

    @security_group_id.setter
    def security_group_id(self, value: builtins.str) -> None:
        jsii.set(self, "securityGroupId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexVpcSecurityGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "folder_id": "folderId",
        "id": "id",
        "name": "name",
        "security_group_id": "securityGroupId",
    },
)
class DataYandexVpcSecurityGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        security_group_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_security_group#folder_id DataYandexVpcSecurityGroup#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_security_group#id DataYandexVpcSecurityGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_security_group#name DataYandexVpcSecurityGroup#name}.
        :param security_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_security_group#security_group_id DataYandexVpcSecurityGroup#security_group_id}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name
        if security_group_id is not None:
            self._values["security_group_id"] = security_group_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_security_group#folder_id DataYandexVpcSecurityGroup#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_security_group#id DataYandexVpcSecurityGroup#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_security_group#name DataYandexVpcSecurityGroup#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def security_group_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_security_group#security_group_id DataYandexVpcSecurityGroup#security_group_id}.'''
        result = self._values.get("security_group_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexVpcSecurityGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexVpcSecurityGroupEgress",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexVpcSecurityGroupEgress:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexVpcSecurityGroupEgress(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexVpcSecurityGroupEgressList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexVpcSecurityGroupEgressList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexVpcSecurityGroupEgressOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexVpcSecurityGroupEgressOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexVpcSecurityGroupEgressOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexVpcSecurityGroupEgressOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fromPort")
    def from_port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "fromPort"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "port"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="predefinedTarget")
    def predefined_target(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "predefinedTarget"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "protocol"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupId")
    def security_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "securityGroupId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="toPort")
    def to_port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "toPort"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="v4CidrBlocks")
    def v4_cidr_blocks(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "v4CidrBlocks"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="v6CidrBlocks")
    def v6_cidr_blocks(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "v6CidrBlocks"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexVpcSecurityGroupEgress]:
        return typing.cast(typing.Optional[DataYandexVpcSecurityGroupEgress], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexVpcSecurityGroupEgress],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexVpcSecurityGroupIngress",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexVpcSecurityGroupIngress:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexVpcSecurityGroupIngress(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexVpcSecurityGroupIngressList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexVpcSecurityGroupIngressList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexVpcSecurityGroupIngressOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexVpcSecurityGroupIngressOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexVpcSecurityGroupIngressOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexVpcSecurityGroupIngressOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fromPort")
    def from_port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "fromPort"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "port"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="predefinedTarget")
    def predefined_target(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "predefinedTarget"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "protocol"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupId")
    def security_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "securityGroupId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="toPort")
    def to_port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "toPort"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="v4CidrBlocks")
    def v4_cidr_blocks(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "v4CidrBlocks"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="v6CidrBlocks")
    def v6_cidr_blocks(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "v6CidrBlocks"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexVpcSecurityGroupIngress]:
        return typing.cast(typing.Optional[DataYandexVpcSecurityGroupIngress], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexVpcSecurityGroupIngress],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexVpcSecurityGroupRule(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexVpcSecurityGroupRule",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/vpc_security_group_rule yandex_vpc_security_group_rule}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        rule_id: builtins.str,
        security_group_binding: builtins.str,
        id: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/vpc_security_group_rule yandex_vpc_security_group_rule} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param rule_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_security_group_rule#rule_id DataYandexVpcSecurityGroupRule#rule_id}.
        :param security_group_binding: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_security_group_rule#security_group_binding DataYandexVpcSecurityGroupRule#security_group_binding}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_security_group_rule#id DataYandexVpcSecurityGroupRule#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexVpcSecurityGroupRuleConfig(
            rule_id=rule_id,
            security_group_binding=security_group_binding,
            id=id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="direction")
    def direction(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "direction"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fromPort")
    def from_port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "fromPort"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "port"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="predefinedTarget")
    def predefined_target(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "predefinedTarget"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "protocol"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupId")
    def security_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "securityGroupId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="toPort")
    def to_port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "toPort"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="v4CidrBlocks")
    def v4_cidr_blocks(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "v4CidrBlocks"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="v6CidrBlocks")
    def v6_cidr_blocks(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "v6CidrBlocks"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ruleIdInput")
    def rule_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "ruleIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupBindingInput")
    def security_group_binding_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "securityGroupBindingInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ruleId")
    def rule_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ruleId"))

    @rule_id.setter
    def rule_id(self, value: builtins.str) -> None:
        jsii.set(self, "ruleId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupBinding")
    def security_group_binding(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "securityGroupBinding"))

    @security_group_binding.setter
    def security_group_binding(self, value: builtins.str) -> None:
        jsii.set(self, "securityGroupBinding", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexVpcSecurityGroupRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "rule_id": "ruleId",
        "security_group_binding": "securityGroupBinding",
        "id": "id",
    },
)
class DataYandexVpcSecurityGroupRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        rule_id: builtins.str,
        security_group_binding: builtins.str,
        id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param rule_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_security_group_rule#rule_id DataYandexVpcSecurityGroupRule#rule_id}.
        :param security_group_binding: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_security_group_rule#security_group_binding DataYandexVpcSecurityGroupRule#security_group_binding}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_security_group_rule#id DataYandexVpcSecurityGroupRule#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {
            "rule_id": rule_id,
            "security_group_binding": security_group_binding,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if id is not None:
            self._values["id"] = id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def rule_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_security_group_rule#rule_id DataYandexVpcSecurityGroupRule#rule_id}.'''
        result = self._values.get("rule_id")
        assert result is not None, "Required property 'rule_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def security_group_binding(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_security_group_rule#security_group_binding DataYandexVpcSecurityGroupRule#security_group_binding}.'''
        result = self._values.get("security_group_binding")
        assert result is not None, "Required property 'security_group_binding' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_security_group_rule#id DataYandexVpcSecurityGroupRule#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexVpcSecurityGroupRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexVpcSubnet(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexVpcSubnet",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/vpc_subnet yandex_vpc_subnet}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/vpc_subnet yandex_vpc_subnet} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_subnet#folder_id DataYandexVpcSubnet#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_subnet#id DataYandexVpcSubnet#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_subnet#name DataYandexVpcSubnet#name}.
        :param subnet_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_subnet#subnet_id DataYandexVpcSubnet#subnet_id}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexVpcSubnetConfig(
            folder_id=folder_id,
            id=id,
            name=name,
            subnet_id=subnet_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetSubnetId")
    def reset_subnet_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSubnetId", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dhcpOptions")
    def dhcp_options(self) -> "DataYandexVpcSubnetDhcpOptionsList":
        return typing.cast("DataYandexVpcSubnetDhcpOptionsList", jsii.get(self, "dhcpOptions"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="routeTableId")
    def route_table_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "routeTableId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="v4CidrBlocks")
    def v4_cidr_blocks(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "v4CidrBlocks"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="v6CidrBlocks")
    def v6_cidr_blocks(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "v6CidrBlocks"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zone")
    def zone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zone"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIdInput")
    def subnet_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "subnetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @subnet_id.setter
    def subnet_id(self, value: builtins.str) -> None:
        jsii.set(self, "subnetId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexVpcSubnetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "folder_id": "folderId",
        "id": "id",
        "name": "name",
        "subnet_id": "subnetId",
    },
)
class DataYandexVpcSubnetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        subnet_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_subnet#folder_id DataYandexVpcSubnet#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_subnet#id DataYandexVpcSubnet#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_subnet#name DataYandexVpcSubnet#name}.
        :param subnet_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_subnet#subnet_id DataYandexVpcSubnet#subnet_id}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_subnet#folder_id DataYandexVpcSubnet#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_subnet#id DataYandexVpcSubnet#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_subnet#name DataYandexVpcSubnet#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/vpc_subnet#subnet_id DataYandexVpcSubnet#subnet_id}.'''
        result = self._values.get("subnet_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexVpcSubnetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexVpcSubnetDhcpOptions",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexVpcSubnetDhcpOptions:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexVpcSubnetDhcpOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexVpcSubnetDhcpOptionsList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexVpcSubnetDhcpOptionsList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexVpcSubnetDhcpOptionsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexVpcSubnetDhcpOptionsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexVpcSubnetDhcpOptionsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexVpcSubnetDhcpOptionsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="domainName")
    def domain_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "domainName"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="domainNameServers")
    def domain_name_servers(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "domainNameServers"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ntpServers")
    def ntp_servers(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "ntpServers"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexVpcSubnetDhcpOptions]:
        return typing.cast(typing.Optional[DataYandexVpcSubnetDhcpOptions], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexVpcSubnetDhcpOptions],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexYdbDatabaseDedicated(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexYdbDatabaseDedicated",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/ydb_database_dedicated yandex_ydb_database_dedicated}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        database_id: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/ydb_database_dedicated yandex_ydb_database_dedicated} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param database_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/ydb_database_dedicated#database_id DataYandexYdbDatabaseDedicated#database_id}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/ydb_database_dedicated#folder_id DataYandexYdbDatabaseDedicated#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/ydb_database_dedicated#id DataYandexYdbDatabaseDedicated#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/ydb_database_dedicated#name DataYandexYdbDatabaseDedicated#name}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexYdbDatabaseDedicatedConfig(
            database_id=database_id,
            folder_id=folder_id,
            id=id,
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetDatabaseId")
    def reset_database_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDatabaseId", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIps")
    def assign_public_ips(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "assignPublicIps"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databasePath")
    def database_path(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "databasePath"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="location")
    def location(self) -> "DataYandexYdbDatabaseDedicatedLocationList":
        return typing.cast("DataYandexYdbDatabaseDedicatedLocationList", jsii.get(self, "location"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="locationId")
    def location_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "locationId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetId")
    def resource_preset_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourcePresetId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="scalePolicy")
    def scale_policy(self) -> "DataYandexYdbDatabaseDedicatedScalePolicyList":
        return typing.cast("DataYandexYdbDatabaseDedicatedScalePolicyList", jsii.get(self, "scalePolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="storageConfig")
    def storage_config(self) -> "DataYandexYdbDatabaseDedicatedStorageConfigList":
        return typing.cast("DataYandexYdbDatabaseDedicatedStorageConfigList", jsii.get(self, "storageConfig"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "subnetIds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tlsEnabled")
    def tls_enabled(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "tlsEnabled"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ydbApiEndpoint")
    def ydb_api_endpoint(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ydbApiEndpoint"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ydbFullEndpoint")
    def ydb_full_endpoint(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ydbFullEndpoint"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databaseIdInput")
    def database_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "databaseIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databaseId")
    def database_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "databaseId"))

    @database_id.setter
    def database_id(self, value: builtins.str) -> None:
        jsii.set(self, "databaseId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexYdbDatabaseDedicatedConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "database_id": "databaseId",
        "folder_id": "folderId",
        "id": "id",
        "name": "name",
    },
)
class DataYandexYdbDatabaseDedicatedConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        database_id: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param database_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/ydb_database_dedicated#database_id DataYandexYdbDatabaseDedicated#database_id}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/ydb_database_dedicated#folder_id DataYandexYdbDatabaseDedicated#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/ydb_database_dedicated#id DataYandexYdbDatabaseDedicated#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/ydb_database_dedicated#name DataYandexYdbDatabaseDedicated#name}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if database_id is not None:
            self._values["database_id"] = database_id
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def database_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/ydb_database_dedicated#database_id DataYandexYdbDatabaseDedicated#database_id}.'''
        result = self._values.get("database_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/ydb_database_dedicated#folder_id DataYandexYdbDatabaseDedicated#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/ydb_database_dedicated#id DataYandexYdbDatabaseDedicated#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/ydb_database_dedicated#name DataYandexYdbDatabaseDedicated#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexYdbDatabaseDedicatedConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexYdbDatabaseDedicatedLocation",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexYdbDatabaseDedicatedLocation:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexYdbDatabaseDedicatedLocation(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexYdbDatabaseDedicatedLocationList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexYdbDatabaseDedicatedLocationList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexYdbDatabaseDedicatedLocationOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexYdbDatabaseDedicatedLocationOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexYdbDatabaseDedicatedLocationOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexYdbDatabaseDedicatedLocationOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="region")
    def region(self) -> "DataYandexYdbDatabaseDedicatedLocationRegionList":
        return typing.cast("DataYandexYdbDatabaseDedicatedLocationRegionList", jsii.get(self, "region"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zone")
    def zone(self) -> "DataYandexYdbDatabaseDedicatedLocationZoneList":
        return typing.cast("DataYandexYdbDatabaseDedicatedLocationZoneList", jsii.get(self, "zone"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataYandexYdbDatabaseDedicatedLocation]:
        return typing.cast(typing.Optional[DataYandexYdbDatabaseDedicatedLocation], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexYdbDatabaseDedicatedLocation],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexYdbDatabaseDedicatedLocationRegion",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexYdbDatabaseDedicatedLocationRegion:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexYdbDatabaseDedicatedLocationRegion(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexYdbDatabaseDedicatedLocationRegionList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexYdbDatabaseDedicatedLocationRegionList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexYdbDatabaseDedicatedLocationRegionOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexYdbDatabaseDedicatedLocationRegionOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexYdbDatabaseDedicatedLocationRegionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexYdbDatabaseDedicatedLocationRegionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexYdbDatabaseDedicatedLocationRegion]:
        return typing.cast(typing.Optional[DataYandexYdbDatabaseDedicatedLocationRegion], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexYdbDatabaseDedicatedLocationRegion],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexYdbDatabaseDedicatedLocationZone",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexYdbDatabaseDedicatedLocationZone:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexYdbDatabaseDedicatedLocationZone(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexYdbDatabaseDedicatedLocationZoneList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexYdbDatabaseDedicatedLocationZoneList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexYdbDatabaseDedicatedLocationZoneOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexYdbDatabaseDedicatedLocationZoneOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexYdbDatabaseDedicatedLocationZoneOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexYdbDatabaseDedicatedLocationZoneOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexYdbDatabaseDedicatedLocationZone]:
        return typing.cast(typing.Optional[DataYandexYdbDatabaseDedicatedLocationZone], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexYdbDatabaseDedicatedLocationZone],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexYdbDatabaseDedicatedScalePolicy",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexYdbDatabaseDedicatedScalePolicy:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexYdbDatabaseDedicatedScalePolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexYdbDatabaseDedicatedScalePolicyFixedScale",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexYdbDatabaseDedicatedScalePolicyFixedScale:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexYdbDatabaseDedicatedScalePolicyFixedScale(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexYdbDatabaseDedicatedScalePolicyFixedScaleList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexYdbDatabaseDedicatedScalePolicyFixedScaleList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexYdbDatabaseDedicatedScalePolicyFixedScaleOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexYdbDatabaseDedicatedScalePolicyFixedScaleOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexYdbDatabaseDedicatedScalePolicyFixedScaleOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexYdbDatabaseDedicatedScalePolicyFixedScaleOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="size")
    def size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "size"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexYdbDatabaseDedicatedScalePolicyFixedScale]:
        return typing.cast(typing.Optional[DataYandexYdbDatabaseDedicatedScalePolicyFixedScale], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexYdbDatabaseDedicatedScalePolicyFixedScale],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexYdbDatabaseDedicatedScalePolicyList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexYdbDatabaseDedicatedScalePolicyList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexYdbDatabaseDedicatedScalePolicyOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexYdbDatabaseDedicatedScalePolicyOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexYdbDatabaseDedicatedScalePolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexYdbDatabaseDedicatedScalePolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fixedScale")
    def fixed_scale(self) -> DataYandexYdbDatabaseDedicatedScalePolicyFixedScaleList:
        return typing.cast(DataYandexYdbDatabaseDedicatedScalePolicyFixedScaleList, jsii.get(self, "fixedScale"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexYdbDatabaseDedicatedScalePolicy]:
        return typing.cast(typing.Optional[DataYandexYdbDatabaseDedicatedScalePolicy], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexYdbDatabaseDedicatedScalePolicy],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexYdbDatabaseDedicatedStorageConfig",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataYandexYdbDatabaseDedicatedStorageConfig:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexYdbDatabaseDedicatedStorageConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataYandexYdbDatabaseDedicatedStorageConfigList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexYdbDatabaseDedicatedStorageConfigList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataYandexYdbDatabaseDedicatedStorageConfigOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataYandexYdbDatabaseDedicatedStorageConfigOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class DataYandexYdbDatabaseDedicatedStorageConfigOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexYdbDatabaseDedicatedStorageConfigOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="groupCount")
    def group_count(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "groupCount"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="storageTypeId")
    def storage_type_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "storageTypeId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataYandexYdbDatabaseDedicatedStorageConfig]:
        return typing.cast(typing.Optional[DataYandexYdbDatabaseDedicatedStorageConfig], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataYandexYdbDatabaseDedicatedStorageConfig],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataYandexYdbDatabaseServerless(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataYandexYdbDatabaseServerless",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/d/ydb_database_serverless yandex_ydb_database_serverless}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        database_id: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/d/ydb_database_serverless yandex_ydb_database_serverless} Data Source.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param database_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/ydb_database_serverless#database_id DataYandexYdbDatabaseServerless#database_id}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/ydb_database_serverless#folder_id DataYandexYdbDatabaseServerless#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/ydb_database_serverless#id DataYandexYdbDatabaseServerless#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/ydb_database_serverless#name DataYandexYdbDatabaseServerless#name}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataYandexYdbDatabaseServerlessConfig(
            database_id=database_id,
            folder_id=folder_id,
            id=id,
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetDatabaseId")
    def reset_database_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDatabaseId", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databasePath")
    def database_path(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "databasePath"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="documentApiEndpoint")
    def document_api_endpoint(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "documentApiEndpoint"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> cdktf.StringMap:
        return typing.cast(cdktf.StringMap, jsii.get(self, "labels"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="locationId")
    def location_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "locationId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tlsEnabled")
    def tls_enabled(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "tlsEnabled"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ydbApiEndpoint")
    def ydb_api_endpoint(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ydbApiEndpoint"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ydbFullEndpoint")
    def ydb_full_endpoint(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ydbFullEndpoint"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databaseIdInput")
    def database_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "databaseIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databaseId")
    def database_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "databaseId"))

    @database_id.setter
    def database_id(self, value: builtins.str) -> None:
        jsii.set(self, "databaseId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataYandexYdbDatabaseServerlessConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "database_id": "databaseId",
        "folder_id": "folderId",
        "id": "id",
        "name": "name",
    },
)
class DataYandexYdbDatabaseServerlessConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        database_id: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param database_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/ydb_database_serverless#database_id DataYandexYdbDatabaseServerless#database_id}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/ydb_database_serverless#folder_id DataYandexYdbDatabaseServerless#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/ydb_database_serverless#id DataYandexYdbDatabaseServerless#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/ydb_database_serverless#name DataYandexYdbDatabaseServerless#name}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if database_id is not None:
            self._values["database_id"] = database_id
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def database_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/ydb_database_serverless#database_id DataYandexYdbDatabaseServerless#database_id}.'''
        result = self._values.get("database_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/ydb_database_serverless#folder_id DataYandexYdbDatabaseServerless#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/ydb_database_serverless#id DataYandexYdbDatabaseServerless#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/d/ydb_database_serverless#name DataYandexYdbDatabaseServerless#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataYandexYdbDatabaseServerlessConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataprocCluster(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataprocCluster",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster yandex_dataproc_cluster}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        cluster_config: "DataprocClusterClusterConfig",
        name: builtins.str,
        service_account_id: builtins.str,
        bucket: typing.Optional[builtins.str] = None,
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        host_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        timeouts: typing.Optional["DataprocClusterTimeouts"] = None,
        ui_proxy: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        zone_id: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster yandex_dataproc_cluster} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param cluster_config: cluster_config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#cluster_config DataprocCluster#cluster_config}
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#name DataprocCluster#name}.
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#service_account_id DataprocCluster#service_account_id}.
        :param bucket: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#bucket DataprocCluster#bucket}.
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#deletion_protection DataprocCluster#deletion_protection}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#description DataprocCluster#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#folder_id DataprocCluster#folder_id}.
        :param host_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#host_group_ids DataprocCluster#host_group_ids}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#id DataprocCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#labels DataprocCluster#labels}.
        :param security_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#security_group_ids DataprocCluster#security_group_ids}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#timeouts DataprocCluster#timeouts}
        :param ui_proxy: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#ui_proxy DataprocCluster#ui_proxy}.
        :param zone_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#zone_id DataprocCluster#zone_id}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DataprocClusterConfig(
            cluster_config=cluster_config,
            name=name,
            service_account_id=service_account_id,
            bucket=bucket,
            deletion_protection=deletion_protection,
            description=description,
            folder_id=folder_id,
            host_group_ids=host_group_ids,
            id=id,
            labels=labels,
            security_group_ids=security_group_ids,
            timeouts=timeouts,
            ui_proxy=ui_proxy,
            zone_id=zone_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putClusterConfig")
    def put_cluster_config(
        self,
        *,
        subcluster_spec: typing.Union[cdktf.IResolvable, typing.Sequence["DataprocClusterClusterConfigSubclusterSpec"]],
        hadoop: typing.Optional["DataprocClusterClusterConfigHadoop"] = None,
        version_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param subcluster_spec: subcluster_spec block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#subcluster_spec DataprocCluster#subcluster_spec}
        :param hadoop: hadoop block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#hadoop DataprocCluster#hadoop}
        :param version_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#version_id DataprocCluster#version_id}.
        '''
        value = DataprocClusterClusterConfig(
            subcluster_spec=subcluster_spec, hadoop=hadoop, version_id=version_id
        )

        return typing.cast(None, jsii.invoke(self, "putClusterConfig", [value]))

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#create DataprocCluster#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#delete DataprocCluster#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#update DataprocCluster#update}.
        '''
        value = DataprocClusterTimeouts(create=create, delete=delete, update=update)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetBucket")
    def reset_bucket(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetBucket", []))

    @jsii.member(jsii_name="resetDeletionProtection")
    def reset_deletion_protection(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDeletionProtection", []))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetHostGroupIds")
    def reset_host_group_ids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHostGroupIds", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetSecurityGroupIds")
    def reset_security_group_ids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityGroupIds", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="resetUiProxy")
    def reset_ui_proxy(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUiProxy", []))

    @jsii.member(jsii_name="resetZoneId")
    def reset_zone_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetZoneId", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterConfig")
    def cluster_config(self) -> "DataprocClusterClusterConfigOutputReference":
        return typing.cast("DataprocClusterClusterConfigOutputReference", jsii.get(self, "clusterConfig"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "DataprocClusterTimeoutsOutputReference":
        return typing.cast("DataprocClusterTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bucketInput")
    def bucket_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "bucketInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterConfigInput")
    def cluster_config_input(self) -> typing.Optional["DataprocClusterClusterConfig"]:
        return typing.cast(typing.Optional["DataprocClusterClusterConfig"], jsii.get(self, "clusterConfigInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtectionInput")
    def deletion_protection_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "deletionProtectionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostGroupIdsInput")
    def host_group_ids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "hostGroupIdsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIdsInput")
    def security_group_ids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "securityGroupIdsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountIdInput")
    def service_account_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceAccountIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "DataprocClusterTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "DataprocClusterTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="uiProxyInput")
    def ui_proxy_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "uiProxyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneIdInput")
    def zone_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "zoneIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bucket")
    def bucket(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "bucket"))

    @bucket.setter
    def bucket(self, value: builtins.str) -> None:
        jsii.set(self, "bucket", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtection")
    def deletion_protection(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "deletionProtection"))

    @deletion_protection.setter
    def deletion_protection(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "deletionProtection", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostGroupIds")
    def host_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "hostGroupIds"))

    @host_group_ids.setter
    def host_group_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "hostGroupIds", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "securityGroupIds"))

    @security_group_ids.setter
    def security_group_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "securityGroupIds", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountId")
    def service_account_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceAccountId"))

    @service_account_id.setter
    def service_account_id(self, value: builtins.str) -> None:
        jsii.set(self, "serviceAccountId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="uiProxy")
    def ui_proxy(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "uiProxy"))

    @ui_proxy.setter
    def ui_proxy(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "uiProxy", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneId")
    def zone_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zoneId"))

    @zone_id.setter
    def zone_id(self, value: builtins.str) -> None:
        jsii.set(self, "zoneId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataprocClusterClusterConfig",
    jsii_struct_bases=[],
    name_mapping={
        "subcluster_spec": "subclusterSpec",
        "hadoop": "hadoop",
        "version_id": "versionId",
    },
)
class DataprocClusterClusterConfig:
    def __init__(
        self,
        *,
        subcluster_spec: typing.Union[cdktf.IResolvable, typing.Sequence["DataprocClusterClusterConfigSubclusterSpec"]],
        hadoop: typing.Optional["DataprocClusterClusterConfigHadoop"] = None,
        version_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param subcluster_spec: subcluster_spec block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#subcluster_spec DataprocCluster#subcluster_spec}
        :param hadoop: hadoop block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#hadoop DataprocCluster#hadoop}
        :param version_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#version_id DataprocCluster#version_id}.
        '''
        if isinstance(hadoop, dict):
            hadoop = DataprocClusterClusterConfigHadoop(**hadoop)
        self._values: typing.Dict[str, typing.Any] = {
            "subcluster_spec": subcluster_spec,
        }
        if hadoop is not None:
            self._values["hadoop"] = hadoop
        if version_id is not None:
            self._values["version_id"] = version_id

    @builtins.property
    def subcluster_spec(
        self,
    ) -> typing.Union[cdktf.IResolvable, typing.List["DataprocClusterClusterConfigSubclusterSpec"]]:
        '''subcluster_spec block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#subcluster_spec DataprocCluster#subcluster_spec}
        '''
        result = self._values.get("subcluster_spec")
        assert result is not None, "Required property 'subcluster_spec' is missing"
        return typing.cast(typing.Union[cdktf.IResolvable, typing.List["DataprocClusterClusterConfigSubclusterSpec"]], result)

    @builtins.property
    def hadoop(self) -> typing.Optional["DataprocClusterClusterConfigHadoop"]:
        '''hadoop block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#hadoop DataprocCluster#hadoop}
        '''
        result = self._values.get("hadoop")
        return typing.cast(typing.Optional["DataprocClusterClusterConfigHadoop"], result)

    @builtins.property
    def version_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#version_id DataprocCluster#version_id}.'''
        result = self._values.get("version_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataprocClusterClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataprocClusterClusterConfigHadoop",
    jsii_struct_bases=[],
    name_mapping={
        "properties": "properties",
        "services": "services",
        "ssh_public_keys": "sshPublicKeys",
    },
)
class DataprocClusterClusterConfigHadoop:
    def __init__(
        self,
        *,
        properties: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        services: typing.Optional[typing.Sequence[builtins.str]] = None,
        ssh_public_keys: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param properties: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#properties DataprocCluster#properties}.
        :param services: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#services DataprocCluster#services}.
        :param ssh_public_keys: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#ssh_public_keys DataprocCluster#ssh_public_keys}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if properties is not None:
            self._values["properties"] = properties
        if services is not None:
            self._values["services"] = services
        if ssh_public_keys is not None:
            self._values["ssh_public_keys"] = ssh_public_keys

    @builtins.property
    def properties(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#properties DataprocCluster#properties}.'''
        result = self._values.get("properties")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def services(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#services DataprocCluster#services}.'''
        result = self._values.get("services")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def ssh_public_keys(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#ssh_public_keys DataprocCluster#ssh_public_keys}.'''
        result = self._values.get("ssh_public_keys")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataprocClusterClusterConfigHadoop(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataprocClusterClusterConfigHadoopOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataprocClusterClusterConfigHadoopOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetProperties")
    def reset_properties(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetProperties", []))

    @jsii.member(jsii_name="resetServices")
    def reset_services(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetServices", []))

    @jsii.member(jsii_name="resetSshPublicKeys")
    def reset_ssh_public_keys(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSshPublicKeys", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="propertiesInput")
    def properties_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "propertiesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="servicesInput")
    def services_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "servicesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sshPublicKeysInput")
    def ssh_public_keys_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "sshPublicKeysInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="properties")
    def properties(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "properties"))

    @properties.setter
    def properties(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "properties", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="services")
    def services(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "services"))

    @services.setter
    def services(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "services", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sshPublicKeys")
    def ssh_public_keys(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "sshPublicKeys"))

    @ssh_public_keys.setter
    def ssh_public_keys(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "sshPublicKeys", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataprocClusterClusterConfigHadoop]:
        return typing.cast(typing.Optional[DataprocClusterClusterConfigHadoop], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataprocClusterClusterConfigHadoop],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataprocClusterClusterConfigOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataprocClusterClusterConfigOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putHadoop")
    def put_hadoop(
        self,
        *,
        properties: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        services: typing.Optional[typing.Sequence[builtins.str]] = None,
        ssh_public_keys: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param properties: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#properties DataprocCluster#properties}.
        :param services: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#services DataprocCluster#services}.
        :param ssh_public_keys: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#ssh_public_keys DataprocCluster#ssh_public_keys}.
        '''
        value = DataprocClusterClusterConfigHadoop(
            properties=properties, services=services, ssh_public_keys=ssh_public_keys
        )

        return typing.cast(None, jsii.invoke(self, "putHadoop", [value]))

    @jsii.member(jsii_name="putSubclusterSpec")
    def put_subcluster_spec(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["DataprocClusterClusterConfigSubclusterSpec"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putSubclusterSpec", [value]))

    @jsii.member(jsii_name="resetHadoop")
    def reset_hadoop(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHadoop", []))

    @jsii.member(jsii_name="resetVersionId")
    def reset_version_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetVersionId", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hadoop")
    def hadoop(self) -> DataprocClusterClusterConfigHadoopOutputReference:
        return typing.cast(DataprocClusterClusterConfigHadoopOutputReference, jsii.get(self, "hadoop"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subclusterSpec")
    def subcluster_spec(self) -> "DataprocClusterClusterConfigSubclusterSpecList":
        return typing.cast("DataprocClusterClusterConfigSubclusterSpecList", jsii.get(self, "subclusterSpec"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hadoopInput")
    def hadoop_input(self) -> typing.Optional[DataprocClusterClusterConfigHadoop]:
        return typing.cast(typing.Optional[DataprocClusterClusterConfigHadoop], jsii.get(self, "hadoopInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subclusterSpecInput")
    def subcluster_spec_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataprocClusterClusterConfigSubclusterSpec"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataprocClusterClusterConfigSubclusterSpec"]]], jsii.get(self, "subclusterSpecInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="versionIdInput")
    def version_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "versionIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="versionId")
    def version_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "versionId"))

    @version_id.setter
    def version_id(self, value: builtins.str) -> None:
        jsii.set(self, "versionId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DataprocClusterClusterConfig]:
        return typing.cast(typing.Optional[DataprocClusterClusterConfig], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataprocClusterClusterConfig],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataprocClusterClusterConfigSubclusterSpec",
    jsii_struct_bases=[],
    name_mapping={
        "hosts_count": "hostsCount",
        "name": "name",
        "resources": "resources",
        "role": "role",
        "subnet_id": "subnetId",
        "assign_public_ip": "assignPublicIp",
        "autoscaling_config": "autoscalingConfig",
    },
)
class DataprocClusterClusterConfigSubclusterSpec:
    def __init__(
        self,
        *,
        hosts_count: jsii.Number,
        name: builtins.str,
        resources: "DataprocClusterClusterConfigSubclusterSpecResources",
        role: builtins.str,
        subnet_id: builtins.str,
        assign_public_ip: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        autoscaling_config: typing.Optional["DataprocClusterClusterConfigSubclusterSpecAutoscalingConfig"] = None,
    ) -> None:
        '''
        :param hosts_count: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#hosts_count DataprocCluster#hosts_count}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#name DataprocCluster#name}.
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#resources DataprocCluster#resources}
        :param role: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#role DataprocCluster#role}.
        :param subnet_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#subnet_id DataprocCluster#subnet_id}.
        :param assign_public_ip: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#assign_public_ip DataprocCluster#assign_public_ip}.
        :param autoscaling_config: autoscaling_config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#autoscaling_config DataprocCluster#autoscaling_config}
        '''
        if isinstance(resources, dict):
            resources = DataprocClusterClusterConfigSubclusterSpecResources(**resources)
        if isinstance(autoscaling_config, dict):
            autoscaling_config = DataprocClusterClusterConfigSubclusterSpecAutoscalingConfig(**autoscaling_config)
        self._values: typing.Dict[str, typing.Any] = {
            "hosts_count": hosts_count,
            "name": name,
            "resources": resources,
            "role": role,
            "subnet_id": subnet_id,
        }
        if assign_public_ip is not None:
            self._values["assign_public_ip"] = assign_public_ip
        if autoscaling_config is not None:
            self._values["autoscaling_config"] = autoscaling_config

    @builtins.property
    def hosts_count(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#hosts_count DataprocCluster#hosts_count}.'''
        result = self._values.get("hosts_count")
        assert result is not None, "Required property 'hosts_count' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#name DataprocCluster#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def resources(self) -> "DataprocClusterClusterConfigSubclusterSpecResources":
        '''resources block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#resources DataprocCluster#resources}
        '''
        result = self._values.get("resources")
        assert result is not None, "Required property 'resources' is missing"
        return typing.cast("DataprocClusterClusterConfigSubclusterSpecResources", result)

    @builtins.property
    def role(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#role DataprocCluster#role}.'''
        result = self._values.get("role")
        assert result is not None, "Required property 'role' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def subnet_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#subnet_id DataprocCluster#subnet_id}.'''
        result = self._values.get("subnet_id")
        assert result is not None, "Required property 'subnet_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def assign_public_ip(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#assign_public_ip DataprocCluster#assign_public_ip}.'''
        result = self._values.get("assign_public_ip")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def autoscaling_config(
        self,
    ) -> typing.Optional["DataprocClusterClusterConfigSubclusterSpecAutoscalingConfig"]:
        '''autoscaling_config block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#autoscaling_config DataprocCluster#autoscaling_config}
        '''
        result = self._values.get("autoscaling_config")
        return typing.cast(typing.Optional["DataprocClusterClusterConfigSubclusterSpecAutoscalingConfig"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataprocClusterClusterConfigSubclusterSpec(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataprocClusterClusterConfigSubclusterSpecAutoscalingConfig",
    jsii_struct_bases=[],
    name_mapping={
        "max_hosts_count": "maxHostsCount",
        "cpu_utilization_target": "cpuUtilizationTarget",
        "decommission_timeout": "decommissionTimeout",
        "measurement_duration": "measurementDuration",
        "preemptible": "preemptible",
        "stabilization_duration": "stabilizationDuration",
        "warmup_duration": "warmupDuration",
    },
)
class DataprocClusterClusterConfigSubclusterSpecAutoscalingConfig:
    def __init__(
        self,
        *,
        max_hosts_count: jsii.Number,
        cpu_utilization_target: typing.Optional[jsii.Number] = None,
        decommission_timeout: typing.Optional[jsii.Number] = None,
        measurement_duration: typing.Optional[jsii.Number] = None,
        preemptible: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        stabilization_duration: typing.Optional[jsii.Number] = None,
        warmup_duration: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param max_hosts_count: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#max_hosts_count DataprocCluster#max_hosts_count}.
        :param cpu_utilization_target: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#cpu_utilization_target DataprocCluster#cpu_utilization_target}.
        :param decommission_timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#decommission_timeout DataprocCluster#decommission_timeout}.
        :param measurement_duration: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#measurement_duration DataprocCluster#measurement_duration}.
        :param preemptible: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#preemptible DataprocCluster#preemptible}.
        :param stabilization_duration: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#stabilization_duration DataprocCluster#stabilization_duration}.
        :param warmup_duration: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#warmup_duration DataprocCluster#warmup_duration}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_hosts_count": max_hosts_count,
        }
        if cpu_utilization_target is not None:
            self._values["cpu_utilization_target"] = cpu_utilization_target
        if decommission_timeout is not None:
            self._values["decommission_timeout"] = decommission_timeout
        if measurement_duration is not None:
            self._values["measurement_duration"] = measurement_duration
        if preemptible is not None:
            self._values["preemptible"] = preemptible
        if stabilization_duration is not None:
            self._values["stabilization_duration"] = stabilization_duration
        if warmup_duration is not None:
            self._values["warmup_duration"] = warmup_duration

    @builtins.property
    def max_hosts_count(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#max_hosts_count DataprocCluster#max_hosts_count}.'''
        result = self._values.get("max_hosts_count")
        assert result is not None, "Required property 'max_hosts_count' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def cpu_utilization_target(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#cpu_utilization_target DataprocCluster#cpu_utilization_target}.'''
        result = self._values.get("cpu_utilization_target")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def decommission_timeout(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#decommission_timeout DataprocCluster#decommission_timeout}.'''
        result = self._values.get("decommission_timeout")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def measurement_duration(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#measurement_duration DataprocCluster#measurement_duration}.'''
        result = self._values.get("measurement_duration")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def preemptible(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#preemptible DataprocCluster#preemptible}.'''
        result = self._values.get("preemptible")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def stabilization_duration(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#stabilization_duration DataprocCluster#stabilization_duration}.'''
        result = self._values.get("stabilization_duration")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def warmup_duration(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#warmup_duration DataprocCluster#warmup_duration}.'''
        result = self._values.get("warmup_duration")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataprocClusterClusterConfigSubclusterSpecAutoscalingConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataprocClusterClusterConfigSubclusterSpecAutoscalingConfigOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataprocClusterClusterConfigSubclusterSpecAutoscalingConfigOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCpuUtilizationTarget")
    def reset_cpu_utilization_target(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCpuUtilizationTarget", []))

    @jsii.member(jsii_name="resetDecommissionTimeout")
    def reset_decommission_timeout(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDecommissionTimeout", []))

    @jsii.member(jsii_name="resetMeasurementDuration")
    def reset_measurement_duration(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMeasurementDuration", []))

    @jsii.member(jsii_name="resetPreemptible")
    def reset_preemptible(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPreemptible", []))

    @jsii.member(jsii_name="resetStabilizationDuration")
    def reset_stabilization_duration(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStabilizationDuration", []))

    @jsii.member(jsii_name="resetWarmupDuration")
    def reset_warmup_duration(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetWarmupDuration", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cpuUtilizationTargetInput")
    def cpu_utilization_target_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "cpuUtilizationTargetInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="decommissionTimeoutInput")
    def decommission_timeout_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "decommissionTimeoutInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxHostsCountInput")
    def max_hosts_count_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxHostsCountInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="measurementDurationInput")
    def measurement_duration_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "measurementDurationInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="preemptibleInput")
    def preemptible_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "preemptibleInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="stabilizationDurationInput")
    def stabilization_duration_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "stabilizationDurationInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="warmupDurationInput")
    def warmup_duration_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "warmupDurationInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cpuUtilizationTarget")
    def cpu_utilization_target(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "cpuUtilizationTarget"))

    @cpu_utilization_target.setter
    def cpu_utilization_target(self, value: jsii.Number) -> None:
        jsii.set(self, "cpuUtilizationTarget", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="decommissionTimeout")
    def decommission_timeout(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "decommissionTimeout"))

    @decommission_timeout.setter
    def decommission_timeout(self, value: jsii.Number) -> None:
        jsii.set(self, "decommissionTimeout", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxHostsCount")
    def max_hosts_count(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxHostsCount"))

    @max_hosts_count.setter
    def max_hosts_count(self, value: jsii.Number) -> None:
        jsii.set(self, "maxHostsCount", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="measurementDuration")
    def measurement_duration(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "measurementDuration"))

    @measurement_duration.setter
    def measurement_duration(self, value: jsii.Number) -> None:
        jsii.set(self, "measurementDuration", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="preemptible")
    def preemptible(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "preemptible"))

    @preemptible.setter
    def preemptible(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "preemptible", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="stabilizationDuration")
    def stabilization_duration(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "stabilizationDuration"))

    @stabilization_duration.setter
    def stabilization_duration(self, value: jsii.Number) -> None:
        jsii.set(self, "stabilizationDuration", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="warmupDuration")
    def warmup_duration(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "warmupDuration"))

    @warmup_duration.setter
    def warmup_duration(self, value: jsii.Number) -> None:
        jsii.set(self, "warmupDuration", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataprocClusterClusterConfigSubclusterSpecAutoscalingConfig]:
        return typing.cast(typing.Optional[DataprocClusterClusterConfigSubclusterSpecAutoscalingConfig], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataprocClusterClusterConfigSubclusterSpecAutoscalingConfig],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataprocClusterClusterConfigSubclusterSpecList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataprocClusterClusterConfigSubclusterSpecList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "DataprocClusterClusterConfigSubclusterSpecOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("DataprocClusterClusterConfigSubclusterSpecOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataprocClusterClusterConfigSubclusterSpec]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataprocClusterClusterConfigSubclusterSpec]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataprocClusterClusterConfigSubclusterSpec]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DataprocClusterClusterConfigSubclusterSpecOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataprocClusterClusterConfigSubclusterSpecOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putAutoscalingConfig")
    def put_autoscaling_config(
        self,
        *,
        max_hosts_count: jsii.Number,
        cpu_utilization_target: typing.Optional[jsii.Number] = None,
        decommission_timeout: typing.Optional[jsii.Number] = None,
        measurement_duration: typing.Optional[jsii.Number] = None,
        preemptible: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        stabilization_duration: typing.Optional[jsii.Number] = None,
        warmup_duration: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param max_hosts_count: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#max_hosts_count DataprocCluster#max_hosts_count}.
        :param cpu_utilization_target: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#cpu_utilization_target DataprocCluster#cpu_utilization_target}.
        :param decommission_timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#decommission_timeout DataprocCluster#decommission_timeout}.
        :param measurement_duration: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#measurement_duration DataprocCluster#measurement_duration}.
        :param preemptible: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#preemptible DataprocCluster#preemptible}.
        :param stabilization_duration: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#stabilization_duration DataprocCluster#stabilization_duration}.
        :param warmup_duration: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#warmup_duration DataprocCluster#warmup_duration}.
        '''
        value = DataprocClusterClusterConfigSubclusterSpecAutoscalingConfig(
            max_hosts_count=max_hosts_count,
            cpu_utilization_target=cpu_utilization_target,
            decommission_timeout=decommission_timeout,
            measurement_duration=measurement_duration,
            preemptible=preemptible,
            stabilization_duration=stabilization_duration,
            warmup_duration=warmup_duration,
        )

        return typing.cast(None, jsii.invoke(self, "putAutoscalingConfig", [value]))

    @jsii.member(jsii_name="putResources")
    def put_resources(
        self,
        *,
        disk_size: jsii.Number,
        resource_preset_id: builtins.str,
        disk_type_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param disk_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#disk_size DataprocCluster#disk_size}.
        :param resource_preset_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#resource_preset_id DataprocCluster#resource_preset_id}.
        :param disk_type_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#disk_type_id DataprocCluster#disk_type_id}.
        '''
        value = DataprocClusterClusterConfigSubclusterSpecResources(
            disk_size=disk_size,
            resource_preset_id=resource_preset_id,
            disk_type_id=disk_type_id,
        )

        return typing.cast(None, jsii.invoke(self, "putResources", [value]))

    @jsii.member(jsii_name="resetAssignPublicIp")
    def reset_assign_public_ip(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAssignPublicIp", []))

    @jsii.member(jsii_name="resetAutoscalingConfig")
    def reset_autoscaling_config(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAutoscalingConfig", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoscalingConfig")
    def autoscaling_config(
        self,
    ) -> DataprocClusterClusterConfigSubclusterSpecAutoscalingConfigOutputReference:
        return typing.cast(DataprocClusterClusterConfigSubclusterSpecAutoscalingConfigOutputReference, jsii.get(self, "autoscalingConfig"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resources")
    def resources(
        self,
    ) -> "DataprocClusterClusterConfigSubclusterSpecResourcesOutputReference":
        return typing.cast("DataprocClusterClusterConfigSubclusterSpecResourcesOutputReference", jsii.get(self, "resources"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIpInput")
    def assign_public_ip_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "assignPublicIpInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoscalingConfigInput")
    def autoscaling_config_input(
        self,
    ) -> typing.Optional[DataprocClusterClusterConfigSubclusterSpecAutoscalingConfig]:
        return typing.cast(typing.Optional[DataprocClusterClusterConfigSubclusterSpecAutoscalingConfig], jsii.get(self, "autoscalingConfigInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostsCountInput")
    def hosts_count_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "hostsCountInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcesInput")
    def resources_input(
        self,
    ) -> typing.Optional["DataprocClusterClusterConfigSubclusterSpecResources"]:
        return typing.cast(typing.Optional["DataprocClusterClusterConfigSubclusterSpecResources"], jsii.get(self, "resourcesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="roleInput")
    def role_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "roleInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIdInput")
    def subnet_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "subnetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIp")
    def assign_public_ip(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "assignPublicIp"))

    @assign_public_ip.setter
    def assign_public_ip(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "assignPublicIp", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostsCount")
    def hosts_count(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "hostsCount"))

    @hosts_count.setter
    def hosts_count(self, value: jsii.Number) -> None:
        jsii.set(self, "hostsCount", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="role")
    def role(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "role"))

    @role.setter
    def role(self, value: builtins.str) -> None:
        jsii.set(self, "role", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @subnet_id.setter
    def subnet_id(self, value: builtins.str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, DataprocClusterClusterConfigSubclusterSpec]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, DataprocClusterClusterConfigSubclusterSpec]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, DataprocClusterClusterConfigSubclusterSpec]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataprocClusterClusterConfigSubclusterSpecResources",
    jsii_struct_bases=[],
    name_mapping={
        "disk_size": "diskSize",
        "resource_preset_id": "resourcePresetId",
        "disk_type_id": "diskTypeId",
    },
)
class DataprocClusterClusterConfigSubclusterSpecResources:
    def __init__(
        self,
        *,
        disk_size: jsii.Number,
        resource_preset_id: builtins.str,
        disk_type_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param disk_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#disk_size DataprocCluster#disk_size}.
        :param resource_preset_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#resource_preset_id DataprocCluster#resource_preset_id}.
        :param disk_type_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#disk_type_id DataprocCluster#disk_type_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "disk_size": disk_size,
            "resource_preset_id": resource_preset_id,
        }
        if disk_type_id is not None:
            self._values["disk_type_id"] = disk_type_id

    @builtins.property
    def disk_size(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#disk_size DataprocCluster#disk_size}.'''
        result = self._values.get("disk_size")
        assert result is not None, "Required property 'disk_size' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def resource_preset_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#resource_preset_id DataprocCluster#resource_preset_id}.'''
        result = self._values.get("resource_preset_id")
        assert result is not None, "Required property 'resource_preset_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def disk_type_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#disk_type_id DataprocCluster#disk_type_id}.'''
        result = self._values.get("disk_type_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataprocClusterClusterConfigSubclusterSpecResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataprocClusterClusterConfigSubclusterSpecResourcesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataprocClusterClusterConfigSubclusterSpecResourcesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetDiskTypeId")
    def reset_disk_type_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDiskTypeId", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSizeInput")
    def disk_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "diskSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeIdInput")
    def disk_type_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "diskTypeIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetIdInput")
    def resource_preset_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourcePresetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSize")
    def disk_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "diskSize"))

    @disk_size.setter
    def disk_size(self, value: jsii.Number) -> None:
        jsii.set(self, "diskSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeId")
    def disk_type_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskTypeId"))

    @disk_type_id.setter
    def disk_type_id(self, value: builtins.str) -> None:
        jsii.set(self, "diskTypeId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetId")
    def resource_preset_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourcePresetId"))

    @resource_preset_id.setter
    def resource_preset_id(self, value: builtins.str) -> None:
        jsii.set(self, "resourcePresetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DataprocClusterClusterConfigSubclusterSpecResources]:
        return typing.cast(typing.Optional[DataprocClusterClusterConfigSubclusterSpecResources], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DataprocClusterClusterConfigSubclusterSpecResources],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataprocClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_config": "clusterConfig",
        "name": "name",
        "service_account_id": "serviceAccountId",
        "bucket": "bucket",
        "deletion_protection": "deletionProtection",
        "description": "description",
        "folder_id": "folderId",
        "host_group_ids": "hostGroupIds",
        "id": "id",
        "labels": "labels",
        "security_group_ids": "securityGroupIds",
        "timeouts": "timeouts",
        "ui_proxy": "uiProxy",
        "zone_id": "zoneId",
    },
)
class DataprocClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_config: DataprocClusterClusterConfig,
        name: builtins.str,
        service_account_id: builtins.str,
        bucket: typing.Optional[builtins.str] = None,
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        host_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        timeouts: typing.Optional["DataprocClusterTimeouts"] = None,
        ui_proxy: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        zone_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_config: cluster_config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#cluster_config DataprocCluster#cluster_config}
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#name DataprocCluster#name}.
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#service_account_id DataprocCluster#service_account_id}.
        :param bucket: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#bucket DataprocCluster#bucket}.
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#deletion_protection DataprocCluster#deletion_protection}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#description DataprocCluster#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#folder_id DataprocCluster#folder_id}.
        :param host_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#host_group_ids DataprocCluster#host_group_ids}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#id DataprocCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#labels DataprocCluster#labels}.
        :param security_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#security_group_ids DataprocCluster#security_group_ids}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#timeouts DataprocCluster#timeouts}
        :param ui_proxy: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#ui_proxy DataprocCluster#ui_proxy}.
        :param zone_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#zone_id DataprocCluster#zone_id}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(cluster_config, dict):
            cluster_config = DataprocClusterClusterConfig(**cluster_config)
        if isinstance(timeouts, dict):
            timeouts = DataprocClusterTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "cluster_config": cluster_config,
            "name": name,
            "service_account_id": service_account_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if bucket is not None:
            self._values["bucket"] = bucket
        if deletion_protection is not None:
            self._values["deletion_protection"] = deletion_protection
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if host_group_ids is not None:
            self._values["host_group_ids"] = host_group_ids
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if security_group_ids is not None:
            self._values["security_group_ids"] = security_group_ids
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if ui_proxy is not None:
            self._values["ui_proxy"] = ui_proxy
        if zone_id is not None:
            self._values["zone_id"] = zone_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def cluster_config(self) -> DataprocClusterClusterConfig:
        '''cluster_config block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#cluster_config DataprocCluster#cluster_config}
        '''
        result = self._values.get("cluster_config")
        assert result is not None, "Required property 'cluster_config' is missing"
        return typing.cast(DataprocClusterClusterConfig, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#name DataprocCluster#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def service_account_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#service_account_id DataprocCluster#service_account_id}.'''
        result = self._values.get("service_account_id")
        assert result is not None, "Required property 'service_account_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def bucket(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#bucket DataprocCluster#bucket}.'''
        result = self._values.get("bucket")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def deletion_protection(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#deletion_protection DataprocCluster#deletion_protection}.'''
        result = self._values.get("deletion_protection")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#description DataprocCluster#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#folder_id DataprocCluster#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def host_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#host_group_ids DataprocCluster#host_group_ids}.'''
        result = self._values.get("host_group_ids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#id DataprocCluster#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#labels DataprocCluster#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def security_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#security_group_ids DataprocCluster#security_group_ids}.'''
        result = self._values.get("security_group_ids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["DataprocClusterTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#timeouts DataprocCluster#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["DataprocClusterTimeouts"], result)

    @builtins.property
    def ui_proxy(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#ui_proxy DataprocCluster#ui_proxy}.'''
        result = self._values.get("ui_proxy")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def zone_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#zone_id DataprocCluster#zone_id}.'''
        result = self._values.get("zone_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataprocClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DataprocClusterTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class DataprocClusterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#create DataprocCluster#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#delete DataprocCluster#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#update DataprocCluster#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#create DataprocCluster#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#delete DataprocCluster#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dataproc_cluster#update DataprocCluster#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataprocClusterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataprocClusterTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DataprocClusterTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, DataprocClusterTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, DataprocClusterTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, DataprocClusterTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DatatransferEndpoint(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DatatransferEndpoint",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint yandex_datatransfer_endpoint}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        settings: typing.Optional["DatatransferEndpointSettings"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint yandex_datatransfer_endpoint} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#description DatatransferEndpoint#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#folder_id DatatransferEndpoint#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#id DatatransferEndpoint#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#labels DatatransferEndpoint#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#name DatatransferEndpoint#name}.
        :param settings: settings block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#settings DatatransferEndpoint#settings}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DatatransferEndpointConfig(
            description=description,
            folder_id=folder_id,
            id=id,
            labels=labels,
            name=name,
            settings=settings,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putSettings")
    def put_settings(
        self,
        *,
        mysql_source: typing.Optional["DatatransferEndpointSettingsMysqlSource"] = None,
        mysql_target: typing.Optional["DatatransferEndpointSettingsMysqlTarget"] = None,
        postgres_source: typing.Optional["DatatransferEndpointSettingsPostgresSource"] = None,
        postgres_target: typing.Optional["DatatransferEndpointSettingsPostgresTarget"] = None,
    ) -> None:
        '''
        :param mysql_source: mysql_source block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#mysql_source DatatransferEndpoint#mysql_source}
        :param mysql_target: mysql_target block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#mysql_target DatatransferEndpoint#mysql_target}
        :param postgres_source: postgres_source block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#postgres_source DatatransferEndpoint#postgres_source}
        :param postgres_target: postgres_target block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#postgres_target DatatransferEndpoint#postgres_target}
        '''
        value = DatatransferEndpointSettings(
            mysql_source=mysql_source,
            mysql_target=mysql_target,
            postgres_source=postgres_source,
            postgres_target=postgres_target,
        )

        return typing.cast(None, jsii.invoke(self, "putSettings", [value]))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetSettings")
    def reset_settings(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSettings", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="author")
    def author(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "author"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="settings")
    def settings(self) -> "DatatransferEndpointSettingsOutputReference":
        return typing.cast("DatatransferEndpointSettingsOutputReference", jsii.get(self, "settings"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="settingsInput")
    def settings_input(self) -> typing.Optional["DatatransferEndpointSettings"]:
        return typing.cast(typing.Optional["DatatransferEndpointSettings"], jsii.get(self, "settingsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "description": "description",
        "folder_id": "folderId",
        "id": "id",
        "labels": "labels",
        "name": "name",
        "settings": "settings",
    },
)
class DatatransferEndpointConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        settings: typing.Optional["DatatransferEndpointSettings"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#description DatatransferEndpoint#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#folder_id DatatransferEndpoint#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#id DatatransferEndpoint#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#labels DatatransferEndpoint#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#name DatatransferEndpoint#name}.
        :param settings: settings block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#settings DatatransferEndpoint#settings}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(settings, dict):
            settings = DatatransferEndpointSettings(**settings)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if name is not None:
            self._values["name"] = name
        if settings is not None:
            self._values["settings"] = settings

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#description DatatransferEndpoint#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#folder_id DatatransferEndpoint#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#id DatatransferEndpoint#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#labels DatatransferEndpoint#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#name DatatransferEndpoint#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def settings(self) -> typing.Optional["DatatransferEndpointSettings"]:
        '''settings block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#settings DatatransferEndpoint#settings}
        '''
        result = self._values.get("settings")
        return typing.cast(typing.Optional["DatatransferEndpointSettings"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatatransferEndpointConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettings",
    jsii_struct_bases=[],
    name_mapping={
        "mysql_source": "mysqlSource",
        "mysql_target": "mysqlTarget",
        "postgres_source": "postgresSource",
        "postgres_target": "postgresTarget",
    },
)
class DatatransferEndpointSettings:
    def __init__(
        self,
        *,
        mysql_source: typing.Optional["DatatransferEndpointSettingsMysqlSource"] = None,
        mysql_target: typing.Optional["DatatransferEndpointSettingsMysqlTarget"] = None,
        postgres_source: typing.Optional["DatatransferEndpointSettingsPostgresSource"] = None,
        postgres_target: typing.Optional["DatatransferEndpointSettingsPostgresTarget"] = None,
    ) -> None:
        '''
        :param mysql_source: mysql_source block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#mysql_source DatatransferEndpoint#mysql_source}
        :param mysql_target: mysql_target block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#mysql_target DatatransferEndpoint#mysql_target}
        :param postgres_source: postgres_source block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#postgres_source DatatransferEndpoint#postgres_source}
        :param postgres_target: postgres_target block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#postgres_target DatatransferEndpoint#postgres_target}
        '''
        if isinstance(mysql_source, dict):
            mysql_source = DatatransferEndpointSettingsMysqlSource(**mysql_source)
        if isinstance(mysql_target, dict):
            mysql_target = DatatransferEndpointSettingsMysqlTarget(**mysql_target)
        if isinstance(postgres_source, dict):
            postgres_source = DatatransferEndpointSettingsPostgresSource(**postgres_source)
        if isinstance(postgres_target, dict):
            postgres_target = DatatransferEndpointSettingsPostgresTarget(**postgres_target)
        self._values: typing.Dict[str, typing.Any] = {}
        if mysql_source is not None:
            self._values["mysql_source"] = mysql_source
        if mysql_target is not None:
            self._values["mysql_target"] = mysql_target
        if postgres_source is not None:
            self._values["postgres_source"] = postgres_source
        if postgres_target is not None:
            self._values["postgres_target"] = postgres_target

    @builtins.property
    def mysql_source(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsMysqlSource"]:
        '''mysql_source block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#mysql_source DatatransferEndpoint#mysql_source}
        '''
        result = self._values.get("mysql_source")
        return typing.cast(typing.Optional["DatatransferEndpointSettingsMysqlSource"], result)

    @builtins.property
    def mysql_target(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsMysqlTarget"]:
        '''mysql_target block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#mysql_target DatatransferEndpoint#mysql_target}
        '''
        result = self._values.get("mysql_target")
        return typing.cast(typing.Optional["DatatransferEndpointSettingsMysqlTarget"], result)

    @builtins.property
    def postgres_source(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsPostgresSource"]:
        '''postgres_source block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#postgres_source DatatransferEndpoint#postgres_source}
        '''
        result = self._values.get("postgres_source")
        return typing.cast(typing.Optional["DatatransferEndpointSettingsPostgresSource"], result)

    @builtins.property
    def postgres_target(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsPostgresTarget"]:
        '''postgres_target block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#postgres_target DatatransferEndpoint#postgres_target}
        '''
        result = self._values.get("postgres_target")
        return typing.cast(typing.Optional["DatatransferEndpointSettingsPostgresTarget"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatatransferEndpointSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsMysqlSource",
    jsii_struct_bases=[],
    name_mapping={
        "connection": "connection",
        "database": "database",
        "exclude_tables_regex": "excludeTablesRegex",
        "include_tables_regex": "includeTablesRegex",
        "object_transfer_settings": "objectTransferSettings",
        "password": "password",
        "timezone": "timezone",
        "user": "user",
    },
)
class DatatransferEndpointSettingsMysqlSource:
    def __init__(
        self,
        *,
        connection: typing.Optional["DatatransferEndpointSettingsMysqlSourceConnection"] = None,
        database: typing.Optional[builtins.str] = None,
        exclude_tables_regex: typing.Optional[typing.Sequence[builtins.str]] = None,
        include_tables_regex: typing.Optional[typing.Sequence[builtins.str]] = None,
        object_transfer_settings: typing.Optional["DatatransferEndpointSettingsMysqlSourceObjectTransferSettings"] = None,
        password: typing.Optional["DatatransferEndpointSettingsMysqlSourcePassword"] = None,
        timezone: typing.Optional[builtins.str] = None,
        user: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param connection: connection block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#connection DatatransferEndpoint#connection}
        :param database: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#database DatatransferEndpoint#database}.
        :param exclude_tables_regex: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#exclude_tables_regex DatatransferEndpoint#exclude_tables_regex}.
        :param include_tables_regex: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#include_tables_regex DatatransferEndpoint#include_tables_regex}.
        :param object_transfer_settings: object_transfer_settings block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#object_transfer_settings DatatransferEndpoint#object_transfer_settings}
        :param password: password block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#password DatatransferEndpoint#password}
        :param timezone: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#timezone DatatransferEndpoint#timezone}.
        :param user: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#user DatatransferEndpoint#user}.
        '''
        if isinstance(connection, dict):
            connection = DatatransferEndpointSettingsMysqlSourceConnection(**connection)
        if isinstance(object_transfer_settings, dict):
            object_transfer_settings = DatatransferEndpointSettingsMysqlSourceObjectTransferSettings(**object_transfer_settings)
        if isinstance(password, dict):
            password = DatatransferEndpointSettingsMysqlSourcePassword(**password)
        self._values: typing.Dict[str, typing.Any] = {}
        if connection is not None:
            self._values["connection"] = connection
        if database is not None:
            self._values["database"] = database
        if exclude_tables_regex is not None:
            self._values["exclude_tables_regex"] = exclude_tables_regex
        if include_tables_regex is not None:
            self._values["include_tables_regex"] = include_tables_regex
        if object_transfer_settings is not None:
            self._values["object_transfer_settings"] = object_transfer_settings
        if password is not None:
            self._values["password"] = password
        if timezone is not None:
            self._values["timezone"] = timezone
        if user is not None:
            self._values["user"] = user

    @builtins.property
    def connection(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsMysqlSourceConnection"]:
        '''connection block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#connection DatatransferEndpoint#connection}
        '''
        result = self._values.get("connection")
        return typing.cast(typing.Optional["DatatransferEndpointSettingsMysqlSourceConnection"], result)

    @builtins.property
    def database(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#database DatatransferEndpoint#database}.'''
        result = self._values.get("database")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def exclude_tables_regex(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#exclude_tables_regex DatatransferEndpoint#exclude_tables_regex}.'''
        result = self._values.get("exclude_tables_regex")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def include_tables_regex(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#include_tables_regex DatatransferEndpoint#include_tables_regex}.'''
        result = self._values.get("include_tables_regex")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def object_transfer_settings(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsMysqlSourceObjectTransferSettings"]:
        '''object_transfer_settings block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#object_transfer_settings DatatransferEndpoint#object_transfer_settings}
        '''
        result = self._values.get("object_transfer_settings")
        return typing.cast(typing.Optional["DatatransferEndpointSettingsMysqlSourceObjectTransferSettings"], result)

    @builtins.property
    def password(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsMysqlSourcePassword"]:
        '''password block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#password DatatransferEndpoint#password}
        '''
        result = self._values.get("password")
        return typing.cast(typing.Optional["DatatransferEndpointSettingsMysqlSourcePassword"], result)

    @builtins.property
    def timezone(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#timezone DatatransferEndpoint#timezone}.'''
        result = self._values.get("timezone")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def user(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#user DatatransferEndpoint#user}.'''
        result = self._values.get("user")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatatransferEndpointSettingsMysqlSource(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsMysqlSourceConnection",
    jsii_struct_bases=[],
    name_mapping={"mdb_cluster_id": "mdbClusterId", "on_premise": "onPremise"},
)
class DatatransferEndpointSettingsMysqlSourceConnection:
    def __init__(
        self,
        *,
        mdb_cluster_id: typing.Optional[builtins.str] = None,
        on_premise: typing.Optional["DatatransferEndpointSettingsMysqlSourceConnectionOnPremise"] = None,
    ) -> None:
        '''
        :param mdb_cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#mdb_cluster_id DatatransferEndpoint#mdb_cluster_id}.
        :param on_premise: on_premise block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#on_premise DatatransferEndpoint#on_premise}
        '''
        if isinstance(on_premise, dict):
            on_premise = DatatransferEndpointSettingsMysqlSourceConnectionOnPremise(**on_premise)
        self._values: typing.Dict[str, typing.Any] = {}
        if mdb_cluster_id is not None:
            self._values["mdb_cluster_id"] = mdb_cluster_id
        if on_premise is not None:
            self._values["on_premise"] = on_premise

    @builtins.property
    def mdb_cluster_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#mdb_cluster_id DatatransferEndpoint#mdb_cluster_id}.'''
        result = self._values.get("mdb_cluster_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def on_premise(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsMysqlSourceConnectionOnPremise"]:
        '''on_premise block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#on_premise DatatransferEndpoint#on_premise}
        '''
        result = self._values.get("on_premise")
        return typing.cast(typing.Optional["DatatransferEndpointSettingsMysqlSourceConnectionOnPremise"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatatransferEndpointSettingsMysqlSourceConnection(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsMysqlSourceConnectionOnPremise",
    jsii_struct_bases=[],
    name_mapping={
        "ca_certificate": "caCertificate",
        "hosts": "hosts",
        "port": "port",
        "subnet_id": "subnetId",
        "tls_mode": "tlsMode",
    },
)
class DatatransferEndpointSettingsMysqlSourceConnectionOnPremise:
    def __init__(
        self,
        *,
        ca_certificate: typing.Optional[builtins.str] = None,
        hosts: typing.Optional[typing.Sequence[builtins.str]] = None,
        port: typing.Optional[jsii.Number] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        tls_mode: typing.Optional["DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsMode"] = None,
    ) -> None:
        '''
        :param ca_certificate: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#ca_certificate DatatransferEndpoint#ca_certificate}.
        :param hosts: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#hosts DatatransferEndpoint#hosts}.
        :param port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#port DatatransferEndpoint#port}.
        :param subnet_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#subnet_id DatatransferEndpoint#subnet_id}.
        :param tls_mode: tls_mode block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#tls_mode DatatransferEndpoint#tls_mode}
        '''
        if isinstance(tls_mode, dict):
            tls_mode = DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsMode(**tls_mode)
        self._values: typing.Dict[str, typing.Any] = {}
        if ca_certificate is not None:
            self._values["ca_certificate"] = ca_certificate
        if hosts is not None:
            self._values["hosts"] = hosts
        if port is not None:
            self._values["port"] = port
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if tls_mode is not None:
            self._values["tls_mode"] = tls_mode

    @builtins.property
    def ca_certificate(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#ca_certificate DatatransferEndpoint#ca_certificate}.'''
        result = self._values.get("ca_certificate")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def hosts(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#hosts DatatransferEndpoint#hosts}.'''
        result = self._values.get("hosts")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#port DatatransferEndpoint#port}.'''
        result = self._values.get("port")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#subnet_id DatatransferEndpoint#subnet_id}.'''
        result = self._values.get("subnet_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def tls_mode(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsMode"]:
        '''tls_mode block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#tls_mode DatatransferEndpoint#tls_mode}
        '''
        result = self._values.get("tls_mode")
        return typing.cast(typing.Optional["DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsMode"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatatransferEndpointSettingsMysqlSourceConnectionOnPremise(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putTlsMode")
    def put_tls_mode(
        self,
        *,
        disabled: typing.Optional["DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeDisabled"] = None,
        enabled: typing.Optional["DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeEnabled"] = None,
    ) -> None:
        '''
        :param disabled: disabled block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#disabled DatatransferEndpoint#disabled}
        :param enabled: enabled block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#enabled DatatransferEndpoint#enabled}
        '''
        value = DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsMode(
            disabled=disabled, enabled=enabled
        )

        return typing.cast(None, jsii.invoke(self, "putTlsMode", [value]))

    @jsii.member(jsii_name="resetCaCertificate")
    def reset_ca_certificate(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCaCertificate", []))

    @jsii.member(jsii_name="resetHosts")
    def reset_hosts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHosts", []))

    @jsii.member(jsii_name="resetPort")
    def reset_port(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPort", []))

    @jsii.member(jsii_name="resetSubnetId")
    def reset_subnet_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSubnetId", []))

    @jsii.member(jsii_name="resetTlsMode")
    def reset_tls_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTlsMode", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tlsMode")
    def tls_mode(
        self,
    ) -> "DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeOutputReference":
        return typing.cast("DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeOutputReference", jsii.get(self, "tlsMode"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="caCertificateInput")
    def ca_certificate_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "caCertificateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostsInput")
    def hosts_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "hostsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="portInput")
    def port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "portInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIdInput")
    def subnet_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "subnetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tlsModeInput")
    def tls_mode_input(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsMode"]:
        return typing.cast(typing.Optional["DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsMode"], jsii.get(self, "tlsModeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="caCertificate")
    def ca_certificate(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "caCertificate"))

    @ca_certificate.setter
    def ca_certificate(self, value: builtins.str) -> None:
        jsii.set(self, "caCertificate", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hosts")
    def hosts(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "hosts"))

    @hosts.setter
    def hosts(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "hosts", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "port"))

    @port.setter
    def port(self, value: jsii.Number) -> None:
        jsii.set(self, "port", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @subnet_id.setter
    def subnet_id(self, value: builtins.str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsMysqlSourceConnectionOnPremise]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsMysqlSourceConnectionOnPremise], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DatatransferEndpointSettingsMysqlSourceConnectionOnPremise],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsMode",
    jsii_struct_bases=[],
    name_mapping={"disabled": "disabled", "enabled": "enabled"},
)
class DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsMode:
    def __init__(
        self,
        *,
        disabled: typing.Optional["DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeDisabled"] = None,
        enabled: typing.Optional["DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeEnabled"] = None,
    ) -> None:
        '''
        :param disabled: disabled block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#disabled DatatransferEndpoint#disabled}
        :param enabled: enabled block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#enabled DatatransferEndpoint#enabled}
        '''
        if isinstance(disabled, dict):
            disabled = DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeDisabled(**disabled)
        if isinstance(enabled, dict):
            enabled = DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeEnabled(**enabled)
        self._values: typing.Dict[str, typing.Any] = {}
        if disabled is not None:
            self._values["disabled"] = disabled
        if enabled is not None:
            self._values["enabled"] = enabled

    @builtins.property
    def disabled(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeDisabled"]:
        '''disabled block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#disabled DatatransferEndpoint#disabled}
        '''
        result = self._values.get("disabled")
        return typing.cast(typing.Optional["DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeDisabled"], result)

    @builtins.property
    def enabled(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeEnabled"]:
        '''enabled block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#enabled DatatransferEndpoint#enabled}
        '''
        result = self._values.get("enabled")
        return typing.cast(typing.Optional["DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeEnabled"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsMode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeDisabled",
    jsii_struct_bases=[],
    name_mapping={},
)
class DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeDisabled:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeDisabled(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeDisabledOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeDisabledOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeDisabled]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeDisabled], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeDisabled],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeEnabled",
    jsii_struct_bases=[],
    name_mapping={"ca_certificate": "caCertificate"},
)
class DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeEnabled:
    def __init__(self, *, ca_certificate: typing.Optional[builtins.str] = None) -> None:
        '''
        :param ca_certificate: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#ca_certificate DatatransferEndpoint#ca_certificate}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if ca_certificate is not None:
            self._values["ca_certificate"] = ca_certificate

    @builtins.property
    def ca_certificate(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#ca_certificate DatatransferEndpoint#ca_certificate}.'''
        result = self._values.get("ca_certificate")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeEnabled(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeEnabledOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeEnabledOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCaCertificate")
    def reset_ca_certificate(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCaCertificate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="caCertificateInput")
    def ca_certificate_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "caCertificateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="caCertificate")
    def ca_certificate(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "caCertificate"))

    @ca_certificate.setter
    def ca_certificate(self, value: builtins.str) -> None:
        jsii.set(self, "caCertificate", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeEnabled]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeEnabled], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeEnabled],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putDisabled")
    def put_disabled(self) -> None:
        value = DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeDisabled()

        return typing.cast(None, jsii.invoke(self, "putDisabled", [value]))

    @jsii.member(jsii_name="putEnabled")
    def put_enabled(
        self,
        *,
        ca_certificate: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param ca_certificate: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#ca_certificate DatatransferEndpoint#ca_certificate}.
        '''
        value = DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeEnabled(
            ca_certificate=ca_certificate
        )

        return typing.cast(None, jsii.invoke(self, "putEnabled", [value]))

    @jsii.member(jsii_name="resetDisabled")
    def reset_disabled(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDisabled", []))

    @jsii.member(jsii_name="resetEnabled")
    def reset_enabled(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEnabled", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="disabled")
    def disabled(
        self,
    ) -> DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeDisabledOutputReference:
        return typing.cast(DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeDisabledOutputReference, jsii.get(self, "disabled"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="enabled")
    def enabled(
        self,
    ) -> DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeEnabledOutputReference:
        return typing.cast(DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeEnabledOutputReference, jsii.get(self, "enabled"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="disabledInput")
    def disabled_input(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeDisabled]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeDisabled], jsii.get(self, "disabledInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="enabledInput")
    def enabled_input(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeEnabled]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeEnabled], jsii.get(self, "enabledInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsMode]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsMode], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsMode],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DatatransferEndpointSettingsMysqlSourceConnectionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsMysqlSourceConnectionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putOnPremise")
    def put_on_premise(
        self,
        *,
        ca_certificate: typing.Optional[builtins.str] = None,
        hosts: typing.Optional[typing.Sequence[builtins.str]] = None,
        port: typing.Optional[jsii.Number] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        tls_mode: typing.Optional[DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsMode] = None,
    ) -> None:
        '''
        :param ca_certificate: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#ca_certificate DatatransferEndpoint#ca_certificate}.
        :param hosts: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#hosts DatatransferEndpoint#hosts}.
        :param port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#port DatatransferEndpoint#port}.
        :param subnet_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#subnet_id DatatransferEndpoint#subnet_id}.
        :param tls_mode: tls_mode block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#tls_mode DatatransferEndpoint#tls_mode}
        '''
        value = DatatransferEndpointSettingsMysqlSourceConnectionOnPremise(
            ca_certificate=ca_certificate,
            hosts=hosts,
            port=port,
            subnet_id=subnet_id,
            tls_mode=tls_mode,
        )

        return typing.cast(None, jsii.invoke(self, "putOnPremise", [value]))

    @jsii.member(jsii_name="resetMdbClusterId")
    def reset_mdb_cluster_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMdbClusterId", []))

    @jsii.member(jsii_name="resetOnPremise")
    def reset_on_premise(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOnPremise", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="onPremise")
    def on_premise(
        self,
    ) -> DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseOutputReference:
        return typing.cast(DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseOutputReference, jsii.get(self, "onPremise"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mdbClusterIdInput")
    def mdb_cluster_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "mdbClusterIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="onPremiseInput")
    def on_premise_input(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsMysqlSourceConnectionOnPremise]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsMysqlSourceConnectionOnPremise], jsii.get(self, "onPremiseInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mdbClusterId")
    def mdb_cluster_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "mdbClusterId"))

    @mdb_cluster_id.setter
    def mdb_cluster_id(self, value: builtins.str) -> None:
        jsii.set(self, "mdbClusterId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsMysqlSourceConnection]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsMysqlSourceConnection], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DatatransferEndpointSettingsMysqlSourceConnection],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsMysqlSourceObjectTransferSettings",
    jsii_struct_bases=[],
    name_mapping={"routine": "routine", "trigger": "trigger", "view": "view"},
)
class DatatransferEndpointSettingsMysqlSourceObjectTransferSettings:
    def __init__(
        self,
        *,
        routine: typing.Optional[builtins.str] = None,
        trigger: typing.Optional[builtins.str] = None,
        view: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param routine: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#routine DatatransferEndpoint#routine}.
        :param trigger: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#trigger DatatransferEndpoint#trigger}.
        :param view: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#view DatatransferEndpoint#view}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if routine is not None:
            self._values["routine"] = routine
        if trigger is not None:
            self._values["trigger"] = trigger
        if view is not None:
            self._values["view"] = view

    @builtins.property
    def routine(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#routine DatatransferEndpoint#routine}.'''
        result = self._values.get("routine")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def trigger(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#trigger DatatransferEndpoint#trigger}.'''
        result = self._values.get("trigger")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def view(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#view DatatransferEndpoint#view}.'''
        result = self._values.get("view")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatatransferEndpointSettingsMysqlSourceObjectTransferSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DatatransferEndpointSettingsMysqlSourceObjectTransferSettingsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsMysqlSourceObjectTransferSettingsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetRoutine")
    def reset_routine(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRoutine", []))

    @jsii.member(jsii_name="resetTrigger")
    def reset_trigger(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTrigger", []))

    @jsii.member(jsii_name="resetView")
    def reset_view(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetView", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="routineInput")
    def routine_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "routineInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="triggerInput")
    def trigger_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "triggerInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="viewInput")
    def view_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "viewInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="routine")
    def routine(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "routine"))

    @routine.setter
    def routine(self, value: builtins.str) -> None:
        jsii.set(self, "routine", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="trigger")
    def trigger(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "trigger"))

    @trigger.setter
    def trigger(self, value: builtins.str) -> None:
        jsii.set(self, "trigger", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="view")
    def view(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "view"))

    @view.setter
    def view(self, value: builtins.str) -> None:
        jsii.set(self, "view", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsMysqlSourceObjectTransferSettings]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsMysqlSourceObjectTransferSettings], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DatatransferEndpointSettingsMysqlSourceObjectTransferSettings],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DatatransferEndpointSettingsMysqlSourceOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsMysqlSourceOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putConnection")
    def put_connection(
        self,
        *,
        mdb_cluster_id: typing.Optional[builtins.str] = None,
        on_premise: typing.Optional[DatatransferEndpointSettingsMysqlSourceConnectionOnPremise] = None,
    ) -> None:
        '''
        :param mdb_cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#mdb_cluster_id DatatransferEndpoint#mdb_cluster_id}.
        :param on_premise: on_premise block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#on_premise DatatransferEndpoint#on_premise}
        '''
        value = DatatransferEndpointSettingsMysqlSourceConnection(
            mdb_cluster_id=mdb_cluster_id, on_premise=on_premise
        )

        return typing.cast(None, jsii.invoke(self, "putConnection", [value]))

    @jsii.member(jsii_name="putObjectTransferSettings")
    def put_object_transfer_settings(
        self,
        *,
        routine: typing.Optional[builtins.str] = None,
        trigger: typing.Optional[builtins.str] = None,
        view: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param routine: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#routine DatatransferEndpoint#routine}.
        :param trigger: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#trigger DatatransferEndpoint#trigger}.
        :param view: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#view DatatransferEndpoint#view}.
        '''
        value = DatatransferEndpointSettingsMysqlSourceObjectTransferSettings(
            routine=routine, trigger=trigger, view=view
        )

        return typing.cast(None, jsii.invoke(self, "putObjectTransferSettings", [value]))

    @jsii.member(jsii_name="putPassword")
    def put_password(self, *, raw: typing.Optional[builtins.str] = None) -> None:
        '''
        :param raw: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#raw DatatransferEndpoint#raw}.
        '''
        value = DatatransferEndpointSettingsMysqlSourcePassword(raw=raw)

        return typing.cast(None, jsii.invoke(self, "putPassword", [value]))

    @jsii.member(jsii_name="resetConnection")
    def reset_connection(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetConnection", []))

    @jsii.member(jsii_name="resetDatabase")
    def reset_database(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDatabase", []))

    @jsii.member(jsii_name="resetExcludeTablesRegex")
    def reset_exclude_tables_regex(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetExcludeTablesRegex", []))

    @jsii.member(jsii_name="resetIncludeTablesRegex")
    def reset_include_tables_regex(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIncludeTablesRegex", []))

    @jsii.member(jsii_name="resetObjectTransferSettings")
    def reset_object_transfer_settings(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetObjectTransferSettings", []))

    @jsii.member(jsii_name="resetPassword")
    def reset_password(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPassword", []))

    @jsii.member(jsii_name="resetTimezone")
    def reset_timezone(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimezone", []))

    @jsii.member(jsii_name="resetUser")
    def reset_user(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUser", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="connection")
    def connection(
        self,
    ) -> DatatransferEndpointSettingsMysqlSourceConnectionOutputReference:
        return typing.cast(DatatransferEndpointSettingsMysqlSourceConnectionOutputReference, jsii.get(self, "connection"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="objectTransferSettings")
    def object_transfer_settings(
        self,
    ) -> DatatransferEndpointSettingsMysqlSourceObjectTransferSettingsOutputReference:
        return typing.cast(DatatransferEndpointSettingsMysqlSourceObjectTransferSettingsOutputReference, jsii.get(self, "objectTransferSettings"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="password")
    def password(
        self,
    ) -> "DatatransferEndpointSettingsMysqlSourcePasswordOutputReference":
        return typing.cast("DatatransferEndpointSettingsMysqlSourcePasswordOutputReference", jsii.get(self, "password"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="connectionInput")
    def connection_input(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsMysqlSourceConnection]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsMysqlSourceConnection], jsii.get(self, "connectionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databaseInput")
    def database_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "databaseInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="excludeTablesRegexInput")
    def exclude_tables_regex_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "excludeTablesRegexInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="includeTablesRegexInput")
    def include_tables_regex_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "includeTablesRegexInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="objectTransferSettingsInput")
    def object_transfer_settings_input(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsMysqlSourceObjectTransferSettings]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsMysqlSourceObjectTransferSettings], jsii.get(self, "objectTransferSettingsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="passwordInput")
    def password_input(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsMysqlSourcePassword"]:
        return typing.cast(typing.Optional["DatatransferEndpointSettingsMysqlSourcePassword"], jsii.get(self, "passwordInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timezoneInput")
    def timezone_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "timezoneInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="userInput")
    def user_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "userInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="database")
    def database(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "database"))

    @database.setter
    def database(self, value: builtins.str) -> None:
        jsii.set(self, "database", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="excludeTablesRegex")
    def exclude_tables_regex(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "excludeTablesRegex"))

    @exclude_tables_regex.setter
    def exclude_tables_regex(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "excludeTablesRegex", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="includeTablesRegex")
    def include_tables_regex(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "includeTablesRegex"))

    @include_tables_regex.setter
    def include_tables_regex(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "includeTablesRegex", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timezone")
    def timezone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "timezone"))

    @timezone.setter
    def timezone(self, value: builtins.str) -> None:
        jsii.set(self, "timezone", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="user")
    def user(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "user"))

    @user.setter
    def user(self, value: builtins.str) -> None:
        jsii.set(self, "user", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsMysqlSource]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsMysqlSource], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DatatransferEndpointSettingsMysqlSource],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsMysqlSourcePassword",
    jsii_struct_bases=[],
    name_mapping={"raw": "raw"},
)
class DatatransferEndpointSettingsMysqlSourcePassword:
    def __init__(self, *, raw: typing.Optional[builtins.str] = None) -> None:
        '''
        :param raw: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#raw DatatransferEndpoint#raw}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if raw is not None:
            self._values["raw"] = raw

    @builtins.property
    def raw(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#raw DatatransferEndpoint#raw}.'''
        result = self._values.get("raw")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatatransferEndpointSettingsMysqlSourcePassword(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DatatransferEndpointSettingsMysqlSourcePasswordOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsMysqlSourcePasswordOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetRaw")
    def reset_raw(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRaw", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="rawInput")
    def raw_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "rawInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="raw")
    def raw(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "raw"))

    @raw.setter
    def raw(self, value: builtins.str) -> None:
        jsii.set(self, "raw", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsMysqlSourcePassword]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsMysqlSourcePassword], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DatatransferEndpointSettingsMysqlSourcePassword],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsMysqlTarget",
    jsii_struct_bases=[],
    name_mapping={
        "connection": "connection",
        "database": "database",
        "password": "password",
        "service_schema": "serviceSchema",
        "skip_constraint_checks": "skipConstraintChecks",
        "sql_mode": "sqlMode",
        "timezone": "timezone",
        "user": "user",
    },
)
class DatatransferEndpointSettingsMysqlTarget:
    def __init__(
        self,
        *,
        connection: typing.Optional["DatatransferEndpointSettingsMysqlTargetConnection"] = None,
        database: typing.Optional[builtins.str] = None,
        password: typing.Optional["DatatransferEndpointSettingsMysqlTargetPassword"] = None,
        service_schema: typing.Optional[builtins.str] = None,
        skip_constraint_checks: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        sql_mode: typing.Optional[builtins.str] = None,
        timezone: typing.Optional[builtins.str] = None,
        user: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param connection: connection block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#connection DatatransferEndpoint#connection}
        :param database: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#database DatatransferEndpoint#database}.
        :param password: password block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#password DatatransferEndpoint#password}
        :param service_schema: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#service_schema DatatransferEndpoint#service_schema}.
        :param skip_constraint_checks: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#skip_constraint_checks DatatransferEndpoint#skip_constraint_checks}.
        :param sql_mode: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#sql_mode DatatransferEndpoint#sql_mode}.
        :param timezone: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#timezone DatatransferEndpoint#timezone}.
        :param user: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#user DatatransferEndpoint#user}.
        '''
        if isinstance(connection, dict):
            connection = DatatransferEndpointSettingsMysqlTargetConnection(**connection)
        if isinstance(password, dict):
            password = DatatransferEndpointSettingsMysqlTargetPassword(**password)
        self._values: typing.Dict[str, typing.Any] = {}
        if connection is not None:
            self._values["connection"] = connection
        if database is not None:
            self._values["database"] = database
        if password is not None:
            self._values["password"] = password
        if service_schema is not None:
            self._values["service_schema"] = service_schema
        if skip_constraint_checks is not None:
            self._values["skip_constraint_checks"] = skip_constraint_checks
        if sql_mode is not None:
            self._values["sql_mode"] = sql_mode
        if timezone is not None:
            self._values["timezone"] = timezone
        if user is not None:
            self._values["user"] = user

    @builtins.property
    def connection(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsMysqlTargetConnection"]:
        '''connection block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#connection DatatransferEndpoint#connection}
        '''
        result = self._values.get("connection")
        return typing.cast(typing.Optional["DatatransferEndpointSettingsMysqlTargetConnection"], result)

    @builtins.property
    def database(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#database DatatransferEndpoint#database}.'''
        result = self._values.get("database")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def password(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsMysqlTargetPassword"]:
        '''password block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#password DatatransferEndpoint#password}
        '''
        result = self._values.get("password")
        return typing.cast(typing.Optional["DatatransferEndpointSettingsMysqlTargetPassword"], result)

    @builtins.property
    def service_schema(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#service_schema DatatransferEndpoint#service_schema}.'''
        result = self._values.get("service_schema")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def skip_constraint_checks(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#skip_constraint_checks DatatransferEndpoint#skip_constraint_checks}.'''
        result = self._values.get("skip_constraint_checks")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def sql_mode(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#sql_mode DatatransferEndpoint#sql_mode}.'''
        result = self._values.get("sql_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timezone(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#timezone DatatransferEndpoint#timezone}.'''
        result = self._values.get("timezone")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def user(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#user DatatransferEndpoint#user}.'''
        result = self._values.get("user")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatatransferEndpointSettingsMysqlTarget(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsMysqlTargetConnection",
    jsii_struct_bases=[],
    name_mapping={"mdb_cluster_id": "mdbClusterId", "on_premise": "onPremise"},
)
class DatatransferEndpointSettingsMysqlTargetConnection:
    def __init__(
        self,
        *,
        mdb_cluster_id: typing.Optional[builtins.str] = None,
        on_premise: typing.Optional["DatatransferEndpointSettingsMysqlTargetConnectionOnPremise"] = None,
    ) -> None:
        '''
        :param mdb_cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#mdb_cluster_id DatatransferEndpoint#mdb_cluster_id}.
        :param on_premise: on_premise block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#on_premise DatatransferEndpoint#on_premise}
        '''
        if isinstance(on_premise, dict):
            on_premise = DatatransferEndpointSettingsMysqlTargetConnectionOnPremise(**on_premise)
        self._values: typing.Dict[str, typing.Any] = {}
        if mdb_cluster_id is not None:
            self._values["mdb_cluster_id"] = mdb_cluster_id
        if on_premise is not None:
            self._values["on_premise"] = on_premise

    @builtins.property
    def mdb_cluster_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#mdb_cluster_id DatatransferEndpoint#mdb_cluster_id}.'''
        result = self._values.get("mdb_cluster_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def on_premise(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsMysqlTargetConnectionOnPremise"]:
        '''on_premise block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#on_premise DatatransferEndpoint#on_premise}
        '''
        result = self._values.get("on_premise")
        return typing.cast(typing.Optional["DatatransferEndpointSettingsMysqlTargetConnectionOnPremise"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatatransferEndpointSettingsMysqlTargetConnection(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsMysqlTargetConnectionOnPremise",
    jsii_struct_bases=[],
    name_mapping={
        "ca_certificate": "caCertificate",
        "hosts": "hosts",
        "port": "port",
        "subnet_id": "subnetId",
        "tls_mode": "tlsMode",
    },
)
class DatatransferEndpointSettingsMysqlTargetConnectionOnPremise:
    def __init__(
        self,
        *,
        ca_certificate: typing.Optional[builtins.str] = None,
        hosts: typing.Optional[typing.Sequence[builtins.str]] = None,
        port: typing.Optional[jsii.Number] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        tls_mode: typing.Optional["DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsMode"] = None,
    ) -> None:
        '''
        :param ca_certificate: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#ca_certificate DatatransferEndpoint#ca_certificate}.
        :param hosts: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#hosts DatatransferEndpoint#hosts}.
        :param port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#port DatatransferEndpoint#port}.
        :param subnet_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#subnet_id DatatransferEndpoint#subnet_id}.
        :param tls_mode: tls_mode block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#tls_mode DatatransferEndpoint#tls_mode}
        '''
        if isinstance(tls_mode, dict):
            tls_mode = DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsMode(**tls_mode)
        self._values: typing.Dict[str, typing.Any] = {}
        if ca_certificate is not None:
            self._values["ca_certificate"] = ca_certificate
        if hosts is not None:
            self._values["hosts"] = hosts
        if port is not None:
            self._values["port"] = port
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if tls_mode is not None:
            self._values["tls_mode"] = tls_mode

    @builtins.property
    def ca_certificate(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#ca_certificate DatatransferEndpoint#ca_certificate}.'''
        result = self._values.get("ca_certificate")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def hosts(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#hosts DatatransferEndpoint#hosts}.'''
        result = self._values.get("hosts")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#port DatatransferEndpoint#port}.'''
        result = self._values.get("port")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#subnet_id DatatransferEndpoint#subnet_id}.'''
        result = self._values.get("subnet_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def tls_mode(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsMode"]:
        '''tls_mode block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#tls_mode DatatransferEndpoint#tls_mode}
        '''
        result = self._values.get("tls_mode")
        return typing.cast(typing.Optional["DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsMode"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatatransferEndpointSettingsMysqlTargetConnectionOnPremise(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putTlsMode")
    def put_tls_mode(
        self,
        *,
        disabled: typing.Optional["DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeDisabled"] = None,
        enabled: typing.Optional["DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeEnabled"] = None,
    ) -> None:
        '''
        :param disabled: disabled block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#disabled DatatransferEndpoint#disabled}
        :param enabled: enabled block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#enabled DatatransferEndpoint#enabled}
        '''
        value = DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsMode(
            disabled=disabled, enabled=enabled
        )

        return typing.cast(None, jsii.invoke(self, "putTlsMode", [value]))

    @jsii.member(jsii_name="resetCaCertificate")
    def reset_ca_certificate(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCaCertificate", []))

    @jsii.member(jsii_name="resetHosts")
    def reset_hosts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHosts", []))

    @jsii.member(jsii_name="resetPort")
    def reset_port(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPort", []))

    @jsii.member(jsii_name="resetSubnetId")
    def reset_subnet_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSubnetId", []))

    @jsii.member(jsii_name="resetTlsMode")
    def reset_tls_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTlsMode", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tlsMode")
    def tls_mode(
        self,
    ) -> "DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeOutputReference":
        return typing.cast("DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeOutputReference", jsii.get(self, "tlsMode"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="caCertificateInput")
    def ca_certificate_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "caCertificateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostsInput")
    def hosts_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "hostsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="portInput")
    def port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "portInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIdInput")
    def subnet_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "subnetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tlsModeInput")
    def tls_mode_input(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsMode"]:
        return typing.cast(typing.Optional["DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsMode"], jsii.get(self, "tlsModeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="caCertificate")
    def ca_certificate(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "caCertificate"))

    @ca_certificate.setter
    def ca_certificate(self, value: builtins.str) -> None:
        jsii.set(self, "caCertificate", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hosts")
    def hosts(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "hosts"))

    @hosts.setter
    def hosts(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "hosts", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "port"))

    @port.setter
    def port(self, value: jsii.Number) -> None:
        jsii.set(self, "port", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @subnet_id.setter
    def subnet_id(self, value: builtins.str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsMysqlTargetConnectionOnPremise]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsMysqlTargetConnectionOnPremise], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DatatransferEndpointSettingsMysqlTargetConnectionOnPremise],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsMode",
    jsii_struct_bases=[],
    name_mapping={"disabled": "disabled", "enabled": "enabled"},
)
class DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsMode:
    def __init__(
        self,
        *,
        disabled: typing.Optional["DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeDisabled"] = None,
        enabled: typing.Optional["DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeEnabled"] = None,
    ) -> None:
        '''
        :param disabled: disabled block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#disabled DatatransferEndpoint#disabled}
        :param enabled: enabled block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#enabled DatatransferEndpoint#enabled}
        '''
        if isinstance(disabled, dict):
            disabled = DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeDisabled(**disabled)
        if isinstance(enabled, dict):
            enabled = DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeEnabled(**enabled)
        self._values: typing.Dict[str, typing.Any] = {}
        if disabled is not None:
            self._values["disabled"] = disabled
        if enabled is not None:
            self._values["enabled"] = enabled

    @builtins.property
    def disabled(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeDisabled"]:
        '''disabled block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#disabled DatatransferEndpoint#disabled}
        '''
        result = self._values.get("disabled")
        return typing.cast(typing.Optional["DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeDisabled"], result)

    @builtins.property
    def enabled(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeEnabled"]:
        '''enabled block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#enabled DatatransferEndpoint#enabled}
        '''
        result = self._values.get("enabled")
        return typing.cast(typing.Optional["DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeEnabled"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsMode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeDisabled",
    jsii_struct_bases=[],
    name_mapping={},
)
class DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeDisabled:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeDisabled(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeDisabledOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeDisabledOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeDisabled]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeDisabled], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeDisabled],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeEnabled",
    jsii_struct_bases=[],
    name_mapping={"ca_certificate": "caCertificate"},
)
class DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeEnabled:
    def __init__(self, *, ca_certificate: typing.Optional[builtins.str] = None) -> None:
        '''
        :param ca_certificate: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#ca_certificate DatatransferEndpoint#ca_certificate}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if ca_certificate is not None:
            self._values["ca_certificate"] = ca_certificate

    @builtins.property
    def ca_certificate(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#ca_certificate DatatransferEndpoint#ca_certificate}.'''
        result = self._values.get("ca_certificate")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeEnabled(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeEnabledOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeEnabledOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCaCertificate")
    def reset_ca_certificate(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCaCertificate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="caCertificateInput")
    def ca_certificate_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "caCertificateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="caCertificate")
    def ca_certificate(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "caCertificate"))

    @ca_certificate.setter
    def ca_certificate(self, value: builtins.str) -> None:
        jsii.set(self, "caCertificate", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeEnabled]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeEnabled], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeEnabled],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putDisabled")
    def put_disabled(self) -> None:
        value = DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeDisabled()

        return typing.cast(None, jsii.invoke(self, "putDisabled", [value]))

    @jsii.member(jsii_name="putEnabled")
    def put_enabled(
        self,
        *,
        ca_certificate: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param ca_certificate: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#ca_certificate DatatransferEndpoint#ca_certificate}.
        '''
        value = DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeEnabled(
            ca_certificate=ca_certificate
        )

        return typing.cast(None, jsii.invoke(self, "putEnabled", [value]))

    @jsii.member(jsii_name="resetDisabled")
    def reset_disabled(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDisabled", []))

    @jsii.member(jsii_name="resetEnabled")
    def reset_enabled(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEnabled", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="disabled")
    def disabled(
        self,
    ) -> DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeDisabledOutputReference:
        return typing.cast(DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeDisabledOutputReference, jsii.get(self, "disabled"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="enabled")
    def enabled(
        self,
    ) -> DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeEnabledOutputReference:
        return typing.cast(DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeEnabledOutputReference, jsii.get(self, "enabled"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="disabledInput")
    def disabled_input(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeDisabled]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeDisabled], jsii.get(self, "disabledInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="enabledInput")
    def enabled_input(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeEnabled]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeEnabled], jsii.get(self, "enabledInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsMode]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsMode], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsMode],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DatatransferEndpointSettingsMysqlTargetConnectionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsMysqlTargetConnectionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putOnPremise")
    def put_on_premise(
        self,
        *,
        ca_certificate: typing.Optional[builtins.str] = None,
        hosts: typing.Optional[typing.Sequence[builtins.str]] = None,
        port: typing.Optional[jsii.Number] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        tls_mode: typing.Optional[DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsMode] = None,
    ) -> None:
        '''
        :param ca_certificate: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#ca_certificate DatatransferEndpoint#ca_certificate}.
        :param hosts: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#hosts DatatransferEndpoint#hosts}.
        :param port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#port DatatransferEndpoint#port}.
        :param subnet_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#subnet_id DatatransferEndpoint#subnet_id}.
        :param tls_mode: tls_mode block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#tls_mode DatatransferEndpoint#tls_mode}
        '''
        value = DatatransferEndpointSettingsMysqlTargetConnectionOnPremise(
            ca_certificate=ca_certificate,
            hosts=hosts,
            port=port,
            subnet_id=subnet_id,
            tls_mode=tls_mode,
        )

        return typing.cast(None, jsii.invoke(self, "putOnPremise", [value]))

    @jsii.member(jsii_name="resetMdbClusterId")
    def reset_mdb_cluster_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMdbClusterId", []))

    @jsii.member(jsii_name="resetOnPremise")
    def reset_on_premise(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOnPremise", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="onPremise")
    def on_premise(
        self,
    ) -> DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseOutputReference:
        return typing.cast(DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseOutputReference, jsii.get(self, "onPremise"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mdbClusterIdInput")
    def mdb_cluster_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "mdbClusterIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="onPremiseInput")
    def on_premise_input(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsMysqlTargetConnectionOnPremise]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsMysqlTargetConnectionOnPremise], jsii.get(self, "onPremiseInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mdbClusterId")
    def mdb_cluster_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "mdbClusterId"))

    @mdb_cluster_id.setter
    def mdb_cluster_id(self, value: builtins.str) -> None:
        jsii.set(self, "mdbClusterId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsMysqlTargetConnection]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsMysqlTargetConnection], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DatatransferEndpointSettingsMysqlTargetConnection],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DatatransferEndpointSettingsMysqlTargetOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsMysqlTargetOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putConnection")
    def put_connection(
        self,
        *,
        mdb_cluster_id: typing.Optional[builtins.str] = None,
        on_premise: typing.Optional[DatatransferEndpointSettingsMysqlTargetConnectionOnPremise] = None,
    ) -> None:
        '''
        :param mdb_cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#mdb_cluster_id DatatransferEndpoint#mdb_cluster_id}.
        :param on_premise: on_premise block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#on_premise DatatransferEndpoint#on_premise}
        '''
        value = DatatransferEndpointSettingsMysqlTargetConnection(
            mdb_cluster_id=mdb_cluster_id, on_premise=on_premise
        )

        return typing.cast(None, jsii.invoke(self, "putConnection", [value]))

    @jsii.member(jsii_name="putPassword")
    def put_password(self, *, raw: typing.Optional[builtins.str] = None) -> None:
        '''
        :param raw: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#raw DatatransferEndpoint#raw}.
        '''
        value = DatatransferEndpointSettingsMysqlTargetPassword(raw=raw)

        return typing.cast(None, jsii.invoke(self, "putPassword", [value]))

    @jsii.member(jsii_name="resetConnection")
    def reset_connection(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetConnection", []))

    @jsii.member(jsii_name="resetDatabase")
    def reset_database(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDatabase", []))

    @jsii.member(jsii_name="resetPassword")
    def reset_password(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPassword", []))

    @jsii.member(jsii_name="resetServiceSchema")
    def reset_service_schema(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetServiceSchema", []))

    @jsii.member(jsii_name="resetSkipConstraintChecks")
    def reset_skip_constraint_checks(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSkipConstraintChecks", []))

    @jsii.member(jsii_name="resetSqlMode")
    def reset_sql_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSqlMode", []))

    @jsii.member(jsii_name="resetTimezone")
    def reset_timezone(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimezone", []))

    @jsii.member(jsii_name="resetUser")
    def reset_user(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUser", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="connection")
    def connection(
        self,
    ) -> DatatransferEndpointSettingsMysqlTargetConnectionOutputReference:
        return typing.cast(DatatransferEndpointSettingsMysqlTargetConnectionOutputReference, jsii.get(self, "connection"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="password")
    def password(
        self,
    ) -> "DatatransferEndpointSettingsMysqlTargetPasswordOutputReference":
        return typing.cast("DatatransferEndpointSettingsMysqlTargetPasswordOutputReference", jsii.get(self, "password"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="connectionInput")
    def connection_input(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsMysqlTargetConnection]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsMysqlTargetConnection], jsii.get(self, "connectionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databaseInput")
    def database_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "databaseInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="passwordInput")
    def password_input(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsMysqlTargetPassword"]:
        return typing.cast(typing.Optional["DatatransferEndpointSettingsMysqlTargetPassword"], jsii.get(self, "passwordInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceSchemaInput")
    def service_schema_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceSchemaInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="skipConstraintChecksInput")
    def skip_constraint_checks_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "skipConstraintChecksInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sqlModeInput")
    def sql_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sqlModeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timezoneInput")
    def timezone_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "timezoneInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="userInput")
    def user_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "userInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="database")
    def database(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "database"))

    @database.setter
    def database(self, value: builtins.str) -> None:
        jsii.set(self, "database", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceSchema")
    def service_schema(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceSchema"))

    @service_schema.setter
    def service_schema(self, value: builtins.str) -> None:
        jsii.set(self, "serviceSchema", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="skipConstraintChecks")
    def skip_constraint_checks(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "skipConstraintChecks"))

    @skip_constraint_checks.setter
    def skip_constraint_checks(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "skipConstraintChecks", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sqlMode")
    def sql_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sqlMode"))

    @sql_mode.setter
    def sql_mode(self, value: builtins.str) -> None:
        jsii.set(self, "sqlMode", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timezone")
    def timezone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "timezone"))

    @timezone.setter
    def timezone(self, value: builtins.str) -> None:
        jsii.set(self, "timezone", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="user")
    def user(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "user"))

    @user.setter
    def user(self, value: builtins.str) -> None:
        jsii.set(self, "user", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsMysqlTarget]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsMysqlTarget], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DatatransferEndpointSettingsMysqlTarget],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsMysqlTargetPassword",
    jsii_struct_bases=[],
    name_mapping={"raw": "raw"},
)
class DatatransferEndpointSettingsMysqlTargetPassword:
    def __init__(self, *, raw: typing.Optional[builtins.str] = None) -> None:
        '''
        :param raw: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#raw DatatransferEndpoint#raw}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if raw is not None:
            self._values["raw"] = raw

    @builtins.property
    def raw(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#raw DatatransferEndpoint#raw}.'''
        result = self._values.get("raw")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatatransferEndpointSettingsMysqlTargetPassword(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DatatransferEndpointSettingsMysqlTargetPasswordOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsMysqlTargetPasswordOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetRaw")
    def reset_raw(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRaw", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="rawInput")
    def raw_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "rawInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="raw")
    def raw(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "raw"))

    @raw.setter
    def raw(self, value: builtins.str) -> None:
        jsii.set(self, "raw", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsMysqlTargetPassword]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsMysqlTargetPassword], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DatatransferEndpointSettingsMysqlTargetPassword],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DatatransferEndpointSettingsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putMysqlSource")
    def put_mysql_source(
        self,
        *,
        connection: typing.Optional[DatatransferEndpointSettingsMysqlSourceConnection] = None,
        database: typing.Optional[builtins.str] = None,
        exclude_tables_regex: typing.Optional[typing.Sequence[builtins.str]] = None,
        include_tables_regex: typing.Optional[typing.Sequence[builtins.str]] = None,
        object_transfer_settings: typing.Optional[DatatransferEndpointSettingsMysqlSourceObjectTransferSettings] = None,
        password: typing.Optional[DatatransferEndpointSettingsMysqlSourcePassword] = None,
        timezone: typing.Optional[builtins.str] = None,
        user: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param connection: connection block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#connection DatatransferEndpoint#connection}
        :param database: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#database DatatransferEndpoint#database}.
        :param exclude_tables_regex: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#exclude_tables_regex DatatransferEndpoint#exclude_tables_regex}.
        :param include_tables_regex: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#include_tables_regex DatatransferEndpoint#include_tables_regex}.
        :param object_transfer_settings: object_transfer_settings block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#object_transfer_settings DatatransferEndpoint#object_transfer_settings}
        :param password: password block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#password DatatransferEndpoint#password}
        :param timezone: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#timezone DatatransferEndpoint#timezone}.
        :param user: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#user DatatransferEndpoint#user}.
        '''
        value = DatatransferEndpointSettingsMysqlSource(
            connection=connection,
            database=database,
            exclude_tables_regex=exclude_tables_regex,
            include_tables_regex=include_tables_regex,
            object_transfer_settings=object_transfer_settings,
            password=password,
            timezone=timezone,
            user=user,
        )

        return typing.cast(None, jsii.invoke(self, "putMysqlSource", [value]))

    @jsii.member(jsii_name="putMysqlTarget")
    def put_mysql_target(
        self,
        *,
        connection: typing.Optional[DatatransferEndpointSettingsMysqlTargetConnection] = None,
        database: typing.Optional[builtins.str] = None,
        password: typing.Optional[DatatransferEndpointSettingsMysqlTargetPassword] = None,
        service_schema: typing.Optional[builtins.str] = None,
        skip_constraint_checks: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        sql_mode: typing.Optional[builtins.str] = None,
        timezone: typing.Optional[builtins.str] = None,
        user: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param connection: connection block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#connection DatatransferEndpoint#connection}
        :param database: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#database DatatransferEndpoint#database}.
        :param password: password block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#password DatatransferEndpoint#password}
        :param service_schema: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#service_schema DatatransferEndpoint#service_schema}.
        :param skip_constraint_checks: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#skip_constraint_checks DatatransferEndpoint#skip_constraint_checks}.
        :param sql_mode: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#sql_mode DatatransferEndpoint#sql_mode}.
        :param timezone: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#timezone DatatransferEndpoint#timezone}.
        :param user: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#user DatatransferEndpoint#user}.
        '''
        value = DatatransferEndpointSettingsMysqlTarget(
            connection=connection,
            database=database,
            password=password,
            service_schema=service_schema,
            skip_constraint_checks=skip_constraint_checks,
            sql_mode=sql_mode,
            timezone=timezone,
            user=user,
        )

        return typing.cast(None, jsii.invoke(self, "putMysqlTarget", [value]))

    @jsii.member(jsii_name="putPostgresSource")
    def put_postgres_source(
        self,
        *,
        collapse_inherit_table: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        connection: typing.Optional["DatatransferEndpointSettingsPostgresSourceConnection"] = None,
        database: typing.Optional[builtins.str] = None,
        exclude_tables: typing.Optional[typing.Sequence[builtins.str]] = None,
        include_tables: typing.Optional[typing.Sequence[builtins.str]] = None,
        object_transfer_settings: typing.Optional["DatatransferEndpointSettingsPostgresSourceObjectTransferSettings"] = None,
        password: typing.Optional["DatatransferEndpointSettingsPostgresSourcePassword"] = None,
        service_schema: typing.Optional[builtins.str] = None,
        slot_gigabyte_lag_limit: typing.Optional[jsii.Number] = None,
        user: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param collapse_inherit_table: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#collapse_inherit_table DatatransferEndpoint#collapse_inherit_table}.
        :param connection: connection block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#connection DatatransferEndpoint#connection}
        :param database: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#database DatatransferEndpoint#database}.
        :param exclude_tables: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#exclude_tables DatatransferEndpoint#exclude_tables}.
        :param include_tables: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#include_tables DatatransferEndpoint#include_tables}.
        :param object_transfer_settings: object_transfer_settings block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#object_transfer_settings DatatransferEndpoint#object_transfer_settings}
        :param password: password block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#password DatatransferEndpoint#password}
        :param service_schema: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#service_schema DatatransferEndpoint#service_schema}.
        :param slot_gigabyte_lag_limit: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#slot_gigabyte_lag_limit DatatransferEndpoint#slot_gigabyte_lag_limit}.
        :param user: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#user DatatransferEndpoint#user}.
        '''
        value = DatatransferEndpointSettingsPostgresSource(
            collapse_inherit_table=collapse_inherit_table,
            connection=connection,
            database=database,
            exclude_tables=exclude_tables,
            include_tables=include_tables,
            object_transfer_settings=object_transfer_settings,
            password=password,
            service_schema=service_schema,
            slot_gigabyte_lag_limit=slot_gigabyte_lag_limit,
            user=user,
        )

        return typing.cast(None, jsii.invoke(self, "putPostgresSource", [value]))

    @jsii.member(jsii_name="putPostgresTarget")
    def put_postgres_target(
        self,
        *,
        connection: typing.Optional["DatatransferEndpointSettingsPostgresTargetConnection"] = None,
        database: typing.Optional[builtins.str] = None,
        password: typing.Optional["DatatransferEndpointSettingsPostgresTargetPassword"] = None,
        user: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param connection: connection block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#connection DatatransferEndpoint#connection}
        :param database: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#database DatatransferEndpoint#database}.
        :param password: password block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#password DatatransferEndpoint#password}
        :param user: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#user DatatransferEndpoint#user}.
        '''
        value = DatatransferEndpointSettingsPostgresTarget(
            connection=connection, database=database, password=password, user=user
        )

        return typing.cast(None, jsii.invoke(self, "putPostgresTarget", [value]))

    @jsii.member(jsii_name="resetMysqlSource")
    def reset_mysql_source(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMysqlSource", []))

    @jsii.member(jsii_name="resetMysqlTarget")
    def reset_mysql_target(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMysqlTarget", []))

    @jsii.member(jsii_name="resetPostgresSource")
    def reset_postgres_source(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPostgresSource", []))

    @jsii.member(jsii_name="resetPostgresTarget")
    def reset_postgres_target(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPostgresTarget", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mysqlSource")
    def mysql_source(self) -> DatatransferEndpointSettingsMysqlSourceOutputReference:
        return typing.cast(DatatransferEndpointSettingsMysqlSourceOutputReference, jsii.get(self, "mysqlSource"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mysqlTarget")
    def mysql_target(self) -> DatatransferEndpointSettingsMysqlTargetOutputReference:
        return typing.cast(DatatransferEndpointSettingsMysqlTargetOutputReference, jsii.get(self, "mysqlTarget"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="postgresSource")
    def postgres_source(
        self,
    ) -> "DatatransferEndpointSettingsPostgresSourceOutputReference":
        return typing.cast("DatatransferEndpointSettingsPostgresSourceOutputReference", jsii.get(self, "postgresSource"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="postgresTarget")
    def postgres_target(
        self,
    ) -> "DatatransferEndpointSettingsPostgresTargetOutputReference":
        return typing.cast("DatatransferEndpointSettingsPostgresTargetOutputReference", jsii.get(self, "postgresTarget"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mysqlSourceInput")
    def mysql_source_input(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsMysqlSource]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsMysqlSource], jsii.get(self, "mysqlSourceInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mysqlTargetInput")
    def mysql_target_input(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsMysqlTarget]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsMysqlTarget], jsii.get(self, "mysqlTargetInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="postgresSourceInput")
    def postgres_source_input(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsPostgresSource"]:
        return typing.cast(typing.Optional["DatatransferEndpointSettingsPostgresSource"], jsii.get(self, "postgresSourceInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="postgresTargetInput")
    def postgres_target_input(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsPostgresTarget"]:
        return typing.cast(typing.Optional["DatatransferEndpointSettingsPostgresTarget"], jsii.get(self, "postgresTargetInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[DatatransferEndpointSettings]:
        return typing.cast(typing.Optional[DatatransferEndpointSettings], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DatatransferEndpointSettings],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsPostgresSource",
    jsii_struct_bases=[],
    name_mapping={
        "collapse_inherit_table": "collapseInheritTable",
        "connection": "connection",
        "database": "database",
        "exclude_tables": "excludeTables",
        "include_tables": "includeTables",
        "object_transfer_settings": "objectTransferSettings",
        "password": "password",
        "service_schema": "serviceSchema",
        "slot_gigabyte_lag_limit": "slotGigabyteLagLimit",
        "user": "user",
    },
)
class DatatransferEndpointSettingsPostgresSource:
    def __init__(
        self,
        *,
        collapse_inherit_table: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        connection: typing.Optional["DatatransferEndpointSettingsPostgresSourceConnection"] = None,
        database: typing.Optional[builtins.str] = None,
        exclude_tables: typing.Optional[typing.Sequence[builtins.str]] = None,
        include_tables: typing.Optional[typing.Sequence[builtins.str]] = None,
        object_transfer_settings: typing.Optional["DatatransferEndpointSettingsPostgresSourceObjectTransferSettings"] = None,
        password: typing.Optional["DatatransferEndpointSettingsPostgresSourcePassword"] = None,
        service_schema: typing.Optional[builtins.str] = None,
        slot_gigabyte_lag_limit: typing.Optional[jsii.Number] = None,
        user: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param collapse_inherit_table: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#collapse_inherit_table DatatransferEndpoint#collapse_inherit_table}.
        :param connection: connection block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#connection DatatransferEndpoint#connection}
        :param database: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#database DatatransferEndpoint#database}.
        :param exclude_tables: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#exclude_tables DatatransferEndpoint#exclude_tables}.
        :param include_tables: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#include_tables DatatransferEndpoint#include_tables}.
        :param object_transfer_settings: object_transfer_settings block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#object_transfer_settings DatatransferEndpoint#object_transfer_settings}
        :param password: password block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#password DatatransferEndpoint#password}
        :param service_schema: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#service_schema DatatransferEndpoint#service_schema}.
        :param slot_gigabyte_lag_limit: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#slot_gigabyte_lag_limit DatatransferEndpoint#slot_gigabyte_lag_limit}.
        :param user: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#user DatatransferEndpoint#user}.
        '''
        if isinstance(connection, dict):
            connection = DatatransferEndpointSettingsPostgresSourceConnection(**connection)
        if isinstance(object_transfer_settings, dict):
            object_transfer_settings = DatatransferEndpointSettingsPostgresSourceObjectTransferSettings(**object_transfer_settings)
        if isinstance(password, dict):
            password = DatatransferEndpointSettingsPostgresSourcePassword(**password)
        self._values: typing.Dict[str, typing.Any] = {}
        if collapse_inherit_table is not None:
            self._values["collapse_inherit_table"] = collapse_inherit_table
        if connection is not None:
            self._values["connection"] = connection
        if database is not None:
            self._values["database"] = database
        if exclude_tables is not None:
            self._values["exclude_tables"] = exclude_tables
        if include_tables is not None:
            self._values["include_tables"] = include_tables
        if object_transfer_settings is not None:
            self._values["object_transfer_settings"] = object_transfer_settings
        if password is not None:
            self._values["password"] = password
        if service_schema is not None:
            self._values["service_schema"] = service_schema
        if slot_gigabyte_lag_limit is not None:
            self._values["slot_gigabyte_lag_limit"] = slot_gigabyte_lag_limit
        if user is not None:
            self._values["user"] = user

    @builtins.property
    def collapse_inherit_table(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#collapse_inherit_table DatatransferEndpoint#collapse_inherit_table}.'''
        result = self._values.get("collapse_inherit_table")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def connection(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsPostgresSourceConnection"]:
        '''connection block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#connection DatatransferEndpoint#connection}
        '''
        result = self._values.get("connection")
        return typing.cast(typing.Optional["DatatransferEndpointSettingsPostgresSourceConnection"], result)

    @builtins.property
    def database(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#database DatatransferEndpoint#database}.'''
        result = self._values.get("database")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def exclude_tables(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#exclude_tables DatatransferEndpoint#exclude_tables}.'''
        result = self._values.get("exclude_tables")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def include_tables(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#include_tables DatatransferEndpoint#include_tables}.'''
        result = self._values.get("include_tables")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def object_transfer_settings(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsPostgresSourceObjectTransferSettings"]:
        '''object_transfer_settings block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#object_transfer_settings DatatransferEndpoint#object_transfer_settings}
        '''
        result = self._values.get("object_transfer_settings")
        return typing.cast(typing.Optional["DatatransferEndpointSettingsPostgresSourceObjectTransferSettings"], result)

    @builtins.property
    def password(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsPostgresSourcePassword"]:
        '''password block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#password DatatransferEndpoint#password}
        '''
        result = self._values.get("password")
        return typing.cast(typing.Optional["DatatransferEndpointSettingsPostgresSourcePassword"], result)

    @builtins.property
    def service_schema(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#service_schema DatatransferEndpoint#service_schema}.'''
        result = self._values.get("service_schema")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def slot_gigabyte_lag_limit(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#slot_gigabyte_lag_limit DatatransferEndpoint#slot_gigabyte_lag_limit}.'''
        result = self._values.get("slot_gigabyte_lag_limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def user(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#user DatatransferEndpoint#user}.'''
        result = self._values.get("user")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatatransferEndpointSettingsPostgresSource(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsPostgresSourceConnection",
    jsii_struct_bases=[],
    name_mapping={"mdb_cluster_id": "mdbClusterId", "on_premise": "onPremise"},
)
class DatatransferEndpointSettingsPostgresSourceConnection:
    def __init__(
        self,
        *,
        mdb_cluster_id: typing.Optional[builtins.str] = None,
        on_premise: typing.Optional["DatatransferEndpointSettingsPostgresSourceConnectionOnPremise"] = None,
    ) -> None:
        '''
        :param mdb_cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#mdb_cluster_id DatatransferEndpoint#mdb_cluster_id}.
        :param on_premise: on_premise block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#on_premise DatatransferEndpoint#on_premise}
        '''
        if isinstance(on_premise, dict):
            on_premise = DatatransferEndpointSettingsPostgresSourceConnectionOnPremise(**on_premise)
        self._values: typing.Dict[str, typing.Any] = {}
        if mdb_cluster_id is not None:
            self._values["mdb_cluster_id"] = mdb_cluster_id
        if on_premise is not None:
            self._values["on_premise"] = on_premise

    @builtins.property
    def mdb_cluster_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#mdb_cluster_id DatatransferEndpoint#mdb_cluster_id}.'''
        result = self._values.get("mdb_cluster_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def on_premise(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsPostgresSourceConnectionOnPremise"]:
        '''on_premise block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#on_premise DatatransferEndpoint#on_premise}
        '''
        result = self._values.get("on_premise")
        return typing.cast(typing.Optional["DatatransferEndpointSettingsPostgresSourceConnectionOnPremise"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatatransferEndpointSettingsPostgresSourceConnection(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsPostgresSourceConnectionOnPremise",
    jsii_struct_bases=[],
    name_mapping={
        "ca_certificate": "caCertificate",
        "hosts": "hosts",
        "port": "port",
        "subnet_id": "subnetId",
        "tls_mode": "tlsMode",
    },
)
class DatatransferEndpointSettingsPostgresSourceConnectionOnPremise:
    def __init__(
        self,
        *,
        ca_certificate: typing.Optional[builtins.str] = None,
        hosts: typing.Optional[typing.Sequence[builtins.str]] = None,
        port: typing.Optional[jsii.Number] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        tls_mode: typing.Optional["DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsMode"] = None,
    ) -> None:
        '''
        :param ca_certificate: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#ca_certificate DatatransferEndpoint#ca_certificate}.
        :param hosts: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#hosts DatatransferEndpoint#hosts}.
        :param port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#port DatatransferEndpoint#port}.
        :param subnet_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#subnet_id DatatransferEndpoint#subnet_id}.
        :param tls_mode: tls_mode block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#tls_mode DatatransferEndpoint#tls_mode}
        '''
        if isinstance(tls_mode, dict):
            tls_mode = DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsMode(**tls_mode)
        self._values: typing.Dict[str, typing.Any] = {}
        if ca_certificate is not None:
            self._values["ca_certificate"] = ca_certificate
        if hosts is not None:
            self._values["hosts"] = hosts
        if port is not None:
            self._values["port"] = port
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if tls_mode is not None:
            self._values["tls_mode"] = tls_mode

    @builtins.property
    def ca_certificate(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#ca_certificate DatatransferEndpoint#ca_certificate}.'''
        result = self._values.get("ca_certificate")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def hosts(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#hosts DatatransferEndpoint#hosts}.'''
        result = self._values.get("hosts")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#port DatatransferEndpoint#port}.'''
        result = self._values.get("port")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#subnet_id DatatransferEndpoint#subnet_id}.'''
        result = self._values.get("subnet_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def tls_mode(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsMode"]:
        '''tls_mode block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#tls_mode DatatransferEndpoint#tls_mode}
        '''
        result = self._values.get("tls_mode")
        return typing.cast(typing.Optional["DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsMode"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatatransferEndpointSettingsPostgresSourceConnectionOnPremise(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putTlsMode")
    def put_tls_mode(
        self,
        *,
        disabled: typing.Optional["DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeDisabled"] = None,
        enabled: typing.Optional["DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeEnabled"] = None,
    ) -> None:
        '''
        :param disabled: disabled block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#disabled DatatransferEndpoint#disabled}
        :param enabled: enabled block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#enabled DatatransferEndpoint#enabled}
        '''
        value = DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsMode(
            disabled=disabled, enabled=enabled
        )

        return typing.cast(None, jsii.invoke(self, "putTlsMode", [value]))

    @jsii.member(jsii_name="resetCaCertificate")
    def reset_ca_certificate(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCaCertificate", []))

    @jsii.member(jsii_name="resetHosts")
    def reset_hosts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHosts", []))

    @jsii.member(jsii_name="resetPort")
    def reset_port(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPort", []))

    @jsii.member(jsii_name="resetSubnetId")
    def reset_subnet_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSubnetId", []))

    @jsii.member(jsii_name="resetTlsMode")
    def reset_tls_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTlsMode", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tlsMode")
    def tls_mode(
        self,
    ) -> "DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeOutputReference":
        return typing.cast("DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeOutputReference", jsii.get(self, "tlsMode"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="caCertificateInput")
    def ca_certificate_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "caCertificateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostsInput")
    def hosts_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "hostsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="portInput")
    def port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "portInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIdInput")
    def subnet_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "subnetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tlsModeInput")
    def tls_mode_input(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsMode"]:
        return typing.cast(typing.Optional["DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsMode"], jsii.get(self, "tlsModeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="caCertificate")
    def ca_certificate(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "caCertificate"))

    @ca_certificate.setter
    def ca_certificate(self, value: builtins.str) -> None:
        jsii.set(self, "caCertificate", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hosts")
    def hosts(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "hosts"))

    @hosts.setter
    def hosts(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "hosts", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "port"))

    @port.setter
    def port(self, value: jsii.Number) -> None:
        jsii.set(self, "port", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @subnet_id.setter
    def subnet_id(self, value: builtins.str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsPostgresSourceConnectionOnPremise]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsPostgresSourceConnectionOnPremise], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DatatransferEndpointSettingsPostgresSourceConnectionOnPremise],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsMode",
    jsii_struct_bases=[],
    name_mapping={"disabled": "disabled", "enabled": "enabled"},
)
class DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsMode:
    def __init__(
        self,
        *,
        disabled: typing.Optional["DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeDisabled"] = None,
        enabled: typing.Optional["DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeEnabled"] = None,
    ) -> None:
        '''
        :param disabled: disabled block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#disabled DatatransferEndpoint#disabled}
        :param enabled: enabled block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#enabled DatatransferEndpoint#enabled}
        '''
        if isinstance(disabled, dict):
            disabled = DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeDisabled(**disabled)
        if isinstance(enabled, dict):
            enabled = DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeEnabled(**enabled)
        self._values: typing.Dict[str, typing.Any] = {}
        if disabled is not None:
            self._values["disabled"] = disabled
        if enabled is not None:
            self._values["enabled"] = enabled

    @builtins.property
    def disabled(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeDisabled"]:
        '''disabled block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#disabled DatatransferEndpoint#disabled}
        '''
        result = self._values.get("disabled")
        return typing.cast(typing.Optional["DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeDisabled"], result)

    @builtins.property
    def enabled(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeEnabled"]:
        '''enabled block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#enabled DatatransferEndpoint#enabled}
        '''
        result = self._values.get("enabled")
        return typing.cast(typing.Optional["DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeEnabled"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsMode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeDisabled",
    jsii_struct_bases=[],
    name_mapping={},
)
class DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeDisabled:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeDisabled(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeDisabledOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeDisabledOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeDisabled]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeDisabled], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeDisabled],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeEnabled",
    jsii_struct_bases=[],
    name_mapping={"ca_certificate": "caCertificate"},
)
class DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeEnabled:
    def __init__(self, *, ca_certificate: typing.Optional[builtins.str] = None) -> None:
        '''
        :param ca_certificate: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#ca_certificate DatatransferEndpoint#ca_certificate}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if ca_certificate is not None:
            self._values["ca_certificate"] = ca_certificate

    @builtins.property
    def ca_certificate(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#ca_certificate DatatransferEndpoint#ca_certificate}.'''
        result = self._values.get("ca_certificate")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeEnabled(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeEnabledOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeEnabledOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCaCertificate")
    def reset_ca_certificate(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCaCertificate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="caCertificateInput")
    def ca_certificate_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "caCertificateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="caCertificate")
    def ca_certificate(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "caCertificate"))

    @ca_certificate.setter
    def ca_certificate(self, value: builtins.str) -> None:
        jsii.set(self, "caCertificate", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeEnabled]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeEnabled], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeEnabled],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putDisabled")
    def put_disabled(self) -> None:
        value = DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeDisabled()

        return typing.cast(None, jsii.invoke(self, "putDisabled", [value]))

    @jsii.member(jsii_name="putEnabled")
    def put_enabled(
        self,
        *,
        ca_certificate: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param ca_certificate: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#ca_certificate DatatransferEndpoint#ca_certificate}.
        '''
        value = DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeEnabled(
            ca_certificate=ca_certificate
        )

        return typing.cast(None, jsii.invoke(self, "putEnabled", [value]))

    @jsii.member(jsii_name="resetDisabled")
    def reset_disabled(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDisabled", []))

    @jsii.member(jsii_name="resetEnabled")
    def reset_enabled(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEnabled", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="disabled")
    def disabled(
        self,
    ) -> DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeDisabledOutputReference:
        return typing.cast(DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeDisabledOutputReference, jsii.get(self, "disabled"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="enabled")
    def enabled(
        self,
    ) -> DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeEnabledOutputReference:
        return typing.cast(DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeEnabledOutputReference, jsii.get(self, "enabled"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="disabledInput")
    def disabled_input(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeDisabled]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeDisabled], jsii.get(self, "disabledInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="enabledInput")
    def enabled_input(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeEnabled]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeEnabled], jsii.get(self, "enabledInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsMode]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsMode], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsMode],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DatatransferEndpointSettingsPostgresSourceConnectionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsPostgresSourceConnectionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putOnPremise")
    def put_on_premise(
        self,
        *,
        ca_certificate: typing.Optional[builtins.str] = None,
        hosts: typing.Optional[typing.Sequence[builtins.str]] = None,
        port: typing.Optional[jsii.Number] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        tls_mode: typing.Optional[DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsMode] = None,
    ) -> None:
        '''
        :param ca_certificate: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#ca_certificate DatatransferEndpoint#ca_certificate}.
        :param hosts: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#hosts DatatransferEndpoint#hosts}.
        :param port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#port DatatransferEndpoint#port}.
        :param subnet_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#subnet_id DatatransferEndpoint#subnet_id}.
        :param tls_mode: tls_mode block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#tls_mode DatatransferEndpoint#tls_mode}
        '''
        value = DatatransferEndpointSettingsPostgresSourceConnectionOnPremise(
            ca_certificate=ca_certificate,
            hosts=hosts,
            port=port,
            subnet_id=subnet_id,
            tls_mode=tls_mode,
        )

        return typing.cast(None, jsii.invoke(self, "putOnPremise", [value]))

    @jsii.member(jsii_name="resetMdbClusterId")
    def reset_mdb_cluster_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMdbClusterId", []))

    @jsii.member(jsii_name="resetOnPremise")
    def reset_on_premise(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOnPremise", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="onPremise")
    def on_premise(
        self,
    ) -> DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseOutputReference:
        return typing.cast(DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseOutputReference, jsii.get(self, "onPremise"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mdbClusterIdInput")
    def mdb_cluster_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "mdbClusterIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="onPremiseInput")
    def on_premise_input(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsPostgresSourceConnectionOnPremise]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsPostgresSourceConnectionOnPremise], jsii.get(self, "onPremiseInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mdbClusterId")
    def mdb_cluster_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "mdbClusterId"))

    @mdb_cluster_id.setter
    def mdb_cluster_id(self, value: builtins.str) -> None:
        jsii.set(self, "mdbClusterId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsPostgresSourceConnection]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsPostgresSourceConnection], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DatatransferEndpointSettingsPostgresSourceConnection],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsPostgresSourceObjectTransferSettings",
    jsii_struct_bases=[],
    name_mapping={
        "cast": "cast",
        "collation": "collation",
        "constraint": "constraint",
        "default_values": "defaultValues",
        "fk_constraint": "fkConstraint",
        "function": "function",
        "index": "index",
        "policy": "policy",
        "primary_key": "primaryKey",
        "rule": "rule",
        "sequence": "sequence",
        "sequence_owned_by": "sequenceOwnedBy",
        "table": "table",
        "trigger": "trigger",
        "type": "type",
        "view": "view",
    },
)
class DatatransferEndpointSettingsPostgresSourceObjectTransferSettings:
    def __init__(
        self,
        *,
        cast: typing.Optional[builtins.str] = None,
        collation: typing.Optional[builtins.str] = None,
        constraint: typing.Optional[builtins.str] = None,
        default_values: typing.Optional[builtins.str] = None,
        fk_constraint: typing.Optional[builtins.str] = None,
        function: typing.Optional[builtins.str] = None,
        index: typing.Optional[builtins.str] = None,
        policy: typing.Optional[builtins.str] = None,
        primary_key: typing.Optional[builtins.str] = None,
        rule: typing.Optional[builtins.str] = None,
        sequence: typing.Optional[builtins.str] = None,
        sequence_owned_by: typing.Optional[builtins.str] = None,
        table: typing.Optional[builtins.str] = None,
        trigger: typing.Optional[builtins.str] = None,
        type: typing.Optional[builtins.str] = None,
        view: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param cast: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#cast DatatransferEndpoint#cast}.
        :param collation: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#collation DatatransferEndpoint#collation}.
        :param constraint: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#constraint DatatransferEndpoint#constraint}.
        :param default_values: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#default_values DatatransferEndpoint#default_values}.
        :param fk_constraint: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#fk_constraint DatatransferEndpoint#fk_constraint}.
        :param function: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#function DatatransferEndpoint#function}.
        :param index: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#index DatatransferEndpoint#index}.
        :param policy: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#policy DatatransferEndpoint#policy}.
        :param primary_key: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#primary_key DatatransferEndpoint#primary_key}.
        :param rule: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#rule DatatransferEndpoint#rule}.
        :param sequence: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#sequence DatatransferEndpoint#sequence}.
        :param sequence_owned_by: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#sequence_owned_by DatatransferEndpoint#sequence_owned_by}.
        :param table: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#table DatatransferEndpoint#table}.
        :param trigger: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#trigger DatatransferEndpoint#trigger}.
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#type DatatransferEndpoint#type}.
        :param view: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#view DatatransferEndpoint#view}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if cast is not None:
            self._values["cast"] = cast
        if collation is not None:
            self._values["collation"] = collation
        if constraint is not None:
            self._values["constraint"] = constraint
        if default_values is not None:
            self._values["default_values"] = default_values
        if fk_constraint is not None:
            self._values["fk_constraint"] = fk_constraint
        if function is not None:
            self._values["function"] = function
        if index is not None:
            self._values["index"] = index
        if policy is not None:
            self._values["policy"] = policy
        if primary_key is not None:
            self._values["primary_key"] = primary_key
        if rule is not None:
            self._values["rule"] = rule
        if sequence is not None:
            self._values["sequence"] = sequence
        if sequence_owned_by is not None:
            self._values["sequence_owned_by"] = sequence_owned_by
        if table is not None:
            self._values["table"] = table
        if trigger is not None:
            self._values["trigger"] = trigger
        if type is not None:
            self._values["type"] = type
        if view is not None:
            self._values["view"] = view

    @builtins.property
    def cast(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#cast DatatransferEndpoint#cast}.'''
        result = self._values.get("cast")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def collation(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#collation DatatransferEndpoint#collation}.'''
        result = self._values.get("collation")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def constraint(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#constraint DatatransferEndpoint#constraint}.'''
        result = self._values.get("constraint")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def default_values(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#default_values DatatransferEndpoint#default_values}.'''
        result = self._values.get("default_values")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def fk_constraint(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#fk_constraint DatatransferEndpoint#fk_constraint}.'''
        result = self._values.get("fk_constraint")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def function(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#function DatatransferEndpoint#function}.'''
        result = self._values.get("function")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def index(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#index DatatransferEndpoint#index}.'''
        result = self._values.get("index")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def policy(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#policy DatatransferEndpoint#policy}.'''
        result = self._values.get("policy")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def primary_key(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#primary_key DatatransferEndpoint#primary_key}.'''
        result = self._values.get("primary_key")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def rule(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#rule DatatransferEndpoint#rule}.'''
        result = self._values.get("rule")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def sequence(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#sequence DatatransferEndpoint#sequence}.'''
        result = self._values.get("sequence")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def sequence_owned_by(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#sequence_owned_by DatatransferEndpoint#sequence_owned_by}.'''
        result = self._values.get("sequence_owned_by")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def table(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#table DatatransferEndpoint#table}.'''
        result = self._values.get("table")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def trigger(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#trigger DatatransferEndpoint#trigger}.'''
        result = self._values.get("trigger")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def type(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#type DatatransferEndpoint#type}.'''
        result = self._values.get("type")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def view(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#view DatatransferEndpoint#view}.'''
        result = self._values.get("view")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatatransferEndpointSettingsPostgresSourceObjectTransferSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DatatransferEndpointSettingsPostgresSourceObjectTransferSettingsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsPostgresSourceObjectTransferSettingsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCast")
    def reset_cast(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCast", []))

    @jsii.member(jsii_name="resetCollation")
    def reset_collation(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCollation", []))

    @jsii.member(jsii_name="resetConstraint")
    def reset_constraint(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetConstraint", []))

    @jsii.member(jsii_name="resetDefaultValues")
    def reset_default_values(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDefaultValues", []))

    @jsii.member(jsii_name="resetFkConstraint")
    def reset_fk_constraint(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFkConstraint", []))

    @jsii.member(jsii_name="resetFunction")
    def reset_function(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFunction", []))

    @jsii.member(jsii_name="resetIndex")
    def reset_index(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIndex", []))

    @jsii.member(jsii_name="resetPolicy")
    def reset_policy(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPolicy", []))

    @jsii.member(jsii_name="resetPrimaryKey")
    def reset_primary_key(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrimaryKey", []))

    @jsii.member(jsii_name="resetRule")
    def reset_rule(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRule", []))

    @jsii.member(jsii_name="resetSequence")
    def reset_sequence(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSequence", []))

    @jsii.member(jsii_name="resetSequenceOwnedBy")
    def reset_sequence_owned_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSequenceOwnedBy", []))

    @jsii.member(jsii_name="resetTable")
    def reset_table(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTable", []))

    @jsii.member(jsii_name="resetTrigger")
    def reset_trigger(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTrigger", []))

    @jsii.member(jsii_name="resetType")
    def reset_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetType", []))

    @jsii.member(jsii_name="resetView")
    def reset_view(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetView", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="castInput")
    def cast_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "castInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="collationInput")
    def collation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "collationInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="constraintInput")
    def constraint_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "constraintInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="defaultValuesInput")
    def default_values_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "defaultValuesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fkConstraintInput")
    def fk_constraint_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "fkConstraintInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="functionInput")
    def function_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "functionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="indexInput")
    def index_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="policyInput")
    def policy_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "policyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="primaryKeyInput")
    def primary_key_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "primaryKeyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ruleInput")
    def rule_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "ruleInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sequenceInput")
    def sequence_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sequenceInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sequenceOwnedByInput")
    def sequence_owned_by_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sequenceOwnedByInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tableInput")
    def table_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "tableInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="triggerInput")
    def trigger_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "triggerInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="typeInput")
    def type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "typeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="viewInput")
    def view_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "viewInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cast")
    def cast(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "cast"))

    @cast.setter
    def cast(self, value: builtins.str) -> None:
        jsii.set(self, "cast", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="collation")
    def collation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "collation"))

    @collation.setter
    def collation(self, value: builtins.str) -> None:
        jsii.set(self, "collation", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="constraint")
    def constraint(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "constraint"))

    @constraint.setter
    def constraint(self, value: builtins.str) -> None:
        jsii.set(self, "constraint", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="defaultValues")
    def default_values(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "defaultValues"))

    @default_values.setter
    def default_values(self, value: builtins.str) -> None:
        jsii.set(self, "defaultValues", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fkConstraint")
    def fk_constraint(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fkConstraint"))

    @fk_constraint.setter
    def fk_constraint(self, value: builtins.str) -> None:
        jsii.set(self, "fkConstraint", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="function")
    def function(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "function"))

    @function.setter
    def function(self, value: builtins.str) -> None:
        jsii.set(self, "function", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="index")
    def index(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "index"))

    @index.setter
    def index(self, value: builtins.str) -> None:
        jsii.set(self, "index", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="policy")
    def policy(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "policy"))

    @policy.setter
    def policy(self, value: builtins.str) -> None:
        jsii.set(self, "policy", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="primaryKey")
    def primary_key(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "primaryKey"))

    @primary_key.setter
    def primary_key(self, value: builtins.str) -> None:
        jsii.set(self, "primaryKey", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="rule")
    def rule(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "rule"))

    @rule.setter
    def rule(self, value: builtins.str) -> None:
        jsii.set(self, "rule", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sequence")
    def sequence(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sequence"))

    @sequence.setter
    def sequence(self, value: builtins.str) -> None:
        jsii.set(self, "sequence", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sequenceOwnedBy")
    def sequence_owned_by(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sequenceOwnedBy"))

    @sequence_owned_by.setter
    def sequence_owned_by(self, value: builtins.str) -> None:
        jsii.set(self, "sequenceOwnedBy", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="table")
    def table(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "table"))

    @table.setter
    def table(self, value: builtins.str) -> None:
        jsii.set(self, "table", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="trigger")
    def trigger(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "trigger"))

    @trigger.setter
    def trigger(self, value: builtins.str) -> None:
        jsii.set(self, "trigger", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @type.setter
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="view")
    def view(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "view"))

    @view.setter
    def view(self, value: builtins.str) -> None:
        jsii.set(self, "view", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsPostgresSourceObjectTransferSettings]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsPostgresSourceObjectTransferSettings], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DatatransferEndpointSettingsPostgresSourceObjectTransferSettings],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DatatransferEndpointSettingsPostgresSourceOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsPostgresSourceOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putConnection")
    def put_connection(
        self,
        *,
        mdb_cluster_id: typing.Optional[builtins.str] = None,
        on_premise: typing.Optional[DatatransferEndpointSettingsPostgresSourceConnectionOnPremise] = None,
    ) -> None:
        '''
        :param mdb_cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#mdb_cluster_id DatatransferEndpoint#mdb_cluster_id}.
        :param on_premise: on_premise block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#on_premise DatatransferEndpoint#on_premise}
        '''
        value = DatatransferEndpointSettingsPostgresSourceConnection(
            mdb_cluster_id=mdb_cluster_id, on_premise=on_premise
        )

        return typing.cast(None, jsii.invoke(self, "putConnection", [value]))

    @jsii.member(jsii_name="putObjectTransferSettings")
    def put_object_transfer_settings(
        self,
        *,
        cast: typing.Optional[builtins.str] = None,
        collation: typing.Optional[builtins.str] = None,
        constraint: typing.Optional[builtins.str] = None,
        default_values: typing.Optional[builtins.str] = None,
        fk_constraint: typing.Optional[builtins.str] = None,
        function: typing.Optional[builtins.str] = None,
        index: typing.Optional[builtins.str] = None,
        policy: typing.Optional[builtins.str] = None,
        primary_key: typing.Optional[builtins.str] = None,
        rule: typing.Optional[builtins.str] = None,
        sequence: typing.Optional[builtins.str] = None,
        sequence_owned_by: typing.Optional[builtins.str] = None,
        table: typing.Optional[builtins.str] = None,
        trigger: typing.Optional[builtins.str] = None,
        type: typing.Optional[builtins.str] = None,
        view: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param cast: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#cast DatatransferEndpoint#cast}.
        :param collation: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#collation DatatransferEndpoint#collation}.
        :param constraint: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#constraint DatatransferEndpoint#constraint}.
        :param default_values: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#default_values DatatransferEndpoint#default_values}.
        :param fk_constraint: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#fk_constraint DatatransferEndpoint#fk_constraint}.
        :param function: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#function DatatransferEndpoint#function}.
        :param index: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#index DatatransferEndpoint#index}.
        :param policy: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#policy DatatransferEndpoint#policy}.
        :param primary_key: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#primary_key DatatransferEndpoint#primary_key}.
        :param rule: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#rule DatatransferEndpoint#rule}.
        :param sequence: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#sequence DatatransferEndpoint#sequence}.
        :param sequence_owned_by: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#sequence_owned_by DatatransferEndpoint#sequence_owned_by}.
        :param table: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#table DatatransferEndpoint#table}.
        :param trigger: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#trigger DatatransferEndpoint#trigger}.
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#type DatatransferEndpoint#type}.
        :param view: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#view DatatransferEndpoint#view}.
        '''
        value = DatatransferEndpointSettingsPostgresSourceObjectTransferSettings(
            cast=cast,
            collation=collation,
            constraint=constraint,
            default_values=default_values,
            fk_constraint=fk_constraint,
            function=function,
            index=index,
            policy=policy,
            primary_key=primary_key,
            rule=rule,
            sequence=sequence,
            sequence_owned_by=sequence_owned_by,
            table=table,
            trigger=trigger,
            type=type,
            view=view,
        )

        return typing.cast(None, jsii.invoke(self, "putObjectTransferSettings", [value]))

    @jsii.member(jsii_name="putPassword")
    def put_password(self, *, raw: typing.Optional[builtins.str] = None) -> None:
        '''
        :param raw: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#raw DatatransferEndpoint#raw}.
        '''
        value = DatatransferEndpointSettingsPostgresSourcePassword(raw=raw)

        return typing.cast(None, jsii.invoke(self, "putPassword", [value]))

    @jsii.member(jsii_name="resetCollapseInheritTable")
    def reset_collapse_inherit_table(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCollapseInheritTable", []))

    @jsii.member(jsii_name="resetConnection")
    def reset_connection(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetConnection", []))

    @jsii.member(jsii_name="resetDatabase")
    def reset_database(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDatabase", []))

    @jsii.member(jsii_name="resetExcludeTables")
    def reset_exclude_tables(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetExcludeTables", []))

    @jsii.member(jsii_name="resetIncludeTables")
    def reset_include_tables(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIncludeTables", []))

    @jsii.member(jsii_name="resetObjectTransferSettings")
    def reset_object_transfer_settings(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetObjectTransferSettings", []))

    @jsii.member(jsii_name="resetPassword")
    def reset_password(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPassword", []))

    @jsii.member(jsii_name="resetServiceSchema")
    def reset_service_schema(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetServiceSchema", []))

    @jsii.member(jsii_name="resetSlotGigabyteLagLimit")
    def reset_slot_gigabyte_lag_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSlotGigabyteLagLimit", []))

    @jsii.member(jsii_name="resetUser")
    def reset_user(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUser", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="connection")
    def connection(
        self,
    ) -> DatatransferEndpointSettingsPostgresSourceConnectionOutputReference:
        return typing.cast(DatatransferEndpointSettingsPostgresSourceConnectionOutputReference, jsii.get(self, "connection"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="objectTransferSettings")
    def object_transfer_settings(
        self,
    ) -> DatatransferEndpointSettingsPostgresSourceObjectTransferSettingsOutputReference:
        return typing.cast(DatatransferEndpointSettingsPostgresSourceObjectTransferSettingsOutputReference, jsii.get(self, "objectTransferSettings"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="password")
    def password(
        self,
    ) -> "DatatransferEndpointSettingsPostgresSourcePasswordOutputReference":
        return typing.cast("DatatransferEndpointSettingsPostgresSourcePasswordOutputReference", jsii.get(self, "password"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="collapseInheritTableInput")
    def collapse_inherit_table_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "collapseInheritTableInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="connectionInput")
    def connection_input(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsPostgresSourceConnection]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsPostgresSourceConnection], jsii.get(self, "connectionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databaseInput")
    def database_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "databaseInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="excludeTablesInput")
    def exclude_tables_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "excludeTablesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="includeTablesInput")
    def include_tables_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "includeTablesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="objectTransferSettingsInput")
    def object_transfer_settings_input(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsPostgresSourceObjectTransferSettings]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsPostgresSourceObjectTransferSettings], jsii.get(self, "objectTransferSettingsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="passwordInput")
    def password_input(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsPostgresSourcePassword"]:
        return typing.cast(typing.Optional["DatatransferEndpointSettingsPostgresSourcePassword"], jsii.get(self, "passwordInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceSchemaInput")
    def service_schema_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceSchemaInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="slotGigabyteLagLimitInput")
    def slot_gigabyte_lag_limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "slotGigabyteLagLimitInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="userInput")
    def user_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "userInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="collapseInheritTable")
    def collapse_inherit_table(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "collapseInheritTable"))

    @collapse_inherit_table.setter
    def collapse_inherit_table(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "collapseInheritTable", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="database")
    def database(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "database"))

    @database.setter
    def database(self, value: builtins.str) -> None:
        jsii.set(self, "database", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="excludeTables")
    def exclude_tables(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "excludeTables"))

    @exclude_tables.setter
    def exclude_tables(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "excludeTables", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="includeTables")
    def include_tables(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "includeTables"))

    @include_tables.setter
    def include_tables(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "includeTables", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceSchema")
    def service_schema(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceSchema"))

    @service_schema.setter
    def service_schema(self, value: builtins.str) -> None:
        jsii.set(self, "serviceSchema", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="slotGigabyteLagLimit")
    def slot_gigabyte_lag_limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "slotGigabyteLagLimit"))

    @slot_gigabyte_lag_limit.setter
    def slot_gigabyte_lag_limit(self, value: jsii.Number) -> None:
        jsii.set(self, "slotGigabyteLagLimit", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="user")
    def user(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "user"))

    @user.setter
    def user(self, value: builtins.str) -> None:
        jsii.set(self, "user", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsPostgresSource]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsPostgresSource], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DatatransferEndpointSettingsPostgresSource],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsPostgresSourcePassword",
    jsii_struct_bases=[],
    name_mapping={"raw": "raw"},
)
class DatatransferEndpointSettingsPostgresSourcePassword:
    def __init__(self, *, raw: typing.Optional[builtins.str] = None) -> None:
        '''
        :param raw: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#raw DatatransferEndpoint#raw}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if raw is not None:
            self._values["raw"] = raw

    @builtins.property
    def raw(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#raw DatatransferEndpoint#raw}.'''
        result = self._values.get("raw")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatatransferEndpointSettingsPostgresSourcePassword(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DatatransferEndpointSettingsPostgresSourcePasswordOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsPostgresSourcePasswordOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetRaw")
    def reset_raw(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRaw", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="rawInput")
    def raw_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "rawInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="raw")
    def raw(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "raw"))

    @raw.setter
    def raw(self, value: builtins.str) -> None:
        jsii.set(self, "raw", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsPostgresSourcePassword]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsPostgresSourcePassword], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DatatransferEndpointSettingsPostgresSourcePassword],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsPostgresTarget",
    jsii_struct_bases=[],
    name_mapping={
        "connection": "connection",
        "database": "database",
        "password": "password",
        "user": "user",
    },
)
class DatatransferEndpointSettingsPostgresTarget:
    def __init__(
        self,
        *,
        connection: typing.Optional["DatatransferEndpointSettingsPostgresTargetConnection"] = None,
        database: typing.Optional[builtins.str] = None,
        password: typing.Optional["DatatransferEndpointSettingsPostgresTargetPassword"] = None,
        user: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param connection: connection block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#connection DatatransferEndpoint#connection}
        :param database: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#database DatatransferEndpoint#database}.
        :param password: password block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#password DatatransferEndpoint#password}
        :param user: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#user DatatransferEndpoint#user}.
        '''
        if isinstance(connection, dict):
            connection = DatatransferEndpointSettingsPostgresTargetConnection(**connection)
        if isinstance(password, dict):
            password = DatatransferEndpointSettingsPostgresTargetPassword(**password)
        self._values: typing.Dict[str, typing.Any] = {}
        if connection is not None:
            self._values["connection"] = connection
        if database is not None:
            self._values["database"] = database
        if password is not None:
            self._values["password"] = password
        if user is not None:
            self._values["user"] = user

    @builtins.property
    def connection(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsPostgresTargetConnection"]:
        '''connection block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#connection DatatransferEndpoint#connection}
        '''
        result = self._values.get("connection")
        return typing.cast(typing.Optional["DatatransferEndpointSettingsPostgresTargetConnection"], result)

    @builtins.property
    def database(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#database DatatransferEndpoint#database}.'''
        result = self._values.get("database")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def password(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsPostgresTargetPassword"]:
        '''password block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#password DatatransferEndpoint#password}
        '''
        result = self._values.get("password")
        return typing.cast(typing.Optional["DatatransferEndpointSettingsPostgresTargetPassword"], result)

    @builtins.property
    def user(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#user DatatransferEndpoint#user}.'''
        result = self._values.get("user")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatatransferEndpointSettingsPostgresTarget(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsPostgresTargetConnection",
    jsii_struct_bases=[],
    name_mapping={"mdb_cluster_id": "mdbClusterId", "on_premise": "onPremise"},
)
class DatatransferEndpointSettingsPostgresTargetConnection:
    def __init__(
        self,
        *,
        mdb_cluster_id: typing.Optional[builtins.str] = None,
        on_premise: typing.Optional["DatatransferEndpointSettingsPostgresTargetConnectionOnPremise"] = None,
    ) -> None:
        '''
        :param mdb_cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#mdb_cluster_id DatatransferEndpoint#mdb_cluster_id}.
        :param on_premise: on_premise block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#on_premise DatatransferEndpoint#on_premise}
        '''
        if isinstance(on_premise, dict):
            on_premise = DatatransferEndpointSettingsPostgresTargetConnectionOnPremise(**on_premise)
        self._values: typing.Dict[str, typing.Any] = {}
        if mdb_cluster_id is not None:
            self._values["mdb_cluster_id"] = mdb_cluster_id
        if on_premise is not None:
            self._values["on_premise"] = on_premise

    @builtins.property
    def mdb_cluster_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#mdb_cluster_id DatatransferEndpoint#mdb_cluster_id}.'''
        result = self._values.get("mdb_cluster_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def on_premise(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsPostgresTargetConnectionOnPremise"]:
        '''on_premise block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#on_premise DatatransferEndpoint#on_premise}
        '''
        result = self._values.get("on_premise")
        return typing.cast(typing.Optional["DatatransferEndpointSettingsPostgresTargetConnectionOnPremise"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatatransferEndpointSettingsPostgresTargetConnection(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsPostgresTargetConnectionOnPremise",
    jsii_struct_bases=[],
    name_mapping={
        "ca_certificate": "caCertificate",
        "hosts": "hosts",
        "port": "port",
        "subnet_id": "subnetId",
        "tls_mode": "tlsMode",
    },
)
class DatatransferEndpointSettingsPostgresTargetConnectionOnPremise:
    def __init__(
        self,
        *,
        ca_certificate: typing.Optional[builtins.str] = None,
        hosts: typing.Optional[typing.Sequence[builtins.str]] = None,
        port: typing.Optional[jsii.Number] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        tls_mode: typing.Optional["DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsMode"] = None,
    ) -> None:
        '''
        :param ca_certificate: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#ca_certificate DatatransferEndpoint#ca_certificate}.
        :param hosts: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#hosts DatatransferEndpoint#hosts}.
        :param port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#port DatatransferEndpoint#port}.
        :param subnet_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#subnet_id DatatransferEndpoint#subnet_id}.
        :param tls_mode: tls_mode block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#tls_mode DatatransferEndpoint#tls_mode}
        '''
        if isinstance(tls_mode, dict):
            tls_mode = DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsMode(**tls_mode)
        self._values: typing.Dict[str, typing.Any] = {}
        if ca_certificate is not None:
            self._values["ca_certificate"] = ca_certificate
        if hosts is not None:
            self._values["hosts"] = hosts
        if port is not None:
            self._values["port"] = port
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if tls_mode is not None:
            self._values["tls_mode"] = tls_mode

    @builtins.property
    def ca_certificate(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#ca_certificate DatatransferEndpoint#ca_certificate}.'''
        result = self._values.get("ca_certificate")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def hosts(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#hosts DatatransferEndpoint#hosts}.'''
        result = self._values.get("hosts")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#port DatatransferEndpoint#port}.'''
        result = self._values.get("port")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#subnet_id DatatransferEndpoint#subnet_id}.'''
        result = self._values.get("subnet_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def tls_mode(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsMode"]:
        '''tls_mode block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#tls_mode DatatransferEndpoint#tls_mode}
        '''
        result = self._values.get("tls_mode")
        return typing.cast(typing.Optional["DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsMode"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatatransferEndpointSettingsPostgresTargetConnectionOnPremise(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putTlsMode")
    def put_tls_mode(
        self,
        *,
        disabled: typing.Optional["DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeDisabled"] = None,
        enabled: typing.Optional["DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeEnabled"] = None,
    ) -> None:
        '''
        :param disabled: disabled block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#disabled DatatransferEndpoint#disabled}
        :param enabled: enabled block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#enabled DatatransferEndpoint#enabled}
        '''
        value = DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsMode(
            disabled=disabled, enabled=enabled
        )

        return typing.cast(None, jsii.invoke(self, "putTlsMode", [value]))

    @jsii.member(jsii_name="resetCaCertificate")
    def reset_ca_certificate(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCaCertificate", []))

    @jsii.member(jsii_name="resetHosts")
    def reset_hosts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHosts", []))

    @jsii.member(jsii_name="resetPort")
    def reset_port(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPort", []))

    @jsii.member(jsii_name="resetSubnetId")
    def reset_subnet_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSubnetId", []))

    @jsii.member(jsii_name="resetTlsMode")
    def reset_tls_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTlsMode", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tlsMode")
    def tls_mode(
        self,
    ) -> "DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeOutputReference":
        return typing.cast("DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeOutputReference", jsii.get(self, "tlsMode"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="caCertificateInput")
    def ca_certificate_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "caCertificateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostsInput")
    def hosts_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "hostsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="portInput")
    def port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "portInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIdInput")
    def subnet_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "subnetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tlsModeInput")
    def tls_mode_input(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsMode"]:
        return typing.cast(typing.Optional["DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsMode"], jsii.get(self, "tlsModeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="caCertificate")
    def ca_certificate(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "caCertificate"))

    @ca_certificate.setter
    def ca_certificate(self, value: builtins.str) -> None:
        jsii.set(self, "caCertificate", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hosts")
    def hosts(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "hosts"))

    @hosts.setter
    def hosts(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "hosts", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "port"))

    @port.setter
    def port(self, value: jsii.Number) -> None:
        jsii.set(self, "port", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @subnet_id.setter
    def subnet_id(self, value: builtins.str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsPostgresTargetConnectionOnPremise]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsPostgresTargetConnectionOnPremise], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DatatransferEndpointSettingsPostgresTargetConnectionOnPremise],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsMode",
    jsii_struct_bases=[],
    name_mapping={"disabled": "disabled", "enabled": "enabled"},
)
class DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsMode:
    def __init__(
        self,
        *,
        disabled: typing.Optional["DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeDisabled"] = None,
        enabled: typing.Optional["DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeEnabled"] = None,
    ) -> None:
        '''
        :param disabled: disabled block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#disabled DatatransferEndpoint#disabled}
        :param enabled: enabled block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#enabled DatatransferEndpoint#enabled}
        '''
        if isinstance(disabled, dict):
            disabled = DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeDisabled(**disabled)
        if isinstance(enabled, dict):
            enabled = DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeEnabled(**enabled)
        self._values: typing.Dict[str, typing.Any] = {}
        if disabled is not None:
            self._values["disabled"] = disabled
        if enabled is not None:
            self._values["enabled"] = enabled

    @builtins.property
    def disabled(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeDisabled"]:
        '''disabled block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#disabled DatatransferEndpoint#disabled}
        '''
        result = self._values.get("disabled")
        return typing.cast(typing.Optional["DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeDisabled"], result)

    @builtins.property
    def enabled(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeEnabled"]:
        '''enabled block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#enabled DatatransferEndpoint#enabled}
        '''
        result = self._values.get("enabled")
        return typing.cast(typing.Optional["DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeEnabled"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsMode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeDisabled",
    jsii_struct_bases=[],
    name_mapping={},
)
class DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeDisabled:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeDisabled(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeDisabledOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeDisabledOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeDisabled]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeDisabled], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeDisabled],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeEnabled",
    jsii_struct_bases=[],
    name_mapping={"ca_certificate": "caCertificate"},
)
class DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeEnabled:
    def __init__(self, *, ca_certificate: typing.Optional[builtins.str] = None) -> None:
        '''
        :param ca_certificate: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#ca_certificate DatatransferEndpoint#ca_certificate}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if ca_certificate is not None:
            self._values["ca_certificate"] = ca_certificate

    @builtins.property
    def ca_certificate(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#ca_certificate DatatransferEndpoint#ca_certificate}.'''
        result = self._values.get("ca_certificate")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeEnabled(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeEnabledOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeEnabledOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCaCertificate")
    def reset_ca_certificate(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCaCertificate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="caCertificateInput")
    def ca_certificate_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "caCertificateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="caCertificate")
    def ca_certificate(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "caCertificate"))

    @ca_certificate.setter
    def ca_certificate(self, value: builtins.str) -> None:
        jsii.set(self, "caCertificate", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeEnabled]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeEnabled], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeEnabled],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putDisabled")
    def put_disabled(self) -> None:
        value = DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeDisabled()

        return typing.cast(None, jsii.invoke(self, "putDisabled", [value]))

    @jsii.member(jsii_name="putEnabled")
    def put_enabled(
        self,
        *,
        ca_certificate: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param ca_certificate: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#ca_certificate DatatransferEndpoint#ca_certificate}.
        '''
        value = DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeEnabled(
            ca_certificate=ca_certificate
        )

        return typing.cast(None, jsii.invoke(self, "putEnabled", [value]))

    @jsii.member(jsii_name="resetDisabled")
    def reset_disabled(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDisabled", []))

    @jsii.member(jsii_name="resetEnabled")
    def reset_enabled(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEnabled", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="disabled")
    def disabled(
        self,
    ) -> DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeDisabledOutputReference:
        return typing.cast(DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeDisabledOutputReference, jsii.get(self, "disabled"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="enabled")
    def enabled(
        self,
    ) -> DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeEnabledOutputReference:
        return typing.cast(DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeEnabledOutputReference, jsii.get(self, "enabled"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="disabledInput")
    def disabled_input(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeDisabled]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeDisabled], jsii.get(self, "disabledInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="enabledInput")
    def enabled_input(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeEnabled]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeEnabled], jsii.get(self, "enabledInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsMode]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsMode], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsMode],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DatatransferEndpointSettingsPostgresTargetConnectionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsPostgresTargetConnectionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putOnPremise")
    def put_on_premise(
        self,
        *,
        ca_certificate: typing.Optional[builtins.str] = None,
        hosts: typing.Optional[typing.Sequence[builtins.str]] = None,
        port: typing.Optional[jsii.Number] = None,
        subnet_id: typing.Optional[builtins.str] = None,
        tls_mode: typing.Optional[DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsMode] = None,
    ) -> None:
        '''
        :param ca_certificate: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#ca_certificate DatatransferEndpoint#ca_certificate}.
        :param hosts: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#hosts DatatransferEndpoint#hosts}.
        :param port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#port DatatransferEndpoint#port}.
        :param subnet_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#subnet_id DatatransferEndpoint#subnet_id}.
        :param tls_mode: tls_mode block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#tls_mode DatatransferEndpoint#tls_mode}
        '''
        value = DatatransferEndpointSettingsPostgresTargetConnectionOnPremise(
            ca_certificate=ca_certificate,
            hosts=hosts,
            port=port,
            subnet_id=subnet_id,
            tls_mode=tls_mode,
        )

        return typing.cast(None, jsii.invoke(self, "putOnPremise", [value]))

    @jsii.member(jsii_name="resetMdbClusterId")
    def reset_mdb_cluster_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMdbClusterId", []))

    @jsii.member(jsii_name="resetOnPremise")
    def reset_on_premise(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOnPremise", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="onPremise")
    def on_premise(
        self,
    ) -> DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseOutputReference:
        return typing.cast(DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseOutputReference, jsii.get(self, "onPremise"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mdbClusterIdInput")
    def mdb_cluster_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "mdbClusterIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="onPremiseInput")
    def on_premise_input(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsPostgresTargetConnectionOnPremise]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsPostgresTargetConnectionOnPremise], jsii.get(self, "onPremiseInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mdbClusterId")
    def mdb_cluster_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "mdbClusterId"))

    @mdb_cluster_id.setter
    def mdb_cluster_id(self, value: builtins.str) -> None:
        jsii.set(self, "mdbClusterId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsPostgresTargetConnection]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsPostgresTargetConnection], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DatatransferEndpointSettingsPostgresTargetConnection],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DatatransferEndpointSettingsPostgresTargetOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsPostgresTargetOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putConnection")
    def put_connection(
        self,
        *,
        mdb_cluster_id: typing.Optional[builtins.str] = None,
        on_premise: typing.Optional[DatatransferEndpointSettingsPostgresTargetConnectionOnPremise] = None,
    ) -> None:
        '''
        :param mdb_cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#mdb_cluster_id DatatransferEndpoint#mdb_cluster_id}.
        :param on_premise: on_premise block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#on_premise DatatransferEndpoint#on_premise}
        '''
        value = DatatransferEndpointSettingsPostgresTargetConnection(
            mdb_cluster_id=mdb_cluster_id, on_premise=on_premise
        )

        return typing.cast(None, jsii.invoke(self, "putConnection", [value]))

    @jsii.member(jsii_name="putPassword")
    def put_password(self, *, raw: typing.Optional[builtins.str] = None) -> None:
        '''
        :param raw: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#raw DatatransferEndpoint#raw}.
        '''
        value = DatatransferEndpointSettingsPostgresTargetPassword(raw=raw)

        return typing.cast(None, jsii.invoke(self, "putPassword", [value]))

    @jsii.member(jsii_name="resetConnection")
    def reset_connection(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetConnection", []))

    @jsii.member(jsii_name="resetDatabase")
    def reset_database(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDatabase", []))

    @jsii.member(jsii_name="resetPassword")
    def reset_password(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPassword", []))

    @jsii.member(jsii_name="resetUser")
    def reset_user(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUser", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="connection")
    def connection(
        self,
    ) -> DatatransferEndpointSettingsPostgresTargetConnectionOutputReference:
        return typing.cast(DatatransferEndpointSettingsPostgresTargetConnectionOutputReference, jsii.get(self, "connection"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="password")
    def password(
        self,
    ) -> "DatatransferEndpointSettingsPostgresTargetPasswordOutputReference":
        return typing.cast("DatatransferEndpointSettingsPostgresTargetPasswordOutputReference", jsii.get(self, "password"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="connectionInput")
    def connection_input(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsPostgresTargetConnection]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsPostgresTargetConnection], jsii.get(self, "connectionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databaseInput")
    def database_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "databaseInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="passwordInput")
    def password_input(
        self,
    ) -> typing.Optional["DatatransferEndpointSettingsPostgresTargetPassword"]:
        return typing.cast(typing.Optional["DatatransferEndpointSettingsPostgresTargetPassword"], jsii.get(self, "passwordInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="userInput")
    def user_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "userInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="database")
    def database(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "database"))

    @database.setter
    def database(self, value: builtins.str) -> None:
        jsii.set(self, "database", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="user")
    def user(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "user"))

    @user.setter
    def user(self, value: builtins.str) -> None:
        jsii.set(self, "user", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsPostgresTarget]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsPostgresTarget], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DatatransferEndpointSettingsPostgresTarget],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsPostgresTargetPassword",
    jsii_struct_bases=[],
    name_mapping={"raw": "raw"},
)
class DatatransferEndpointSettingsPostgresTargetPassword:
    def __init__(self, *, raw: typing.Optional[builtins.str] = None) -> None:
        '''
        :param raw: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#raw DatatransferEndpoint#raw}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if raw is not None:
            self._values["raw"] = raw

    @builtins.property
    def raw(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_endpoint#raw DatatransferEndpoint#raw}.'''
        result = self._values.get("raw")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatatransferEndpointSettingsPostgresTargetPassword(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DatatransferEndpointSettingsPostgresTargetPasswordOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DatatransferEndpointSettingsPostgresTargetPasswordOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetRaw")
    def reset_raw(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRaw", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="rawInput")
    def raw_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "rawInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="raw")
    def raw(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "raw"))

    @raw.setter
    def raw(self, value: builtins.str) -> None:
        jsii.set(self, "raw", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[DatatransferEndpointSettingsPostgresTargetPassword]:
        return typing.cast(typing.Optional[DatatransferEndpointSettingsPostgresTargetPassword], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[DatatransferEndpointSettingsPostgresTargetPassword],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DatatransferTransfer(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DatatransferTransfer",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_transfer yandex_datatransfer_transfer}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        source_id: typing.Optional[builtins.str] = None,
        target_id: typing.Optional[builtins.str] = None,
        type: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_transfer yandex_datatransfer_transfer} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_transfer#description DatatransferTransfer#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_transfer#folder_id DatatransferTransfer#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_transfer#id DatatransferTransfer#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_transfer#labels DatatransferTransfer#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_transfer#name DatatransferTransfer#name}.
        :param source_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_transfer#source_id DatatransferTransfer#source_id}.
        :param target_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_transfer#target_id DatatransferTransfer#target_id}.
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_transfer#type DatatransferTransfer#type}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DatatransferTransferConfig(
            description=description,
            folder_id=folder_id,
            id=id,
            labels=labels,
            name=name,
            source_id=source_id,
            target_id=target_id,
            type=type,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetSourceId")
    def reset_source_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSourceId", []))

    @jsii.member(jsii_name="resetTargetId")
    def reset_target_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTargetId", []))

    @jsii.member(jsii_name="resetType")
    def reset_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetType", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="warning")
    def warning(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "warning"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sourceIdInput")
    def source_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sourceIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetIdInput")
    def target_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "targetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="typeInput")
    def type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "typeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sourceId")
    def source_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sourceId"))

    @source_id.setter
    def source_id(self, value: builtins.str) -> None:
        jsii.set(self, "sourceId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetId")
    def target_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "targetId"))

    @target_id.setter
    def target_id(self, value: builtins.str) -> None:
        jsii.set(self, "targetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @type.setter
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DatatransferTransferConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "description": "description",
        "folder_id": "folderId",
        "id": "id",
        "labels": "labels",
        "name": "name",
        "source_id": "sourceId",
        "target_id": "targetId",
        "type": "type",
    },
)
class DatatransferTransferConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        source_id: typing.Optional[builtins.str] = None,
        target_id: typing.Optional[builtins.str] = None,
        type: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_transfer#description DatatransferTransfer#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_transfer#folder_id DatatransferTransfer#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_transfer#id DatatransferTransfer#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_transfer#labels DatatransferTransfer#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_transfer#name DatatransferTransfer#name}.
        :param source_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_transfer#source_id DatatransferTransfer#source_id}.
        :param target_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_transfer#target_id DatatransferTransfer#target_id}.
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_transfer#type DatatransferTransfer#type}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if name is not None:
            self._values["name"] = name
        if source_id is not None:
            self._values["source_id"] = source_id
        if target_id is not None:
            self._values["target_id"] = target_id
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_transfer#description DatatransferTransfer#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_transfer#folder_id DatatransferTransfer#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_transfer#id DatatransferTransfer#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_transfer#labels DatatransferTransfer#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_transfer#name DatatransferTransfer#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def source_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_transfer#source_id DatatransferTransfer#source_id}.'''
        result = self._values.get("source_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def target_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_transfer#target_id DatatransferTransfer#target_id}.'''
        result = self._values.get("target_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def type(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/datatransfer_transfer#type DatatransferTransfer#type}.'''
        result = self._values.get("type")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatatransferTransferConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DnsRecordset(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DnsRecordset",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/dns_recordset yandex_dns_recordset}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        data: typing.Sequence[builtins.str],
        name: builtins.str,
        ttl: jsii.Number,
        type: builtins.str,
        zone_id: builtins.str,
        id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DnsRecordsetTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/dns_recordset yandex_dns_recordset} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param data: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_recordset#data DnsRecordset#data}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_recordset#name DnsRecordset#name}.
        :param ttl: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_recordset#ttl DnsRecordset#ttl}.
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_recordset#type DnsRecordset#type}.
        :param zone_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_recordset#zone_id DnsRecordset#zone_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_recordset#id DnsRecordset#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_recordset#timeouts DnsRecordset#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DnsRecordsetConfig(
            data=data,
            name=name,
            ttl=ttl,
            type=type,
            zone_id=zone_id,
            id=id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_recordset#create DnsRecordset#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_recordset#delete DnsRecordset#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_recordset#update DnsRecordset#update}.
        '''
        value = DnsRecordsetTimeouts(create=create, delete=delete, update=update)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "DnsRecordsetTimeoutsOutputReference":
        return typing.cast("DnsRecordsetTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dataInput")
    def data_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "dataInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "DnsRecordsetTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "DnsRecordsetTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ttlInput")
    def ttl_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "ttlInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="typeInput")
    def type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "typeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneIdInput")
    def zone_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "zoneIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="data")
    def data(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "data"))

    @data.setter
    def data(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "data", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ttl")
    def ttl(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "ttl"))

    @ttl.setter
    def ttl(self, value: jsii.Number) -> None:
        jsii.set(self, "ttl", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @type.setter
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneId")
    def zone_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zoneId"))

    @zone_id.setter
    def zone_id(self, value: builtins.str) -> None:
        jsii.set(self, "zoneId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DnsRecordsetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "data": "data",
        "name": "name",
        "ttl": "ttl",
        "type": "type",
        "zone_id": "zoneId",
        "id": "id",
        "timeouts": "timeouts",
    },
)
class DnsRecordsetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        data: typing.Sequence[builtins.str],
        name: builtins.str,
        ttl: jsii.Number,
        type: builtins.str,
        zone_id: builtins.str,
        id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["DnsRecordsetTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param data: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_recordset#data DnsRecordset#data}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_recordset#name DnsRecordset#name}.
        :param ttl: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_recordset#ttl DnsRecordset#ttl}.
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_recordset#type DnsRecordset#type}.
        :param zone_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_recordset#zone_id DnsRecordset#zone_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_recordset#id DnsRecordset#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_recordset#timeouts DnsRecordset#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DnsRecordsetTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "data": data,
            "name": name,
            "ttl": ttl,
            "type": type,
            "zone_id": zone_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if id is not None:
            self._values["id"] = id
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def data(self) -> typing.List[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_recordset#data DnsRecordset#data}.'''
        result = self._values.get("data")
        assert result is not None, "Required property 'data' is missing"
        return typing.cast(typing.List[builtins.str], result)

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_recordset#name DnsRecordset#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def ttl(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_recordset#ttl DnsRecordset#ttl}.'''
        result = self._values.get("ttl")
        assert result is not None, "Required property 'ttl' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def type(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_recordset#type DnsRecordset#type}.'''
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def zone_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_recordset#zone_id DnsRecordset#zone_id}.'''
        result = self._values.get("zone_id")
        assert result is not None, "Required property 'zone_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_recordset#id DnsRecordset#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["DnsRecordsetTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_recordset#timeouts DnsRecordset#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["DnsRecordsetTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DnsRecordsetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DnsRecordsetTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class DnsRecordsetTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_recordset#create DnsRecordset#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_recordset#delete DnsRecordset#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_recordset#update DnsRecordset#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_recordset#create DnsRecordset#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_recordset#delete DnsRecordset#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_recordset#update DnsRecordset#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DnsRecordsetTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DnsRecordsetTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DnsRecordsetTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, DnsRecordsetTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, DnsRecordsetTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, DnsRecordsetTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class DnsZone(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DnsZone",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone yandex_dns_zone}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        zone: builtins.str,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        private_networks: typing.Optional[typing.Sequence[builtins.str]] = None,
        public: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        timeouts: typing.Optional["DnsZoneTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone yandex_dns_zone} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param zone: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#zone DnsZone#zone}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#description DnsZone#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#folder_id DnsZone#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#id DnsZone#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#labels DnsZone#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#name DnsZone#name}.
        :param private_networks: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#private_networks DnsZone#private_networks}.
        :param public: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#public DnsZone#public}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#timeouts DnsZone#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = DnsZoneConfig(
            zone=zone,
            description=description,
            folder_id=folder_id,
            id=id,
            labels=labels,
            name=name,
            private_networks=private_networks,
            public=public,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#create DnsZone#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#delete DnsZone#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#update DnsZone#update}.
        '''
        value = DnsZoneTimeouts(create=create, delete=delete, update=update)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetPrivateNetworks")
    def reset_private_networks(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrivateNetworks", []))

    @jsii.member(jsii_name="resetPublic")
    def reset_public(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPublic", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "DnsZoneTimeoutsOutputReference":
        return typing.cast("DnsZoneTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="privateNetworksInput")
    def private_networks_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "privateNetworksInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="publicInput")
    def public_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "publicInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "DnsZoneTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "DnsZoneTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneInput")
    def zone_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "zoneInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="privateNetworks")
    def private_networks(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "privateNetworks"))

    @private_networks.setter
    def private_networks(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "privateNetworks", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="public")
    def public(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "public"))

    @public.setter
    def public(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "public", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zone")
    def zone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zone"))

    @zone.setter
    def zone(self, value: builtins.str) -> None:
        jsii.set(self, "zone", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DnsZoneConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "zone": "zone",
        "description": "description",
        "folder_id": "folderId",
        "id": "id",
        "labels": "labels",
        "name": "name",
        "private_networks": "privateNetworks",
        "public": "public",
        "timeouts": "timeouts",
    },
)
class DnsZoneConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        zone: builtins.str,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        private_networks: typing.Optional[typing.Sequence[builtins.str]] = None,
        public: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        timeouts: typing.Optional["DnsZoneTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param zone: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#zone DnsZone#zone}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#description DnsZone#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#folder_id DnsZone#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#id DnsZone#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#labels DnsZone#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#name DnsZone#name}.
        :param private_networks: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#private_networks DnsZone#private_networks}.
        :param public: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#public DnsZone#public}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#timeouts DnsZone#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DnsZoneTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "zone": zone,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if name is not None:
            self._values["name"] = name
        if private_networks is not None:
            self._values["private_networks"] = private_networks
        if public is not None:
            self._values["public"] = public
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def zone(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#zone DnsZone#zone}.'''
        result = self._values.get("zone")
        assert result is not None, "Required property 'zone' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#description DnsZone#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#folder_id DnsZone#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#id DnsZone#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#labels DnsZone#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#name DnsZone#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def private_networks(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#private_networks DnsZone#private_networks}.'''
        result = self._values.get("private_networks")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def public(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#public DnsZone#public}.'''
        result = self._values.get("public")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["DnsZoneTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#timeouts DnsZone#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["DnsZoneTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DnsZoneConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.DnsZoneTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class DnsZoneTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#create DnsZone#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#delete DnsZone#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#update DnsZone#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#create DnsZone#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#delete DnsZone#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/dns_zone#update DnsZone#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DnsZoneTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DnsZoneTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.DnsZoneTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, DnsZoneTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, DnsZoneTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, DnsZoneTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class Function(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.Function",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/function yandex_function}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        entrypoint: builtins.str,
        memory: jsii.Number,
        name: builtins.str,
        runtime: builtins.str,
        user_hash: builtins.str,
        content: typing.Optional["FunctionContent"] = None,
        description: typing.Optional[builtins.str] = None,
        environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        execution_timeout: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        package: typing.Optional["FunctionPackage"] = None,
        service_account_id: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        timeouts: typing.Optional["FunctionTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/function yandex_function} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param entrypoint: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#entrypoint Function#entrypoint}.
        :param memory: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#memory Function#memory}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#name Function#name}.
        :param runtime: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#runtime Function#runtime}.
        :param user_hash: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#user_hash Function#user_hash}.
        :param content: content block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#content Function#content}
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#description Function#description}.
        :param environment: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#environment Function#environment}.
        :param execution_timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#execution_timeout Function#execution_timeout}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#folder_id Function#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#id Function#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#labels Function#labels}.
        :param package: package block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#package Function#package}
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#service_account_id Function#service_account_id}.
        :param tags: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#tags Function#tags}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#timeouts Function#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = FunctionConfig(
            entrypoint=entrypoint,
            memory=memory,
            name=name,
            runtime=runtime,
            user_hash=user_hash,
            content=content,
            description=description,
            environment=environment,
            execution_timeout=execution_timeout,
            folder_id=folder_id,
            id=id,
            labels=labels,
            package=package,
            service_account_id=service_account_id,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putContent")
    def put_content(self, *, zip_filename: builtins.str) -> None:
        '''
        :param zip_filename: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#zip_filename Function#zip_filename}.
        '''
        value = FunctionContent(zip_filename=zip_filename)

        return typing.cast(None, jsii.invoke(self, "putContent", [value]))

    @jsii.member(jsii_name="putPackage")
    def put_package(
        self,
        *,
        bucket_name: builtins.str,
        object_name: builtins.str,
        sha256: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param bucket_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#bucket_name Function#bucket_name}.
        :param object_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#object_name Function#object_name}.
        :param sha256: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#sha_256 Function#sha_256}.
        '''
        value = FunctionPackage(
            bucket_name=bucket_name, object_name=object_name, sha256=sha256
        )

        return typing.cast(None, jsii.invoke(self, "putPackage", [value]))

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#create Function#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#delete Function#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#update Function#update}.
        '''
        value = FunctionTimeouts(create=create, delete=delete, update=update)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetContent")
    def reset_content(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetContent", []))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetEnvironment")
    def reset_environment(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEnvironment", []))

    @jsii.member(jsii_name="resetExecutionTimeout")
    def reset_execution_timeout(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetExecutionTimeout", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetPackage")
    def reset_package(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPackage", []))

    @jsii.member(jsii_name="resetServiceAccountId")
    def reset_service_account_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetServiceAccountId", []))

    @jsii.member(jsii_name="resetTags")
    def reset_tags(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTags", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="content")
    def content(self) -> "FunctionContentOutputReference":
        return typing.cast("FunctionContentOutputReference", jsii.get(self, "content"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="imageSize")
    def image_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "imageSize"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="loggroupId")
    def loggroup_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "loggroupId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="package")
    def package(self) -> "FunctionPackageOutputReference":
        return typing.cast("FunctionPackageOutputReference", jsii.get(self, "package"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "FunctionTimeoutsOutputReference":
        return typing.cast("FunctionTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "version"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="contentInput")
    def content_input(self) -> typing.Optional["FunctionContent"]:
        return typing.cast(typing.Optional["FunctionContent"], jsii.get(self, "contentInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="entrypointInput")
    def entrypoint_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "entrypointInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="environmentInput")
    def environment_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "environmentInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="executionTimeoutInput")
    def execution_timeout_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "executionTimeoutInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="memoryInput")
    def memory_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "memoryInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="packageInput")
    def package_input(self) -> typing.Optional["FunctionPackage"]:
        return typing.cast(typing.Optional["FunctionPackage"], jsii.get(self, "packageInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="runtimeInput")
    def runtime_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "runtimeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountIdInput")
    def service_account_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceAccountIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tagsInput")
    def tags_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "tagsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "FunctionTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "FunctionTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="userHashInput")
    def user_hash_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "userHashInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="entrypoint")
    def entrypoint(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "entrypoint"))

    @entrypoint.setter
    def entrypoint(self, value: builtins.str) -> None:
        jsii.set(self, "entrypoint", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="environment")
    def environment(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "environment"))

    @environment.setter
    def environment(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "environment", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="executionTimeout")
    def execution_timeout(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "executionTimeout"))

    @execution_timeout.setter
    def execution_timeout(self, value: builtins.str) -> None:
        jsii.set(self, "executionTimeout", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="memory")
    def memory(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "memory"))

    @memory.setter
    def memory(self, value: jsii.Number) -> None:
        jsii.set(self, "memory", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="runtime")
    def runtime(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "runtime"))

    @runtime.setter
    def runtime(self, value: builtins.str) -> None:
        jsii.set(self, "runtime", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountId")
    def service_account_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceAccountId"))

    @service_account_id.setter
    def service_account_id(self, value: builtins.str) -> None:
        jsii.set(self, "serviceAccountId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "tags"))

    @tags.setter
    def tags(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="userHash")
    def user_hash(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "userHash"))

    @user_hash.setter
    def user_hash(self, value: builtins.str) -> None:
        jsii.set(self, "userHash", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.FunctionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "entrypoint": "entrypoint",
        "memory": "memory",
        "name": "name",
        "runtime": "runtime",
        "user_hash": "userHash",
        "content": "content",
        "description": "description",
        "environment": "environment",
        "execution_timeout": "executionTimeout",
        "folder_id": "folderId",
        "id": "id",
        "labels": "labels",
        "package": "package",
        "service_account_id": "serviceAccountId",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class FunctionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        entrypoint: builtins.str,
        memory: jsii.Number,
        name: builtins.str,
        runtime: builtins.str,
        user_hash: builtins.str,
        content: typing.Optional["FunctionContent"] = None,
        description: typing.Optional[builtins.str] = None,
        environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        execution_timeout: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        package: typing.Optional["FunctionPackage"] = None,
        service_account_id: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        timeouts: typing.Optional["FunctionTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param entrypoint: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#entrypoint Function#entrypoint}.
        :param memory: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#memory Function#memory}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#name Function#name}.
        :param runtime: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#runtime Function#runtime}.
        :param user_hash: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#user_hash Function#user_hash}.
        :param content: content block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#content Function#content}
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#description Function#description}.
        :param environment: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#environment Function#environment}.
        :param execution_timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#execution_timeout Function#execution_timeout}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#folder_id Function#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#id Function#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#labels Function#labels}.
        :param package: package block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#package Function#package}
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#service_account_id Function#service_account_id}.
        :param tags: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#tags Function#tags}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#timeouts Function#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(content, dict):
            content = FunctionContent(**content)
        if isinstance(package, dict):
            package = FunctionPackage(**package)
        if isinstance(timeouts, dict):
            timeouts = FunctionTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "entrypoint": entrypoint,
            "memory": memory,
            "name": name,
            "runtime": runtime,
            "user_hash": user_hash,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if content is not None:
            self._values["content"] = content
        if description is not None:
            self._values["description"] = description
        if environment is not None:
            self._values["environment"] = environment
        if execution_timeout is not None:
            self._values["execution_timeout"] = execution_timeout
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if package is not None:
            self._values["package"] = package
        if service_account_id is not None:
            self._values["service_account_id"] = service_account_id
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def entrypoint(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#entrypoint Function#entrypoint}.'''
        result = self._values.get("entrypoint")
        assert result is not None, "Required property 'entrypoint' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def memory(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#memory Function#memory}.'''
        result = self._values.get("memory")
        assert result is not None, "Required property 'memory' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#name Function#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def runtime(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#runtime Function#runtime}.'''
        result = self._values.get("runtime")
        assert result is not None, "Required property 'runtime' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def user_hash(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#user_hash Function#user_hash}.'''
        result = self._values.get("user_hash")
        assert result is not None, "Required property 'user_hash' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def content(self) -> typing.Optional["FunctionContent"]:
        '''content block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#content Function#content}
        '''
        result = self._values.get("content")
        return typing.cast(typing.Optional["FunctionContent"], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#description Function#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def environment(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#environment Function#environment}.'''
        result = self._values.get("environment")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def execution_timeout(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#execution_timeout Function#execution_timeout}.'''
        result = self._values.get("execution_timeout")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#folder_id Function#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#id Function#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#labels Function#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def package(self) -> typing.Optional["FunctionPackage"]:
        '''package block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#package Function#package}
        '''
        result = self._values.get("package")
        return typing.cast(typing.Optional["FunctionPackage"], result)

    @builtins.property
    def service_account_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#service_account_id Function#service_account_id}.'''
        result = self._values.get("service_account_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#tags Function#tags}.'''
        result = self._values.get("tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["FunctionTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#timeouts Function#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["FunctionTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FunctionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.FunctionContent",
    jsii_struct_bases=[],
    name_mapping={"zip_filename": "zipFilename"},
)
class FunctionContent:
    def __init__(self, *, zip_filename: builtins.str) -> None:
        '''
        :param zip_filename: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#zip_filename Function#zip_filename}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "zip_filename": zip_filename,
        }

    @builtins.property
    def zip_filename(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#zip_filename Function#zip_filename}.'''
        result = self._values.get("zip_filename")
        assert result is not None, "Required property 'zip_filename' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FunctionContent(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class FunctionContentOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.FunctionContentOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zipFilenameInput")
    def zip_filename_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "zipFilenameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zipFilename")
    def zip_filename(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zipFilename"))

    @zip_filename.setter
    def zip_filename(self, value: builtins.str) -> None:
        jsii.set(self, "zipFilename", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[FunctionContent]:
        return typing.cast(typing.Optional[FunctionContent], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(self, value: typing.Optional[FunctionContent]) -> None:
        jsii.set(self, "internalValue", value)


class FunctionIamBinding(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.FunctionIamBinding",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/function_iam_binding yandex_function_iam_binding}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        function_id: builtins.str,
        members: typing.Sequence[builtins.str],
        role: builtins.str,
        id: typing.Optional[builtins.str] = None,
        sleep_after: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/function_iam_binding yandex_function_iam_binding} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param function_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_iam_binding#function_id FunctionIamBinding#function_id}.
        :param members: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_iam_binding#members FunctionIamBinding#members}.
        :param role: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_iam_binding#role FunctionIamBinding#role}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_iam_binding#id FunctionIamBinding#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param sleep_after: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_iam_binding#sleep_after FunctionIamBinding#sleep_after}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = FunctionIamBindingConfig(
            function_id=function_id,
            members=members,
            role=role,
            id=id,
            sleep_after=sleep_after,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetSleepAfter")
    def reset_sleep_after(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSleepAfter", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="functionIdInput")
    def function_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "functionIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="membersInput")
    def members_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "membersInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="roleInput")
    def role_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "roleInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sleepAfterInput")
    def sleep_after_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "sleepAfterInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="functionId")
    def function_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "functionId"))

    @function_id.setter
    def function_id(self, value: builtins.str) -> None:
        jsii.set(self, "functionId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="members")
    def members(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "members"))

    @members.setter
    def members(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "members", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="role")
    def role(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "role"))

    @role.setter
    def role(self, value: builtins.str) -> None:
        jsii.set(self, "role", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sleepAfter")
    def sleep_after(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "sleepAfter"))

    @sleep_after.setter
    def sleep_after(self, value: jsii.Number) -> None:
        jsii.set(self, "sleepAfter", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.FunctionIamBindingConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "function_id": "functionId",
        "members": "members",
        "role": "role",
        "id": "id",
        "sleep_after": "sleepAfter",
    },
)
class FunctionIamBindingConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        function_id: builtins.str,
        members: typing.Sequence[builtins.str],
        role: builtins.str,
        id: typing.Optional[builtins.str] = None,
        sleep_after: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param function_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_iam_binding#function_id FunctionIamBinding#function_id}.
        :param members: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_iam_binding#members FunctionIamBinding#members}.
        :param role: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_iam_binding#role FunctionIamBinding#role}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_iam_binding#id FunctionIamBinding#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param sleep_after: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_iam_binding#sleep_after FunctionIamBinding#sleep_after}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {
            "function_id": function_id,
            "members": members,
            "role": role,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if id is not None:
            self._values["id"] = id
        if sleep_after is not None:
            self._values["sleep_after"] = sleep_after

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def function_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_iam_binding#function_id FunctionIamBinding#function_id}.'''
        result = self._values.get("function_id")
        assert result is not None, "Required property 'function_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def members(self) -> typing.List[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_iam_binding#members FunctionIamBinding#members}.'''
        result = self._values.get("members")
        assert result is not None, "Required property 'members' is missing"
        return typing.cast(typing.List[builtins.str], result)

    @builtins.property
    def role(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_iam_binding#role FunctionIamBinding#role}.'''
        result = self._values.get("role")
        assert result is not None, "Required property 'role' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_iam_binding#id FunctionIamBinding#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def sleep_after(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_iam_binding#sleep_after FunctionIamBinding#sleep_after}.'''
        result = self._values.get("sleep_after")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FunctionIamBindingConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.FunctionPackage",
    jsii_struct_bases=[],
    name_mapping={
        "bucket_name": "bucketName",
        "object_name": "objectName",
        "sha256": "sha256",
    },
)
class FunctionPackage:
    def __init__(
        self,
        *,
        bucket_name: builtins.str,
        object_name: builtins.str,
        sha256: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param bucket_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#bucket_name Function#bucket_name}.
        :param object_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#object_name Function#object_name}.
        :param sha256: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#sha_256 Function#sha_256}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "bucket_name": bucket_name,
            "object_name": object_name,
        }
        if sha256 is not None:
            self._values["sha256"] = sha256

    @builtins.property
    def bucket_name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#bucket_name Function#bucket_name}.'''
        result = self._values.get("bucket_name")
        assert result is not None, "Required property 'bucket_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def object_name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#object_name Function#object_name}.'''
        result = self._values.get("object_name")
        assert result is not None, "Required property 'object_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def sha256(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#sha_256 Function#sha_256}.'''
        result = self._values.get("sha256")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FunctionPackage(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class FunctionPackageOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.FunctionPackageOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetSha256")
    def reset_sha256(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSha256", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bucketNameInput")
    def bucket_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "bucketNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="objectNameInput")
    def object_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "objectNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sha256Input")
    def sha256_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sha256Input"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bucketName")
    def bucket_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "bucketName"))

    @bucket_name.setter
    def bucket_name(self, value: builtins.str) -> None:
        jsii.set(self, "bucketName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="objectName")
    def object_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "objectName"))

    @object_name.setter
    def object_name(self, value: builtins.str) -> None:
        jsii.set(self, "objectName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sha256")
    def sha256(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sha256"))

    @sha256.setter
    def sha256(self, value: builtins.str) -> None:
        jsii.set(self, "sha256", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[FunctionPackage]:
        return typing.cast(typing.Optional[FunctionPackage], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(self, value: typing.Optional[FunctionPackage]) -> None:
        jsii.set(self, "internalValue", value)


class FunctionScalingPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.FunctionScalingPolicy",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/function_scaling_policy yandex_function_scaling_policy}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        function_id: builtins.str,
        id: typing.Optional[builtins.str] = None,
        policy: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["FunctionScalingPolicyPolicy"]]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/function_scaling_policy yandex_function_scaling_policy} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param function_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_scaling_policy#function_id FunctionScalingPolicy#function_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_scaling_policy#id FunctionScalingPolicy#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param policy: policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_scaling_policy#policy FunctionScalingPolicy#policy}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = FunctionScalingPolicyConfig(
            function_id=function_id,
            id=id,
            policy=policy,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putPolicy")
    def put_policy(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["FunctionScalingPolicyPolicy"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putPolicy", [value]))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetPolicy")
    def reset_policy(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPolicy", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="policy")
    def policy(self) -> "FunctionScalingPolicyPolicyList":
        return typing.cast("FunctionScalingPolicyPolicyList", jsii.get(self, "policy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="functionIdInput")
    def function_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "functionIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="policyInput")
    def policy_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["FunctionScalingPolicyPolicy"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["FunctionScalingPolicyPolicy"]]], jsii.get(self, "policyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="functionId")
    def function_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "functionId"))

    @function_id.setter
    def function_id(self, value: builtins.str) -> None:
        jsii.set(self, "functionId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.FunctionScalingPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "function_id": "functionId",
        "id": "id",
        "policy": "policy",
    },
)
class FunctionScalingPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        function_id: builtins.str,
        id: typing.Optional[builtins.str] = None,
        policy: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["FunctionScalingPolicyPolicy"]]] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param function_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_scaling_policy#function_id FunctionScalingPolicy#function_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_scaling_policy#id FunctionScalingPolicy#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param policy: policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_scaling_policy#policy FunctionScalingPolicy#policy}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {
            "function_id": function_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if id is not None:
            self._values["id"] = id
        if policy is not None:
            self._values["policy"] = policy

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def function_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_scaling_policy#function_id FunctionScalingPolicy#function_id}.'''
        result = self._values.get("function_id")
        assert result is not None, "Required property 'function_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_scaling_policy#id FunctionScalingPolicy#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def policy(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["FunctionScalingPolicyPolicy"]]]:
        '''policy block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_scaling_policy#policy FunctionScalingPolicy#policy}
        '''
        result = self._values.get("policy")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["FunctionScalingPolicyPolicy"]]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FunctionScalingPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.FunctionScalingPolicyPolicy",
    jsii_struct_bases=[],
    name_mapping={
        "tag": "tag",
        "zone_instances_limit": "zoneInstancesLimit",
        "zone_requests_limit": "zoneRequestsLimit",
    },
)
class FunctionScalingPolicyPolicy:
    def __init__(
        self,
        *,
        tag: builtins.str,
        zone_instances_limit: typing.Optional[jsii.Number] = None,
        zone_requests_limit: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param tag: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_scaling_policy#tag FunctionScalingPolicy#tag}.
        :param zone_instances_limit: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_scaling_policy#zone_instances_limit FunctionScalingPolicy#zone_instances_limit}.
        :param zone_requests_limit: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_scaling_policy#zone_requests_limit FunctionScalingPolicy#zone_requests_limit}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "tag": tag,
        }
        if zone_instances_limit is not None:
            self._values["zone_instances_limit"] = zone_instances_limit
        if zone_requests_limit is not None:
            self._values["zone_requests_limit"] = zone_requests_limit

    @builtins.property
    def tag(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_scaling_policy#tag FunctionScalingPolicy#tag}.'''
        result = self._values.get("tag")
        assert result is not None, "Required property 'tag' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def zone_instances_limit(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_scaling_policy#zone_instances_limit FunctionScalingPolicy#zone_instances_limit}.'''
        result = self._values.get("zone_instances_limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def zone_requests_limit(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_scaling_policy#zone_requests_limit FunctionScalingPolicy#zone_requests_limit}.'''
        result = self._values.get("zone_requests_limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FunctionScalingPolicyPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class FunctionScalingPolicyPolicyList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.FunctionScalingPolicyPolicyList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "FunctionScalingPolicyPolicyOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("FunctionScalingPolicyPolicyOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[FunctionScalingPolicyPolicy]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[FunctionScalingPolicyPolicy]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[FunctionScalingPolicyPolicy]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class FunctionScalingPolicyPolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.FunctionScalingPolicyPolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetZoneInstancesLimit")
    def reset_zone_instances_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetZoneInstancesLimit", []))

    @jsii.member(jsii_name="resetZoneRequestsLimit")
    def reset_zone_requests_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetZoneRequestsLimit", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tagInput")
    def tag_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "tagInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneInstancesLimitInput")
    def zone_instances_limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "zoneInstancesLimitInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneRequestsLimitInput")
    def zone_requests_limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "zoneRequestsLimitInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tag")
    def tag(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "tag"))

    @tag.setter
    def tag(self, value: builtins.str) -> None:
        jsii.set(self, "tag", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneInstancesLimit")
    def zone_instances_limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "zoneInstancesLimit"))

    @zone_instances_limit.setter
    def zone_instances_limit(self, value: jsii.Number) -> None:
        jsii.set(self, "zoneInstancesLimit", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneRequestsLimit")
    def zone_requests_limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "zoneRequestsLimit"))

    @zone_requests_limit.setter
    def zone_requests_limit(self, value: jsii.Number) -> None:
        jsii.set(self, "zoneRequestsLimit", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, FunctionScalingPolicyPolicy]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, FunctionScalingPolicyPolicy]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, FunctionScalingPolicyPolicy]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.FunctionTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class FunctionTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#create Function#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#delete Function#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#update Function#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#create Function#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#delete Function#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function#update Function#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FunctionTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class FunctionTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.FunctionTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, FunctionTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, FunctionTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, FunctionTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class FunctionTrigger(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.FunctionTrigger",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger yandex_function_trigger}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        function: "FunctionTriggerFunction",
        name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        dlq: typing.Optional["FunctionTriggerDlq"] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        iot: typing.Optional["FunctionTriggerIot"] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        logging: typing.Optional["FunctionTriggerLogging"] = None,
        log_group: typing.Optional["FunctionTriggerLogGroup"] = None,
        message_queue: typing.Optional["FunctionTriggerMessageQueue"] = None,
        object_storage: typing.Optional["FunctionTriggerObjectStorage"] = None,
        timeouts: typing.Optional["FunctionTriggerTimeouts"] = None,
        timer: typing.Optional["FunctionTriggerTimer"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger yandex_function_trigger} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param function: function block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#function FunctionTrigger#function}
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#name FunctionTrigger#name}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#description FunctionTrigger#description}.
        :param dlq: dlq block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#dlq FunctionTrigger#dlq}
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#folder_id FunctionTrigger#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#id FunctionTrigger#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param iot: iot block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#iot FunctionTrigger#iot}
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#labels FunctionTrigger#labels}.
        :param logging: logging block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#logging FunctionTrigger#logging}
        :param log_group: log_group block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#log_group FunctionTrigger#log_group}
        :param message_queue: message_queue block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#message_queue FunctionTrigger#message_queue}
        :param object_storage: object_storage block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#object_storage FunctionTrigger#object_storage}
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#timeouts FunctionTrigger#timeouts}
        :param timer: timer block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#timer FunctionTrigger#timer}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = FunctionTriggerConfig(
            function=function,
            name=name,
            description=description,
            dlq=dlq,
            folder_id=folder_id,
            id=id,
            iot=iot,
            labels=labels,
            logging=logging,
            log_group=log_group,
            message_queue=message_queue,
            object_storage=object_storage,
            timeouts=timeouts,
            timer=timer,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putDlq")
    def put_dlq(
        self,
        *,
        queue_id: builtins.str,
        service_account_id: builtins.str,
    ) -> None:
        '''
        :param queue_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#queue_id FunctionTrigger#queue_id}.
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#service_account_id FunctionTrigger#service_account_id}.
        '''
        value = FunctionTriggerDlq(
            queue_id=queue_id, service_account_id=service_account_id
        )

        return typing.cast(None, jsii.invoke(self, "putDlq", [value]))

    @jsii.member(jsii_name="putFunction")
    def put_function(
        self,
        *,
        id: builtins.str,
        retry_attempts: typing.Optional[builtins.str] = None,
        retry_interval: typing.Optional[builtins.str] = None,
        service_account_id: typing.Optional[builtins.str] = None,
        tag: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#id FunctionTrigger#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param retry_attempts: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#retry_attempts FunctionTrigger#retry_attempts}.
        :param retry_interval: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#retry_interval FunctionTrigger#retry_interval}.
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#service_account_id FunctionTrigger#service_account_id}.
        :param tag: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#tag FunctionTrigger#tag}.
        '''
        value = FunctionTriggerFunction(
            id=id,
            retry_attempts=retry_attempts,
            retry_interval=retry_interval,
            service_account_id=service_account_id,
            tag=tag,
        )

        return typing.cast(None, jsii.invoke(self, "putFunction", [value]))

    @jsii.member(jsii_name="putIot")
    def put_iot(
        self,
        *,
        registry_id: builtins.str,
        device_id: typing.Optional[builtins.str] = None,
        topic: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param registry_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#registry_id FunctionTrigger#registry_id}.
        :param device_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#device_id FunctionTrigger#device_id}.
        :param topic: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#topic FunctionTrigger#topic}.
        '''
        value = FunctionTriggerIot(
            registry_id=registry_id, device_id=device_id, topic=topic
        )

        return typing.cast(None, jsii.invoke(self, "putIot", [value]))

    @jsii.member(jsii_name="putLogging")
    def put_logging(
        self,
        *,
        batch_cutoff: builtins.str,
        group_id: builtins.str,
        levels: typing.Sequence[builtins.str],
        resource_ids: typing.Sequence[builtins.str],
        resource_types: typing.Sequence[builtins.str],
        batch_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param batch_cutoff: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#batch_cutoff FunctionTrigger#batch_cutoff}.
        :param group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#group_id FunctionTrigger#group_id}.
        :param levels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#levels FunctionTrigger#levels}.
        :param resource_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#resource_ids FunctionTrigger#resource_ids}.
        :param resource_types: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#resource_types FunctionTrigger#resource_types}.
        :param batch_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#batch_size FunctionTrigger#batch_size}.
        '''
        value = FunctionTriggerLogging(
            batch_cutoff=batch_cutoff,
            group_id=group_id,
            levels=levels,
            resource_ids=resource_ids,
            resource_types=resource_types,
            batch_size=batch_size,
        )

        return typing.cast(None, jsii.invoke(self, "putLogging", [value]))

    @jsii.member(jsii_name="putLogGroup")
    def put_log_group(
        self,
        *,
        batch_cutoff: builtins.str,
        log_group_ids: typing.Sequence[builtins.str],
        batch_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param batch_cutoff: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#batch_cutoff FunctionTrigger#batch_cutoff}.
        :param log_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#log_group_ids FunctionTrigger#log_group_ids}.
        :param batch_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#batch_size FunctionTrigger#batch_size}.
        '''
        value = FunctionTriggerLogGroup(
            batch_cutoff=batch_cutoff,
            log_group_ids=log_group_ids,
            batch_size=batch_size,
        )

        return typing.cast(None, jsii.invoke(self, "putLogGroup", [value]))

    @jsii.member(jsii_name="putMessageQueue")
    def put_message_queue(
        self,
        *,
        batch_cutoff: builtins.str,
        queue_id: builtins.str,
        service_account_id: builtins.str,
        batch_size: typing.Optional[builtins.str] = None,
        visibility_timeout: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param batch_cutoff: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#batch_cutoff FunctionTrigger#batch_cutoff}.
        :param queue_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#queue_id FunctionTrigger#queue_id}.
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#service_account_id FunctionTrigger#service_account_id}.
        :param batch_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#batch_size FunctionTrigger#batch_size}.
        :param visibility_timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#visibility_timeout FunctionTrigger#visibility_timeout}.
        '''
        value = FunctionTriggerMessageQueue(
            batch_cutoff=batch_cutoff,
            queue_id=queue_id,
            service_account_id=service_account_id,
            batch_size=batch_size,
            visibility_timeout=visibility_timeout,
        )

        return typing.cast(None, jsii.invoke(self, "putMessageQueue", [value]))

    @jsii.member(jsii_name="putObjectStorage")
    def put_object_storage(
        self,
        *,
        bucket_id: builtins.str,
        create: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        delete: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        prefix: typing.Optional[builtins.str] = None,
        suffix: typing.Optional[builtins.str] = None,
        update: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param bucket_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#bucket_id FunctionTrigger#bucket_id}.
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#create FunctionTrigger#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#delete FunctionTrigger#delete}.
        :param prefix: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#prefix FunctionTrigger#prefix}.
        :param suffix: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#suffix FunctionTrigger#suffix}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#update FunctionTrigger#update}.
        '''
        value = FunctionTriggerObjectStorage(
            bucket_id=bucket_id,
            create=create,
            delete=delete,
            prefix=prefix,
            suffix=suffix,
            update=update,
        )

        return typing.cast(None, jsii.invoke(self, "putObjectStorage", [value]))

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#create FunctionTrigger#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#delete FunctionTrigger#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#update FunctionTrigger#update}.
        '''
        value = FunctionTriggerTimeouts(create=create, delete=delete, update=update)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="putTimer")
    def put_timer(self, *, cron_expression: builtins.str) -> None:
        '''
        :param cron_expression: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#cron_expression FunctionTrigger#cron_expression}.
        '''
        value = FunctionTriggerTimer(cron_expression=cron_expression)

        return typing.cast(None, jsii.invoke(self, "putTimer", [value]))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetDlq")
    def reset_dlq(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDlq", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetIot")
    def reset_iot(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIot", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetLogging")
    def reset_logging(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogging", []))

    @jsii.member(jsii_name="resetLogGroup")
    def reset_log_group(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogGroup", []))

    @jsii.member(jsii_name="resetMessageQueue")
    def reset_message_queue(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMessageQueue", []))

    @jsii.member(jsii_name="resetObjectStorage")
    def reset_object_storage(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetObjectStorage", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="resetTimer")
    def reset_timer(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimer", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dlq")
    def dlq(self) -> "FunctionTriggerDlqOutputReference":
        return typing.cast("FunctionTriggerDlqOutputReference", jsii.get(self, "dlq"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="function")
    def function(self) -> "FunctionTriggerFunctionOutputReference":
        return typing.cast("FunctionTriggerFunctionOutputReference", jsii.get(self, "function"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="iot")
    def iot(self) -> "FunctionTriggerIotOutputReference":
        return typing.cast("FunctionTriggerIotOutputReference", jsii.get(self, "iot"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logging")
    def logging(self) -> "FunctionTriggerLoggingOutputReference":
        return typing.cast("FunctionTriggerLoggingOutputReference", jsii.get(self, "logging"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logGroup")
    def log_group(self) -> "FunctionTriggerLogGroupOutputReference":
        return typing.cast("FunctionTriggerLogGroupOutputReference", jsii.get(self, "logGroup"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="messageQueue")
    def message_queue(self) -> "FunctionTriggerMessageQueueOutputReference":
        return typing.cast("FunctionTriggerMessageQueueOutputReference", jsii.get(self, "messageQueue"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="objectStorage")
    def object_storage(self) -> "FunctionTriggerObjectStorageOutputReference":
        return typing.cast("FunctionTriggerObjectStorageOutputReference", jsii.get(self, "objectStorage"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "FunctionTriggerTimeoutsOutputReference":
        return typing.cast("FunctionTriggerTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timer")
    def timer(self) -> "FunctionTriggerTimerOutputReference":
        return typing.cast("FunctionTriggerTimerOutputReference", jsii.get(self, "timer"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dlqInput")
    def dlq_input(self) -> typing.Optional["FunctionTriggerDlq"]:
        return typing.cast(typing.Optional["FunctionTriggerDlq"], jsii.get(self, "dlqInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="functionInput")
    def function_input(self) -> typing.Optional["FunctionTriggerFunction"]:
        return typing.cast(typing.Optional["FunctionTriggerFunction"], jsii.get(self, "functionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="iotInput")
    def iot_input(self) -> typing.Optional["FunctionTriggerIot"]:
        return typing.cast(typing.Optional["FunctionTriggerIot"], jsii.get(self, "iotInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="loggingInput")
    def logging_input(self) -> typing.Optional["FunctionTriggerLogging"]:
        return typing.cast(typing.Optional["FunctionTriggerLogging"], jsii.get(self, "loggingInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logGroupInput")
    def log_group_input(self) -> typing.Optional["FunctionTriggerLogGroup"]:
        return typing.cast(typing.Optional["FunctionTriggerLogGroup"], jsii.get(self, "logGroupInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="messageQueueInput")
    def message_queue_input(self) -> typing.Optional["FunctionTriggerMessageQueue"]:
        return typing.cast(typing.Optional["FunctionTriggerMessageQueue"], jsii.get(self, "messageQueueInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="objectStorageInput")
    def object_storage_input(self) -> typing.Optional["FunctionTriggerObjectStorage"]:
        return typing.cast(typing.Optional["FunctionTriggerObjectStorage"], jsii.get(self, "objectStorageInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "FunctionTriggerTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "FunctionTriggerTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timerInput")
    def timer_input(self) -> typing.Optional["FunctionTriggerTimer"]:
        return typing.cast(typing.Optional["FunctionTriggerTimer"], jsii.get(self, "timerInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.FunctionTriggerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "function": "function",
        "name": "name",
        "description": "description",
        "dlq": "dlq",
        "folder_id": "folderId",
        "id": "id",
        "iot": "iot",
        "labels": "labels",
        "logging": "logging",
        "log_group": "logGroup",
        "message_queue": "messageQueue",
        "object_storage": "objectStorage",
        "timeouts": "timeouts",
        "timer": "timer",
    },
)
class FunctionTriggerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        function: "FunctionTriggerFunction",
        name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        dlq: typing.Optional["FunctionTriggerDlq"] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        iot: typing.Optional["FunctionTriggerIot"] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        logging: typing.Optional["FunctionTriggerLogging"] = None,
        log_group: typing.Optional["FunctionTriggerLogGroup"] = None,
        message_queue: typing.Optional["FunctionTriggerMessageQueue"] = None,
        object_storage: typing.Optional["FunctionTriggerObjectStorage"] = None,
        timeouts: typing.Optional["FunctionTriggerTimeouts"] = None,
        timer: typing.Optional["FunctionTriggerTimer"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param function: function block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#function FunctionTrigger#function}
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#name FunctionTrigger#name}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#description FunctionTrigger#description}.
        :param dlq: dlq block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#dlq FunctionTrigger#dlq}
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#folder_id FunctionTrigger#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#id FunctionTrigger#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param iot: iot block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#iot FunctionTrigger#iot}
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#labels FunctionTrigger#labels}.
        :param logging: logging block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#logging FunctionTrigger#logging}
        :param log_group: log_group block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#log_group FunctionTrigger#log_group}
        :param message_queue: message_queue block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#message_queue FunctionTrigger#message_queue}
        :param object_storage: object_storage block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#object_storage FunctionTrigger#object_storage}
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#timeouts FunctionTrigger#timeouts}
        :param timer: timer block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#timer FunctionTrigger#timer}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(function, dict):
            function = FunctionTriggerFunction(**function)
        if isinstance(dlq, dict):
            dlq = FunctionTriggerDlq(**dlq)
        if isinstance(iot, dict):
            iot = FunctionTriggerIot(**iot)
        if isinstance(logging, dict):
            logging = FunctionTriggerLogging(**logging)
        if isinstance(log_group, dict):
            log_group = FunctionTriggerLogGroup(**log_group)
        if isinstance(message_queue, dict):
            message_queue = FunctionTriggerMessageQueue(**message_queue)
        if isinstance(object_storage, dict):
            object_storage = FunctionTriggerObjectStorage(**object_storage)
        if isinstance(timeouts, dict):
            timeouts = FunctionTriggerTimeouts(**timeouts)
        if isinstance(timer, dict):
            timer = FunctionTriggerTimer(**timer)
        self._values: typing.Dict[str, typing.Any] = {
            "function": function,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if dlq is not None:
            self._values["dlq"] = dlq
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if iot is not None:
            self._values["iot"] = iot
        if labels is not None:
            self._values["labels"] = labels
        if logging is not None:
            self._values["logging"] = logging
        if log_group is not None:
            self._values["log_group"] = log_group
        if message_queue is not None:
            self._values["message_queue"] = message_queue
        if object_storage is not None:
            self._values["object_storage"] = object_storage
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if timer is not None:
            self._values["timer"] = timer

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def function(self) -> "FunctionTriggerFunction":
        '''function block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#function FunctionTrigger#function}
        '''
        result = self._values.get("function")
        assert result is not None, "Required property 'function' is missing"
        return typing.cast("FunctionTriggerFunction", result)

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#name FunctionTrigger#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#description FunctionTrigger#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def dlq(self) -> typing.Optional["FunctionTriggerDlq"]:
        '''dlq block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#dlq FunctionTrigger#dlq}
        '''
        result = self._values.get("dlq")
        return typing.cast(typing.Optional["FunctionTriggerDlq"], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#folder_id FunctionTrigger#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#id FunctionTrigger#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def iot(self) -> typing.Optional["FunctionTriggerIot"]:
        '''iot block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#iot FunctionTrigger#iot}
        '''
        result = self._values.get("iot")
        return typing.cast(typing.Optional["FunctionTriggerIot"], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#labels FunctionTrigger#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def logging(self) -> typing.Optional["FunctionTriggerLogging"]:
        '''logging block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#logging FunctionTrigger#logging}
        '''
        result = self._values.get("logging")
        return typing.cast(typing.Optional["FunctionTriggerLogging"], result)

    @builtins.property
    def log_group(self) -> typing.Optional["FunctionTriggerLogGroup"]:
        '''log_group block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#log_group FunctionTrigger#log_group}
        '''
        result = self._values.get("log_group")
        return typing.cast(typing.Optional["FunctionTriggerLogGroup"], result)

    @builtins.property
    def message_queue(self) -> typing.Optional["FunctionTriggerMessageQueue"]:
        '''message_queue block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#message_queue FunctionTrigger#message_queue}
        '''
        result = self._values.get("message_queue")
        return typing.cast(typing.Optional["FunctionTriggerMessageQueue"], result)

    @builtins.property
    def object_storage(self) -> typing.Optional["FunctionTriggerObjectStorage"]:
        '''object_storage block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#object_storage FunctionTrigger#object_storage}
        '''
        result = self._values.get("object_storage")
        return typing.cast(typing.Optional["FunctionTriggerObjectStorage"], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["FunctionTriggerTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#timeouts FunctionTrigger#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["FunctionTriggerTimeouts"], result)

    @builtins.property
    def timer(self) -> typing.Optional["FunctionTriggerTimer"]:
        '''timer block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#timer FunctionTrigger#timer}
        '''
        result = self._values.get("timer")
        return typing.cast(typing.Optional["FunctionTriggerTimer"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FunctionTriggerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.FunctionTriggerDlq",
    jsii_struct_bases=[],
    name_mapping={"queue_id": "queueId", "service_account_id": "serviceAccountId"},
)
class FunctionTriggerDlq:
    def __init__(
        self,
        *,
        queue_id: builtins.str,
        service_account_id: builtins.str,
    ) -> None:
        '''
        :param queue_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#queue_id FunctionTrigger#queue_id}.
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#service_account_id FunctionTrigger#service_account_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "queue_id": queue_id,
            "service_account_id": service_account_id,
        }

    @builtins.property
    def queue_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#queue_id FunctionTrigger#queue_id}.'''
        result = self._values.get("queue_id")
        assert result is not None, "Required property 'queue_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def service_account_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#service_account_id FunctionTrigger#service_account_id}.'''
        result = self._values.get("service_account_id")
        assert result is not None, "Required property 'service_account_id' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FunctionTriggerDlq(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class FunctionTriggerDlqOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.FunctionTriggerDlqOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queueIdInput")
    def queue_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queueIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountIdInput")
    def service_account_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceAccountIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queueId")
    def queue_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "queueId"))

    @queue_id.setter
    def queue_id(self, value: builtins.str) -> None:
        jsii.set(self, "queueId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountId")
    def service_account_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceAccountId"))

    @service_account_id.setter
    def service_account_id(self, value: builtins.str) -> None:
        jsii.set(self, "serviceAccountId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[FunctionTriggerDlq]:
        return typing.cast(typing.Optional[FunctionTriggerDlq], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(self, value: typing.Optional[FunctionTriggerDlq]) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.FunctionTriggerFunction",
    jsii_struct_bases=[],
    name_mapping={
        "id": "id",
        "retry_attempts": "retryAttempts",
        "retry_interval": "retryInterval",
        "service_account_id": "serviceAccountId",
        "tag": "tag",
    },
)
class FunctionTriggerFunction:
    def __init__(
        self,
        *,
        id: builtins.str,
        retry_attempts: typing.Optional[builtins.str] = None,
        retry_interval: typing.Optional[builtins.str] = None,
        service_account_id: typing.Optional[builtins.str] = None,
        tag: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#id FunctionTrigger#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param retry_attempts: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#retry_attempts FunctionTrigger#retry_attempts}.
        :param retry_interval: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#retry_interval FunctionTrigger#retry_interval}.
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#service_account_id FunctionTrigger#service_account_id}.
        :param tag: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#tag FunctionTrigger#tag}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "id": id,
        }
        if retry_attempts is not None:
            self._values["retry_attempts"] = retry_attempts
        if retry_interval is not None:
            self._values["retry_interval"] = retry_interval
        if service_account_id is not None:
            self._values["service_account_id"] = service_account_id
        if tag is not None:
            self._values["tag"] = tag

    @builtins.property
    def id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#id FunctionTrigger#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        assert result is not None, "Required property 'id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def retry_attempts(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#retry_attempts FunctionTrigger#retry_attempts}.'''
        result = self._values.get("retry_attempts")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def retry_interval(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#retry_interval FunctionTrigger#retry_interval}.'''
        result = self._values.get("retry_interval")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def service_account_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#service_account_id FunctionTrigger#service_account_id}.'''
        result = self._values.get("service_account_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def tag(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#tag FunctionTrigger#tag}.'''
        result = self._values.get("tag")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FunctionTriggerFunction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class FunctionTriggerFunctionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.FunctionTriggerFunctionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetRetryAttempts")
    def reset_retry_attempts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRetryAttempts", []))

    @jsii.member(jsii_name="resetRetryInterval")
    def reset_retry_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRetryInterval", []))

    @jsii.member(jsii_name="resetServiceAccountId")
    def reset_service_account_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetServiceAccountId", []))

    @jsii.member(jsii_name="resetTag")
    def reset_tag(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTag", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="retryAttemptsInput")
    def retry_attempts_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "retryAttemptsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="retryIntervalInput")
    def retry_interval_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "retryIntervalInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountIdInput")
    def service_account_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceAccountIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tagInput")
    def tag_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "tagInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="retryAttempts")
    def retry_attempts(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "retryAttempts"))

    @retry_attempts.setter
    def retry_attempts(self, value: builtins.str) -> None:
        jsii.set(self, "retryAttempts", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="retryInterval")
    def retry_interval(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "retryInterval"))

    @retry_interval.setter
    def retry_interval(self, value: builtins.str) -> None:
        jsii.set(self, "retryInterval", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountId")
    def service_account_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceAccountId"))

    @service_account_id.setter
    def service_account_id(self, value: builtins.str) -> None:
        jsii.set(self, "serviceAccountId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tag")
    def tag(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "tag"))

    @tag.setter
    def tag(self, value: builtins.str) -> None:
        jsii.set(self, "tag", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[FunctionTriggerFunction]:
        return typing.cast(typing.Optional[FunctionTriggerFunction], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(self, value: typing.Optional[FunctionTriggerFunction]) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.FunctionTriggerIot",
    jsii_struct_bases=[],
    name_mapping={
        "registry_id": "registryId",
        "device_id": "deviceId",
        "topic": "topic",
    },
)
class FunctionTriggerIot:
    def __init__(
        self,
        *,
        registry_id: builtins.str,
        device_id: typing.Optional[builtins.str] = None,
        topic: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param registry_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#registry_id FunctionTrigger#registry_id}.
        :param device_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#device_id FunctionTrigger#device_id}.
        :param topic: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#topic FunctionTrigger#topic}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "registry_id": registry_id,
        }
        if device_id is not None:
            self._values["device_id"] = device_id
        if topic is not None:
            self._values["topic"] = topic

    @builtins.property
    def registry_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#registry_id FunctionTrigger#registry_id}.'''
        result = self._values.get("registry_id")
        assert result is not None, "Required property 'registry_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def device_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#device_id FunctionTrigger#device_id}.'''
        result = self._values.get("device_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def topic(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#topic FunctionTrigger#topic}.'''
        result = self._values.get("topic")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FunctionTriggerIot(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class FunctionTriggerIotOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.FunctionTriggerIotOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetDeviceId")
    def reset_device_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDeviceId", []))

    @jsii.member(jsii_name="resetTopic")
    def reset_topic(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTopic", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deviceIdInput")
    def device_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deviceIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="registryIdInput")
    def registry_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "registryIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="topicInput")
    def topic_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "topicInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deviceId")
    def device_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "deviceId"))

    @device_id.setter
    def device_id(self, value: builtins.str) -> None:
        jsii.set(self, "deviceId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="registryId")
    def registry_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "registryId"))

    @registry_id.setter
    def registry_id(self, value: builtins.str) -> None:
        jsii.set(self, "registryId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="topic")
    def topic(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "topic"))

    @topic.setter
    def topic(self, value: builtins.str) -> None:
        jsii.set(self, "topic", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[FunctionTriggerIot]:
        return typing.cast(typing.Optional[FunctionTriggerIot], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(self, value: typing.Optional[FunctionTriggerIot]) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.FunctionTriggerLogGroup",
    jsii_struct_bases=[],
    name_mapping={
        "batch_cutoff": "batchCutoff",
        "log_group_ids": "logGroupIds",
        "batch_size": "batchSize",
    },
)
class FunctionTriggerLogGroup:
    def __init__(
        self,
        *,
        batch_cutoff: builtins.str,
        log_group_ids: typing.Sequence[builtins.str],
        batch_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param batch_cutoff: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#batch_cutoff FunctionTrigger#batch_cutoff}.
        :param log_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#log_group_ids FunctionTrigger#log_group_ids}.
        :param batch_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#batch_size FunctionTrigger#batch_size}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "batch_cutoff": batch_cutoff,
            "log_group_ids": log_group_ids,
        }
        if batch_size is not None:
            self._values["batch_size"] = batch_size

    @builtins.property
    def batch_cutoff(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#batch_cutoff FunctionTrigger#batch_cutoff}.'''
        result = self._values.get("batch_cutoff")
        assert result is not None, "Required property 'batch_cutoff' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def log_group_ids(self) -> typing.List[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#log_group_ids FunctionTrigger#log_group_ids}.'''
        result = self._values.get("log_group_ids")
        assert result is not None, "Required property 'log_group_ids' is missing"
        return typing.cast(typing.List[builtins.str], result)

    @builtins.property
    def batch_size(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#batch_size FunctionTrigger#batch_size}.'''
        result = self._values.get("batch_size")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FunctionTriggerLogGroup(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class FunctionTriggerLogGroupOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.FunctionTriggerLogGroupOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetBatchSize")
    def reset_batch_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetBatchSize", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="batchCutoffInput")
    def batch_cutoff_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "batchCutoffInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="batchSizeInput")
    def batch_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "batchSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logGroupIdsInput")
    def log_group_ids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "logGroupIdsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="batchCutoff")
    def batch_cutoff(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "batchCutoff"))

    @batch_cutoff.setter
    def batch_cutoff(self, value: builtins.str) -> None:
        jsii.set(self, "batchCutoff", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="batchSize")
    def batch_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "batchSize"))

    @batch_size.setter
    def batch_size(self, value: builtins.str) -> None:
        jsii.set(self, "batchSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logGroupIds")
    def log_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "logGroupIds"))

    @log_group_ids.setter
    def log_group_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "logGroupIds", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[FunctionTriggerLogGroup]:
        return typing.cast(typing.Optional[FunctionTriggerLogGroup], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(self, value: typing.Optional[FunctionTriggerLogGroup]) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.FunctionTriggerLogging",
    jsii_struct_bases=[],
    name_mapping={
        "batch_cutoff": "batchCutoff",
        "group_id": "groupId",
        "levels": "levels",
        "resource_ids": "resourceIds",
        "resource_types": "resourceTypes",
        "batch_size": "batchSize",
    },
)
class FunctionTriggerLogging:
    def __init__(
        self,
        *,
        batch_cutoff: builtins.str,
        group_id: builtins.str,
        levels: typing.Sequence[builtins.str],
        resource_ids: typing.Sequence[builtins.str],
        resource_types: typing.Sequence[builtins.str],
        batch_size: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param batch_cutoff: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#batch_cutoff FunctionTrigger#batch_cutoff}.
        :param group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#group_id FunctionTrigger#group_id}.
        :param levels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#levels FunctionTrigger#levels}.
        :param resource_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#resource_ids FunctionTrigger#resource_ids}.
        :param resource_types: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#resource_types FunctionTrigger#resource_types}.
        :param batch_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#batch_size FunctionTrigger#batch_size}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "batch_cutoff": batch_cutoff,
            "group_id": group_id,
            "levels": levels,
            "resource_ids": resource_ids,
            "resource_types": resource_types,
        }
        if batch_size is not None:
            self._values["batch_size"] = batch_size

    @builtins.property
    def batch_cutoff(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#batch_cutoff FunctionTrigger#batch_cutoff}.'''
        result = self._values.get("batch_cutoff")
        assert result is not None, "Required property 'batch_cutoff' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def group_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#group_id FunctionTrigger#group_id}.'''
        result = self._values.get("group_id")
        assert result is not None, "Required property 'group_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def levels(self) -> typing.List[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#levels FunctionTrigger#levels}.'''
        result = self._values.get("levels")
        assert result is not None, "Required property 'levels' is missing"
        return typing.cast(typing.List[builtins.str], result)

    @builtins.property
    def resource_ids(self) -> typing.List[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#resource_ids FunctionTrigger#resource_ids}.'''
        result = self._values.get("resource_ids")
        assert result is not None, "Required property 'resource_ids' is missing"
        return typing.cast(typing.List[builtins.str], result)

    @builtins.property
    def resource_types(self) -> typing.List[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#resource_types FunctionTrigger#resource_types}.'''
        result = self._values.get("resource_types")
        assert result is not None, "Required property 'resource_types' is missing"
        return typing.cast(typing.List[builtins.str], result)

    @builtins.property
    def batch_size(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#batch_size FunctionTrigger#batch_size}.'''
        result = self._values.get("batch_size")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FunctionTriggerLogging(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class FunctionTriggerLoggingOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.FunctionTriggerLoggingOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetBatchSize")
    def reset_batch_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetBatchSize", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="batchCutoffInput")
    def batch_cutoff_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "batchCutoffInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="batchSizeInput")
    def batch_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "batchSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="groupIdInput")
    def group_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "groupIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="levelsInput")
    def levels_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "levelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourceIdsInput")
    def resource_ids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "resourceIdsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourceTypesInput")
    def resource_types_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "resourceTypesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="batchCutoff")
    def batch_cutoff(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "batchCutoff"))

    @batch_cutoff.setter
    def batch_cutoff(self, value: builtins.str) -> None:
        jsii.set(self, "batchCutoff", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="batchSize")
    def batch_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "batchSize"))

    @batch_size.setter
    def batch_size(self, value: builtins.str) -> None:
        jsii.set(self, "batchSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="groupId")
    def group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "groupId"))

    @group_id.setter
    def group_id(self, value: builtins.str) -> None:
        jsii.set(self, "groupId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="levels")
    def levels(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "levels"))

    @levels.setter
    def levels(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "levels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourceIds")
    def resource_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "resourceIds"))

    @resource_ids.setter
    def resource_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "resourceIds", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourceTypes")
    def resource_types(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "resourceTypes"))

    @resource_types.setter
    def resource_types(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[FunctionTriggerLogging]:
        return typing.cast(typing.Optional[FunctionTriggerLogging], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(self, value: typing.Optional[FunctionTriggerLogging]) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.FunctionTriggerMessageQueue",
    jsii_struct_bases=[],
    name_mapping={
        "batch_cutoff": "batchCutoff",
        "queue_id": "queueId",
        "service_account_id": "serviceAccountId",
        "batch_size": "batchSize",
        "visibility_timeout": "visibilityTimeout",
    },
)
class FunctionTriggerMessageQueue:
    def __init__(
        self,
        *,
        batch_cutoff: builtins.str,
        queue_id: builtins.str,
        service_account_id: builtins.str,
        batch_size: typing.Optional[builtins.str] = None,
        visibility_timeout: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param batch_cutoff: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#batch_cutoff FunctionTrigger#batch_cutoff}.
        :param queue_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#queue_id FunctionTrigger#queue_id}.
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#service_account_id FunctionTrigger#service_account_id}.
        :param batch_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#batch_size FunctionTrigger#batch_size}.
        :param visibility_timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#visibility_timeout FunctionTrigger#visibility_timeout}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "batch_cutoff": batch_cutoff,
            "queue_id": queue_id,
            "service_account_id": service_account_id,
        }
        if batch_size is not None:
            self._values["batch_size"] = batch_size
        if visibility_timeout is not None:
            self._values["visibility_timeout"] = visibility_timeout

    @builtins.property
    def batch_cutoff(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#batch_cutoff FunctionTrigger#batch_cutoff}.'''
        result = self._values.get("batch_cutoff")
        assert result is not None, "Required property 'batch_cutoff' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def queue_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#queue_id FunctionTrigger#queue_id}.'''
        result = self._values.get("queue_id")
        assert result is not None, "Required property 'queue_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def service_account_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#service_account_id FunctionTrigger#service_account_id}.'''
        result = self._values.get("service_account_id")
        assert result is not None, "Required property 'service_account_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def batch_size(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#batch_size FunctionTrigger#batch_size}.'''
        result = self._values.get("batch_size")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def visibility_timeout(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#visibility_timeout FunctionTrigger#visibility_timeout}.'''
        result = self._values.get("visibility_timeout")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FunctionTriggerMessageQueue(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class FunctionTriggerMessageQueueOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.FunctionTriggerMessageQueueOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetBatchSize")
    def reset_batch_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetBatchSize", []))

    @jsii.member(jsii_name="resetVisibilityTimeout")
    def reset_visibility_timeout(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetVisibilityTimeout", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="batchCutoffInput")
    def batch_cutoff_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "batchCutoffInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="batchSizeInput")
    def batch_size_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "batchSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queueIdInput")
    def queue_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queueIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountIdInput")
    def service_account_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceAccountIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="visibilityTimeoutInput")
    def visibility_timeout_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "visibilityTimeoutInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="batchCutoff")
    def batch_cutoff(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "batchCutoff"))

    @batch_cutoff.setter
    def batch_cutoff(self, value: builtins.str) -> None:
        jsii.set(self, "batchCutoff", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="batchSize")
    def batch_size(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "batchSize"))

    @batch_size.setter
    def batch_size(self, value: builtins.str) -> None:
        jsii.set(self, "batchSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queueId")
    def queue_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "queueId"))

    @queue_id.setter
    def queue_id(self, value: builtins.str) -> None:
        jsii.set(self, "queueId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountId")
    def service_account_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceAccountId"))

    @service_account_id.setter
    def service_account_id(self, value: builtins.str) -> None:
        jsii.set(self, "serviceAccountId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="visibilityTimeout")
    def visibility_timeout(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "visibilityTimeout"))

    @visibility_timeout.setter
    def visibility_timeout(self, value: builtins.str) -> None:
        jsii.set(self, "visibilityTimeout", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[FunctionTriggerMessageQueue]:
        return typing.cast(typing.Optional[FunctionTriggerMessageQueue], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[FunctionTriggerMessageQueue],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.FunctionTriggerObjectStorage",
    jsii_struct_bases=[],
    name_mapping={
        "bucket_id": "bucketId",
        "create": "create",
        "delete": "delete",
        "prefix": "prefix",
        "suffix": "suffix",
        "update": "update",
    },
)
class FunctionTriggerObjectStorage:
    def __init__(
        self,
        *,
        bucket_id: builtins.str,
        create: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        delete: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        prefix: typing.Optional[builtins.str] = None,
        suffix: typing.Optional[builtins.str] = None,
        update: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param bucket_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#bucket_id FunctionTrigger#bucket_id}.
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#create FunctionTrigger#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#delete FunctionTrigger#delete}.
        :param prefix: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#prefix FunctionTrigger#prefix}.
        :param suffix: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#suffix FunctionTrigger#suffix}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#update FunctionTrigger#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "bucket_id": bucket_id,
        }
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if prefix is not None:
            self._values["prefix"] = prefix
        if suffix is not None:
            self._values["suffix"] = suffix
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def bucket_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#bucket_id FunctionTrigger#bucket_id}.'''
        result = self._values.get("bucket_id")
        assert result is not None, "Required property 'bucket_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def create(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#create FunctionTrigger#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def delete(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#delete FunctionTrigger#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def prefix(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#prefix FunctionTrigger#prefix}.'''
        result = self._values.get("prefix")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def suffix(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#suffix FunctionTrigger#suffix}.'''
        result = self._values.get("suffix")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#update FunctionTrigger#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FunctionTriggerObjectStorage(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class FunctionTriggerObjectStorageOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.FunctionTriggerObjectStorageOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetPrefix")
    def reset_prefix(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrefix", []))

    @jsii.member(jsii_name="resetSuffix")
    def reset_suffix(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSuffix", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bucketIdInput")
    def bucket_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "bucketIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="prefixInput")
    def prefix_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "prefixInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="suffixInput")
    def suffix_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "suffixInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bucketId")
    def bucket_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "bucketId"))

    @bucket_id.setter
    def bucket_id(self, value: builtins.str) -> None:
        jsii.set(self, "bucketId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "create"))

    @create.setter
    def create(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="prefix")
    def prefix(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "prefix"))

    @prefix.setter
    def prefix(self, value: builtins.str) -> None:
        jsii.set(self, "prefix", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="suffix")
    def suffix(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "suffix"))

    @suffix.setter
    def suffix(self, value: builtins.str) -> None:
        jsii.set(self, "suffix", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "update"))

    @update.setter
    def update(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[FunctionTriggerObjectStorage]:
        return typing.cast(typing.Optional[FunctionTriggerObjectStorage], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[FunctionTriggerObjectStorage],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.FunctionTriggerTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class FunctionTriggerTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#create FunctionTrigger#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#delete FunctionTrigger#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#update FunctionTrigger#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#create FunctionTrigger#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#delete FunctionTrigger#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#update FunctionTrigger#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FunctionTriggerTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class FunctionTriggerTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.FunctionTriggerTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, FunctionTriggerTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, FunctionTriggerTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, FunctionTriggerTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.FunctionTriggerTimer",
    jsii_struct_bases=[],
    name_mapping={"cron_expression": "cronExpression"},
)
class FunctionTriggerTimer:
    def __init__(self, *, cron_expression: builtins.str) -> None:
        '''
        :param cron_expression: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#cron_expression FunctionTrigger#cron_expression}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "cron_expression": cron_expression,
        }

    @builtins.property
    def cron_expression(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/function_trigger#cron_expression FunctionTrigger#cron_expression}.'''
        result = self._values.get("cron_expression")
        assert result is not None, "Required property 'cron_expression' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FunctionTriggerTimer(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class FunctionTriggerTimerOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.FunctionTriggerTimerOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cronExpressionInput")
    def cron_expression_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "cronExpressionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cronExpression")
    def cron_expression(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "cronExpression"))

    @cron_expression.setter
    def cron_expression(self, value: builtins.str) -> None:
        jsii.set(self, "cronExpression", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[FunctionTriggerTimer]:
        return typing.cast(typing.Optional[FunctionTriggerTimer], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(self, value: typing.Optional[FunctionTriggerTimer]) -> None:
        jsii.set(self, "internalValue", value)


class IamServiceAccount(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.IamServiceAccount",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account yandex_iam_service_account}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["IamServiceAccountTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account yandex_iam_service_account} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account#name IamServiceAccount#name}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account#description IamServiceAccount#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account#folder_id IamServiceAccount#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account#id IamServiceAccount#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account#timeouts IamServiceAccount#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = IamServiceAccountConfig(
            name=name,
            description=description,
            folder_id=folder_id,
            id=id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account#create IamServiceAccount#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account#delete IamServiceAccount#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account#update IamServiceAccount#update}.
        '''
        value = IamServiceAccountTimeouts(create=create, delete=delete, update=update)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "IamServiceAccountTimeoutsOutputReference":
        return typing.cast("IamServiceAccountTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "IamServiceAccountTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "IamServiceAccountTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


class IamServiceAccountApiKey(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.IamServiceAccountApiKey",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_api_key yandex_iam_service_account_api_key}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        service_account_id: builtins.str,
        description: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        pgp_key: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_api_key yandex_iam_service_account_api_key} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_api_key#service_account_id IamServiceAccountApiKey#service_account_id}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_api_key#description IamServiceAccountApiKey#description}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_api_key#id IamServiceAccountApiKey#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param pgp_key: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_api_key#pgp_key IamServiceAccountApiKey#pgp_key}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = IamServiceAccountApiKeyConfig(
            service_account_id=service_account_id,
            description=description,
            id=id,
            pgp_key=pgp_key,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetPgpKey")
    def reset_pgp_key(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPgpKey", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="encryptedSecretKey")
    def encrypted_secret_key(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "encryptedSecretKey"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="keyFingerprint")
    def key_fingerprint(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "keyFingerprint"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="secretKey")
    def secret_key(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "secretKey"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="pgpKeyInput")
    def pgp_key_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "pgpKeyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountIdInput")
    def service_account_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceAccountIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="pgpKey")
    def pgp_key(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "pgpKey"))

    @pgp_key.setter
    def pgp_key(self, value: builtins.str) -> None:
        jsii.set(self, "pgpKey", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountId")
    def service_account_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceAccountId"))

    @service_account_id.setter
    def service_account_id(self, value: builtins.str) -> None:
        jsii.set(self, "serviceAccountId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.IamServiceAccountApiKeyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "service_account_id": "serviceAccountId",
        "description": "description",
        "id": "id",
        "pgp_key": "pgpKey",
    },
)
class IamServiceAccountApiKeyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        service_account_id: builtins.str,
        description: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        pgp_key: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_api_key#service_account_id IamServiceAccountApiKey#service_account_id}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_api_key#description IamServiceAccountApiKey#description}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_api_key#id IamServiceAccountApiKey#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param pgp_key: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_api_key#pgp_key IamServiceAccountApiKey#pgp_key}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {
            "service_account_id": service_account_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if id is not None:
            self._values["id"] = id
        if pgp_key is not None:
            self._values["pgp_key"] = pgp_key

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def service_account_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_api_key#service_account_id IamServiceAccountApiKey#service_account_id}.'''
        result = self._values.get("service_account_id")
        assert result is not None, "Required property 'service_account_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_api_key#description IamServiceAccountApiKey#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_api_key#id IamServiceAccountApiKey#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def pgp_key(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_api_key#pgp_key IamServiceAccountApiKey#pgp_key}.'''
        result = self._values.get("pgp_key")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IamServiceAccountApiKeyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.IamServiceAccountConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "description": "description",
        "folder_id": "folderId",
        "id": "id",
        "timeouts": "timeouts",
    },
)
class IamServiceAccountConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["IamServiceAccountTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account#name IamServiceAccount#name}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account#description IamServiceAccount#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account#folder_id IamServiceAccount#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account#id IamServiceAccount#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account#timeouts IamServiceAccount#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = IamServiceAccountTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account#name IamServiceAccount#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account#description IamServiceAccount#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account#folder_id IamServiceAccount#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account#id IamServiceAccount#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["IamServiceAccountTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account#timeouts IamServiceAccount#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["IamServiceAccountTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IamServiceAccountConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IamServiceAccountIamBinding(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.IamServiceAccountIamBinding",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_binding yandex_iam_service_account_iam_binding}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        members: typing.Sequence[builtins.str],
        role: builtins.str,
        service_account_id: builtins.str,
        id: typing.Optional[builtins.str] = None,
        sleep_after: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_binding yandex_iam_service_account_iam_binding} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param members: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_binding#members IamServiceAccountIamBinding#members}.
        :param role: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_binding#role IamServiceAccountIamBinding#role}.
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_binding#service_account_id IamServiceAccountIamBinding#service_account_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_binding#id IamServiceAccountIamBinding#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param sleep_after: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_binding#sleep_after IamServiceAccountIamBinding#sleep_after}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = IamServiceAccountIamBindingConfig(
            members=members,
            role=role,
            service_account_id=service_account_id,
            id=id,
            sleep_after=sleep_after,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetSleepAfter")
    def reset_sleep_after(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSleepAfter", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="membersInput")
    def members_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "membersInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="roleInput")
    def role_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "roleInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountIdInput")
    def service_account_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceAccountIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sleepAfterInput")
    def sleep_after_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "sleepAfterInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="members")
    def members(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "members"))

    @members.setter
    def members(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "members", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="role")
    def role(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "role"))

    @role.setter
    def role(self, value: builtins.str) -> None:
        jsii.set(self, "role", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountId")
    def service_account_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceAccountId"))

    @service_account_id.setter
    def service_account_id(self, value: builtins.str) -> None:
        jsii.set(self, "serviceAccountId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sleepAfter")
    def sleep_after(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "sleepAfter"))

    @sleep_after.setter
    def sleep_after(self, value: jsii.Number) -> None:
        jsii.set(self, "sleepAfter", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.IamServiceAccountIamBindingConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "members": "members",
        "role": "role",
        "service_account_id": "serviceAccountId",
        "id": "id",
        "sleep_after": "sleepAfter",
    },
)
class IamServiceAccountIamBindingConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        members: typing.Sequence[builtins.str],
        role: builtins.str,
        service_account_id: builtins.str,
        id: typing.Optional[builtins.str] = None,
        sleep_after: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param members: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_binding#members IamServiceAccountIamBinding#members}.
        :param role: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_binding#role IamServiceAccountIamBinding#role}.
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_binding#service_account_id IamServiceAccountIamBinding#service_account_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_binding#id IamServiceAccountIamBinding#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param sleep_after: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_binding#sleep_after IamServiceAccountIamBinding#sleep_after}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {
            "members": members,
            "role": role,
            "service_account_id": service_account_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if id is not None:
            self._values["id"] = id
        if sleep_after is not None:
            self._values["sleep_after"] = sleep_after

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def members(self) -> typing.List[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_binding#members IamServiceAccountIamBinding#members}.'''
        result = self._values.get("members")
        assert result is not None, "Required property 'members' is missing"
        return typing.cast(typing.List[builtins.str], result)

    @builtins.property
    def role(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_binding#role IamServiceAccountIamBinding#role}.'''
        result = self._values.get("role")
        assert result is not None, "Required property 'role' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def service_account_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_binding#service_account_id IamServiceAccountIamBinding#service_account_id}.'''
        result = self._values.get("service_account_id")
        assert result is not None, "Required property 'service_account_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_binding#id IamServiceAccountIamBinding#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def sleep_after(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_binding#sleep_after IamServiceAccountIamBinding#sleep_after}.'''
        result = self._values.get("sleep_after")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IamServiceAccountIamBindingConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IamServiceAccountIamMember(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.IamServiceAccountIamMember",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_member yandex_iam_service_account_iam_member}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        member: builtins.str,
        role: builtins.str,
        service_account_id: builtins.str,
        id: typing.Optional[builtins.str] = None,
        sleep_after: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_member yandex_iam_service_account_iam_member} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param member: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_member#member IamServiceAccountIamMember#member}.
        :param role: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_member#role IamServiceAccountIamMember#role}.
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_member#service_account_id IamServiceAccountIamMember#service_account_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_member#id IamServiceAccountIamMember#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param sleep_after: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_member#sleep_after IamServiceAccountIamMember#sleep_after}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = IamServiceAccountIamMemberConfig(
            member=member,
            role=role,
            service_account_id=service_account_id,
            id=id,
            sleep_after=sleep_after,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetSleepAfter")
    def reset_sleep_after(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSleepAfter", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="memberInput")
    def member_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "memberInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="roleInput")
    def role_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "roleInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountIdInput")
    def service_account_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceAccountIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sleepAfterInput")
    def sleep_after_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "sleepAfterInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="member")
    def member(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "member"))

    @member.setter
    def member(self, value: builtins.str) -> None:
        jsii.set(self, "member", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="role")
    def role(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "role"))

    @role.setter
    def role(self, value: builtins.str) -> None:
        jsii.set(self, "role", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountId")
    def service_account_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceAccountId"))

    @service_account_id.setter
    def service_account_id(self, value: builtins.str) -> None:
        jsii.set(self, "serviceAccountId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sleepAfter")
    def sleep_after(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "sleepAfter"))

    @sleep_after.setter
    def sleep_after(self, value: jsii.Number) -> None:
        jsii.set(self, "sleepAfter", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.IamServiceAccountIamMemberConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "member": "member",
        "role": "role",
        "service_account_id": "serviceAccountId",
        "id": "id",
        "sleep_after": "sleepAfter",
    },
)
class IamServiceAccountIamMemberConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        member: builtins.str,
        role: builtins.str,
        service_account_id: builtins.str,
        id: typing.Optional[builtins.str] = None,
        sleep_after: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param member: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_member#member IamServiceAccountIamMember#member}.
        :param role: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_member#role IamServiceAccountIamMember#role}.
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_member#service_account_id IamServiceAccountIamMember#service_account_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_member#id IamServiceAccountIamMember#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param sleep_after: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_member#sleep_after IamServiceAccountIamMember#sleep_after}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {
            "member": member,
            "role": role,
            "service_account_id": service_account_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if id is not None:
            self._values["id"] = id
        if sleep_after is not None:
            self._values["sleep_after"] = sleep_after

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def member(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_member#member IamServiceAccountIamMember#member}.'''
        result = self._values.get("member")
        assert result is not None, "Required property 'member' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def role(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_member#role IamServiceAccountIamMember#role}.'''
        result = self._values.get("role")
        assert result is not None, "Required property 'role' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def service_account_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_member#service_account_id IamServiceAccountIamMember#service_account_id}.'''
        result = self._values.get("service_account_id")
        assert result is not None, "Required property 'service_account_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_member#id IamServiceAccountIamMember#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def sleep_after(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_member#sleep_after IamServiceAccountIamMember#sleep_after}.'''
        result = self._values.get("sleep_after")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IamServiceAccountIamMemberConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IamServiceAccountIamPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.IamServiceAccountIamPolicy",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_policy yandex_iam_service_account_iam_policy}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        policy_data: builtins.str,
        service_account_id: builtins.str,
        id: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_policy yandex_iam_service_account_iam_policy} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param policy_data: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_policy#policy_data IamServiceAccountIamPolicy#policy_data}.
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_policy#service_account_id IamServiceAccountIamPolicy#service_account_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_policy#id IamServiceAccountIamPolicy#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = IamServiceAccountIamPolicyConfig(
            policy_data=policy_data,
            service_account_id=service_account_id,
            id=id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="policyDataInput")
    def policy_data_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "policyDataInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountIdInput")
    def service_account_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceAccountIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="policyData")
    def policy_data(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "policyData"))

    @policy_data.setter
    def policy_data(self, value: builtins.str) -> None:
        jsii.set(self, "policyData", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountId")
    def service_account_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceAccountId"))

    @service_account_id.setter
    def service_account_id(self, value: builtins.str) -> None:
        jsii.set(self, "serviceAccountId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.IamServiceAccountIamPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "policy_data": "policyData",
        "service_account_id": "serviceAccountId",
        "id": "id",
    },
)
class IamServiceAccountIamPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        policy_data: builtins.str,
        service_account_id: builtins.str,
        id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param policy_data: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_policy#policy_data IamServiceAccountIamPolicy#policy_data}.
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_policy#service_account_id IamServiceAccountIamPolicy#service_account_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_policy#id IamServiceAccountIamPolicy#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {
            "policy_data": policy_data,
            "service_account_id": service_account_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if id is not None:
            self._values["id"] = id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def policy_data(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_policy#policy_data IamServiceAccountIamPolicy#policy_data}.'''
        result = self._values.get("policy_data")
        assert result is not None, "Required property 'policy_data' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def service_account_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_policy#service_account_id IamServiceAccountIamPolicy#service_account_id}.'''
        result = self._values.get("service_account_id")
        assert result is not None, "Required property 'service_account_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_iam_policy#id IamServiceAccountIamPolicy#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IamServiceAccountIamPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IamServiceAccountKey(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.IamServiceAccountKey",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_key yandex_iam_service_account_key}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        service_account_id: builtins.str,
        description: typing.Optional[builtins.str] = None,
        format: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        key_algorithm: typing.Optional[builtins.str] = None,
        pgp_key: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_key yandex_iam_service_account_key} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_key#service_account_id IamServiceAccountKey#service_account_id}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_key#description IamServiceAccountKey#description}.
        :param format: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_key#format IamServiceAccountKey#format}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_key#id IamServiceAccountKey#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param key_algorithm: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_key#key_algorithm IamServiceAccountKey#key_algorithm}.
        :param pgp_key: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_key#pgp_key IamServiceAccountKey#pgp_key}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = IamServiceAccountKeyConfig(
            service_account_id=service_account_id,
            description=description,
            format=format,
            id=id,
            key_algorithm=key_algorithm,
            pgp_key=pgp_key,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFormat")
    def reset_format(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFormat", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetKeyAlgorithm")
    def reset_key_algorithm(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetKeyAlgorithm", []))

    @jsii.member(jsii_name="resetPgpKey")
    def reset_pgp_key(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPgpKey", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="encryptedPrivateKey")
    def encrypted_private_key(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "encryptedPrivateKey"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="keyFingerprint")
    def key_fingerprint(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "keyFingerprint"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="privateKey")
    def private_key(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "privateKey"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="publicKey")
    def public_key(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "publicKey"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="formatInput")
    def format_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "formatInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="keyAlgorithmInput")
    def key_algorithm_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "keyAlgorithmInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="pgpKeyInput")
    def pgp_key_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "pgpKeyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountIdInput")
    def service_account_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceAccountIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="format")
    def format(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "format"))

    @format.setter
    def format(self, value: builtins.str) -> None:
        jsii.set(self, "format", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="keyAlgorithm")
    def key_algorithm(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "keyAlgorithm"))

    @key_algorithm.setter
    def key_algorithm(self, value: builtins.str) -> None:
        jsii.set(self, "keyAlgorithm", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="pgpKey")
    def pgp_key(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "pgpKey"))

    @pgp_key.setter
    def pgp_key(self, value: builtins.str) -> None:
        jsii.set(self, "pgpKey", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountId")
    def service_account_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceAccountId"))

    @service_account_id.setter
    def service_account_id(self, value: builtins.str) -> None:
        jsii.set(self, "serviceAccountId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.IamServiceAccountKeyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "service_account_id": "serviceAccountId",
        "description": "description",
        "format": "format",
        "id": "id",
        "key_algorithm": "keyAlgorithm",
        "pgp_key": "pgpKey",
    },
)
class IamServiceAccountKeyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        service_account_id: builtins.str,
        description: typing.Optional[builtins.str] = None,
        format: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        key_algorithm: typing.Optional[builtins.str] = None,
        pgp_key: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_key#service_account_id IamServiceAccountKey#service_account_id}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_key#description IamServiceAccountKey#description}.
        :param format: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_key#format IamServiceAccountKey#format}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_key#id IamServiceAccountKey#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param key_algorithm: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_key#key_algorithm IamServiceAccountKey#key_algorithm}.
        :param pgp_key: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_key#pgp_key IamServiceAccountKey#pgp_key}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {
            "service_account_id": service_account_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if format is not None:
            self._values["format"] = format
        if id is not None:
            self._values["id"] = id
        if key_algorithm is not None:
            self._values["key_algorithm"] = key_algorithm
        if pgp_key is not None:
            self._values["pgp_key"] = pgp_key

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def service_account_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_key#service_account_id IamServiceAccountKey#service_account_id}.'''
        result = self._values.get("service_account_id")
        assert result is not None, "Required property 'service_account_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_key#description IamServiceAccountKey#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def format(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_key#format IamServiceAccountKey#format}.'''
        result = self._values.get("format")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_key#id IamServiceAccountKey#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def key_algorithm(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_key#key_algorithm IamServiceAccountKey#key_algorithm}.'''
        result = self._values.get("key_algorithm")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def pgp_key(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_key#pgp_key IamServiceAccountKey#pgp_key}.'''
        result = self._values.get("pgp_key")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IamServiceAccountKeyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IamServiceAccountStaticAccessKey(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.IamServiceAccountStaticAccessKey",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_static_access_key yandex_iam_service_account_static_access_key}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        service_account_id: builtins.str,
        description: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        pgp_key: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_static_access_key yandex_iam_service_account_static_access_key} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_static_access_key#service_account_id IamServiceAccountStaticAccessKey#service_account_id}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_static_access_key#description IamServiceAccountStaticAccessKey#description}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_static_access_key#id IamServiceAccountStaticAccessKey#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param pgp_key: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_static_access_key#pgp_key IamServiceAccountStaticAccessKey#pgp_key}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = IamServiceAccountStaticAccessKeyConfig(
            service_account_id=service_account_id,
            description=description,
            id=id,
            pgp_key=pgp_key,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetPgpKey")
    def reset_pgp_key(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPgpKey", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="accessKey")
    def access_key(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "accessKey"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="encryptedSecretKey")
    def encrypted_secret_key(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "encryptedSecretKey"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="keyFingerprint")
    def key_fingerprint(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "keyFingerprint"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="secretKey")
    def secret_key(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "secretKey"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="pgpKeyInput")
    def pgp_key_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "pgpKeyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountIdInput")
    def service_account_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceAccountIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="pgpKey")
    def pgp_key(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "pgpKey"))

    @pgp_key.setter
    def pgp_key(self, value: builtins.str) -> None:
        jsii.set(self, "pgpKey", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountId")
    def service_account_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceAccountId"))

    @service_account_id.setter
    def service_account_id(self, value: builtins.str) -> None:
        jsii.set(self, "serviceAccountId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.IamServiceAccountStaticAccessKeyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "service_account_id": "serviceAccountId",
        "description": "description",
        "id": "id",
        "pgp_key": "pgpKey",
    },
)
class IamServiceAccountStaticAccessKeyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        service_account_id: builtins.str,
        description: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        pgp_key: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_static_access_key#service_account_id IamServiceAccountStaticAccessKey#service_account_id}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_static_access_key#description IamServiceAccountStaticAccessKey#description}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_static_access_key#id IamServiceAccountStaticAccessKey#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param pgp_key: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_static_access_key#pgp_key IamServiceAccountStaticAccessKey#pgp_key}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {
            "service_account_id": service_account_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if id is not None:
            self._values["id"] = id
        if pgp_key is not None:
            self._values["pgp_key"] = pgp_key

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def service_account_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_static_access_key#service_account_id IamServiceAccountStaticAccessKey#service_account_id}.'''
        result = self._values.get("service_account_id")
        assert result is not None, "Required property 'service_account_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_static_access_key#description IamServiceAccountStaticAccessKey#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_static_access_key#id IamServiceAccountStaticAccessKey#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def pgp_key(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account_static_access_key#pgp_key IamServiceAccountStaticAccessKey#pgp_key}.'''
        result = self._values.get("pgp_key")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IamServiceAccountStaticAccessKeyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.IamServiceAccountTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class IamServiceAccountTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account#create IamServiceAccount#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account#delete IamServiceAccount#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account#update IamServiceAccount#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account#create IamServiceAccount#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account#delete IamServiceAccount#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iam_service_account#update IamServiceAccount#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IamServiceAccountTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IamServiceAccountTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.IamServiceAccountTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, IamServiceAccountTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, IamServiceAccountTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, IamServiceAccountTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class IotCoreDevice(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.IotCoreDevice",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device yandex_iot_core_device}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        name: builtins.str,
        registry_id: builtins.str,
        aliases: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        certificates: typing.Optional[typing.Sequence[builtins.str]] = None,
        description: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        passwords: typing.Optional[typing.Sequence[builtins.str]] = None,
        timeouts: typing.Optional["IotCoreDeviceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device yandex_iot_core_device} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device#name IotCoreDevice#name}.
        :param registry_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device#registry_id IotCoreDevice#registry_id}.
        :param aliases: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device#aliases IotCoreDevice#aliases}.
        :param certificates: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device#certificates IotCoreDevice#certificates}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device#description IotCoreDevice#description}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device#id IotCoreDevice#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param passwords: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device#passwords IotCoreDevice#passwords}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device#timeouts IotCoreDevice#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = IotCoreDeviceConfig(
            name=name,
            registry_id=registry_id,
            aliases=aliases,
            certificates=certificates,
            description=description,
            id=id,
            passwords=passwords,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device#create IotCoreDevice#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device#delete IotCoreDevice#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device#update IotCoreDevice#update}.
        '''
        value = IotCoreDeviceTimeouts(create=create, delete=delete, update=update)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetAliases")
    def reset_aliases(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAliases", []))

    @jsii.member(jsii_name="resetCertificates")
    def reset_certificates(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCertificates", []))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetPasswords")
    def reset_passwords(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPasswords", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "IotCoreDeviceTimeoutsOutputReference":
        return typing.cast("IotCoreDeviceTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="aliasesInput")
    def aliases_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "aliasesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="certificatesInput")
    def certificates_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "certificatesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="passwordsInput")
    def passwords_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "passwordsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="registryIdInput")
    def registry_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "registryIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "IotCoreDeviceTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "IotCoreDeviceTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="aliases")
    def aliases(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "aliases"))

    @aliases.setter
    def aliases(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "aliases", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="certificates")
    def certificates(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "certificates"))

    @certificates.setter
    def certificates(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "certificates", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="passwords")
    def passwords(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "passwords"))

    @passwords.setter
    def passwords(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "passwords", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="registryId")
    def registry_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "registryId"))

    @registry_id.setter
    def registry_id(self, value: builtins.str) -> None:
        jsii.set(self, "registryId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.IotCoreDeviceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "registry_id": "registryId",
        "aliases": "aliases",
        "certificates": "certificates",
        "description": "description",
        "id": "id",
        "passwords": "passwords",
        "timeouts": "timeouts",
    },
)
class IotCoreDeviceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        registry_id: builtins.str,
        aliases: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        certificates: typing.Optional[typing.Sequence[builtins.str]] = None,
        description: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        passwords: typing.Optional[typing.Sequence[builtins.str]] = None,
        timeouts: typing.Optional["IotCoreDeviceTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device#name IotCoreDevice#name}.
        :param registry_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device#registry_id IotCoreDevice#registry_id}.
        :param aliases: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device#aliases IotCoreDevice#aliases}.
        :param certificates: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device#certificates IotCoreDevice#certificates}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device#description IotCoreDevice#description}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device#id IotCoreDevice#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param passwords: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device#passwords IotCoreDevice#passwords}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device#timeouts IotCoreDevice#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = IotCoreDeviceTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "registry_id": registry_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if aliases is not None:
            self._values["aliases"] = aliases
        if certificates is not None:
            self._values["certificates"] = certificates
        if description is not None:
            self._values["description"] = description
        if id is not None:
            self._values["id"] = id
        if passwords is not None:
            self._values["passwords"] = passwords
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device#name IotCoreDevice#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def registry_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device#registry_id IotCoreDevice#registry_id}.'''
        result = self._values.get("registry_id")
        assert result is not None, "Required property 'registry_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aliases(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device#aliases IotCoreDevice#aliases}.'''
        result = self._values.get("aliases")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def certificates(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device#certificates IotCoreDevice#certificates}.'''
        result = self._values.get("certificates")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device#description IotCoreDevice#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device#id IotCoreDevice#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def passwords(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device#passwords IotCoreDevice#passwords}.'''
        result = self._values.get("passwords")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["IotCoreDeviceTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device#timeouts IotCoreDevice#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["IotCoreDeviceTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotCoreDeviceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.IotCoreDeviceTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class IotCoreDeviceTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device#create IotCoreDevice#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device#delete IotCoreDevice#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device#update IotCoreDevice#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device#create IotCoreDevice#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device#delete IotCoreDevice#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_device#update IotCoreDevice#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotCoreDeviceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IotCoreDeviceTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.IotCoreDeviceTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, IotCoreDeviceTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, IotCoreDeviceTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, IotCoreDeviceTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class IotCoreRegistry(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.IotCoreRegistry",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry yandex_iot_core_registry}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        name: builtins.str,
        certificates: typing.Optional[typing.Sequence[builtins.str]] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        passwords: typing.Optional[typing.Sequence[builtins.str]] = None,
        timeouts: typing.Optional["IotCoreRegistryTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry yandex_iot_core_registry} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry#name IotCoreRegistry#name}.
        :param certificates: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry#certificates IotCoreRegistry#certificates}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry#description IotCoreRegistry#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry#folder_id IotCoreRegistry#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry#id IotCoreRegistry#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry#labels IotCoreRegistry#labels}.
        :param passwords: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry#passwords IotCoreRegistry#passwords}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry#timeouts IotCoreRegistry#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = IotCoreRegistryConfig(
            name=name,
            certificates=certificates,
            description=description,
            folder_id=folder_id,
            id=id,
            labels=labels,
            passwords=passwords,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry#create IotCoreRegistry#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry#delete IotCoreRegistry#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry#update IotCoreRegistry#update}.
        '''
        value = IotCoreRegistryTimeouts(create=create, delete=delete, update=update)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetCertificates")
    def reset_certificates(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCertificates", []))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetPasswords")
    def reset_passwords(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPasswords", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "IotCoreRegistryTimeoutsOutputReference":
        return typing.cast("IotCoreRegistryTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="certificatesInput")
    def certificates_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "certificatesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="passwordsInput")
    def passwords_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "passwordsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "IotCoreRegistryTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "IotCoreRegistryTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="certificates")
    def certificates(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "certificates"))

    @certificates.setter
    def certificates(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "certificates", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="passwords")
    def passwords(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "passwords"))

    @passwords.setter
    def passwords(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "passwords", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.IotCoreRegistryConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "certificates": "certificates",
        "description": "description",
        "folder_id": "folderId",
        "id": "id",
        "labels": "labels",
        "passwords": "passwords",
        "timeouts": "timeouts",
    },
)
class IotCoreRegistryConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        certificates: typing.Optional[typing.Sequence[builtins.str]] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        passwords: typing.Optional[typing.Sequence[builtins.str]] = None,
        timeouts: typing.Optional["IotCoreRegistryTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry#name IotCoreRegistry#name}.
        :param certificates: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry#certificates IotCoreRegistry#certificates}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry#description IotCoreRegistry#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry#folder_id IotCoreRegistry#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry#id IotCoreRegistry#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry#labels IotCoreRegistry#labels}.
        :param passwords: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry#passwords IotCoreRegistry#passwords}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry#timeouts IotCoreRegistry#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = IotCoreRegistryTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if certificates is not None:
            self._values["certificates"] = certificates
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if passwords is not None:
            self._values["passwords"] = passwords
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry#name IotCoreRegistry#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def certificates(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry#certificates IotCoreRegistry#certificates}.'''
        result = self._values.get("certificates")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry#description IotCoreRegistry#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry#folder_id IotCoreRegistry#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry#id IotCoreRegistry#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry#labels IotCoreRegistry#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def passwords(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry#passwords IotCoreRegistry#passwords}.'''
        result = self._values.get("passwords")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["IotCoreRegistryTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry#timeouts IotCoreRegistry#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["IotCoreRegistryTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotCoreRegistryConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.IotCoreRegistryTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class IotCoreRegistryTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry#create IotCoreRegistry#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry#delete IotCoreRegistry#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry#update IotCoreRegistry#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry#create IotCoreRegistry#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry#delete IotCoreRegistry#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/iot_core_registry#update IotCoreRegistry#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotCoreRegistryTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IotCoreRegistryTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.IotCoreRegistryTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, IotCoreRegistryTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, IotCoreRegistryTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, IotCoreRegistryTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class KmsSecretCiphertext(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KmsSecretCiphertext",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/kms_secret_ciphertext yandex_kms_secret_ciphertext}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        key_id: builtins.str,
        plaintext: builtins.str,
        aad_context: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["KmsSecretCiphertextTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/kms_secret_ciphertext yandex_kms_secret_ciphertext} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param key_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_secret_ciphertext#key_id KmsSecretCiphertext#key_id}.
        :param plaintext: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_secret_ciphertext#plaintext KmsSecretCiphertext#plaintext}.
        :param aad_context: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_secret_ciphertext#aad_context KmsSecretCiphertext#aad_context}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_secret_ciphertext#id KmsSecretCiphertext#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_secret_ciphertext#timeouts KmsSecretCiphertext#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = KmsSecretCiphertextConfig(
            key_id=key_id,
            plaintext=plaintext,
            aad_context=aad_context,
            id=id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_secret_ciphertext#create KmsSecretCiphertext#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_secret_ciphertext#delete KmsSecretCiphertext#delete}.
        :param read: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_secret_ciphertext#read KmsSecretCiphertext#read}.
        '''
        value = KmsSecretCiphertextTimeouts(create=create, delete=delete, read=read)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetAadContext")
    def reset_aad_context(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAadContext", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ciphertext")
    def ciphertext(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ciphertext"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "KmsSecretCiphertextTimeoutsOutputReference":
        return typing.cast("KmsSecretCiphertextTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="aadContextInput")
    def aad_context_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aadContextInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="keyIdInput")
    def key_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "keyIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="plaintextInput")
    def plaintext_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "plaintextInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "KmsSecretCiphertextTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "KmsSecretCiphertextTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="aadContext")
    def aad_context(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "aadContext"))

    @aad_context.setter
    def aad_context(self, value: builtins.str) -> None:
        jsii.set(self, "aadContext", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="keyId")
    def key_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "keyId"))

    @key_id.setter
    def key_id(self, value: builtins.str) -> None:
        jsii.set(self, "keyId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="plaintext")
    def plaintext(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "plaintext"))

    @plaintext.setter
    def plaintext(self, value: builtins.str) -> None:
        jsii.set(self, "plaintext", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KmsSecretCiphertextConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "key_id": "keyId",
        "plaintext": "plaintext",
        "aad_context": "aadContext",
        "id": "id",
        "timeouts": "timeouts",
    },
)
class KmsSecretCiphertextConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        key_id: builtins.str,
        plaintext: builtins.str,
        aad_context: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["KmsSecretCiphertextTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param key_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_secret_ciphertext#key_id KmsSecretCiphertext#key_id}.
        :param plaintext: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_secret_ciphertext#plaintext KmsSecretCiphertext#plaintext}.
        :param aad_context: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_secret_ciphertext#aad_context KmsSecretCiphertext#aad_context}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_secret_ciphertext#id KmsSecretCiphertext#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_secret_ciphertext#timeouts KmsSecretCiphertext#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = KmsSecretCiphertextTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "key_id": key_id,
            "plaintext": plaintext,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if aad_context is not None:
            self._values["aad_context"] = aad_context
        if id is not None:
            self._values["id"] = id
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def key_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_secret_ciphertext#key_id KmsSecretCiphertext#key_id}.'''
        result = self._values.get("key_id")
        assert result is not None, "Required property 'key_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def plaintext(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_secret_ciphertext#plaintext KmsSecretCiphertext#plaintext}.'''
        result = self._values.get("plaintext")
        assert result is not None, "Required property 'plaintext' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aad_context(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_secret_ciphertext#aad_context KmsSecretCiphertext#aad_context}.'''
        result = self._values.get("aad_context")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_secret_ciphertext#id KmsSecretCiphertext#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["KmsSecretCiphertextTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_secret_ciphertext#timeouts KmsSecretCiphertext#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["KmsSecretCiphertextTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KmsSecretCiphertextConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KmsSecretCiphertextTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "read": "read"},
)
class KmsSecretCiphertextTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_secret_ciphertext#create KmsSecretCiphertext#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_secret_ciphertext#delete KmsSecretCiphertext#delete}.
        :param read: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_secret_ciphertext#read KmsSecretCiphertext#read}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_secret_ciphertext#create KmsSecretCiphertext#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_secret_ciphertext#delete KmsSecretCiphertext#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_secret_ciphertext#read KmsSecretCiphertext#read}.'''
        result = self._values.get("read")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KmsSecretCiphertextTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KmsSecretCiphertextTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KmsSecretCiphertextTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetRead")
    def reset_read(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRead", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="readInput")
    def read_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "readInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="read")
    def read(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "read"))

    @read.setter
    def read(self, value: builtins.str) -> None:
        jsii.set(self, "read", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, KmsSecretCiphertextTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, KmsSecretCiphertextTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, KmsSecretCiphertextTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class KmsSymmetricKey(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KmsSymmetricKey",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key yandex_kms_symmetric_key}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        default_algorithm: typing.Optional[builtins.str] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        rotation_period: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["KmsSymmetricKeyTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key yandex_kms_symmetric_key} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param default_algorithm: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#default_algorithm KmsSymmetricKey#default_algorithm}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#description KmsSymmetricKey#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#folder_id KmsSymmetricKey#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#id KmsSymmetricKey#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#labels KmsSymmetricKey#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#name KmsSymmetricKey#name}.
        :param rotation_period: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#rotation_period KmsSymmetricKey#rotation_period}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#timeouts KmsSymmetricKey#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = KmsSymmetricKeyConfig(
            default_algorithm=default_algorithm,
            description=description,
            folder_id=folder_id,
            id=id,
            labels=labels,
            name=name,
            rotation_period=rotation_period,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#create KmsSymmetricKey#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#delete KmsSymmetricKey#delete}.
        :param read: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#read KmsSymmetricKey#read}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#update KmsSymmetricKey#update}.
        '''
        value = KmsSymmetricKeyTimeouts(
            create=create, delete=delete, read=read, update=update
        )

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetDefaultAlgorithm")
    def reset_default_algorithm(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDefaultAlgorithm", []))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetRotationPeriod")
    def reset_rotation_period(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRotationPeriod", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="rotatedAt")
    def rotated_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "rotatedAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "KmsSymmetricKeyTimeoutsOutputReference":
        return typing.cast("KmsSymmetricKeyTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="defaultAlgorithmInput")
    def default_algorithm_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "defaultAlgorithmInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="rotationPeriodInput")
    def rotation_period_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "rotationPeriodInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "KmsSymmetricKeyTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "KmsSymmetricKeyTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="defaultAlgorithm")
    def default_algorithm(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "defaultAlgorithm"))

    @default_algorithm.setter
    def default_algorithm(self, value: builtins.str) -> None:
        jsii.set(self, "defaultAlgorithm", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="rotationPeriod")
    def rotation_period(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "rotationPeriod"))

    @rotation_period.setter
    def rotation_period(self, value: builtins.str) -> None:
        jsii.set(self, "rotationPeriod", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KmsSymmetricKeyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "default_algorithm": "defaultAlgorithm",
        "description": "description",
        "folder_id": "folderId",
        "id": "id",
        "labels": "labels",
        "name": "name",
        "rotation_period": "rotationPeriod",
        "timeouts": "timeouts",
    },
)
class KmsSymmetricKeyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        default_algorithm: typing.Optional[builtins.str] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        rotation_period: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["KmsSymmetricKeyTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param default_algorithm: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#default_algorithm KmsSymmetricKey#default_algorithm}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#description KmsSymmetricKey#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#folder_id KmsSymmetricKey#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#id KmsSymmetricKey#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#labels KmsSymmetricKey#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#name KmsSymmetricKey#name}.
        :param rotation_period: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#rotation_period KmsSymmetricKey#rotation_period}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#timeouts KmsSymmetricKey#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = KmsSymmetricKeyTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if default_algorithm is not None:
            self._values["default_algorithm"] = default_algorithm
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if name is not None:
            self._values["name"] = name
        if rotation_period is not None:
            self._values["rotation_period"] = rotation_period
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def default_algorithm(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#default_algorithm KmsSymmetricKey#default_algorithm}.'''
        result = self._values.get("default_algorithm")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#description KmsSymmetricKey#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#folder_id KmsSymmetricKey#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#id KmsSymmetricKey#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#labels KmsSymmetricKey#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#name KmsSymmetricKey#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def rotation_period(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#rotation_period KmsSymmetricKey#rotation_period}.'''
        result = self._values.get("rotation_period")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["KmsSymmetricKeyTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#timeouts KmsSymmetricKey#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["KmsSymmetricKeyTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KmsSymmetricKeyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KmsSymmetricKeyIamBinding(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KmsSymmetricKeyIamBinding",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key_iam_binding yandex_kms_symmetric_key_iam_binding}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        members: typing.Sequence[builtins.str],
        role: builtins.str,
        symmetric_key_id: builtins.str,
        id: typing.Optional[builtins.str] = None,
        sleep_after: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key_iam_binding yandex_kms_symmetric_key_iam_binding} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param members: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key_iam_binding#members KmsSymmetricKeyIamBinding#members}.
        :param role: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key_iam_binding#role KmsSymmetricKeyIamBinding#role}.
        :param symmetric_key_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key_iam_binding#symmetric_key_id KmsSymmetricKeyIamBinding#symmetric_key_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key_iam_binding#id KmsSymmetricKeyIamBinding#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param sleep_after: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key_iam_binding#sleep_after KmsSymmetricKeyIamBinding#sleep_after}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = KmsSymmetricKeyIamBindingConfig(
            members=members,
            role=role,
            symmetric_key_id=symmetric_key_id,
            id=id,
            sleep_after=sleep_after,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetSleepAfter")
    def reset_sleep_after(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSleepAfter", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="membersInput")
    def members_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "membersInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="roleInput")
    def role_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "roleInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sleepAfterInput")
    def sleep_after_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "sleepAfterInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="symmetricKeyIdInput")
    def symmetric_key_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "symmetricKeyIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="members")
    def members(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "members"))

    @members.setter
    def members(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "members", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="role")
    def role(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "role"))

    @role.setter
    def role(self, value: builtins.str) -> None:
        jsii.set(self, "role", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sleepAfter")
    def sleep_after(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "sleepAfter"))

    @sleep_after.setter
    def sleep_after(self, value: jsii.Number) -> None:
        jsii.set(self, "sleepAfter", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="symmetricKeyId")
    def symmetric_key_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "symmetricKeyId"))

    @symmetric_key_id.setter
    def symmetric_key_id(self, value: builtins.str) -> None:
        jsii.set(self, "symmetricKeyId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KmsSymmetricKeyIamBindingConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "members": "members",
        "role": "role",
        "symmetric_key_id": "symmetricKeyId",
        "id": "id",
        "sleep_after": "sleepAfter",
    },
)
class KmsSymmetricKeyIamBindingConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        members: typing.Sequence[builtins.str],
        role: builtins.str,
        symmetric_key_id: builtins.str,
        id: typing.Optional[builtins.str] = None,
        sleep_after: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param members: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key_iam_binding#members KmsSymmetricKeyIamBinding#members}.
        :param role: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key_iam_binding#role KmsSymmetricKeyIamBinding#role}.
        :param symmetric_key_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key_iam_binding#symmetric_key_id KmsSymmetricKeyIamBinding#symmetric_key_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key_iam_binding#id KmsSymmetricKeyIamBinding#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param sleep_after: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key_iam_binding#sleep_after KmsSymmetricKeyIamBinding#sleep_after}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {
            "members": members,
            "role": role,
            "symmetric_key_id": symmetric_key_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if id is not None:
            self._values["id"] = id
        if sleep_after is not None:
            self._values["sleep_after"] = sleep_after

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def members(self) -> typing.List[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key_iam_binding#members KmsSymmetricKeyIamBinding#members}.'''
        result = self._values.get("members")
        assert result is not None, "Required property 'members' is missing"
        return typing.cast(typing.List[builtins.str], result)

    @builtins.property
    def role(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key_iam_binding#role KmsSymmetricKeyIamBinding#role}.'''
        result = self._values.get("role")
        assert result is not None, "Required property 'role' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def symmetric_key_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key_iam_binding#symmetric_key_id KmsSymmetricKeyIamBinding#symmetric_key_id}.'''
        result = self._values.get("symmetric_key_id")
        assert result is not None, "Required property 'symmetric_key_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key_iam_binding#id KmsSymmetricKeyIamBinding#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def sleep_after(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key_iam_binding#sleep_after KmsSymmetricKeyIamBinding#sleep_after}.'''
        result = self._values.get("sleep_after")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KmsSymmetricKeyIamBindingConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KmsSymmetricKeyTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class KmsSymmetricKeyTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#create KmsSymmetricKey#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#delete KmsSymmetricKey#delete}.
        :param read: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#read KmsSymmetricKey#read}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#update KmsSymmetricKey#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#create KmsSymmetricKey#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#delete KmsSymmetricKey#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#read KmsSymmetricKey#read}.'''
        result = self._values.get("read")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kms_symmetric_key#update KmsSymmetricKey#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KmsSymmetricKeyTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KmsSymmetricKeyTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KmsSymmetricKeyTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetRead")
    def reset_read(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRead", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="readInput")
    def read_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "readInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="read")
    def read(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "read"))

    @read.setter
    def read(self, value: builtins.str) -> None:
        jsii.set(self, "read", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, KmsSymmetricKeyTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, KmsSymmetricKeyTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, KmsSymmetricKeyTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class KubernetesCluster(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesCluster",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster yandex_kubernetes_cluster}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        master: "KubernetesClusterMaster",
        network_id: builtins.str,
        node_service_account_id: builtins.str,
        service_account_id: builtins.str,
        cluster_ipv4_range: typing.Optional[builtins.str] = None,
        cluster_ipv6_range: typing.Optional[builtins.str] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        kms_provider: typing.Optional["KubernetesClusterKmsProvider"] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        network_implementation: typing.Optional["KubernetesClusterNetworkImplementation"] = None,
        network_policy_provider: typing.Optional[builtins.str] = None,
        node_ipv4_cidr_mask_size: typing.Optional[jsii.Number] = None,
        release_channel: typing.Optional[builtins.str] = None,
        service_ipv4_range: typing.Optional[builtins.str] = None,
        service_ipv6_range: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["KubernetesClusterTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster yandex_kubernetes_cluster} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param master: master block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#master KubernetesCluster#master}
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#network_id KubernetesCluster#network_id}.
        :param node_service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#node_service_account_id KubernetesCluster#node_service_account_id}.
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#service_account_id KubernetesCluster#service_account_id}.
        :param cluster_ipv4_range: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#cluster_ipv4_range KubernetesCluster#cluster_ipv4_range}.
        :param cluster_ipv6_range: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#cluster_ipv6_range KubernetesCluster#cluster_ipv6_range}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#description KubernetesCluster#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#folder_id KubernetesCluster#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#id KubernetesCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param kms_provider: kms_provider block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#kms_provider KubernetesCluster#kms_provider}
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#labels KubernetesCluster#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#name KubernetesCluster#name}.
        :param network_implementation: network_implementation block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#network_implementation KubernetesCluster#network_implementation}
        :param network_policy_provider: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#network_policy_provider KubernetesCluster#network_policy_provider}.
        :param node_ipv4_cidr_mask_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#node_ipv4_cidr_mask_size KubernetesCluster#node_ipv4_cidr_mask_size}.
        :param release_channel: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#release_channel KubernetesCluster#release_channel}.
        :param service_ipv4_range: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#service_ipv4_range KubernetesCluster#service_ipv4_range}.
        :param service_ipv6_range: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#service_ipv6_range KubernetesCluster#service_ipv6_range}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#timeouts KubernetesCluster#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = KubernetesClusterConfig(
            master=master,
            network_id=network_id,
            node_service_account_id=node_service_account_id,
            service_account_id=service_account_id,
            cluster_ipv4_range=cluster_ipv4_range,
            cluster_ipv6_range=cluster_ipv6_range,
            description=description,
            folder_id=folder_id,
            id=id,
            kms_provider=kms_provider,
            labels=labels,
            name=name,
            network_implementation=network_implementation,
            network_policy_provider=network_policy_provider,
            node_ipv4_cidr_mask_size=node_ipv4_cidr_mask_size,
            release_channel=release_channel,
            service_ipv4_range=service_ipv4_range,
            service_ipv6_range=service_ipv6_range,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putKmsProvider")
    def put_kms_provider(self, *, key_id: typing.Optional[builtins.str] = None) -> None:
        '''
        :param key_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#key_id KubernetesCluster#key_id}.
        '''
        value = KubernetesClusterKmsProvider(key_id=key_id)

        return typing.cast(None, jsii.invoke(self, "putKmsProvider", [value]))

    @jsii.member(jsii_name="putMaster")
    def put_master(
        self,
        *,
        maintenance_policy: typing.Optional["KubernetesClusterMasterMaintenancePolicy"] = None,
        public_ip: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        regional: typing.Optional["KubernetesClusterMasterRegional"] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        version: typing.Optional[builtins.str] = None,
        zonal: typing.Optional["KubernetesClusterMasterZonal"] = None,
    ) -> None:
        '''
        :param maintenance_policy: maintenance_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#maintenance_policy KubernetesCluster#maintenance_policy}
        :param public_ip: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#public_ip KubernetesCluster#public_ip}.
        :param regional: regional block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#regional KubernetesCluster#regional}
        :param security_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#security_group_ids KubernetesCluster#security_group_ids}.
        :param version: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#version KubernetesCluster#version}.
        :param zonal: zonal block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#zonal KubernetesCluster#zonal}
        '''
        value = KubernetesClusterMaster(
            maintenance_policy=maintenance_policy,
            public_ip=public_ip,
            regional=regional,
            security_group_ids=security_group_ids,
            version=version,
            zonal=zonal,
        )

        return typing.cast(None, jsii.invoke(self, "putMaster", [value]))

    @jsii.member(jsii_name="putNetworkImplementation")
    def put_network_implementation(
        self,
        *,
        cilium: typing.Optional["KubernetesClusterNetworkImplementationCilium"] = None,
    ) -> None:
        '''
        :param cilium: cilium block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#cilium KubernetesCluster#cilium}
        '''
        value = KubernetesClusterNetworkImplementation(cilium=cilium)

        return typing.cast(None, jsii.invoke(self, "putNetworkImplementation", [value]))

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#create KubernetesCluster#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#delete KubernetesCluster#delete}.
        :param read: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#read KubernetesCluster#read}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#update KubernetesCluster#update}.
        '''
        value = KubernetesClusterTimeouts(
            create=create, delete=delete, read=read, update=update
        )

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetClusterIpv4Range")
    def reset_cluster_ipv4_range(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetClusterIpv4Range", []))

    @jsii.member(jsii_name="resetClusterIpv6Range")
    def reset_cluster_ipv6_range(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetClusterIpv6Range", []))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetKmsProvider")
    def reset_kms_provider(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetKmsProvider", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetNetworkImplementation")
    def reset_network_implementation(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNetworkImplementation", []))

    @jsii.member(jsii_name="resetNetworkPolicyProvider")
    def reset_network_policy_provider(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNetworkPolicyProvider", []))

    @jsii.member(jsii_name="resetNodeIpv4CidrMaskSize")
    def reset_node_ipv4_cidr_mask_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNodeIpv4CidrMaskSize", []))

    @jsii.member(jsii_name="resetReleaseChannel")
    def reset_release_channel(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetReleaseChannel", []))

    @jsii.member(jsii_name="resetServiceIpv4Range")
    def reset_service_ipv4_range(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetServiceIpv4Range", []))

    @jsii.member(jsii_name="resetServiceIpv6Range")
    def reset_service_ipv6_range(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetServiceIpv6Range", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="health")
    def health(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "health"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="kmsProvider")
    def kms_provider(self) -> "KubernetesClusterKmsProviderOutputReference":
        return typing.cast("KubernetesClusterKmsProviderOutputReference", jsii.get(self, "kmsProvider"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logGroupId")
    def log_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "logGroupId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="master")
    def master(self) -> "KubernetesClusterMasterOutputReference":
        return typing.cast("KubernetesClusterMasterOutputReference", jsii.get(self, "master"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkImplementation")
    def network_implementation(
        self,
    ) -> "KubernetesClusterNetworkImplementationOutputReference":
        return typing.cast("KubernetesClusterNetworkImplementationOutputReference", jsii.get(self, "networkImplementation"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "KubernetesClusterTimeoutsOutputReference":
        return typing.cast("KubernetesClusterTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterIpv4RangeInput")
    def cluster_ipv4_range_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "clusterIpv4RangeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterIpv6RangeInput")
    def cluster_ipv6_range_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "clusterIpv6RangeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="kmsProviderInput")
    def kms_provider_input(self) -> typing.Optional["KubernetesClusterKmsProvider"]:
        return typing.cast(typing.Optional["KubernetesClusterKmsProvider"], jsii.get(self, "kmsProviderInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="masterInput")
    def master_input(self) -> typing.Optional["KubernetesClusterMaster"]:
        return typing.cast(typing.Optional["KubernetesClusterMaster"], jsii.get(self, "masterInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkIdInput")
    def network_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "networkIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkImplementationInput")
    def network_implementation_input(
        self,
    ) -> typing.Optional["KubernetesClusterNetworkImplementation"]:
        return typing.cast(typing.Optional["KubernetesClusterNetworkImplementation"], jsii.get(self, "networkImplementationInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkPolicyProviderInput")
    def network_policy_provider_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "networkPolicyProviderInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nodeIpv4CidrMaskSizeInput")
    def node_ipv4_cidr_mask_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "nodeIpv4CidrMaskSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nodeServiceAccountIdInput")
    def node_service_account_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nodeServiceAccountIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="releaseChannelInput")
    def release_channel_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "releaseChannelInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountIdInput")
    def service_account_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceAccountIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceIpv4RangeInput")
    def service_ipv4_range_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceIpv4RangeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceIpv6RangeInput")
    def service_ipv6_range_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceIpv6RangeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "KubernetesClusterTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "KubernetesClusterTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterIpv4Range")
    def cluster_ipv4_range(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "clusterIpv4Range"))

    @cluster_ipv4_range.setter
    def cluster_ipv4_range(self, value: builtins.str) -> None:
        jsii.set(self, "clusterIpv4Range", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterIpv6Range")
    def cluster_ipv6_range(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "clusterIpv6Range"))

    @cluster_ipv6_range.setter
    def cluster_ipv6_range(self, value: builtins.str) -> None:
        jsii.set(self, "clusterIpv6Range", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @network_id.setter
    def network_id(self, value: builtins.str) -> None:
        jsii.set(self, "networkId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkPolicyProvider")
    def network_policy_provider(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkPolicyProvider"))

    @network_policy_provider.setter
    def network_policy_provider(self, value: builtins.str) -> None:
        jsii.set(self, "networkPolicyProvider", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nodeIpv4CidrMaskSize")
    def node_ipv4_cidr_mask_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "nodeIpv4CidrMaskSize"))

    @node_ipv4_cidr_mask_size.setter
    def node_ipv4_cidr_mask_size(self, value: jsii.Number) -> None:
        jsii.set(self, "nodeIpv4CidrMaskSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nodeServiceAccountId")
    def node_service_account_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "nodeServiceAccountId"))

    @node_service_account_id.setter
    def node_service_account_id(self, value: builtins.str) -> None:
        jsii.set(self, "nodeServiceAccountId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="releaseChannel")
    def release_channel(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "releaseChannel"))

    @release_channel.setter
    def release_channel(self, value: builtins.str) -> None:
        jsii.set(self, "releaseChannel", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountId")
    def service_account_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceAccountId"))

    @service_account_id.setter
    def service_account_id(self, value: builtins.str) -> None:
        jsii.set(self, "serviceAccountId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceIpv4Range")
    def service_ipv4_range(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceIpv4Range"))

    @service_ipv4_range.setter
    def service_ipv4_range(self, value: builtins.str) -> None:
        jsii.set(self, "serviceIpv4Range", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceIpv6Range")
    def service_ipv6_range(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceIpv6Range"))

    @service_ipv6_range.setter
    def service_ipv6_range(self, value: builtins.str) -> None:
        jsii.set(self, "serviceIpv6Range", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KubernetesClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "master": "master",
        "network_id": "networkId",
        "node_service_account_id": "nodeServiceAccountId",
        "service_account_id": "serviceAccountId",
        "cluster_ipv4_range": "clusterIpv4Range",
        "cluster_ipv6_range": "clusterIpv6Range",
        "description": "description",
        "folder_id": "folderId",
        "id": "id",
        "kms_provider": "kmsProvider",
        "labels": "labels",
        "name": "name",
        "network_implementation": "networkImplementation",
        "network_policy_provider": "networkPolicyProvider",
        "node_ipv4_cidr_mask_size": "nodeIpv4CidrMaskSize",
        "release_channel": "releaseChannel",
        "service_ipv4_range": "serviceIpv4Range",
        "service_ipv6_range": "serviceIpv6Range",
        "timeouts": "timeouts",
    },
)
class KubernetesClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        master: "KubernetesClusterMaster",
        network_id: builtins.str,
        node_service_account_id: builtins.str,
        service_account_id: builtins.str,
        cluster_ipv4_range: typing.Optional[builtins.str] = None,
        cluster_ipv6_range: typing.Optional[builtins.str] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        kms_provider: typing.Optional["KubernetesClusterKmsProvider"] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        network_implementation: typing.Optional["KubernetesClusterNetworkImplementation"] = None,
        network_policy_provider: typing.Optional[builtins.str] = None,
        node_ipv4_cidr_mask_size: typing.Optional[jsii.Number] = None,
        release_channel: typing.Optional[builtins.str] = None,
        service_ipv4_range: typing.Optional[builtins.str] = None,
        service_ipv6_range: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["KubernetesClusterTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param master: master block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#master KubernetesCluster#master}
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#network_id KubernetesCluster#network_id}.
        :param node_service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#node_service_account_id KubernetesCluster#node_service_account_id}.
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#service_account_id KubernetesCluster#service_account_id}.
        :param cluster_ipv4_range: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#cluster_ipv4_range KubernetesCluster#cluster_ipv4_range}.
        :param cluster_ipv6_range: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#cluster_ipv6_range KubernetesCluster#cluster_ipv6_range}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#description KubernetesCluster#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#folder_id KubernetesCluster#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#id KubernetesCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param kms_provider: kms_provider block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#kms_provider KubernetesCluster#kms_provider}
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#labels KubernetesCluster#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#name KubernetesCluster#name}.
        :param network_implementation: network_implementation block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#network_implementation KubernetesCluster#network_implementation}
        :param network_policy_provider: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#network_policy_provider KubernetesCluster#network_policy_provider}.
        :param node_ipv4_cidr_mask_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#node_ipv4_cidr_mask_size KubernetesCluster#node_ipv4_cidr_mask_size}.
        :param release_channel: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#release_channel KubernetesCluster#release_channel}.
        :param service_ipv4_range: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#service_ipv4_range KubernetesCluster#service_ipv4_range}.
        :param service_ipv6_range: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#service_ipv6_range KubernetesCluster#service_ipv6_range}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#timeouts KubernetesCluster#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(master, dict):
            master = KubernetesClusterMaster(**master)
        if isinstance(kms_provider, dict):
            kms_provider = KubernetesClusterKmsProvider(**kms_provider)
        if isinstance(network_implementation, dict):
            network_implementation = KubernetesClusterNetworkImplementation(**network_implementation)
        if isinstance(timeouts, dict):
            timeouts = KubernetesClusterTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "master": master,
            "network_id": network_id,
            "node_service_account_id": node_service_account_id,
            "service_account_id": service_account_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if cluster_ipv4_range is not None:
            self._values["cluster_ipv4_range"] = cluster_ipv4_range
        if cluster_ipv6_range is not None:
            self._values["cluster_ipv6_range"] = cluster_ipv6_range
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if kms_provider is not None:
            self._values["kms_provider"] = kms_provider
        if labels is not None:
            self._values["labels"] = labels
        if name is not None:
            self._values["name"] = name
        if network_implementation is not None:
            self._values["network_implementation"] = network_implementation
        if network_policy_provider is not None:
            self._values["network_policy_provider"] = network_policy_provider
        if node_ipv4_cidr_mask_size is not None:
            self._values["node_ipv4_cidr_mask_size"] = node_ipv4_cidr_mask_size
        if release_channel is not None:
            self._values["release_channel"] = release_channel
        if service_ipv4_range is not None:
            self._values["service_ipv4_range"] = service_ipv4_range
        if service_ipv6_range is not None:
            self._values["service_ipv6_range"] = service_ipv6_range
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def master(self) -> "KubernetesClusterMaster":
        '''master block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#master KubernetesCluster#master}
        '''
        result = self._values.get("master")
        assert result is not None, "Required property 'master' is missing"
        return typing.cast("KubernetesClusterMaster", result)

    @builtins.property
    def network_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#network_id KubernetesCluster#network_id}.'''
        result = self._values.get("network_id")
        assert result is not None, "Required property 'network_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def node_service_account_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#node_service_account_id KubernetesCluster#node_service_account_id}.'''
        result = self._values.get("node_service_account_id")
        assert result is not None, "Required property 'node_service_account_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def service_account_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#service_account_id KubernetesCluster#service_account_id}.'''
        result = self._values.get("service_account_id")
        assert result is not None, "Required property 'service_account_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def cluster_ipv4_range(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#cluster_ipv4_range KubernetesCluster#cluster_ipv4_range}.'''
        result = self._values.get("cluster_ipv4_range")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cluster_ipv6_range(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#cluster_ipv6_range KubernetesCluster#cluster_ipv6_range}.'''
        result = self._values.get("cluster_ipv6_range")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#description KubernetesCluster#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#folder_id KubernetesCluster#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#id KubernetesCluster#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def kms_provider(self) -> typing.Optional["KubernetesClusterKmsProvider"]:
        '''kms_provider block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#kms_provider KubernetesCluster#kms_provider}
        '''
        result = self._values.get("kms_provider")
        return typing.cast(typing.Optional["KubernetesClusterKmsProvider"], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#labels KubernetesCluster#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#name KubernetesCluster#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def network_implementation(
        self,
    ) -> typing.Optional["KubernetesClusterNetworkImplementation"]:
        '''network_implementation block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#network_implementation KubernetesCluster#network_implementation}
        '''
        result = self._values.get("network_implementation")
        return typing.cast(typing.Optional["KubernetesClusterNetworkImplementation"], result)

    @builtins.property
    def network_policy_provider(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#network_policy_provider KubernetesCluster#network_policy_provider}.'''
        result = self._values.get("network_policy_provider")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def node_ipv4_cidr_mask_size(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#node_ipv4_cidr_mask_size KubernetesCluster#node_ipv4_cidr_mask_size}.'''
        result = self._values.get("node_ipv4_cidr_mask_size")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def release_channel(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#release_channel KubernetesCluster#release_channel}.'''
        result = self._values.get("release_channel")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def service_ipv4_range(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#service_ipv4_range KubernetesCluster#service_ipv4_range}.'''
        result = self._values.get("service_ipv4_range")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def service_ipv6_range(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#service_ipv6_range KubernetesCluster#service_ipv6_range}.'''
        result = self._values.get("service_ipv6_range")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["KubernetesClusterTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#timeouts KubernetesCluster#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["KubernetesClusterTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KubernetesClusterKmsProvider",
    jsii_struct_bases=[],
    name_mapping={"key_id": "keyId"},
)
class KubernetesClusterKmsProvider:
    def __init__(self, *, key_id: typing.Optional[builtins.str] = None) -> None:
        '''
        :param key_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#key_id KubernetesCluster#key_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if key_id is not None:
            self._values["key_id"] = key_id

    @builtins.property
    def key_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#key_id KubernetesCluster#key_id}.'''
        result = self._values.get("key_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesClusterKmsProvider(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KubernetesClusterKmsProviderOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesClusterKmsProviderOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetKeyId")
    def reset_key_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetKeyId", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="keyIdInput")
    def key_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "keyIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="keyId")
    def key_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "keyId"))

    @key_id.setter
    def key_id(self, value: builtins.str) -> None:
        jsii.set(self, "keyId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[KubernetesClusterKmsProvider]:
        return typing.cast(typing.Optional[KubernetesClusterKmsProvider], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[KubernetesClusterKmsProvider],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KubernetesClusterMaster",
    jsii_struct_bases=[],
    name_mapping={
        "maintenance_policy": "maintenancePolicy",
        "public_ip": "publicIp",
        "regional": "regional",
        "security_group_ids": "securityGroupIds",
        "version": "version",
        "zonal": "zonal",
    },
)
class KubernetesClusterMaster:
    def __init__(
        self,
        *,
        maintenance_policy: typing.Optional["KubernetesClusterMasterMaintenancePolicy"] = None,
        public_ip: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        regional: typing.Optional["KubernetesClusterMasterRegional"] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        version: typing.Optional[builtins.str] = None,
        zonal: typing.Optional["KubernetesClusterMasterZonal"] = None,
    ) -> None:
        '''
        :param maintenance_policy: maintenance_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#maintenance_policy KubernetesCluster#maintenance_policy}
        :param public_ip: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#public_ip KubernetesCluster#public_ip}.
        :param regional: regional block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#regional KubernetesCluster#regional}
        :param security_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#security_group_ids KubernetesCluster#security_group_ids}.
        :param version: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#version KubernetesCluster#version}.
        :param zonal: zonal block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#zonal KubernetesCluster#zonal}
        '''
        if isinstance(maintenance_policy, dict):
            maintenance_policy = KubernetesClusterMasterMaintenancePolicy(**maintenance_policy)
        if isinstance(regional, dict):
            regional = KubernetesClusterMasterRegional(**regional)
        if isinstance(zonal, dict):
            zonal = KubernetesClusterMasterZonal(**zonal)
        self._values: typing.Dict[str, typing.Any] = {}
        if maintenance_policy is not None:
            self._values["maintenance_policy"] = maintenance_policy
        if public_ip is not None:
            self._values["public_ip"] = public_ip
        if regional is not None:
            self._values["regional"] = regional
        if security_group_ids is not None:
            self._values["security_group_ids"] = security_group_ids
        if version is not None:
            self._values["version"] = version
        if zonal is not None:
            self._values["zonal"] = zonal

    @builtins.property
    def maintenance_policy(
        self,
    ) -> typing.Optional["KubernetesClusterMasterMaintenancePolicy"]:
        '''maintenance_policy block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#maintenance_policy KubernetesCluster#maintenance_policy}
        '''
        result = self._values.get("maintenance_policy")
        return typing.cast(typing.Optional["KubernetesClusterMasterMaintenancePolicy"], result)

    @builtins.property
    def public_ip(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#public_ip KubernetesCluster#public_ip}.'''
        result = self._values.get("public_ip")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def regional(self) -> typing.Optional["KubernetesClusterMasterRegional"]:
        '''regional block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#regional KubernetesCluster#regional}
        '''
        result = self._values.get("regional")
        return typing.cast(typing.Optional["KubernetesClusterMasterRegional"], result)

    @builtins.property
    def security_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#security_group_ids KubernetesCluster#security_group_ids}.'''
        result = self._values.get("security_group_ids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def version(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#version KubernetesCluster#version}.'''
        result = self._values.get("version")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def zonal(self) -> typing.Optional["KubernetesClusterMasterZonal"]:
        '''zonal block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#zonal KubernetesCluster#zonal}
        '''
        result = self._values.get("zonal")
        return typing.cast(typing.Optional["KubernetesClusterMasterZonal"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesClusterMaster(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KubernetesClusterMasterMaintenancePolicy",
    jsii_struct_bases=[],
    name_mapping={
        "auto_upgrade": "autoUpgrade",
        "maintenance_window": "maintenanceWindow",
    },
)
class KubernetesClusterMasterMaintenancePolicy:
    def __init__(
        self,
        *,
        auto_upgrade: typing.Union[builtins.bool, cdktf.IResolvable],
        maintenance_window: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["KubernetesClusterMasterMaintenancePolicyMaintenanceWindow"]]] = None,
    ) -> None:
        '''
        :param auto_upgrade: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#auto_upgrade KubernetesCluster#auto_upgrade}.
        :param maintenance_window: maintenance_window block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#maintenance_window KubernetesCluster#maintenance_window}
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "auto_upgrade": auto_upgrade,
        }
        if maintenance_window is not None:
            self._values["maintenance_window"] = maintenance_window

    @builtins.property
    def auto_upgrade(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#auto_upgrade KubernetesCluster#auto_upgrade}.'''
        result = self._values.get("auto_upgrade")
        assert result is not None, "Required property 'auto_upgrade' is missing"
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], result)

    @builtins.property
    def maintenance_window(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["KubernetesClusterMasterMaintenancePolicyMaintenanceWindow"]]]:
        '''maintenance_window block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#maintenance_window KubernetesCluster#maintenance_window}
        '''
        result = self._values.get("maintenance_window")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["KubernetesClusterMasterMaintenancePolicyMaintenanceWindow"]]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesClusterMasterMaintenancePolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KubernetesClusterMasterMaintenancePolicyMaintenanceWindow",
    jsii_struct_bases=[],
    name_mapping={"duration": "duration", "start_time": "startTime", "day": "day"},
)
class KubernetesClusterMasterMaintenancePolicyMaintenanceWindow:
    def __init__(
        self,
        *,
        duration: builtins.str,
        start_time: builtins.str,
        day: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param duration: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#duration KubernetesCluster#duration}.
        :param start_time: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#start_time KubernetesCluster#start_time}.
        :param day: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#day KubernetesCluster#day}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "duration": duration,
            "start_time": start_time,
        }
        if day is not None:
            self._values["day"] = day

    @builtins.property
    def duration(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#duration KubernetesCluster#duration}.'''
        result = self._values.get("duration")
        assert result is not None, "Required property 'duration' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def start_time(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#start_time KubernetesCluster#start_time}.'''
        result = self._values.get("start_time")
        assert result is not None, "Required property 'start_time' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def day(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#day KubernetesCluster#day}.'''
        result = self._values.get("day")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesClusterMasterMaintenancePolicyMaintenanceWindow(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KubernetesClusterMasterMaintenancePolicyMaintenanceWindowList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesClusterMasterMaintenancePolicyMaintenanceWindowList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "KubernetesClusterMasterMaintenancePolicyMaintenanceWindowOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("KubernetesClusterMasterMaintenancePolicyMaintenanceWindowOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[KubernetesClusterMasterMaintenancePolicyMaintenanceWindow]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[KubernetesClusterMasterMaintenancePolicyMaintenanceWindow]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[KubernetesClusterMasterMaintenancePolicyMaintenanceWindow]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class KubernetesClusterMasterMaintenancePolicyMaintenanceWindowOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesClusterMasterMaintenancePolicyMaintenanceWindowOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetDay")
    def reset_day(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDay", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dayInput")
    def day_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dayInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="durationInput")
    def duration_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "durationInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="startTimeInput")
    def start_time_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "startTimeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="day")
    def day(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "day"))

    @day.setter
    def day(self, value: builtins.str) -> None:
        jsii.set(self, "day", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="duration")
    def duration(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "duration"))

    @duration.setter
    def duration(self, value: builtins.str) -> None:
        jsii.set(self, "duration", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="startTime")
    def start_time(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "startTime"))

    @start_time.setter
    def start_time(self, value: builtins.str) -> None:
        jsii.set(self, "startTime", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, KubernetesClusterMasterMaintenancePolicyMaintenanceWindow]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, KubernetesClusterMasterMaintenancePolicyMaintenanceWindow]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, KubernetesClusterMasterMaintenancePolicyMaintenanceWindow]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class KubernetesClusterMasterMaintenancePolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesClusterMasterMaintenancePolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putMaintenanceWindow")
    def put_maintenance_window(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence[KubernetesClusterMasterMaintenancePolicyMaintenanceWindow]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putMaintenanceWindow", [value]))

    @jsii.member(jsii_name="resetMaintenanceWindow")
    def reset_maintenance_window(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaintenanceWindow", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maintenanceWindow")
    def maintenance_window(
        self,
    ) -> KubernetesClusterMasterMaintenancePolicyMaintenanceWindowList:
        return typing.cast(KubernetesClusterMasterMaintenancePolicyMaintenanceWindowList, jsii.get(self, "maintenanceWindow"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoUpgradeInput")
    def auto_upgrade_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "autoUpgradeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maintenanceWindowInput")
    def maintenance_window_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[KubernetesClusterMasterMaintenancePolicyMaintenanceWindow]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[KubernetesClusterMasterMaintenancePolicyMaintenanceWindow]]], jsii.get(self, "maintenanceWindowInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoUpgrade")
    def auto_upgrade(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "autoUpgrade"))

    @auto_upgrade.setter
    def auto_upgrade(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "autoUpgrade", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[KubernetesClusterMasterMaintenancePolicy]:
        return typing.cast(typing.Optional[KubernetesClusterMasterMaintenancePolicy], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[KubernetesClusterMasterMaintenancePolicy],
    ) -> None:
        jsii.set(self, "internalValue", value)


class KubernetesClusterMasterOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesClusterMasterOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putMaintenancePolicy")
    def put_maintenance_policy(
        self,
        *,
        auto_upgrade: typing.Union[builtins.bool, cdktf.IResolvable],
        maintenance_window: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence[KubernetesClusterMasterMaintenancePolicyMaintenanceWindow]]] = None,
    ) -> None:
        '''
        :param auto_upgrade: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#auto_upgrade KubernetesCluster#auto_upgrade}.
        :param maintenance_window: maintenance_window block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#maintenance_window KubernetesCluster#maintenance_window}
        '''
        value = KubernetesClusterMasterMaintenancePolicy(
            auto_upgrade=auto_upgrade, maintenance_window=maintenance_window
        )

        return typing.cast(None, jsii.invoke(self, "putMaintenancePolicy", [value]))

    @jsii.member(jsii_name="putRegional")
    def put_regional(
        self,
        *,
        region: builtins.str,
        location: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["KubernetesClusterMasterRegionalLocation"]]] = None,
    ) -> None:
        '''
        :param region: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#region KubernetesCluster#region}.
        :param location: location block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#location KubernetesCluster#location}
        '''
        value = KubernetesClusterMasterRegional(region=region, location=location)

        return typing.cast(None, jsii.invoke(self, "putRegional", [value]))

    @jsii.member(jsii_name="putZonal")
    def put_zonal(
        self,
        *,
        subnet_id: typing.Optional[builtins.str] = None,
        zone: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param subnet_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#subnet_id KubernetesCluster#subnet_id}.
        :param zone: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#zone KubernetesCluster#zone}.
        '''
        value = KubernetesClusterMasterZonal(subnet_id=subnet_id, zone=zone)

        return typing.cast(None, jsii.invoke(self, "putZonal", [value]))

    @jsii.member(jsii_name="resetMaintenancePolicy")
    def reset_maintenance_policy(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaintenancePolicy", []))

    @jsii.member(jsii_name="resetPublicIp")
    def reset_public_ip(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPublicIp", []))

    @jsii.member(jsii_name="resetRegional")
    def reset_regional(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRegional", []))

    @jsii.member(jsii_name="resetSecurityGroupIds")
    def reset_security_group_ids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityGroupIds", []))

    @jsii.member(jsii_name="resetVersion")
    def reset_version(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetVersion", []))

    @jsii.member(jsii_name="resetZonal")
    def reset_zonal(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetZonal", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterCaCertificate")
    def cluster_ca_certificate(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "clusterCaCertificate"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="externalV4Address")
    def external_v4_address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "externalV4Address"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="externalV4Endpoint")
    def external_v4_endpoint(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "externalV4Endpoint"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalV4Address")
    def internal_v4_address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "internalV4Address"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalV4Endpoint")
    def internal_v4_endpoint(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "internalV4Endpoint"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maintenancePolicy")
    def maintenance_policy(
        self,
    ) -> KubernetesClusterMasterMaintenancePolicyOutputReference:
        return typing.cast(KubernetesClusterMasterMaintenancePolicyOutputReference, jsii.get(self, "maintenancePolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="regional")
    def regional(self) -> "KubernetesClusterMasterRegionalOutputReference":
        return typing.cast("KubernetesClusterMasterRegionalOutputReference", jsii.get(self, "regional"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="versionInfo")
    def version_info(self) -> "KubernetesClusterMasterVersionInfoList":
        return typing.cast("KubernetesClusterMasterVersionInfoList", jsii.get(self, "versionInfo"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zonal")
    def zonal(self) -> "KubernetesClusterMasterZonalOutputReference":
        return typing.cast("KubernetesClusterMasterZonalOutputReference", jsii.get(self, "zonal"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maintenancePolicyInput")
    def maintenance_policy_input(
        self,
    ) -> typing.Optional[KubernetesClusterMasterMaintenancePolicy]:
        return typing.cast(typing.Optional[KubernetesClusterMasterMaintenancePolicy], jsii.get(self, "maintenancePolicyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="publicIpInput")
    def public_ip_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "publicIpInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="regionalInput")
    def regional_input(self) -> typing.Optional["KubernetesClusterMasterRegional"]:
        return typing.cast(typing.Optional["KubernetesClusterMasterRegional"], jsii.get(self, "regionalInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIdsInput")
    def security_group_ids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "securityGroupIdsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="versionInput")
    def version_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "versionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zonalInput")
    def zonal_input(self) -> typing.Optional["KubernetesClusterMasterZonal"]:
        return typing.cast(typing.Optional["KubernetesClusterMasterZonal"], jsii.get(self, "zonalInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="publicIp")
    def public_ip(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "publicIp"))

    @public_ip.setter
    def public_ip(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "publicIp", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "securityGroupIds"))

    @security_group_ids.setter
    def security_group_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "securityGroupIds", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "version"))

    @version.setter
    def version(self, value: builtins.str) -> None:
        jsii.set(self, "version", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[KubernetesClusterMaster]:
        return typing.cast(typing.Optional[KubernetesClusterMaster], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(self, value: typing.Optional[KubernetesClusterMaster]) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KubernetesClusterMasterRegional",
    jsii_struct_bases=[],
    name_mapping={"region": "region", "location": "location"},
)
class KubernetesClusterMasterRegional:
    def __init__(
        self,
        *,
        region: builtins.str,
        location: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["KubernetesClusterMasterRegionalLocation"]]] = None,
    ) -> None:
        '''
        :param region: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#region KubernetesCluster#region}.
        :param location: location block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#location KubernetesCluster#location}
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "region": region,
        }
        if location is not None:
            self._values["location"] = location

    @builtins.property
    def region(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#region KubernetesCluster#region}.'''
        result = self._values.get("region")
        assert result is not None, "Required property 'region' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def location(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["KubernetesClusterMasterRegionalLocation"]]]:
        '''location block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#location KubernetesCluster#location}
        '''
        result = self._values.get("location")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["KubernetesClusterMasterRegionalLocation"]]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesClusterMasterRegional(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KubernetesClusterMasterRegionalLocation",
    jsii_struct_bases=[],
    name_mapping={"subnet_id": "subnetId", "zone": "zone"},
)
class KubernetesClusterMasterRegionalLocation:
    def __init__(
        self,
        *,
        subnet_id: typing.Optional[builtins.str] = None,
        zone: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param subnet_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#subnet_id KubernetesCluster#subnet_id}.
        :param zone: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#zone KubernetesCluster#zone}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if zone is not None:
            self._values["zone"] = zone

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#subnet_id KubernetesCluster#subnet_id}.'''
        result = self._values.get("subnet_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def zone(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#zone KubernetesCluster#zone}.'''
        result = self._values.get("zone")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesClusterMasterRegionalLocation(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KubernetesClusterMasterRegionalLocationList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesClusterMasterRegionalLocationList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "KubernetesClusterMasterRegionalLocationOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("KubernetesClusterMasterRegionalLocationOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[KubernetesClusterMasterRegionalLocation]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[KubernetesClusterMasterRegionalLocation]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[KubernetesClusterMasterRegionalLocation]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class KubernetesClusterMasterRegionalLocationOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesClusterMasterRegionalLocationOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetSubnetId")
    def reset_subnet_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSubnetId", []))

    @jsii.member(jsii_name="resetZone")
    def reset_zone(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetZone", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIdInput")
    def subnet_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "subnetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneInput")
    def zone_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "zoneInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @subnet_id.setter
    def subnet_id(self, value: builtins.str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zone")
    def zone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zone"))

    @zone.setter
    def zone(self, value: builtins.str) -> None:
        jsii.set(self, "zone", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, KubernetesClusterMasterRegionalLocation]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, KubernetesClusterMasterRegionalLocation]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, KubernetesClusterMasterRegionalLocation]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class KubernetesClusterMasterRegionalOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesClusterMasterRegionalOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putLocation")
    def put_location(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence[KubernetesClusterMasterRegionalLocation]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putLocation", [value]))

    @jsii.member(jsii_name="resetLocation")
    def reset_location(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLocation", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="location")
    def location(self) -> KubernetesClusterMasterRegionalLocationList:
        return typing.cast(KubernetesClusterMasterRegionalLocationList, jsii.get(self, "location"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="locationInput")
    def location_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[KubernetesClusterMasterRegionalLocation]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[KubernetesClusterMasterRegionalLocation]]], jsii.get(self, "locationInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="regionInput")
    def region_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "regionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="region")
    def region(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "region"))

    @region.setter
    def region(self, value: builtins.str) -> None:
        jsii.set(self, "region", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[KubernetesClusterMasterRegional]:
        return typing.cast(typing.Optional[KubernetesClusterMasterRegional], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[KubernetesClusterMasterRegional],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KubernetesClusterMasterVersionInfo",
    jsii_struct_bases=[],
    name_mapping={},
)
class KubernetesClusterMasterVersionInfo:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesClusterMasterVersionInfo(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KubernetesClusterMasterVersionInfoList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesClusterMasterVersionInfoList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "KubernetesClusterMasterVersionInfoOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("KubernetesClusterMasterVersionInfoOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class KubernetesClusterMasterVersionInfoOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesClusterMasterVersionInfoOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="currentVersion")
    def current_version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "currentVersion"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="newRevisionAvailable")
    def new_revision_available(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "newRevisionAvailable"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="newRevisionSummary")
    def new_revision_summary(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "newRevisionSummary"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="versionDeprecated")
    def version_deprecated(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "versionDeprecated"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[KubernetesClusterMasterVersionInfo]:
        return typing.cast(typing.Optional[KubernetesClusterMasterVersionInfo], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[KubernetesClusterMasterVersionInfo],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KubernetesClusterMasterZonal",
    jsii_struct_bases=[],
    name_mapping={"subnet_id": "subnetId", "zone": "zone"},
)
class KubernetesClusterMasterZonal:
    def __init__(
        self,
        *,
        subnet_id: typing.Optional[builtins.str] = None,
        zone: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param subnet_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#subnet_id KubernetesCluster#subnet_id}.
        :param zone: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#zone KubernetesCluster#zone}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if zone is not None:
            self._values["zone"] = zone

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#subnet_id KubernetesCluster#subnet_id}.'''
        result = self._values.get("subnet_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def zone(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#zone KubernetesCluster#zone}.'''
        result = self._values.get("zone")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesClusterMasterZonal(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KubernetesClusterMasterZonalOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesClusterMasterZonalOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetSubnetId")
    def reset_subnet_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSubnetId", []))

    @jsii.member(jsii_name="resetZone")
    def reset_zone(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetZone", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIdInput")
    def subnet_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "subnetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneInput")
    def zone_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "zoneInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @subnet_id.setter
    def subnet_id(self, value: builtins.str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zone")
    def zone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zone"))

    @zone.setter
    def zone(self, value: builtins.str) -> None:
        jsii.set(self, "zone", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[KubernetesClusterMasterZonal]:
        return typing.cast(typing.Optional[KubernetesClusterMasterZonal], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[KubernetesClusterMasterZonal],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KubernetesClusterNetworkImplementation",
    jsii_struct_bases=[],
    name_mapping={"cilium": "cilium"},
)
class KubernetesClusterNetworkImplementation:
    def __init__(
        self,
        *,
        cilium: typing.Optional["KubernetesClusterNetworkImplementationCilium"] = None,
    ) -> None:
        '''
        :param cilium: cilium block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#cilium KubernetesCluster#cilium}
        '''
        if isinstance(cilium, dict):
            cilium = KubernetesClusterNetworkImplementationCilium(**cilium)
        self._values: typing.Dict[str, typing.Any] = {}
        if cilium is not None:
            self._values["cilium"] = cilium

    @builtins.property
    def cilium(self) -> typing.Optional["KubernetesClusterNetworkImplementationCilium"]:
        '''cilium block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#cilium KubernetesCluster#cilium}
        '''
        result = self._values.get("cilium")
        return typing.cast(typing.Optional["KubernetesClusterNetworkImplementationCilium"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesClusterNetworkImplementation(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KubernetesClusterNetworkImplementationCilium",
    jsii_struct_bases=[],
    name_mapping={},
)
class KubernetesClusterNetworkImplementationCilium:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesClusterNetworkImplementationCilium(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KubernetesClusterNetworkImplementationCiliumOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesClusterNetworkImplementationCiliumOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[KubernetesClusterNetworkImplementationCilium]:
        return typing.cast(typing.Optional[KubernetesClusterNetworkImplementationCilium], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[KubernetesClusterNetworkImplementationCilium],
    ) -> None:
        jsii.set(self, "internalValue", value)


class KubernetesClusterNetworkImplementationOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesClusterNetworkImplementationOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCilium")
    def put_cilium(self) -> None:
        value = KubernetesClusterNetworkImplementationCilium()

        return typing.cast(None, jsii.invoke(self, "putCilium", [value]))

    @jsii.member(jsii_name="resetCilium")
    def reset_cilium(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCilium", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cilium")
    def cilium(self) -> KubernetesClusterNetworkImplementationCiliumOutputReference:
        return typing.cast(KubernetesClusterNetworkImplementationCiliumOutputReference, jsii.get(self, "cilium"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ciliumInput")
    def cilium_input(
        self,
    ) -> typing.Optional[KubernetesClusterNetworkImplementationCilium]:
        return typing.cast(typing.Optional[KubernetesClusterNetworkImplementationCilium], jsii.get(self, "ciliumInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[KubernetesClusterNetworkImplementation]:
        return typing.cast(typing.Optional[KubernetesClusterNetworkImplementation], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[KubernetesClusterNetworkImplementation],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KubernetesClusterTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class KubernetesClusterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#create KubernetesCluster#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#delete KubernetesCluster#delete}.
        :param read: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#read KubernetesCluster#read}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#update KubernetesCluster#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#create KubernetesCluster#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#delete KubernetesCluster#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#read KubernetesCluster#read}.'''
        result = self._values.get("read")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_cluster#update KubernetesCluster#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesClusterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KubernetesClusterTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesClusterTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetRead")
    def reset_read(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRead", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="readInput")
    def read_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "readInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="read")
    def read(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "read"))

    @read.setter
    def read(self, value: builtins.str) -> None:
        jsii.set(self, "read", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, KubernetesClusterTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, KubernetesClusterTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, KubernetesClusterTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class KubernetesNodeGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroup",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group yandex_kubernetes_node_group}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        cluster_id: builtins.str,
        instance_template: "KubernetesNodeGroupInstanceTemplate",
        scale_policy: "KubernetesNodeGroupScalePolicy",
        allocation_policy: typing.Optional["KubernetesNodeGroupAllocationPolicy"] = None,
        allowed_unsafe_sysctls: typing.Optional[typing.Sequence[builtins.str]] = None,
        deploy_policy: typing.Optional["KubernetesNodeGroupDeployPolicy"] = None,
        description: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        maintenance_policy: typing.Optional["KubernetesNodeGroupMaintenancePolicy"] = None,
        name: typing.Optional[builtins.str] = None,
        node_labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        node_taints: typing.Optional[typing.Sequence[builtins.str]] = None,
        timeouts: typing.Optional["KubernetesNodeGroupTimeouts"] = None,
        version: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group yandex_kubernetes_node_group} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#cluster_id KubernetesNodeGroup#cluster_id}.
        :param instance_template: instance_template block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#instance_template KubernetesNodeGroup#instance_template}
        :param scale_policy: scale_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#scale_policy KubernetesNodeGroup#scale_policy}
        :param allocation_policy: allocation_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#allocation_policy KubernetesNodeGroup#allocation_policy}
        :param allowed_unsafe_sysctls: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#allowed_unsafe_sysctls KubernetesNodeGroup#allowed_unsafe_sysctls}.
        :param deploy_policy: deploy_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#deploy_policy KubernetesNodeGroup#deploy_policy}
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#description KubernetesNodeGroup#description}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#id KubernetesNodeGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#labels KubernetesNodeGroup#labels}.
        :param maintenance_policy: maintenance_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#maintenance_policy KubernetesNodeGroup#maintenance_policy}
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#name KubernetesNodeGroup#name}.
        :param node_labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#node_labels KubernetesNodeGroup#node_labels}.
        :param node_taints: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#node_taints KubernetesNodeGroup#node_taints}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#timeouts KubernetesNodeGroup#timeouts}
        :param version: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#version KubernetesNodeGroup#version}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = KubernetesNodeGroupConfig(
            cluster_id=cluster_id,
            instance_template=instance_template,
            scale_policy=scale_policy,
            allocation_policy=allocation_policy,
            allowed_unsafe_sysctls=allowed_unsafe_sysctls,
            deploy_policy=deploy_policy,
            description=description,
            id=id,
            labels=labels,
            maintenance_policy=maintenance_policy,
            name=name,
            node_labels=node_labels,
            node_taints=node_taints,
            timeouts=timeouts,
            version=version,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putAllocationPolicy")
    def put_allocation_policy(
        self,
        *,
        location: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["KubernetesNodeGroupAllocationPolicyLocation"]]] = None,
    ) -> None:
        '''
        :param location: location block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#location KubernetesNodeGroup#location}
        '''
        value = KubernetesNodeGroupAllocationPolicy(location=location)

        return typing.cast(None, jsii.invoke(self, "putAllocationPolicy", [value]))

    @jsii.member(jsii_name="putDeployPolicy")
    def put_deploy_policy(
        self,
        *,
        max_expansion: jsii.Number,
        max_unavailable: jsii.Number,
    ) -> None:
        '''
        :param max_expansion: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#max_expansion KubernetesNodeGroup#max_expansion}.
        :param max_unavailable: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#max_unavailable KubernetesNodeGroup#max_unavailable}.
        '''
        value = KubernetesNodeGroupDeployPolicy(
            max_expansion=max_expansion, max_unavailable=max_unavailable
        )

        return typing.cast(None, jsii.invoke(self, "putDeployPolicy", [value]))

    @jsii.member(jsii_name="putInstanceTemplate")
    def put_instance_template(
        self,
        *,
        boot_disk: typing.Optional["KubernetesNodeGroupInstanceTemplateBootDisk"] = None,
        container_runtime: typing.Optional["KubernetesNodeGroupInstanceTemplateContainerRuntime"] = None,
        metadata: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        nat: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        network_acceleration_type: typing.Optional[builtins.str] = None,
        network_interface: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["KubernetesNodeGroupInstanceTemplateNetworkInterface"]]] = None,
        placement_policy: typing.Optional["KubernetesNodeGroupInstanceTemplatePlacementPolicy"] = None,
        platform_id: typing.Optional[builtins.str] = None,
        resources: typing.Optional["KubernetesNodeGroupInstanceTemplateResources"] = None,
        scheduling_policy: typing.Optional["KubernetesNodeGroupInstanceTemplateSchedulingPolicy"] = None,
    ) -> None:
        '''
        :param boot_disk: boot_disk block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#boot_disk KubernetesNodeGroup#boot_disk}
        :param container_runtime: container_runtime block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#container_runtime KubernetesNodeGroup#container_runtime}
        :param metadata: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#metadata KubernetesNodeGroup#metadata}.
        :param nat: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#nat KubernetesNodeGroup#nat}.
        :param network_acceleration_type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#network_acceleration_type KubernetesNodeGroup#network_acceleration_type}.
        :param network_interface: network_interface block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#network_interface KubernetesNodeGroup#network_interface}
        :param placement_policy: placement_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#placement_policy KubernetesNodeGroup#placement_policy}
        :param platform_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#platform_id KubernetesNodeGroup#platform_id}.
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#resources KubernetesNodeGroup#resources}
        :param scheduling_policy: scheduling_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#scheduling_policy KubernetesNodeGroup#scheduling_policy}
        '''
        value = KubernetesNodeGroupInstanceTemplate(
            boot_disk=boot_disk,
            container_runtime=container_runtime,
            metadata=metadata,
            nat=nat,
            network_acceleration_type=network_acceleration_type,
            network_interface=network_interface,
            placement_policy=placement_policy,
            platform_id=platform_id,
            resources=resources,
            scheduling_policy=scheduling_policy,
        )

        return typing.cast(None, jsii.invoke(self, "putInstanceTemplate", [value]))

    @jsii.member(jsii_name="putMaintenancePolicy")
    def put_maintenance_policy(
        self,
        *,
        auto_repair: typing.Union[builtins.bool, cdktf.IResolvable],
        auto_upgrade: typing.Union[builtins.bool, cdktf.IResolvable],
        maintenance_window: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["KubernetesNodeGroupMaintenancePolicyMaintenanceWindow"]]] = None,
    ) -> None:
        '''
        :param auto_repair: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#auto_repair KubernetesNodeGroup#auto_repair}.
        :param auto_upgrade: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#auto_upgrade KubernetesNodeGroup#auto_upgrade}.
        :param maintenance_window: maintenance_window block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#maintenance_window KubernetesNodeGroup#maintenance_window}
        '''
        value = KubernetesNodeGroupMaintenancePolicy(
            auto_repair=auto_repair,
            auto_upgrade=auto_upgrade,
            maintenance_window=maintenance_window,
        )

        return typing.cast(None, jsii.invoke(self, "putMaintenancePolicy", [value]))

    @jsii.member(jsii_name="putScalePolicy")
    def put_scale_policy(
        self,
        *,
        auto_scale: typing.Optional["KubernetesNodeGroupScalePolicyAutoScale"] = None,
        fixed_scale: typing.Optional["KubernetesNodeGroupScalePolicyFixedScale"] = None,
    ) -> None:
        '''
        :param auto_scale: auto_scale block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#auto_scale KubernetesNodeGroup#auto_scale}
        :param fixed_scale: fixed_scale block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#fixed_scale KubernetesNodeGroup#fixed_scale}
        '''
        value = KubernetesNodeGroupScalePolicy(
            auto_scale=auto_scale, fixed_scale=fixed_scale
        )

        return typing.cast(None, jsii.invoke(self, "putScalePolicy", [value]))

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#create KubernetesNodeGroup#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#delete KubernetesNodeGroup#delete}.
        :param read: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#read KubernetesNodeGroup#read}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#update KubernetesNodeGroup#update}.
        '''
        value = KubernetesNodeGroupTimeouts(
            create=create, delete=delete, read=read, update=update
        )

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetAllocationPolicy")
    def reset_allocation_policy(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAllocationPolicy", []))

    @jsii.member(jsii_name="resetAllowedUnsafeSysctls")
    def reset_allowed_unsafe_sysctls(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAllowedUnsafeSysctls", []))

    @jsii.member(jsii_name="resetDeployPolicy")
    def reset_deploy_policy(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDeployPolicy", []))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetMaintenancePolicy")
    def reset_maintenance_policy(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaintenancePolicy", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetNodeLabels")
    def reset_node_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNodeLabels", []))

    @jsii.member(jsii_name="resetNodeTaints")
    def reset_node_taints(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNodeTaints", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="resetVersion")
    def reset_version(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetVersion", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allocationPolicy")
    def allocation_policy(self) -> "KubernetesNodeGroupAllocationPolicyOutputReference":
        return typing.cast("KubernetesNodeGroupAllocationPolicyOutputReference", jsii.get(self, "allocationPolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deployPolicy")
    def deploy_policy(self) -> "KubernetesNodeGroupDeployPolicyOutputReference":
        return typing.cast("KubernetesNodeGroupDeployPolicyOutputReference", jsii.get(self, "deployPolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="instanceGroupId")
    def instance_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "instanceGroupId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="instanceTemplate")
    def instance_template(self) -> "KubernetesNodeGroupInstanceTemplateOutputReference":
        return typing.cast("KubernetesNodeGroupInstanceTemplateOutputReference", jsii.get(self, "instanceTemplate"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maintenancePolicy")
    def maintenance_policy(
        self,
    ) -> "KubernetesNodeGroupMaintenancePolicyOutputReference":
        return typing.cast("KubernetesNodeGroupMaintenancePolicyOutputReference", jsii.get(self, "maintenancePolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="scalePolicy")
    def scale_policy(self) -> "KubernetesNodeGroupScalePolicyOutputReference":
        return typing.cast("KubernetesNodeGroupScalePolicyOutputReference", jsii.get(self, "scalePolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "KubernetesNodeGroupTimeoutsOutputReference":
        return typing.cast("KubernetesNodeGroupTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="versionInfo")
    def version_info(self) -> "KubernetesNodeGroupVersionInfoList":
        return typing.cast("KubernetesNodeGroupVersionInfoList", jsii.get(self, "versionInfo"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allocationPolicyInput")
    def allocation_policy_input(
        self,
    ) -> typing.Optional["KubernetesNodeGroupAllocationPolicy"]:
        return typing.cast(typing.Optional["KubernetesNodeGroupAllocationPolicy"], jsii.get(self, "allocationPolicyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allowedUnsafeSysctlsInput")
    def allowed_unsafe_sysctls_input(
        self,
    ) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "allowedUnsafeSysctlsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterIdInput")
    def cluster_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "clusterIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deployPolicyInput")
    def deploy_policy_input(self) -> typing.Optional["KubernetesNodeGroupDeployPolicy"]:
        return typing.cast(typing.Optional["KubernetesNodeGroupDeployPolicy"], jsii.get(self, "deployPolicyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="instanceTemplateInput")
    def instance_template_input(
        self,
    ) -> typing.Optional["KubernetesNodeGroupInstanceTemplate"]:
        return typing.cast(typing.Optional["KubernetesNodeGroupInstanceTemplate"], jsii.get(self, "instanceTemplateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maintenancePolicyInput")
    def maintenance_policy_input(
        self,
    ) -> typing.Optional["KubernetesNodeGroupMaintenancePolicy"]:
        return typing.cast(typing.Optional["KubernetesNodeGroupMaintenancePolicy"], jsii.get(self, "maintenancePolicyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nodeLabelsInput")
    def node_labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "nodeLabelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nodeTaintsInput")
    def node_taints_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "nodeTaintsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="scalePolicyInput")
    def scale_policy_input(self) -> typing.Optional["KubernetesNodeGroupScalePolicy"]:
        return typing.cast(typing.Optional["KubernetesNodeGroupScalePolicy"], jsii.get(self, "scalePolicyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "KubernetesNodeGroupTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "KubernetesNodeGroupTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="versionInput")
    def version_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "versionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allowedUnsafeSysctls")
    def allowed_unsafe_sysctls(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "allowedUnsafeSysctls"))

    @allowed_unsafe_sysctls.setter
    def allowed_unsafe_sysctls(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "allowedUnsafeSysctls", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterId")
    def cluster_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "clusterId"))

    @cluster_id.setter
    def cluster_id(self, value: builtins.str) -> None:
        jsii.set(self, "clusterId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nodeLabels")
    def node_labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "nodeLabels"))

    @node_labels.setter
    def node_labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "nodeLabels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nodeTaints")
    def node_taints(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "nodeTaints"))

    @node_taints.setter
    def node_taints(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "nodeTaints", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "version"))

    @version.setter
    def version(self, value: builtins.str) -> None:
        jsii.set(self, "version", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupAllocationPolicy",
    jsii_struct_bases=[],
    name_mapping={"location": "location"},
)
class KubernetesNodeGroupAllocationPolicy:
    def __init__(
        self,
        *,
        location: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["KubernetesNodeGroupAllocationPolicyLocation"]]] = None,
    ) -> None:
        '''
        :param location: location block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#location KubernetesNodeGroup#location}
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if location is not None:
            self._values["location"] = location

    @builtins.property
    def location(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["KubernetesNodeGroupAllocationPolicyLocation"]]]:
        '''location block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#location KubernetesNodeGroup#location}
        '''
        result = self._values.get("location")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["KubernetesNodeGroupAllocationPolicyLocation"]]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesNodeGroupAllocationPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupAllocationPolicyLocation",
    jsii_struct_bases=[],
    name_mapping={"subnet_id": "subnetId", "zone": "zone"},
)
class KubernetesNodeGroupAllocationPolicyLocation:
    def __init__(
        self,
        *,
        subnet_id: typing.Optional[builtins.str] = None,
        zone: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param subnet_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#subnet_id KubernetesNodeGroup#subnet_id}.
        :param zone: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#zone KubernetesNodeGroup#zone}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if zone is not None:
            self._values["zone"] = zone

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#subnet_id KubernetesNodeGroup#subnet_id}.'''
        result = self._values.get("subnet_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def zone(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#zone KubernetesNodeGroup#zone}.'''
        result = self._values.get("zone")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesNodeGroupAllocationPolicyLocation(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KubernetesNodeGroupAllocationPolicyLocationList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupAllocationPolicyLocationList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "KubernetesNodeGroupAllocationPolicyLocationOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("KubernetesNodeGroupAllocationPolicyLocationOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[KubernetesNodeGroupAllocationPolicyLocation]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[KubernetesNodeGroupAllocationPolicyLocation]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[KubernetesNodeGroupAllocationPolicyLocation]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class KubernetesNodeGroupAllocationPolicyLocationOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupAllocationPolicyLocationOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetSubnetId")
    def reset_subnet_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSubnetId", []))

    @jsii.member(jsii_name="resetZone")
    def reset_zone(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetZone", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIdInput")
    def subnet_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "subnetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneInput")
    def zone_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "zoneInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @subnet_id.setter
    def subnet_id(self, value: builtins.str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zone")
    def zone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zone"))

    @zone.setter
    def zone(self, value: builtins.str) -> None:
        jsii.set(self, "zone", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, KubernetesNodeGroupAllocationPolicyLocation]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, KubernetesNodeGroupAllocationPolicyLocation]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, KubernetesNodeGroupAllocationPolicyLocation]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class KubernetesNodeGroupAllocationPolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupAllocationPolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putLocation")
    def put_location(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence[KubernetesNodeGroupAllocationPolicyLocation]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putLocation", [value]))

    @jsii.member(jsii_name="resetLocation")
    def reset_location(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLocation", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="location")
    def location(self) -> KubernetesNodeGroupAllocationPolicyLocationList:
        return typing.cast(KubernetesNodeGroupAllocationPolicyLocationList, jsii.get(self, "location"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="locationInput")
    def location_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[KubernetesNodeGroupAllocationPolicyLocation]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[KubernetesNodeGroupAllocationPolicyLocation]]], jsii.get(self, "locationInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[KubernetesNodeGroupAllocationPolicy]:
        return typing.cast(typing.Optional[KubernetesNodeGroupAllocationPolicy], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[KubernetesNodeGroupAllocationPolicy],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_id": "clusterId",
        "instance_template": "instanceTemplate",
        "scale_policy": "scalePolicy",
        "allocation_policy": "allocationPolicy",
        "allowed_unsafe_sysctls": "allowedUnsafeSysctls",
        "deploy_policy": "deployPolicy",
        "description": "description",
        "id": "id",
        "labels": "labels",
        "maintenance_policy": "maintenancePolicy",
        "name": "name",
        "node_labels": "nodeLabels",
        "node_taints": "nodeTaints",
        "timeouts": "timeouts",
        "version": "version",
    },
)
class KubernetesNodeGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_id: builtins.str,
        instance_template: "KubernetesNodeGroupInstanceTemplate",
        scale_policy: "KubernetesNodeGroupScalePolicy",
        allocation_policy: typing.Optional[KubernetesNodeGroupAllocationPolicy] = None,
        allowed_unsafe_sysctls: typing.Optional[typing.Sequence[builtins.str]] = None,
        deploy_policy: typing.Optional["KubernetesNodeGroupDeployPolicy"] = None,
        description: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        maintenance_policy: typing.Optional["KubernetesNodeGroupMaintenancePolicy"] = None,
        name: typing.Optional[builtins.str] = None,
        node_labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        node_taints: typing.Optional[typing.Sequence[builtins.str]] = None,
        timeouts: typing.Optional["KubernetesNodeGroupTimeouts"] = None,
        version: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#cluster_id KubernetesNodeGroup#cluster_id}.
        :param instance_template: instance_template block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#instance_template KubernetesNodeGroup#instance_template}
        :param scale_policy: scale_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#scale_policy KubernetesNodeGroup#scale_policy}
        :param allocation_policy: allocation_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#allocation_policy KubernetesNodeGroup#allocation_policy}
        :param allowed_unsafe_sysctls: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#allowed_unsafe_sysctls KubernetesNodeGroup#allowed_unsafe_sysctls}.
        :param deploy_policy: deploy_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#deploy_policy KubernetesNodeGroup#deploy_policy}
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#description KubernetesNodeGroup#description}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#id KubernetesNodeGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#labels KubernetesNodeGroup#labels}.
        :param maintenance_policy: maintenance_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#maintenance_policy KubernetesNodeGroup#maintenance_policy}
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#name KubernetesNodeGroup#name}.
        :param node_labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#node_labels KubernetesNodeGroup#node_labels}.
        :param node_taints: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#node_taints KubernetesNodeGroup#node_taints}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#timeouts KubernetesNodeGroup#timeouts}
        :param version: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#version KubernetesNodeGroup#version}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(instance_template, dict):
            instance_template = KubernetesNodeGroupInstanceTemplate(**instance_template)
        if isinstance(scale_policy, dict):
            scale_policy = KubernetesNodeGroupScalePolicy(**scale_policy)
        if isinstance(allocation_policy, dict):
            allocation_policy = KubernetesNodeGroupAllocationPolicy(**allocation_policy)
        if isinstance(deploy_policy, dict):
            deploy_policy = KubernetesNodeGroupDeployPolicy(**deploy_policy)
        if isinstance(maintenance_policy, dict):
            maintenance_policy = KubernetesNodeGroupMaintenancePolicy(**maintenance_policy)
        if isinstance(timeouts, dict):
            timeouts = KubernetesNodeGroupTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "cluster_id": cluster_id,
            "instance_template": instance_template,
            "scale_policy": scale_policy,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if allocation_policy is not None:
            self._values["allocation_policy"] = allocation_policy
        if allowed_unsafe_sysctls is not None:
            self._values["allowed_unsafe_sysctls"] = allowed_unsafe_sysctls
        if deploy_policy is not None:
            self._values["deploy_policy"] = deploy_policy
        if description is not None:
            self._values["description"] = description
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if maintenance_policy is not None:
            self._values["maintenance_policy"] = maintenance_policy
        if name is not None:
            self._values["name"] = name
        if node_labels is not None:
            self._values["node_labels"] = node_labels
        if node_taints is not None:
            self._values["node_taints"] = node_taints
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if version is not None:
            self._values["version"] = version

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def cluster_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#cluster_id KubernetesNodeGroup#cluster_id}.'''
        result = self._values.get("cluster_id")
        assert result is not None, "Required property 'cluster_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def instance_template(self) -> "KubernetesNodeGroupInstanceTemplate":
        '''instance_template block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#instance_template KubernetesNodeGroup#instance_template}
        '''
        result = self._values.get("instance_template")
        assert result is not None, "Required property 'instance_template' is missing"
        return typing.cast("KubernetesNodeGroupInstanceTemplate", result)

    @builtins.property
    def scale_policy(self) -> "KubernetesNodeGroupScalePolicy":
        '''scale_policy block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#scale_policy KubernetesNodeGroup#scale_policy}
        '''
        result = self._values.get("scale_policy")
        assert result is not None, "Required property 'scale_policy' is missing"
        return typing.cast("KubernetesNodeGroupScalePolicy", result)

    @builtins.property
    def allocation_policy(self) -> typing.Optional[KubernetesNodeGroupAllocationPolicy]:
        '''allocation_policy block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#allocation_policy KubernetesNodeGroup#allocation_policy}
        '''
        result = self._values.get("allocation_policy")
        return typing.cast(typing.Optional[KubernetesNodeGroupAllocationPolicy], result)

    @builtins.property
    def allowed_unsafe_sysctls(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#allowed_unsafe_sysctls KubernetesNodeGroup#allowed_unsafe_sysctls}.'''
        result = self._values.get("allowed_unsafe_sysctls")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def deploy_policy(self) -> typing.Optional["KubernetesNodeGroupDeployPolicy"]:
        '''deploy_policy block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#deploy_policy KubernetesNodeGroup#deploy_policy}
        '''
        result = self._values.get("deploy_policy")
        return typing.cast(typing.Optional["KubernetesNodeGroupDeployPolicy"], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#description KubernetesNodeGroup#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#id KubernetesNodeGroup#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#labels KubernetesNodeGroup#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def maintenance_policy(
        self,
    ) -> typing.Optional["KubernetesNodeGroupMaintenancePolicy"]:
        '''maintenance_policy block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#maintenance_policy KubernetesNodeGroup#maintenance_policy}
        '''
        result = self._values.get("maintenance_policy")
        return typing.cast(typing.Optional["KubernetesNodeGroupMaintenancePolicy"], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#name KubernetesNodeGroup#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def node_labels(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#node_labels KubernetesNodeGroup#node_labels}.'''
        result = self._values.get("node_labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def node_taints(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#node_taints KubernetesNodeGroup#node_taints}.'''
        result = self._values.get("node_taints")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["KubernetesNodeGroupTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#timeouts KubernetesNodeGroup#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["KubernetesNodeGroupTimeouts"], result)

    @builtins.property
    def version(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#version KubernetesNodeGroup#version}.'''
        result = self._values.get("version")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesNodeGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupDeployPolicy",
    jsii_struct_bases=[],
    name_mapping={
        "max_expansion": "maxExpansion",
        "max_unavailable": "maxUnavailable",
    },
)
class KubernetesNodeGroupDeployPolicy:
    def __init__(
        self,
        *,
        max_expansion: jsii.Number,
        max_unavailable: jsii.Number,
    ) -> None:
        '''
        :param max_expansion: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#max_expansion KubernetesNodeGroup#max_expansion}.
        :param max_unavailable: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#max_unavailable KubernetesNodeGroup#max_unavailable}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_expansion": max_expansion,
            "max_unavailable": max_unavailable,
        }

    @builtins.property
    def max_expansion(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#max_expansion KubernetesNodeGroup#max_expansion}.'''
        result = self._values.get("max_expansion")
        assert result is not None, "Required property 'max_expansion' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def max_unavailable(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#max_unavailable KubernetesNodeGroup#max_unavailable}.'''
        result = self._values.get("max_unavailable")
        assert result is not None, "Required property 'max_unavailable' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesNodeGroupDeployPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KubernetesNodeGroupDeployPolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupDeployPolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxExpansionInput")
    def max_expansion_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxExpansionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxUnavailableInput")
    def max_unavailable_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxUnavailableInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxExpansion")
    def max_expansion(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxExpansion"))

    @max_expansion.setter
    def max_expansion(self, value: jsii.Number) -> None:
        jsii.set(self, "maxExpansion", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxUnavailable")
    def max_unavailable(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxUnavailable"))

    @max_unavailable.setter
    def max_unavailable(self, value: jsii.Number) -> None:
        jsii.set(self, "maxUnavailable", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[KubernetesNodeGroupDeployPolicy]:
        return typing.cast(typing.Optional[KubernetesNodeGroupDeployPolicy], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[KubernetesNodeGroupDeployPolicy],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupInstanceTemplate",
    jsii_struct_bases=[],
    name_mapping={
        "boot_disk": "bootDisk",
        "container_runtime": "containerRuntime",
        "metadata": "metadata",
        "nat": "nat",
        "network_acceleration_type": "networkAccelerationType",
        "network_interface": "networkInterface",
        "placement_policy": "placementPolicy",
        "platform_id": "platformId",
        "resources": "resources",
        "scheduling_policy": "schedulingPolicy",
    },
)
class KubernetesNodeGroupInstanceTemplate:
    def __init__(
        self,
        *,
        boot_disk: typing.Optional["KubernetesNodeGroupInstanceTemplateBootDisk"] = None,
        container_runtime: typing.Optional["KubernetesNodeGroupInstanceTemplateContainerRuntime"] = None,
        metadata: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        nat: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        network_acceleration_type: typing.Optional[builtins.str] = None,
        network_interface: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["KubernetesNodeGroupInstanceTemplateNetworkInterface"]]] = None,
        placement_policy: typing.Optional["KubernetesNodeGroupInstanceTemplatePlacementPolicy"] = None,
        platform_id: typing.Optional[builtins.str] = None,
        resources: typing.Optional["KubernetesNodeGroupInstanceTemplateResources"] = None,
        scheduling_policy: typing.Optional["KubernetesNodeGroupInstanceTemplateSchedulingPolicy"] = None,
    ) -> None:
        '''
        :param boot_disk: boot_disk block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#boot_disk KubernetesNodeGroup#boot_disk}
        :param container_runtime: container_runtime block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#container_runtime KubernetesNodeGroup#container_runtime}
        :param metadata: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#metadata KubernetesNodeGroup#metadata}.
        :param nat: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#nat KubernetesNodeGroup#nat}.
        :param network_acceleration_type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#network_acceleration_type KubernetesNodeGroup#network_acceleration_type}.
        :param network_interface: network_interface block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#network_interface KubernetesNodeGroup#network_interface}
        :param placement_policy: placement_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#placement_policy KubernetesNodeGroup#placement_policy}
        :param platform_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#platform_id KubernetesNodeGroup#platform_id}.
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#resources KubernetesNodeGroup#resources}
        :param scheduling_policy: scheduling_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#scheduling_policy KubernetesNodeGroup#scheduling_policy}
        '''
        if isinstance(boot_disk, dict):
            boot_disk = KubernetesNodeGroupInstanceTemplateBootDisk(**boot_disk)
        if isinstance(container_runtime, dict):
            container_runtime = KubernetesNodeGroupInstanceTemplateContainerRuntime(**container_runtime)
        if isinstance(placement_policy, dict):
            placement_policy = KubernetesNodeGroupInstanceTemplatePlacementPolicy(**placement_policy)
        if isinstance(resources, dict):
            resources = KubernetesNodeGroupInstanceTemplateResources(**resources)
        if isinstance(scheduling_policy, dict):
            scheduling_policy = KubernetesNodeGroupInstanceTemplateSchedulingPolicy(**scheduling_policy)
        self._values: typing.Dict[str, typing.Any] = {}
        if boot_disk is not None:
            self._values["boot_disk"] = boot_disk
        if container_runtime is not None:
            self._values["container_runtime"] = container_runtime
        if metadata is not None:
            self._values["metadata"] = metadata
        if nat is not None:
            self._values["nat"] = nat
        if network_acceleration_type is not None:
            self._values["network_acceleration_type"] = network_acceleration_type
        if network_interface is not None:
            self._values["network_interface"] = network_interface
        if placement_policy is not None:
            self._values["placement_policy"] = placement_policy
        if platform_id is not None:
            self._values["platform_id"] = platform_id
        if resources is not None:
            self._values["resources"] = resources
        if scheduling_policy is not None:
            self._values["scheduling_policy"] = scheduling_policy

    @builtins.property
    def boot_disk(
        self,
    ) -> typing.Optional["KubernetesNodeGroupInstanceTemplateBootDisk"]:
        '''boot_disk block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#boot_disk KubernetesNodeGroup#boot_disk}
        '''
        result = self._values.get("boot_disk")
        return typing.cast(typing.Optional["KubernetesNodeGroupInstanceTemplateBootDisk"], result)

    @builtins.property
    def container_runtime(
        self,
    ) -> typing.Optional["KubernetesNodeGroupInstanceTemplateContainerRuntime"]:
        '''container_runtime block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#container_runtime KubernetesNodeGroup#container_runtime}
        '''
        result = self._values.get("container_runtime")
        return typing.cast(typing.Optional["KubernetesNodeGroupInstanceTemplateContainerRuntime"], result)

    @builtins.property
    def metadata(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#metadata KubernetesNodeGroup#metadata}.'''
        result = self._values.get("metadata")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def nat(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#nat KubernetesNodeGroup#nat}.'''
        result = self._values.get("nat")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def network_acceleration_type(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#network_acceleration_type KubernetesNodeGroup#network_acceleration_type}.'''
        result = self._values.get("network_acceleration_type")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def network_interface(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["KubernetesNodeGroupInstanceTemplateNetworkInterface"]]]:
        '''network_interface block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#network_interface KubernetesNodeGroup#network_interface}
        '''
        result = self._values.get("network_interface")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["KubernetesNodeGroupInstanceTemplateNetworkInterface"]]], result)

    @builtins.property
    def placement_policy(
        self,
    ) -> typing.Optional["KubernetesNodeGroupInstanceTemplatePlacementPolicy"]:
        '''placement_policy block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#placement_policy KubernetesNodeGroup#placement_policy}
        '''
        result = self._values.get("placement_policy")
        return typing.cast(typing.Optional["KubernetesNodeGroupInstanceTemplatePlacementPolicy"], result)

    @builtins.property
    def platform_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#platform_id KubernetesNodeGroup#platform_id}.'''
        result = self._values.get("platform_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def resources(
        self,
    ) -> typing.Optional["KubernetesNodeGroupInstanceTemplateResources"]:
        '''resources block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#resources KubernetesNodeGroup#resources}
        '''
        result = self._values.get("resources")
        return typing.cast(typing.Optional["KubernetesNodeGroupInstanceTemplateResources"], result)

    @builtins.property
    def scheduling_policy(
        self,
    ) -> typing.Optional["KubernetesNodeGroupInstanceTemplateSchedulingPolicy"]:
        '''scheduling_policy block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#scheduling_policy KubernetesNodeGroup#scheduling_policy}
        '''
        result = self._values.get("scheduling_policy")
        return typing.cast(typing.Optional["KubernetesNodeGroupInstanceTemplateSchedulingPolicy"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesNodeGroupInstanceTemplate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupInstanceTemplateBootDisk",
    jsii_struct_bases=[],
    name_mapping={"size": "size", "type": "type"},
)
class KubernetesNodeGroupInstanceTemplateBootDisk:
    def __init__(
        self,
        *,
        size: typing.Optional[jsii.Number] = None,
        type: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#size KubernetesNodeGroup#size}.
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#type KubernetesNodeGroup#type}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if size is not None:
            self._values["size"] = size
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def size(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#size KubernetesNodeGroup#size}.'''
        result = self._values.get("size")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def type(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#type KubernetesNodeGroup#type}.'''
        result = self._values.get("type")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesNodeGroupInstanceTemplateBootDisk(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KubernetesNodeGroupInstanceTemplateBootDiskOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupInstanceTemplateBootDiskOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetSize")
    def reset_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSize", []))

    @jsii.member(jsii_name="resetType")
    def reset_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetType", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sizeInput")
    def size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "sizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="typeInput")
    def type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "typeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="size")
    def size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "size"))

    @size.setter
    def size(self, value: jsii.Number) -> None:
        jsii.set(self, "size", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @type.setter
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[KubernetesNodeGroupInstanceTemplateBootDisk]:
        return typing.cast(typing.Optional[KubernetesNodeGroupInstanceTemplateBootDisk], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[KubernetesNodeGroupInstanceTemplateBootDisk],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupInstanceTemplateContainerRuntime",
    jsii_struct_bases=[],
    name_mapping={"type": "type"},
)
class KubernetesNodeGroupInstanceTemplateContainerRuntime:
    def __init__(self, *, type: builtins.str) -> None:
        '''
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#type KubernetesNodeGroup#type}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }

    @builtins.property
    def type(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#type KubernetesNodeGroup#type}.'''
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesNodeGroupInstanceTemplateContainerRuntime(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KubernetesNodeGroupInstanceTemplateContainerRuntimeOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupInstanceTemplateContainerRuntimeOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="typeInput")
    def type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "typeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @type.setter
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[KubernetesNodeGroupInstanceTemplateContainerRuntime]:
        return typing.cast(typing.Optional[KubernetesNodeGroupInstanceTemplateContainerRuntime], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[KubernetesNodeGroupInstanceTemplateContainerRuntime],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupInstanceTemplateNetworkInterface",
    jsii_struct_bases=[],
    name_mapping={
        "subnet_ids": "subnetIds",
        "ipv4": "ipv4",
        "ipv6": "ipv6",
        "nat": "nat",
        "security_group_ids": "securityGroupIds",
    },
)
class KubernetesNodeGroupInstanceTemplateNetworkInterface:
    def __init__(
        self,
        *,
        subnet_ids: typing.Sequence[builtins.str],
        ipv4: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        ipv6: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        nat: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param subnet_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#subnet_ids KubernetesNodeGroup#subnet_ids}.
        :param ipv4: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#ipv4 KubernetesNodeGroup#ipv4}.
        :param ipv6: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#ipv6 KubernetesNodeGroup#ipv6}.
        :param nat: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#nat KubernetesNodeGroup#nat}.
        :param security_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#security_group_ids KubernetesNodeGroup#security_group_ids}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "subnet_ids": subnet_ids,
        }
        if ipv4 is not None:
            self._values["ipv4"] = ipv4
        if ipv6 is not None:
            self._values["ipv6"] = ipv6
        if nat is not None:
            self._values["nat"] = nat
        if security_group_ids is not None:
            self._values["security_group_ids"] = security_group_ids

    @builtins.property
    def subnet_ids(self) -> typing.List[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#subnet_ids KubernetesNodeGroup#subnet_ids}.'''
        result = self._values.get("subnet_ids")
        assert result is not None, "Required property 'subnet_ids' is missing"
        return typing.cast(typing.List[builtins.str], result)

    @builtins.property
    def ipv4(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#ipv4 KubernetesNodeGroup#ipv4}.'''
        result = self._values.get("ipv4")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def ipv6(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#ipv6 KubernetesNodeGroup#ipv6}.'''
        result = self._values.get("ipv6")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def nat(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#nat KubernetesNodeGroup#nat}.'''
        result = self._values.get("nat")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def security_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#security_group_ids KubernetesNodeGroup#security_group_ids}.'''
        result = self._values.get("security_group_ids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesNodeGroupInstanceTemplateNetworkInterface(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KubernetesNodeGroupInstanceTemplateNetworkInterfaceList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupInstanceTemplateNetworkInterfaceList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "KubernetesNodeGroupInstanceTemplateNetworkInterfaceOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("KubernetesNodeGroupInstanceTemplateNetworkInterfaceOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[KubernetesNodeGroupInstanceTemplateNetworkInterface]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[KubernetesNodeGroupInstanceTemplateNetworkInterface]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[KubernetesNodeGroupInstanceTemplateNetworkInterface]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class KubernetesNodeGroupInstanceTemplateNetworkInterfaceOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupInstanceTemplateNetworkInterfaceOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetIpv4")
    def reset_ipv4(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIpv4", []))

    @jsii.member(jsii_name="resetIpv6")
    def reset_ipv6(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIpv6", []))

    @jsii.member(jsii_name="resetNat")
    def reset_nat(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNat", []))

    @jsii.member(jsii_name="resetSecurityGroupIds")
    def reset_security_group_ids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityGroupIds", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv4Input")
    def ipv4_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "ipv4Input"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv6Input")
    def ipv6_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "ipv6Input"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="natInput")
    def nat_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "natInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIdsInput")
    def security_group_ids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "securityGroupIdsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIdsInput")
    def subnet_ids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "subnetIdsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv4")
    def ipv4(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "ipv4"))

    @ipv4.setter
    def ipv4(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "ipv4", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipv6")
    def ipv6(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "ipv6"))

    @ipv6.setter
    def ipv6(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "ipv6", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nat")
    def nat(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "nat"))

    @nat.setter
    def nat(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "nat", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "securityGroupIds"))

    @security_group_ids.setter
    def security_group_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "securityGroupIds", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "subnetIds"))

    @subnet_ids.setter
    def subnet_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "subnetIds", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, KubernetesNodeGroupInstanceTemplateNetworkInterface]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, KubernetesNodeGroupInstanceTemplateNetworkInterface]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, KubernetesNodeGroupInstanceTemplateNetworkInterface]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class KubernetesNodeGroupInstanceTemplateOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupInstanceTemplateOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putBootDisk")
    def put_boot_disk(
        self,
        *,
        size: typing.Optional[jsii.Number] = None,
        type: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#size KubernetesNodeGroup#size}.
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#type KubernetesNodeGroup#type}.
        '''
        value = KubernetesNodeGroupInstanceTemplateBootDisk(size=size, type=type)

        return typing.cast(None, jsii.invoke(self, "putBootDisk", [value]))

    @jsii.member(jsii_name="putContainerRuntime")
    def put_container_runtime(self, *, type: builtins.str) -> None:
        '''
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#type KubernetesNodeGroup#type}.
        '''
        value = KubernetesNodeGroupInstanceTemplateContainerRuntime(type=type)

        return typing.cast(None, jsii.invoke(self, "putContainerRuntime", [value]))

    @jsii.member(jsii_name="putNetworkInterface")
    def put_network_interface(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence[KubernetesNodeGroupInstanceTemplateNetworkInterface]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putNetworkInterface", [value]))

    @jsii.member(jsii_name="putPlacementPolicy")
    def put_placement_policy(self, *, placement_group_id: builtins.str) -> None:
        '''
        :param placement_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#placement_group_id KubernetesNodeGroup#placement_group_id}.
        '''
        value = KubernetesNodeGroupInstanceTemplatePlacementPolicy(
            placement_group_id=placement_group_id
        )

        return typing.cast(None, jsii.invoke(self, "putPlacementPolicy", [value]))

    @jsii.member(jsii_name="putResources")
    def put_resources(
        self,
        *,
        core_fraction: typing.Optional[jsii.Number] = None,
        cores: typing.Optional[jsii.Number] = None,
        gpus: typing.Optional[jsii.Number] = None,
        memory: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param core_fraction: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#core_fraction KubernetesNodeGroup#core_fraction}.
        :param cores: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#cores KubernetesNodeGroup#cores}.
        :param gpus: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#gpus KubernetesNodeGroup#gpus}.
        :param memory: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#memory KubernetesNodeGroup#memory}.
        '''
        value = KubernetesNodeGroupInstanceTemplateResources(
            core_fraction=core_fraction, cores=cores, gpus=gpus, memory=memory
        )

        return typing.cast(None, jsii.invoke(self, "putResources", [value]))

    @jsii.member(jsii_name="putSchedulingPolicy")
    def put_scheduling_policy(
        self,
        *,
        preemptible: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param preemptible: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#preemptible KubernetesNodeGroup#preemptible}.
        '''
        value = KubernetesNodeGroupInstanceTemplateSchedulingPolicy(
            preemptible=preemptible
        )

        return typing.cast(None, jsii.invoke(self, "putSchedulingPolicy", [value]))

    @jsii.member(jsii_name="resetBootDisk")
    def reset_boot_disk(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetBootDisk", []))

    @jsii.member(jsii_name="resetContainerRuntime")
    def reset_container_runtime(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetContainerRuntime", []))

    @jsii.member(jsii_name="resetMetadata")
    def reset_metadata(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetadata", []))

    @jsii.member(jsii_name="resetNat")
    def reset_nat(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNat", []))

    @jsii.member(jsii_name="resetNetworkAccelerationType")
    def reset_network_acceleration_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNetworkAccelerationType", []))

    @jsii.member(jsii_name="resetNetworkInterface")
    def reset_network_interface(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNetworkInterface", []))

    @jsii.member(jsii_name="resetPlacementPolicy")
    def reset_placement_policy(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPlacementPolicy", []))

    @jsii.member(jsii_name="resetPlatformId")
    def reset_platform_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPlatformId", []))

    @jsii.member(jsii_name="resetResources")
    def reset_resources(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetResources", []))

    @jsii.member(jsii_name="resetSchedulingPolicy")
    def reset_scheduling_policy(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSchedulingPolicy", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bootDisk")
    def boot_disk(self) -> KubernetesNodeGroupInstanceTemplateBootDiskOutputReference:
        return typing.cast(KubernetesNodeGroupInstanceTemplateBootDiskOutputReference, jsii.get(self, "bootDisk"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="containerRuntime")
    def container_runtime(
        self,
    ) -> KubernetesNodeGroupInstanceTemplateContainerRuntimeOutputReference:
        return typing.cast(KubernetesNodeGroupInstanceTemplateContainerRuntimeOutputReference, jsii.get(self, "containerRuntime"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkInterface")
    def network_interface(
        self,
    ) -> KubernetesNodeGroupInstanceTemplateNetworkInterfaceList:
        return typing.cast(KubernetesNodeGroupInstanceTemplateNetworkInterfaceList, jsii.get(self, "networkInterface"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="placementPolicy")
    def placement_policy(
        self,
    ) -> "KubernetesNodeGroupInstanceTemplatePlacementPolicyOutputReference":
        return typing.cast("KubernetesNodeGroupInstanceTemplatePlacementPolicyOutputReference", jsii.get(self, "placementPolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resources")
    def resources(
        self,
    ) -> "KubernetesNodeGroupInstanceTemplateResourcesOutputReference":
        return typing.cast("KubernetesNodeGroupInstanceTemplateResourcesOutputReference", jsii.get(self, "resources"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="schedulingPolicy")
    def scheduling_policy(
        self,
    ) -> "KubernetesNodeGroupInstanceTemplateSchedulingPolicyOutputReference":
        return typing.cast("KubernetesNodeGroupInstanceTemplateSchedulingPolicyOutputReference", jsii.get(self, "schedulingPolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bootDiskInput")
    def boot_disk_input(
        self,
    ) -> typing.Optional[KubernetesNodeGroupInstanceTemplateBootDisk]:
        return typing.cast(typing.Optional[KubernetesNodeGroupInstanceTemplateBootDisk], jsii.get(self, "bootDiskInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="containerRuntimeInput")
    def container_runtime_input(
        self,
    ) -> typing.Optional[KubernetesNodeGroupInstanceTemplateContainerRuntime]:
        return typing.cast(typing.Optional[KubernetesNodeGroupInstanceTemplateContainerRuntime], jsii.get(self, "containerRuntimeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metadataInput")
    def metadata_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "metadataInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="natInput")
    def nat_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "natInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkAccelerationTypeInput")
    def network_acceleration_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "networkAccelerationTypeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkInterfaceInput")
    def network_interface_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[KubernetesNodeGroupInstanceTemplateNetworkInterface]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[KubernetesNodeGroupInstanceTemplateNetworkInterface]]], jsii.get(self, "networkInterfaceInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="placementPolicyInput")
    def placement_policy_input(
        self,
    ) -> typing.Optional["KubernetesNodeGroupInstanceTemplatePlacementPolicy"]:
        return typing.cast(typing.Optional["KubernetesNodeGroupInstanceTemplatePlacementPolicy"], jsii.get(self, "placementPolicyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="platformIdInput")
    def platform_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "platformIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcesInput")
    def resources_input(
        self,
    ) -> typing.Optional["KubernetesNodeGroupInstanceTemplateResources"]:
        return typing.cast(typing.Optional["KubernetesNodeGroupInstanceTemplateResources"], jsii.get(self, "resourcesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="schedulingPolicyInput")
    def scheduling_policy_input(
        self,
    ) -> typing.Optional["KubernetesNodeGroupInstanceTemplateSchedulingPolicy"]:
        return typing.cast(typing.Optional["KubernetesNodeGroupInstanceTemplateSchedulingPolicy"], jsii.get(self, "schedulingPolicyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metadata")
    def metadata(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "metadata"))

    @metadata.setter
    def metadata(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "metadata", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nat")
    def nat(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "nat"))

    @nat.setter
    def nat(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "nat", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkAccelerationType")
    def network_acceleration_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkAccelerationType"))

    @network_acceleration_type.setter
    def network_acceleration_type(self, value: builtins.str) -> None:
        jsii.set(self, "networkAccelerationType", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="platformId")
    def platform_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "platformId"))

    @platform_id.setter
    def platform_id(self, value: builtins.str) -> None:
        jsii.set(self, "platformId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[KubernetesNodeGroupInstanceTemplate]:
        return typing.cast(typing.Optional[KubernetesNodeGroupInstanceTemplate], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[KubernetesNodeGroupInstanceTemplate],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupInstanceTemplatePlacementPolicy",
    jsii_struct_bases=[],
    name_mapping={"placement_group_id": "placementGroupId"},
)
class KubernetesNodeGroupInstanceTemplatePlacementPolicy:
    def __init__(self, *, placement_group_id: builtins.str) -> None:
        '''
        :param placement_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#placement_group_id KubernetesNodeGroup#placement_group_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "placement_group_id": placement_group_id,
        }

    @builtins.property
    def placement_group_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#placement_group_id KubernetesNodeGroup#placement_group_id}.'''
        result = self._values.get("placement_group_id")
        assert result is not None, "Required property 'placement_group_id' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesNodeGroupInstanceTemplatePlacementPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KubernetesNodeGroupInstanceTemplatePlacementPolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupInstanceTemplatePlacementPolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="placementGroupIdInput")
    def placement_group_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "placementGroupIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="placementGroupId")
    def placement_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "placementGroupId"))

    @placement_group_id.setter
    def placement_group_id(self, value: builtins.str) -> None:
        jsii.set(self, "placementGroupId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[KubernetesNodeGroupInstanceTemplatePlacementPolicy]:
        return typing.cast(typing.Optional[KubernetesNodeGroupInstanceTemplatePlacementPolicy], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[KubernetesNodeGroupInstanceTemplatePlacementPolicy],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupInstanceTemplateResources",
    jsii_struct_bases=[],
    name_mapping={
        "core_fraction": "coreFraction",
        "cores": "cores",
        "gpus": "gpus",
        "memory": "memory",
    },
)
class KubernetesNodeGroupInstanceTemplateResources:
    def __init__(
        self,
        *,
        core_fraction: typing.Optional[jsii.Number] = None,
        cores: typing.Optional[jsii.Number] = None,
        gpus: typing.Optional[jsii.Number] = None,
        memory: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param core_fraction: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#core_fraction KubernetesNodeGroup#core_fraction}.
        :param cores: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#cores KubernetesNodeGroup#cores}.
        :param gpus: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#gpus KubernetesNodeGroup#gpus}.
        :param memory: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#memory KubernetesNodeGroup#memory}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if core_fraction is not None:
            self._values["core_fraction"] = core_fraction
        if cores is not None:
            self._values["cores"] = cores
        if gpus is not None:
            self._values["gpus"] = gpus
        if memory is not None:
            self._values["memory"] = memory

    @builtins.property
    def core_fraction(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#core_fraction KubernetesNodeGroup#core_fraction}.'''
        result = self._values.get("core_fraction")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def cores(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#cores KubernetesNodeGroup#cores}.'''
        result = self._values.get("cores")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def gpus(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#gpus KubernetesNodeGroup#gpus}.'''
        result = self._values.get("gpus")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def memory(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#memory KubernetesNodeGroup#memory}.'''
        result = self._values.get("memory")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesNodeGroupInstanceTemplateResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KubernetesNodeGroupInstanceTemplateResourcesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupInstanceTemplateResourcesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCoreFraction")
    def reset_core_fraction(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCoreFraction", []))

    @jsii.member(jsii_name="resetCores")
    def reset_cores(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCores", []))

    @jsii.member(jsii_name="resetGpus")
    def reset_gpus(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGpus", []))

    @jsii.member(jsii_name="resetMemory")
    def reset_memory(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMemory", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="coreFractionInput")
    def core_fraction_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "coreFractionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="coresInput")
    def cores_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "coresInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="gpusInput")
    def gpus_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "gpusInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="memoryInput")
    def memory_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "memoryInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="coreFraction")
    def core_fraction(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "coreFraction"))

    @core_fraction.setter
    def core_fraction(self, value: jsii.Number) -> None:
        jsii.set(self, "coreFraction", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cores")
    def cores(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "cores"))

    @cores.setter
    def cores(self, value: jsii.Number) -> None:
        jsii.set(self, "cores", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="gpus")
    def gpus(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "gpus"))

    @gpus.setter
    def gpus(self, value: jsii.Number) -> None:
        jsii.set(self, "gpus", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="memory")
    def memory(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "memory"))

    @memory.setter
    def memory(self, value: jsii.Number) -> None:
        jsii.set(self, "memory", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[KubernetesNodeGroupInstanceTemplateResources]:
        return typing.cast(typing.Optional[KubernetesNodeGroupInstanceTemplateResources], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[KubernetesNodeGroupInstanceTemplateResources],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupInstanceTemplateSchedulingPolicy",
    jsii_struct_bases=[],
    name_mapping={"preemptible": "preemptible"},
)
class KubernetesNodeGroupInstanceTemplateSchedulingPolicy:
    def __init__(
        self,
        *,
        preemptible: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param preemptible: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#preemptible KubernetesNodeGroup#preemptible}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if preemptible is not None:
            self._values["preemptible"] = preemptible

    @builtins.property
    def preemptible(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#preemptible KubernetesNodeGroup#preemptible}.'''
        result = self._values.get("preemptible")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesNodeGroupInstanceTemplateSchedulingPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KubernetesNodeGroupInstanceTemplateSchedulingPolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupInstanceTemplateSchedulingPolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetPreemptible")
    def reset_preemptible(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPreemptible", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="preemptibleInput")
    def preemptible_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "preemptibleInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="preemptible")
    def preemptible(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "preemptible"))

    @preemptible.setter
    def preemptible(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "preemptible", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[KubernetesNodeGroupInstanceTemplateSchedulingPolicy]:
        return typing.cast(typing.Optional[KubernetesNodeGroupInstanceTemplateSchedulingPolicy], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[KubernetesNodeGroupInstanceTemplateSchedulingPolicy],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupMaintenancePolicy",
    jsii_struct_bases=[],
    name_mapping={
        "auto_repair": "autoRepair",
        "auto_upgrade": "autoUpgrade",
        "maintenance_window": "maintenanceWindow",
    },
)
class KubernetesNodeGroupMaintenancePolicy:
    def __init__(
        self,
        *,
        auto_repair: typing.Union[builtins.bool, cdktf.IResolvable],
        auto_upgrade: typing.Union[builtins.bool, cdktf.IResolvable],
        maintenance_window: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["KubernetesNodeGroupMaintenancePolicyMaintenanceWindow"]]] = None,
    ) -> None:
        '''
        :param auto_repair: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#auto_repair KubernetesNodeGroup#auto_repair}.
        :param auto_upgrade: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#auto_upgrade KubernetesNodeGroup#auto_upgrade}.
        :param maintenance_window: maintenance_window block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#maintenance_window KubernetesNodeGroup#maintenance_window}
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "auto_repair": auto_repair,
            "auto_upgrade": auto_upgrade,
        }
        if maintenance_window is not None:
            self._values["maintenance_window"] = maintenance_window

    @builtins.property
    def auto_repair(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#auto_repair KubernetesNodeGroup#auto_repair}.'''
        result = self._values.get("auto_repair")
        assert result is not None, "Required property 'auto_repair' is missing"
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], result)

    @builtins.property
    def auto_upgrade(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#auto_upgrade KubernetesNodeGroup#auto_upgrade}.'''
        result = self._values.get("auto_upgrade")
        assert result is not None, "Required property 'auto_upgrade' is missing"
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], result)

    @builtins.property
    def maintenance_window(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["KubernetesNodeGroupMaintenancePolicyMaintenanceWindow"]]]:
        '''maintenance_window block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#maintenance_window KubernetesNodeGroup#maintenance_window}
        '''
        result = self._values.get("maintenance_window")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["KubernetesNodeGroupMaintenancePolicyMaintenanceWindow"]]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesNodeGroupMaintenancePolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupMaintenancePolicyMaintenanceWindow",
    jsii_struct_bases=[],
    name_mapping={"duration": "duration", "start_time": "startTime", "day": "day"},
)
class KubernetesNodeGroupMaintenancePolicyMaintenanceWindow:
    def __init__(
        self,
        *,
        duration: builtins.str,
        start_time: builtins.str,
        day: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param duration: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#duration KubernetesNodeGroup#duration}.
        :param start_time: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#start_time KubernetesNodeGroup#start_time}.
        :param day: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#day KubernetesNodeGroup#day}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "duration": duration,
            "start_time": start_time,
        }
        if day is not None:
            self._values["day"] = day

    @builtins.property
    def duration(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#duration KubernetesNodeGroup#duration}.'''
        result = self._values.get("duration")
        assert result is not None, "Required property 'duration' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def start_time(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#start_time KubernetesNodeGroup#start_time}.'''
        result = self._values.get("start_time")
        assert result is not None, "Required property 'start_time' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def day(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#day KubernetesNodeGroup#day}.'''
        result = self._values.get("day")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesNodeGroupMaintenancePolicyMaintenanceWindow(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KubernetesNodeGroupMaintenancePolicyMaintenanceWindowList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupMaintenancePolicyMaintenanceWindowList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "KubernetesNodeGroupMaintenancePolicyMaintenanceWindowOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("KubernetesNodeGroupMaintenancePolicyMaintenanceWindowOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[KubernetesNodeGroupMaintenancePolicyMaintenanceWindow]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[KubernetesNodeGroupMaintenancePolicyMaintenanceWindow]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[KubernetesNodeGroupMaintenancePolicyMaintenanceWindow]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class KubernetesNodeGroupMaintenancePolicyMaintenanceWindowOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupMaintenancePolicyMaintenanceWindowOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetDay")
    def reset_day(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDay", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dayInput")
    def day_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dayInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="durationInput")
    def duration_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "durationInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="startTimeInput")
    def start_time_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "startTimeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="day")
    def day(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "day"))

    @day.setter
    def day(self, value: builtins.str) -> None:
        jsii.set(self, "day", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="duration")
    def duration(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "duration"))

    @duration.setter
    def duration(self, value: builtins.str) -> None:
        jsii.set(self, "duration", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="startTime")
    def start_time(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "startTime"))

    @start_time.setter
    def start_time(self, value: builtins.str) -> None:
        jsii.set(self, "startTime", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, KubernetesNodeGroupMaintenancePolicyMaintenanceWindow]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, KubernetesNodeGroupMaintenancePolicyMaintenanceWindow]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, KubernetesNodeGroupMaintenancePolicyMaintenanceWindow]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class KubernetesNodeGroupMaintenancePolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupMaintenancePolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putMaintenanceWindow")
    def put_maintenance_window(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence[KubernetesNodeGroupMaintenancePolicyMaintenanceWindow]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putMaintenanceWindow", [value]))

    @jsii.member(jsii_name="resetMaintenanceWindow")
    def reset_maintenance_window(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaintenanceWindow", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maintenanceWindow")
    def maintenance_window(
        self,
    ) -> KubernetesNodeGroupMaintenancePolicyMaintenanceWindowList:
        return typing.cast(KubernetesNodeGroupMaintenancePolicyMaintenanceWindowList, jsii.get(self, "maintenanceWindow"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoRepairInput")
    def auto_repair_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "autoRepairInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoUpgradeInput")
    def auto_upgrade_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "autoUpgradeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maintenanceWindowInput")
    def maintenance_window_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[KubernetesNodeGroupMaintenancePolicyMaintenanceWindow]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[KubernetesNodeGroupMaintenancePolicyMaintenanceWindow]]], jsii.get(self, "maintenanceWindowInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoRepair")
    def auto_repair(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "autoRepair"))

    @auto_repair.setter
    def auto_repair(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "autoRepair", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoUpgrade")
    def auto_upgrade(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "autoUpgrade"))

    @auto_upgrade.setter
    def auto_upgrade(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "autoUpgrade", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[KubernetesNodeGroupMaintenancePolicy]:
        return typing.cast(typing.Optional[KubernetesNodeGroupMaintenancePolicy], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[KubernetesNodeGroupMaintenancePolicy],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupScalePolicy",
    jsii_struct_bases=[],
    name_mapping={"auto_scale": "autoScale", "fixed_scale": "fixedScale"},
)
class KubernetesNodeGroupScalePolicy:
    def __init__(
        self,
        *,
        auto_scale: typing.Optional["KubernetesNodeGroupScalePolicyAutoScale"] = None,
        fixed_scale: typing.Optional["KubernetesNodeGroupScalePolicyFixedScale"] = None,
    ) -> None:
        '''
        :param auto_scale: auto_scale block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#auto_scale KubernetesNodeGroup#auto_scale}
        :param fixed_scale: fixed_scale block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#fixed_scale KubernetesNodeGroup#fixed_scale}
        '''
        if isinstance(auto_scale, dict):
            auto_scale = KubernetesNodeGroupScalePolicyAutoScale(**auto_scale)
        if isinstance(fixed_scale, dict):
            fixed_scale = KubernetesNodeGroupScalePolicyFixedScale(**fixed_scale)
        self._values: typing.Dict[str, typing.Any] = {}
        if auto_scale is not None:
            self._values["auto_scale"] = auto_scale
        if fixed_scale is not None:
            self._values["fixed_scale"] = fixed_scale

    @builtins.property
    def auto_scale(self) -> typing.Optional["KubernetesNodeGroupScalePolicyAutoScale"]:
        '''auto_scale block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#auto_scale KubernetesNodeGroup#auto_scale}
        '''
        result = self._values.get("auto_scale")
        return typing.cast(typing.Optional["KubernetesNodeGroupScalePolicyAutoScale"], result)

    @builtins.property
    def fixed_scale(
        self,
    ) -> typing.Optional["KubernetesNodeGroupScalePolicyFixedScale"]:
        '''fixed_scale block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#fixed_scale KubernetesNodeGroup#fixed_scale}
        '''
        result = self._values.get("fixed_scale")
        return typing.cast(typing.Optional["KubernetesNodeGroupScalePolicyFixedScale"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesNodeGroupScalePolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupScalePolicyAutoScale",
    jsii_struct_bases=[],
    name_mapping={"initial": "initial", "max": "max", "min": "min"},
)
class KubernetesNodeGroupScalePolicyAutoScale:
    def __init__(
        self,
        *,
        initial: jsii.Number,
        max: jsii.Number,
        min: jsii.Number,
    ) -> None:
        '''
        :param initial: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#initial KubernetesNodeGroup#initial}.
        :param max: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#max KubernetesNodeGroup#max}.
        :param min: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#min KubernetesNodeGroup#min}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "initial": initial,
            "max": max,
            "min": min,
        }

    @builtins.property
    def initial(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#initial KubernetesNodeGroup#initial}.'''
        result = self._values.get("initial")
        assert result is not None, "Required property 'initial' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def max(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#max KubernetesNodeGroup#max}.'''
        result = self._values.get("max")
        assert result is not None, "Required property 'max' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def min(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#min KubernetesNodeGroup#min}.'''
        result = self._values.get("min")
        assert result is not None, "Required property 'min' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesNodeGroupScalePolicyAutoScale(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KubernetesNodeGroupScalePolicyAutoScaleOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupScalePolicyAutoScaleOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="initialInput")
    def initial_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "initialInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxInput")
    def max_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minInput")
    def min_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "minInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="initial")
    def initial(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "initial"))

    @initial.setter
    def initial(self, value: jsii.Number) -> None:
        jsii.set(self, "initial", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="max")
    def max(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "max"))

    @max.setter
    def max(self, value: jsii.Number) -> None:
        jsii.set(self, "max", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="min")
    def min(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "min"))

    @min.setter
    def min(self, value: jsii.Number) -> None:
        jsii.set(self, "min", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[KubernetesNodeGroupScalePolicyAutoScale]:
        return typing.cast(typing.Optional[KubernetesNodeGroupScalePolicyAutoScale], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[KubernetesNodeGroupScalePolicyAutoScale],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupScalePolicyFixedScale",
    jsii_struct_bases=[],
    name_mapping={"size": "size"},
)
class KubernetesNodeGroupScalePolicyFixedScale:
    def __init__(self, *, size: typing.Optional[jsii.Number] = None) -> None:
        '''
        :param size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#size KubernetesNodeGroup#size}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if size is not None:
            self._values["size"] = size

    @builtins.property
    def size(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#size KubernetesNodeGroup#size}.'''
        result = self._values.get("size")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesNodeGroupScalePolicyFixedScale(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KubernetesNodeGroupScalePolicyFixedScaleOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupScalePolicyFixedScaleOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetSize")
    def reset_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSize", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sizeInput")
    def size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "sizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="size")
    def size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "size"))

    @size.setter
    def size(self, value: jsii.Number) -> None:
        jsii.set(self, "size", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[KubernetesNodeGroupScalePolicyFixedScale]:
        return typing.cast(typing.Optional[KubernetesNodeGroupScalePolicyFixedScale], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[KubernetesNodeGroupScalePolicyFixedScale],
    ) -> None:
        jsii.set(self, "internalValue", value)


class KubernetesNodeGroupScalePolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupScalePolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putAutoScale")
    def put_auto_scale(
        self,
        *,
        initial: jsii.Number,
        max: jsii.Number,
        min: jsii.Number,
    ) -> None:
        '''
        :param initial: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#initial KubernetesNodeGroup#initial}.
        :param max: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#max KubernetesNodeGroup#max}.
        :param min: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#min KubernetesNodeGroup#min}.
        '''
        value = KubernetesNodeGroupScalePolicyAutoScale(
            initial=initial, max=max, min=min
        )

        return typing.cast(None, jsii.invoke(self, "putAutoScale", [value]))

    @jsii.member(jsii_name="putFixedScale")
    def put_fixed_scale(self, *, size: typing.Optional[jsii.Number] = None) -> None:
        '''
        :param size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#size KubernetesNodeGroup#size}.
        '''
        value = KubernetesNodeGroupScalePolicyFixedScale(size=size)

        return typing.cast(None, jsii.invoke(self, "putFixedScale", [value]))

    @jsii.member(jsii_name="resetAutoScale")
    def reset_auto_scale(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAutoScale", []))

    @jsii.member(jsii_name="resetFixedScale")
    def reset_fixed_scale(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFixedScale", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoScale")
    def auto_scale(self) -> KubernetesNodeGroupScalePolicyAutoScaleOutputReference:
        return typing.cast(KubernetesNodeGroupScalePolicyAutoScaleOutputReference, jsii.get(self, "autoScale"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fixedScale")
    def fixed_scale(self) -> KubernetesNodeGroupScalePolicyFixedScaleOutputReference:
        return typing.cast(KubernetesNodeGroupScalePolicyFixedScaleOutputReference, jsii.get(self, "fixedScale"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoScaleInput")
    def auto_scale_input(
        self,
    ) -> typing.Optional[KubernetesNodeGroupScalePolicyAutoScale]:
        return typing.cast(typing.Optional[KubernetesNodeGroupScalePolicyAutoScale], jsii.get(self, "autoScaleInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fixedScaleInput")
    def fixed_scale_input(
        self,
    ) -> typing.Optional[KubernetesNodeGroupScalePolicyFixedScale]:
        return typing.cast(typing.Optional[KubernetesNodeGroupScalePolicyFixedScale], jsii.get(self, "fixedScaleInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[KubernetesNodeGroupScalePolicy]:
        return typing.cast(typing.Optional[KubernetesNodeGroupScalePolicy], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[KubernetesNodeGroupScalePolicy],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class KubernetesNodeGroupTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#create KubernetesNodeGroup#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#delete KubernetesNodeGroup#delete}.
        :param read: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#read KubernetesNodeGroup#read}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#update KubernetesNodeGroup#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#create KubernetesNodeGroup#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#delete KubernetesNodeGroup#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#read KubernetesNodeGroup#read}.'''
        result = self._values.get("read")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/kubernetes_node_group#update KubernetesNodeGroup#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesNodeGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KubernetesNodeGroupTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetRead")
    def reset_read(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRead", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="readInput")
    def read_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "readInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="read")
    def read(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "read"))

    @read.setter
    def read(self, value: builtins.str) -> None:
        jsii.set(self, "read", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, KubernetesNodeGroupTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, KubernetesNodeGroupTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, KubernetesNodeGroupTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupVersionInfo",
    jsii_struct_bases=[],
    name_mapping={},
)
class KubernetesNodeGroupVersionInfo:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KubernetesNodeGroupVersionInfo(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KubernetesNodeGroupVersionInfoList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupVersionInfoList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "KubernetesNodeGroupVersionInfoOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("KubernetesNodeGroupVersionInfoOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class KubernetesNodeGroupVersionInfoOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.KubernetesNodeGroupVersionInfoOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="currentVersion")
    def current_version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "currentVersion"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="newRevisionAvailable")
    def new_revision_available(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "newRevisionAvailable"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="newRevisionSummary")
    def new_revision_summary(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "newRevisionSummary"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="versionDeprecated")
    def version_deprecated(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "versionDeprecated"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[KubernetesNodeGroupVersionInfo]:
        return typing.cast(typing.Optional[KubernetesNodeGroupVersionInfo], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[KubernetesNodeGroupVersionInfo],
    ) -> None:
        jsii.set(self, "internalValue", value)


class LbNetworkLoadBalancer(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.LbNetworkLoadBalancer",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer yandex_lb_network_load_balancer}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        attached_target_group: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["LbNetworkLoadBalancerAttachedTargetGroup"]]] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        listener: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["LbNetworkLoadBalancerListener"]]] = None,
        name: typing.Optional[builtins.str] = None,
        region_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["LbNetworkLoadBalancerTimeouts"] = None,
        type: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer yandex_lb_network_load_balancer} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param attached_target_group: attached_target_group block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#attached_target_group LbNetworkLoadBalancer#attached_target_group}
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#description LbNetworkLoadBalancer#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#folder_id LbNetworkLoadBalancer#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#id LbNetworkLoadBalancer#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#labels LbNetworkLoadBalancer#labels}.
        :param listener: listener block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#listener LbNetworkLoadBalancer#listener}
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#name LbNetworkLoadBalancer#name}.
        :param region_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#region_id LbNetworkLoadBalancer#region_id}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#timeouts LbNetworkLoadBalancer#timeouts}
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#type LbNetworkLoadBalancer#type}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = LbNetworkLoadBalancerConfig(
            attached_target_group=attached_target_group,
            description=description,
            folder_id=folder_id,
            id=id,
            labels=labels,
            listener=listener,
            name=name,
            region_id=region_id,
            timeouts=timeouts,
            type=type,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putAttachedTargetGroup")
    def put_attached_target_group(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["LbNetworkLoadBalancerAttachedTargetGroup"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putAttachedTargetGroup", [value]))

    @jsii.member(jsii_name="putListener")
    def put_listener(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["LbNetworkLoadBalancerListener"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putListener", [value]))

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#create LbNetworkLoadBalancer#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#delete LbNetworkLoadBalancer#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#update LbNetworkLoadBalancer#update}.
        '''
        value = LbNetworkLoadBalancerTimeouts(
            create=create, delete=delete, update=update
        )

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetAttachedTargetGroup")
    def reset_attached_target_group(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAttachedTargetGroup", []))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetListener")
    def reset_listener(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetListener", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetRegionId")
    def reset_region_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRegionId", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="resetType")
    def reset_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetType", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="attachedTargetGroup")
    def attached_target_group(self) -> "LbNetworkLoadBalancerAttachedTargetGroupList":
        return typing.cast("LbNetworkLoadBalancerAttachedTargetGroupList", jsii.get(self, "attachedTargetGroup"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="listener")
    def listener(self) -> "LbNetworkLoadBalancerListenerList":
        return typing.cast("LbNetworkLoadBalancerListenerList", jsii.get(self, "listener"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "LbNetworkLoadBalancerTimeoutsOutputReference":
        return typing.cast("LbNetworkLoadBalancerTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="attachedTargetGroupInput")
    def attached_target_group_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["LbNetworkLoadBalancerAttachedTargetGroup"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["LbNetworkLoadBalancerAttachedTargetGroup"]]], jsii.get(self, "attachedTargetGroupInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="listenerInput")
    def listener_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["LbNetworkLoadBalancerListener"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["LbNetworkLoadBalancerListener"]]], jsii.get(self, "listenerInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="regionIdInput")
    def region_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "regionIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "LbNetworkLoadBalancerTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "LbNetworkLoadBalancerTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="typeInput")
    def type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "typeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="regionId")
    def region_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "regionId"))

    @region_id.setter
    def region_id(self, value: builtins.str) -> None:
        jsii.set(self, "regionId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @type.setter
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.LbNetworkLoadBalancerAttachedTargetGroup",
    jsii_struct_bases=[],
    name_mapping={"healthcheck": "healthcheck", "target_group_id": "targetGroupId"},
)
class LbNetworkLoadBalancerAttachedTargetGroup:
    def __init__(
        self,
        *,
        healthcheck: typing.Union[cdktf.IResolvable, typing.Sequence["LbNetworkLoadBalancerAttachedTargetGroupHealthcheck"]],
        target_group_id: builtins.str,
    ) -> None:
        '''
        :param healthcheck: healthcheck block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#healthcheck LbNetworkLoadBalancer#healthcheck}
        :param target_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#target_group_id LbNetworkLoadBalancer#target_group_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "healthcheck": healthcheck,
            "target_group_id": target_group_id,
        }

    @builtins.property
    def healthcheck(
        self,
    ) -> typing.Union[cdktf.IResolvable, typing.List["LbNetworkLoadBalancerAttachedTargetGroupHealthcheck"]]:
        '''healthcheck block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#healthcheck LbNetworkLoadBalancer#healthcheck}
        '''
        result = self._values.get("healthcheck")
        assert result is not None, "Required property 'healthcheck' is missing"
        return typing.cast(typing.Union[cdktf.IResolvable, typing.List["LbNetworkLoadBalancerAttachedTargetGroupHealthcheck"]], result)

    @builtins.property
    def target_group_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#target_group_id LbNetworkLoadBalancer#target_group_id}.'''
        result = self._values.get("target_group_id")
        assert result is not None, "Required property 'target_group_id' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbNetworkLoadBalancerAttachedTargetGroup(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.LbNetworkLoadBalancerAttachedTargetGroupHealthcheck",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "healthy_threshold": "healthyThreshold",
        "http_options": "httpOptions",
        "interval": "interval",
        "tcp_options": "tcpOptions",
        "timeout": "timeout",
        "unhealthy_threshold": "unhealthyThreshold",
    },
)
class LbNetworkLoadBalancerAttachedTargetGroupHealthcheck:
    def __init__(
        self,
        *,
        name: builtins.str,
        healthy_threshold: typing.Optional[jsii.Number] = None,
        http_options: typing.Optional["LbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptions"] = None,
        interval: typing.Optional[jsii.Number] = None,
        tcp_options: typing.Optional["LbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptions"] = None,
        timeout: typing.Optional[jsii.Number] = None,
        unhealthy_threshold: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#name LbNetworkLoadBalancer#name}.
        :param healthy_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#healthy_threshold LbNetworkLoadBalancer#healthy_threshold}.
        :param http_options: http_options block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#http_options LbNetworkLoadBalancer#http_options}
        :param interval: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#interval LbNetworkLoadBalancer#interval}.
        :param tcp_options: tcp_options block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#tcp_options LbNetworkLoadBalancer#tcp_options}
        :param timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#timeout LbNetworkLoadBalancer#timeout}.
        :param unhealthy_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#unhealthy_threshold LbNetworkLoadBalancer#unhealthy_threshold}.
        '''
        if isinstance(http_options, dict):
            http_options = LbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptions(**http_options)
        if isinstance(tcp_options, dict):
            tcp_options = LbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptions(**tcp_options)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }
        if healthy_threshold is not None:
            self._values["healthy_threshold"] = healthy_threshold
        if http_options is not None:
            self._values["http_options"] = http_options
        if interval is not None:
            self._values["interval"] = interval
        if tcp_options is not None:
            self._values["tcp_options"] = tcp_options
        if timeout is not None:
            self._values["timeout"] = timeout
        if unhealthy_threshold is not None:
            self._values["unhealthy_threshold"] = unhealthy_threshold

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#name LbNetworkLoadBalancer#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def healthy_threshold(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#healthy_threshold LbNetworkLoadBalancer#healthy_threshold}.'''
        result = self._values.get("healthy_threshold")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def http_options(
        self,
    ) -> typing.Optional["LbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptions"]:
        '''http_options block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#http_options LbNetworkLoadBalancer#http_options}
        '''
        result = self._values.get("http_options")
        return typing.cast(typing.Optional["LbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptions"], result)

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#interval LbNetworkLoadBalancer#interval}.'''
        result = self._values.get("interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def tcp_options(
        self,
    ) -> typing.Optional["LbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptions"]:
        '''tcp_options block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#tcp_options LbNetworkLoadBalancer#tcp_options}
        '''
        result = self._values.get("tcp_options")
        return typing.cast(typing.Optional["LbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptions"], result)

    @builtins.property
    def timeout(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#timeout LbNetworkLoadBalancer#timeout}.'''
        result = self._values.get("timeout")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def unhealthy_threshold(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#unhealthy_threshold LbNetworkLoadBalancer#unhealthy_threshold}.'''
        result = self._values.get("unhealthy_threshold")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbNetworkLoadBalancerAttachedTargetGroupHealthcheck(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.LbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptions",
    jsii_struct_bases=[],
    name_mapping={"port": "port", "path": "path"},
)
class LbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptions:
    def __init__(
        self,
        *,
        port: jsii.Number,
        path: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#port LbNetworkLoadBalancer#port}.
        :param path: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#path LbNetworkLoadBalancer#path}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "port": port,
        }
        if path is not None:
            self._values["path"] = path

    @builtins.property
    def port(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#port LbNetworkLoadBalancer#port}.'''
        result = self._values.get("port")
        assert result is not None, "Required property 'port' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def path(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#path LbNetworkLoadBalancer#path}.'''
        result = self._values.get("path")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptionsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.LbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptionsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetPath")
    def reset_path(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPath", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="pathInput")
    def path_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "pathInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="portInput")
    def port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "portInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="path")
    def path(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "path"))

    @path.setter
    def path(self, value: builtins.str) -> None:
        jsii.set(self, "path", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "port"))

    @port.setter
    def port(self, value: jsii.Number) -> None:
        jsii.set(self, "port", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[LbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptions]:
        return typing.cast(typing.Optional[LbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptions], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[LbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptions],
    ) -> None:
        jsii.set(self, "internalValue", value)


class LbNetworkLoadBalancerAttachedTargetGroupHealthcheckList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.LbNetworkLoadBalancerAttachedTargetGroupHealthcheckList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "LbNetworkLoadBalancerAttachedTargetGroupHealthcheckOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("LbNetworkLoadBalancerAttachedTargetGroupHealthcheckOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[LbNetworkLoadBalancerAttachedTargetGroupHealthcheck]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[LbNetworkLoadBalancerAttachedTargetGroupHealthcheck]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[LbNetworkLoadBalancerAttachedTargetGroupHealthcheck]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class LbNetworkLoadBalancerAttachedTargetGroupHealthcheckOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.LbNetworkLoadBalancerAttachedTargetGroupHealthcheckOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putHttpOptions")
    def put_http_options(
        self,
        *,
        port: jsii.Number,
        path: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#port LbNetworkLoadBalancer#port}.
        :param path: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#path LbNetworkLoadBalancer#path}.
        '''
        value = LbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptions(
            port=port, path=path
        )

        return typing.cast(None, jsii.invoke(self, "putHttpOptions", [value]))

    @jsii.member(jsii_name="putTcpOptions")
    def put_tcp_options(self, *, port: jsii.Number) -> None:
        '''
        :param port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#port LbNetworkLoadBalancer#port}.
        '''
        value = LbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptions(
            port=port
        )

        return typing.cast(None, jsii.invoke(self, "putTcpOptions", [value]))

    @jsii.member(jsii_name="resetHealthyThreshold")
    def reset_healthy_threshold(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHealthyThreshold", []))

    @jsii.member(jsii_name="resetHttpOptions")
    def reset_http_options(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttpOptions", []))

    @jsii.member(jsii_name="resetInterval")
    def reset_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInterval", []))

    @jsii.member(jsii_name="resetTcpOptions")
    def reset_tcp_options(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTcpOptions", []))

    @jsii.member(jsii_name="resetTimeout")
    def reset_timeout(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeout", []))

    @jsii.member(jsii_name="resetUnhealthyThreshold")
    def reset_unhealthy_threshold(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUnhealthyThreshold", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpOptions")
    def http_options(
        self,
    ) -> LbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptionsOutputReference:
        return typing.cast(LbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptionsOutputReference, jsii.get(self, "httpOptions"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tcpOptions")
    def tcp_options(
        self,
    ) -> "LbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptionsOutputReference":
        return typing.cast("LbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptionsOutputReference", jsii.get(self, "tcpOptions"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthyThresholdInput")
    def healthy_threshold_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "healthyThresholdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpOptionsInput")
    def http_options_input(
        self,
    ) -> typing.Optional[LbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptions]:
        return typing.cast(typing.Optional[LbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptions], jsii.get(self, "httpOptionsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="intervalInput")
    def interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tcpOptionsInput")
    def tcp_options_input(
        self,
    ) -> typing.Optional["LbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptions"]:
        return typing.cast(typing.Optional["LbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptions"], jsii.get(self, "tcpOptionsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutInput")
    def timeout_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "timeoutInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="unhealthyThresholdInput")
    def unhealthy_threshold_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "unhealthyThresholdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthyThreshold")
    def healthy_threshold(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "healthyThreshold"))

    @healthy_threshold.setter
    def healthy_threshold(self, value: jsii.Number) -> None:
        jsii.set(self, "healthyThreshold", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "interval"))

    @interval.setter
    def interval(self, value: jsii.Number) -> None:
        jsii.set(self, "interval", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeout")
    def timeout(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "timeout"))

    @timeout.setter
    def timeout(self, value: jsii.Number) -> None:
        jsii.set(self, "timeout", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="unhealthyThreshold")
    def unhealthy_threshold(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "unhealthyThreshold"))

    @unhealthy_threshold.setter
    def unhealthy_threshold(self, value: jsii.Number) -> None:
        jsii.set(self, "unhealthyThreshold", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, LbNetworkLoadBalancerAttachedTargetGroupHealthcheck]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, LbNetworkLoadBalancerAttachedTargetGroupHealthcheck]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, LbNetworkLoadBalancerAttachedTargetGroupHealthcheck]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.LbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptions",
    jsii_struct_bases=[],
    name_mapping={"port": "port"},
)
class LbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptions:
    def __init__(self, *, port: jsii.Number) -> None:
        '''
        :param port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#port LbNetworkLoadBalancer#port}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "port": port,
        }

    @builtins.property
    def port(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#port LbNetworkLoadBalancer#port}.'''
        result = self._values.get("port")
        assert result is not None, "Required property 'port' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptionsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.LbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptionsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="portInput")
    def port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "portInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "port"))

    @port.setter
    def port(self, value: jsii.Number) -> None:
        jsii.set(self, "port", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[LbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptions]:
        return typing.cast(typing.Optional[LbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptions], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[LbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptions],
    ) -> None:
        jsii.set(self, "internalValue", value)


class LbNetworkLoadBalancerAttachedTargetGroupList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.LbNetworkLoadBalancerAttachedTargetGroupList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "LbNetworkLoadBalancerAttachedTargetGroupOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("LbNetworkLoadBalancerAttachedTargetGroupOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[LbNetworkLoadBalancerAttachedTargetGroup]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[LbNetworkLoadBalancerAttachedTargetGroup]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[LbNetworkLoadBalancerAttachedTargetGroup]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class LbNetworkLoadBalancerAttachedTargetGroupOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.LbNetworkLoadBalancerAttachedTargetGroupOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putHealthcheck")
    def put_healthcheck(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence[LbNetworkLoadBalancerAttachedTargetGroupHealthcheck]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putHealthcheck", [value]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthcheck")
    def healthcheck(self) -> LbNetworkLoadBalancerAttachedTargetGroupHealthcheckList:
        return typing.cast(LbNetworkLoadBalancerAttachedTargetGroupHealthcheckList, jsii.get(self, "healthcheck"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthcheckInput")
    def healthcheck_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[LbNetworkLoadBalancerAttachedTargetGroupHealthcheck]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[LbNetworkLoadBalancerAttachedTargetGroupHealthcheck]]], jsii.get(self, "healthcheckInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupIdInput")
    def target_group_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "targetGroupIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetGroupId")
    def target_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "targetGroupId"))

    @target_group_id.setter
    def target_group_id(self, value: builtins.str) -> None:
        jsii.set(self, "targetGroupId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, LbNetworkLoadBalancerAttachedTargetGroup]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, LbNetworkLoadBalancerAttachedTargetGroup]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, LbNetworkLoadBalancerAttachedTargetGroup]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.LbNetworkLoadBalancerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "attached_target_group": "attachedTargetGroup",
        "description": "description",
        "folder_id": "folderId",
        "id": "id",
        "labels": "labels",
        "listener": "listener",
        "name": "name",
        "region_id": "regionId",
        "timeouts": "timeouts",
        "type": "type",
    },
)
class LbNetworkLoadBalancerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        attached_target_group: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence[LbNetworkLoadBalancerAttachedTargetGroup]]] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        listener: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["LbNetworkLoadBalancerListener"]]] = None,
        name: typing.Optional[builtins.str] = None,
        region_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["LbNetworkLoadBalancerTimeouts"] = None,
        type: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param attached_target_group: attached_target_group block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#attached_target_group LbNetworkLoadBalancer#attached_target_group}
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#description LbNetworkLoadBalancer#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#folder_id LbNetworkLoadBalancer#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#id LbNetworkLoadBalancer#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#labels LbNetworkLoadBalancer#labels}.
        :param listener: listener block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#listener LbNetworkLoadBalancer#listener}
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#name LbNetworkLoadBalancer#name}.
        :param region_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#region_id LbNetworkLoadBalancer#region_id}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#timeouts LbNetworkLoadBalancer#timeouts}
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#type LbNetworkLoadBalancer#type}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = LbNetworkLoadBalancerTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if attached_target_group is not None:
            self._values["attached_target_group"] = attached_target_group
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if listener is not None:
            self._values["listener"] = listener
        if name is not None:
            self._values["name"] = name
        if region_id is not None:
            self._values["region_id"] = region_id
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def attached_target_group(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[LbNetworkLoadBalancerAttachedTargetGroup]]]:
        '''attached_target_group block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#attached_target_group LbNetworkLoadBalancer#attached_target_group}
        '''
        result = self._values.get("attached_target_group")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[LbNetworkLoadBalancerAttachedTargetGroup]]], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#description LbNetworkLoadBalancer#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#folder_id LbNetworkLoadBalancer#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#id LbNetworkLoadBalancer#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#labels LbNetworkLoadBalancer#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def listener(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["LbNetworkLoadBalancerListener"]]]:
        '''listener block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#listener LbNetworkLoadBalancer#listener}
        '''
        result = self._values.get("listener")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["LbNetworkLoadBalancerListener"]]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#name LbNetworkLoadBalancer#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def region_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#region_id LbNetworkLoadBalancer#region_id}.'''
        result = self._values.get("region_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["LbNetworkLoadBalancerTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#timeouts LbNetworkLoadBalancer#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["LbNetworkLoadBalancerTimeouts"], result)

    @builtins.property
    def type(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#type LbNetworkLoadBalancer#type}.'''
        result = self._values.get("type")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbNetworkLoadBalancerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.LbNetworkLoadBalancerListener",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "port": "port",
        "external_address_spec": "externalAddressSpec",
        "internal_address_spec": "internalAddressSpec",
        "protocol": "protocol",
        "target_port": "targetPort",
    },
)
class LbNetworkLoadBalancerListener:
    def __init__(
        self,
        *,
        name: builtins.str,
        port: jsii.Number,
        external_address_spec: typing.Optional["LbNetworkLoadBalancerListenerExternalAddressSpec"] = None,
        internal_address_spec: typing.Optional["LbNetworkLoadBalancerListenerInternalAddressSpec"] = None,
        protocol: typing.Optional[builtins.str] = None,
        target_port: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#name LbNetworkLoadBalancer#name}.
        :param port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#port LbNetworkLoadBalancer#port}.
        :param external_address_spec: external_address_spec block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#external_address_spec LbNetworkLoadBalancer#external_address_spec}
        :param internal_address_spec: internal_address_spec block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#internal_address_spec LbNetworkLoadBalancer#internal_address_spec}
        :param protocol: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#protocol LbNetworkLoadBalancer#protocol}.
        :param target_port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#target_port LbNetworkLoadBalancer#target_port}.
        '''
        if isinstance(external_address_spec, dict):
            external_address_spec = LbNetworkLoadBalancerListenerExternalAddressSpec(**external_address_spec)
        if isinstance(internal_address_spec, dict):
            internal_address_spec = LbNetworkLoadBalancerListenerInternalAddressSpec(**internal_address_spec)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "port": port,
        }
        if external_address_spec is not None:
            self._values["external_address_spec"] = external_address_spec
        if internal_address_spec is not None:
            self._values["internal_address_spec"] = internal_address_spec
        if protocol is not None:
            self._values["protocol"] = protocol
        if target_port is not None:
            self._values["target_port"] = target_port

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#name LbNetworkLoadBalancer#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def port(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#port LbNetworkLoadBalancer#port}.'''
        result = self._values.get("port")
        assert result is not None, "Required property 'port' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def external_address_spec(
        self,
    ) -> typing.Optional["LbNetworkLoadBalancerListenerExternalAddressSpec"]:
        '''external_address_spec block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#external_address_spec LbNetworkLoadBalancer#external_address_spec}
        '''
        result = self._values.get("external_address_spec")
        return typing.cast(typing.Optional["LbNetworkLoadBalancerListenerExternalAddressSpec"], result)

    @builtins.property
    def internal_address_spec(
        self,
    ) -> typing.Optional["LbNetworkLoadBalancerListenerInternalAddressSpec"]:
        '''internal_address_spec block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#internal_address_spec LbNetworkLoadBalancer#internal_address_spec}
        '''
        result = self._values.get("internal_address_spec")
        return typing.cast(typing.Optional["LbNetworkLoadBalancerListenerInternalAddressSpec"], result)

    @builtins.property
    def protocol(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#protocol LbNetworkLoadBalancer#protocol}.'''
        result = self._values.get("protocol")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def target_port(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#target_port LbNetworkLoadBalancer#target_port}.'''
        result = self._values.get("target_port")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbNetworkLoadBalancerListener(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.LbNetworkLoadBalancerListenerExternalAddressSpec",
    jsii_struct_bases=[],
    name_mapping={"address": "address", "ip_version": "ipVersion"},
)
class LbNetworkLoadBalancerListenerExternalAddressSpec:
    def __init__(
        self,
        *,
        address: typing.Optional[builtins.str] = None,
        ip_version: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param address: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#address LbNetworkLoadBalancer#address}.
        :param ip_version: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#ip_version LbNetworkLoadBalancer#ip_version}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if address is not None:
            self._values["address"] = address
        if ip_version is not None:
            self._values["ip_version"] = ip_version

    @builtins.property
    def address(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#address LbNetworkLoadBalancer#address}.'''
        result = self._values.get("address")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def ip_version(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#ip_version LbNetworkLoadBalancer#ip_version}.'''
        result = self._values.get("ip_version")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbNetworkLoadBalancerListenerExternalAddressSpec(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LbNetworkLoadBalancerListenerExternalAddressSpecOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.LbNetworkLoadBalancerListenerExternalAddressSpecOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAddress")
    def reset_address(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAddress", []))

    @jsii.member(jsii_name="resetIpVersion")
    def reset_ip_version(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIpVersion", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="addressInput")
    def address_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "addressInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipVersionInput")
    def ip_version_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "ipVersionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="address")
    def address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "address"))

    @address.setter
    def address(self, value: builtins.str) -> None:
        jsii.set(self, "address", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipVersion")
    def ip_version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ipVersion"))

    @ip_version.setter
    def ip_version(self, value: builtins.str) -> None:
        jsii.set(self, "ipVersion", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[LbNetworkLoadBalancerListenerExternalAddressSpec]:
        return typing.cast(typing.Optional[LbNetworkLoadBalancerListenerExternalAddressSpec], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[LbNetworkLoadBalancerListenerExternalAddressSpec],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.LbNetworkLoadBalancerListenerInternalAddressSpec",
    jsii_struct_bases=[],
    name_mapping={
        "subnet_id": "subnetId",
        "address": "address",
        "ip_version": "ipVersion",
    },
)
class LbNetworkLoadBalancerListenerInternalAddressSpec:
    def __init__(
        self,
        *,
        subnet_id: builtins.str,
        address: typing.Optional[builtins.str] = None,
        ip_version: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param subnet_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#subnet_id LbNetworkLoadBalancer#subnet_id}.
        :param address: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#address LbNetworkLoadBalancer#address}.
        :param ip_version: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#ip_version LbNetworkLoadBalancer#ip_version}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "subnet_id": subnet_id,
        }
        if address is not None:
            self._values["address"] = address
        if ip_version is not None:
            self._values["ip_version"] = ip_version

    @builtins.property
    def subnet_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#subnet_id LbNetworkLoadBalancer#subnet_id}.'''
        result = self._values.get("subnet_id")
        assert result is not None, "Required property 'subnet_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def address(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#address LbNetworkLoadBalancer#address}.'''
        result = self._values.get("address")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def ip_version(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#ip_version LbNetworkLoadBalancer#ip_version}.'''
        result = self._values.get("ip_version")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbNetworkLoadBalancerListenerInternalAddressSpec(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LbNetworkLoadBalancerListenerInternalAddressSpecOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.LbNetworkLoadBalancerListenerInternalAddressSpecOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAddress")
    def reset_address(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAddress", []))

    @jsii.member(jsii_name="resetIpVersion")
    def reset_ip_version(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIpVersion", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="addressInput")
    def address_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "addressInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipVersionInput")
    def ip_version_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "ipVersionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIdInput")
    def subnet_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "subnetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="address")
    def address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "address"))

    @address.setter
    def address(self, value: builtins.str) -> None:
        jsii.set(self, "address", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ipVersion")
    def ip_version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ipVersion"))

    @ip_version.setter
    def ip_version(self, value: builtins.str) -> None:
        jsii.set(self, "ipVersion", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @subnet_id.setter
    def subnet_id(self, value: builtins.str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[LbNetworkLoadBalancerListenerInternalAddressSpec]:
        return typing.cast(typing.Optional[LbNetworkLoadBalancerListenerInternalAddressSpec], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[LbNetworkLoadBalancerListenerInternalAddressSpec],
    ) -> None:
        jsii.set(self, "internalValue", value)


class LbNetworkLoadBalancerListenerList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.LbNetworkLoadBalancerListenerList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "LbNetworkLoadBalancerListenerOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("LbNetworkLoadBalancerListenerOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[LbNetworkLoadBalancerListener]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[LbNetworkLoadBalancerListener]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[LbNetworkLoadBalancerListener]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class LbNetworkLoadBalancerListenerOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.LbNetworkLoadBalancerListenerOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putExternalAddressSpec")
    def put_external_address_spec(
        self,
        *,
        address: typing.Optional[builtins.str] = None,
        ip_version: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param address: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#address LbNetworkLoadBalancer#address}.
        :param ip_version: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#ip_version LbNetworkLoadBalancer#ip_version}.
        '''
        value = LbNetworkLoadBalancerListenerExternalAddressSpec(
            address=address, ip_version=ip_version
        )

        return typing.cast(None, jsii.invoke(self, "putExternalAddressSpec", [value]))

    @jsii.member(jsii_name="putInternalAddressSpec")
    def put_internal_address_spec(
        self,
        *,
        subnet_id: builtins.str,
        address: typing.Optional[builtins.str] = None,
        ip_version: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param subnet_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#subnet_id LbNetworkLoadBalancer#subnet_id}.
        :param address: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#address LbNetworkLoadBalancer#address}.
        :param ip_version: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#ip_version LbNetworkLoadBalancer#ip_version}.
        '''
        value = LbNetworkLoadBalancerListenerInternalAddressSpec(
            subnet_id=subnet_id, address=address, ip_version=ip_version
        )

        return typing.cast(None, jsii.invoke(self, "putInternalAddressSpec", [value]))

    @jsii.member(jsii_name="resetExternalAddressSpec")
    def reset_external_address_spec(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetExternalAddressSpec", []))

    @jsii.member(jsii_name="resetInternalAddressSpec")
    def reset_internal_address_spec(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInternalAddressSpec", []))

    @jsii.member(jsii_name="resetProtocol")
    def reset_protocol(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetProtocol", []))

    @jsii.member(jsii_name="resetTargetPort")
    def reset_target_port(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTargetPort", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="externalAddressSpec")
    def external_address_spec(
        self,
    ) -> LbNetworkLoadBalancerListenerExternalAddressSpecOutputReference:
        return typing.cast(LbNetworkLoadBalancerListenerExternalAddressSpecOutputReference, jsii.get(self, "externalAddressSpec"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalAddressSpec")
    def internal_address_spec(
        self,
    ) -> LbNetworkLoadBalancerListenerInternalAddressSpecOutputReference:
        return typing.cast(LbNetworkLoadBalancerListenerInternalAddressSpecOutputReference, jsii.get(self, "internalAddressSpec"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="externalAddressSpecInput")
    def external_address_spec_input(
        self,
    ) -> typing.Optional[LbNetworkLoadBalancerListenerExternalAddressSpec]:
        return typing.cast(typing.Optional[LbNetworkLoadBalancerListenerExternalAddressSpec], jsii.get(self, "externalAddressSpecInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalAddressSpecInput")
    def internal_address_spec_input(
        self,
    ) -> typing.Optional[LbNetworkLoadBalancerListenerInternalAddressSpec]:
        return typing.cast(typing.Optional[LbNetworkLoadBalancerListenerInternalAddressSpec], jsii.get(self, "internalAddressSpecInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="portInput")
    def port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "portInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="protocolInput")
    def protocol_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "protocolInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetPortInput")
    def target_port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "targetPortInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "port"))

    @port.setter
    def port(self, value: jsii.Number) -> None:
        jsii.set(self, "port", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "protocol"))

    @protocol.setter
    def protocol(self, value: builtins.str) -> None:
        jsii.set(self, "protocol", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetPort")
    def target_port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "targetPort"))

    @target_port.setter
    def target_port(self, value: jsii.Number) -> None:
        jsii.set(self, "targetPort", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, LbNetworkLoadBalancerListener]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, LbNetworkLoadBalancerListener]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, LbNetworkLoadBalancerListener]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.LbNetworkLoadBalancerTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class LbNetworkLoadBalancerTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#create LbNetworkLoadBalancer#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#delete LbNetworkLoadBalancer#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#update LbNetworkLoadBalancer#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#create LbNetworkLoadBalancer#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#delete LbNetworkLoadBalancer#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_network_load_balancer#update LbNetworkLoadBalancer#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbNetworkLoadBalancerTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LbNetworkLoadBalancerTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.LbNetworkLoadBalancerTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, LbNetworkLoadBalancerTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, LbNetworkLoadBalancerTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, LbNetworkLoadBalancerTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class LbTargetGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.LbTargetGroup",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group yandex_lb_target_group}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        region_id: typing.Optional[builtins.str] = None,
        target: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["LbTargetGroupTarget"]]] = None,
        timeouts: typing.Optional["LbTargetGroupTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group yandex_lb_target_group} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#description LbTargetGroup#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#folder_id LbTargetGroup#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#id LbTargetGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#labels LbTargetGroup#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#name LbTargetGroup#name}.
        :param region_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#region_id LbTargetGroup#region_id}.
        :param target: target block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#target LbTargetGroup#target}
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#timeouts LbTargetGroup#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = LbTargetGroupConfig(
            description=description,
            folder_id=folder_id,
            id=id,
            labels=labels,
            name=name,
            region_id=region_id,
            target=target,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putTarget")
    def put_target(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["LbTargetGroupTarget"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putTarget", [value]))

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#create LbTargetGroup#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#delete LbTargetGroup#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#update LbTargetGroup#update}.
        '''
        value = LbTargetGroupTimeouts(create=create, delete=delete, update=update)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetRegionId")
    def reset_region_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRegionId", []))

    @jsii.member(jsii_name="resetTarget")
    def reset_target(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTarget", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="target")
    def target(self) -> "LbTargetGroupTargetList":
        return typing.cast("LbTargetGroupTargetList", jsii.get(self, "target"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "LbTargetGroupTimeoutsOutputReference":
        return typing.cast("LbTargetGroupTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="regionIdInput")
    def region_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "regionIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetInput")
    def target_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["LbTargetGroupTarget"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["LbTargetGroupTarget"]]], jsii.get(self, "targetInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "LbTargetGroupTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "LbTargetGroupTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="regionId")
    def region_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "regionId"))

    @region_id.setter
    def region_id(self, value: builtins.str) -> None:
        jsii.set(self, "regionId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.LbTargetGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "description": "description",
        "folder_id": "folderId",
        "id": "id",
        "labels": "labels",
        "name": "name",
        "region_id": "regionId",
        "target": "target",
        "timeouts": "timeouts",
    },
)
class LbTargetGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        region_id: typing.Optional[builtins.str] = None,
        target: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["LbTargetGroupTarget"]]] = None,
        timeouts: typing.Optional["LbTargetGroupTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#description LbTargetGroup#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#folder_id LbTargetGroup#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#id LbTargetGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#labels LbTargetGroup#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#name LbTargetGroup#name}.
        :param region_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#region_id LbTargetGroup#region_id}.
        :param target: target block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#target LbTargetGroup#target}
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#timeouts LbTargetGroup#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = LbTargetGroupTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if name is not None:
            self._values["name"] = name
        if region_id is not None:
            self._values["region_id"] = region_id
        if target is not None:
            self._values["target"] = target
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#description LbTargetGroup#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#folder_id LbTargetGroup#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#id LbTargetGroup#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#labels LbTargetGroup#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#name LbTargetGroup#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def region_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#region_id LbTargetGroup#region_id}.'''
        result = self._values.get("region_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def target(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["LbTargetGroupTarget"]]]:
        '''target block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#target LbTargetGroup#target}
        '''
        result = self._values.get("target")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["LbTargetGroupTarget"]]], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["LbTargetGroupTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#timeouts LbTargetGroup#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["LbTargetGroupTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbTargetGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.LbTargetGroupTarget",
    jsii_struct_bases=[],
    name_mapping={"address": "address", "subnet_id": "subnetId"},
)
class LbTargetGroupTarget:
    def __init__(self, *, address: builtins.str, subnet_id: builtins.str) -> None:
        '''
        :param address: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#address LbTargetGroup#address}.
        :param subnet_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#subnet_id LbTargetGroup#subnet_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "address": address,
            "subnet_id": subnet_id,
        }

    @builtins.property
    def address(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#address LbTargetGroup#address}.'''
        result = self._values.get("address")
        assert result is not None, "Required property 'address' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def subnet_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#subnet_id LbTargetGroup#subnet_id}.'''
        result = self._values.get("subnet_id")
        assert result is not None, "Required property 'subnet_id' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbTargetGroupTarget(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LbTargetGroupTargetList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.LbTargetGroupTargetList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "LbTargetGroupTargetOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("LbTargetGroupTargetOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[LbTargetGroupTarget]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[LbTargetGroupTarget]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[LbTargetGroupTarget]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class LbTargetGroupTargetOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.LbTargetGroupTargetOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="addressInput")
    def address_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "addressInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIdInput")
    def subnet_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "subnetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="address")
    def address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "address"))

    @address.setter
    def address(self, value: builtins.str) -> None:
        jsii.set(self, "address", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @subnet_id.setter
    def subnet_id(self, value: builtins.str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, LbTargetGroupTarget]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, LbTargetGroupTarget]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, LbTargetGroupTarget]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.LbTargetGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class LbTargetGroupTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#create LbTargetGroup#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#delete LbTargetGroup#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#update LbTargetGroup#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#create LbTargetGroup#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#delete LbTargetGroup#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/lb_target_group#update LbTargetGroup#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbTargetGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LbTargetGroupTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.LbTargetGroupTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, LbTargetGroupTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, LbTargetGroupTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, LbTargetGroupTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class LoggingGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.LoggingGroup",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/logging_group yandex_logging_group}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        retention_period: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["LoggingGroupTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/logging_group yandex_logging_group} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/logging_group#description LoggingGroup#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/logging_group#folder_id LoggingGroup#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/logging_group#id LoggingGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/logging_group#labels LoggingGroup#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/logging_group#name LoggingGroup#name}.
        :param retention_period: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/logging_group#retention_period LoggingGroup#retention_period}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/logging_group#timeouts LoggingGroup#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = LoggingGroupConfig(
            description=description,
            folder_id=folder_id,
            id=id,
            labels=labels,
            name=name,
            retention_period=retention_period,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(self, *, default: typing.Optional[builtins.str] = None) -> None:
        '''
        :param default: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/logging_group#default LoggingGroup#default}.
        '''
        value = LoggingGroupTimeouts(default=default)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetRetentionPeriod")
    def reset_retention_period(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRetentionPeriod", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cloudId")
    def cloud_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "cloudId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "LoggingGroupTimeoutsOutputReference":
        return typing.cast("LoggingGroupTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="retentionPeriodInput")
    def retention_period_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "retentionPeriodInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "LoggingGroupTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "LoggingGroupTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="retentionPeriod")
    def retention_period(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "retentionPeriod"))

    @retention_period.setter
    def retention_period(self, value: builtins.str) -> None:
        jsii.set(self, "retentionPeriod", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.LoggingGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "description": "description",
        "folder_id": "folderId",
        "id": "id",
        "labels": "labels",
        "name": "name",
        "retention_period": "retentionPeriod",
        "timeouts": "timeouts",
    },
)
class LoggingGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        retention_period: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["LoggingGroupTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/logging_group#description LoggingGroup#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/logging_group#folder_id LoggingGroup#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/logging_group#id LoggingGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/logging_group#labels LoggingGroup#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/logging_group#name LoggingGroup#name}.
        :param retention_period: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/logging_group#retention_period LoggingGroup#retention_period}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/logging_group#timeouts LoggingGroup#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = LoggingGroupTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if name is not None:
            self._values["name"] = name
        if retention_period is not None:
            self._values["retention_period"] = retention_period
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/logging_group#description LoggingGroup#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/logging_group#folder_id LoggingGroup#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/logging_group#id LoggingGroup#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/logging_group#labels LoggingGroup#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/logging_group#name LoggingGroup#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def retention_period(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/logging_group#retention_period LoggingGroup#retention_period}.'''
        result = self._values.get("retention_period")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["LoggingGroupTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/logging_group#timeouts LoggingGroup#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["LoggingGroupTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LoggingGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.LoggingGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={"default": "default"},
)
class LoggingGroupTimeouts:
    def __init__(self, *, default: typing.Optional[builtins.str] = None) -> None:
        '''
        :param default: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/logging_group#default LoggingGroup#default}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if default is not None:
            self._values["default"] = default

    @builtins.property
    def default(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/logging_group#default LoggingGroup#default}.'''
        result = self._values.get("default")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LoggingGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LoggingGroupTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.LoggingGroupTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetDefault")
    def reset_default(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDefault", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="defaultInput")
    def default_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "defaultInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="default")
    def default(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "default"))

    @default.setter
    def default(self, value: builtins.str) -> None:
        jsii.set(self, "default", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, LoggingGroupTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, LoggingGroupTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, LoggingGroupTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbClickhouseCluster(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseCluster",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster yandex_mdb_clickhouse_cluster}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        clickhouse: "MdbClickhouseClusterClickhouse",
        environment: builtins.str,
        host: typing.Union[cdktf.IResolvable, typing.Sequence["MdbClickhouseClusterHost"]],
        name: builtins.str,
        network_id: builtins.str,
        access: typing.Optional["MdbClickhouseClusterAccess"] = None,
        admin_password: typing.Optional[builtins.str] = None,
        backup_window_start: typing.Optional["MdbClickhouseClusterBackupWindowStart"] = None,
        cloud_storage: typing.Optional["MdbClickhouseClusterCloudStorage"] = None,
        copy_schema_on_new_hosts: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        database: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbClickhouseClusterDatabase"]]] = None,
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        description: typing.Optional[builtins.str] = None,
        embedded_keeper: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        folder_id: typing.Optional[builtins.str] = None,
        format_schema: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbClickhouseClusterFormatSchema"]]] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        maintenance_window: typing.Optional["MdbClickhouseClusterMaintenanceWindow"] = None,
        ml_model: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbClickhouseClusterMlModel"]]] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        service_account_id: typing.Optional[builtins.str] = None,
        shard_group: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbClickhouseClusterShardGroup"]]] = None,
        sql_database_management: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        sql_user_management: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        timeouts: typing.Optional["MdbClickhouseClusterTimeouts"] = None,
        user: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbClickhouseClusterUser"]]] = None,
        version: typing.Optional[builtins.str] = None,
        zookeeper: typing.Optional["MdbClickhouseClusterZookeeper"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster yandex_mdb_clickhouse_cluster} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param clickhouse: clickhouse block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#clickhouse MdbClickhouseCluster#clickhouse}
        :param environment: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#environment MdbClickhouseCluster#environment}.
        :param host: host block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#host MdbClickhouseCluster#host}
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#name MdbClickhouseCluster#name}.
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#network_id MdbClickhouseCluster#network_id}.
        :param access: access block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#access MdbClickhouseCluster#access}
        :param admin_password: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#admin_password MdbClickhouseCluster#admin_password}.
        :param backup_window_start: backup_window_start block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#backup_window_start MdbClickhouseCluster#backup_window_start}
        :param cloud_storage: cloud_storage block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#cloud_storage MdbClickhouseCluster#cloud_storage}
        :param copy_schema_on_new_hosts: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#copy_schema_on_new_hosts MdbClickhouseCluster#copy_schema_on_new_hosts}.
        :param database: database block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#database MdbClickhouseCluster#database}
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#deletion_protection MdbClickhouseCluster#deletion_protection}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#description MdbClickhouseCluster#description}.
        :param embedded_keeper: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#embedded_keeper MdbClickhouseCluster#embedded_keeper}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#folder_id MdbClickhouseCluster#folder_id}.
        :param format_schema: format_schema block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#format_schema MdbClickhouseCluster#format_schema}
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#id MdbClickhouseCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#labels MdbClickhouseCluster#labels}.
        :param maintenance_window: maintenance_window block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#maintenance_window MdbClickhouseCluster#maintenance_window}
        :param ml_model: ml_model block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#ml_model MdbClickhouseCluster#ml_model}
        :param security_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#security_group_ids MdbClickhouseCluster#security_group_ids}.
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#service_account_id MdbClickhouseCluster#service_account_id}.
        :param shard_group: shard_group block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#shard_group MdbClickhouseCluster#shard_group}
        :param sql_database_management: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#sql_database_management MdbClickhouseCluster#sql_database_management}.
        :param sql_user_management: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#sql_user_management MdbClickhouseCluster#sql_user_management}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#timeouts MdbClickhouseCluster#timeouts}
        :param user: user block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#user MdbClickhouseCluster#user}
        :param version: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#version MdbClickhouseCluster#version}.
        :param zookeeper: zookeeper block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#zookeeper MdbClickhouseCluster#zookeeper}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = MdbClickhouseClusterConfig(
            clickhouse=clickhouse,
            environment=environment,
            host=host,
            name=name,
            network_id=network_id,
            access=access,
            admin_password=admin_password,
            backup_window_start=backup_window_start,
            cloud_storage=cloud_storage,
            copy_schema_on_new_hosts=copy_schema_on_new_hosts,
            database=database,
            deletion_protection=deletion_protection,
            description=description,
            embedded_keeper=embedded_keeper,
            folder_id=folder_id,
            format_schema=format_schema,
            id=id,
            labels=labels,
            maintenance_window=maintenance_window,
            ml_model=ml_model,
            security_group_ids=security_group_ids,
            service_account_id=service_account_id,
            shard_group=shard_group,
            sql_database_management=sql_database_management,
            sql_user_management=sql_user_management,
            timeouts=timeouts,
            user=user,
            version=version,
            zookeeper=zookeeper,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putAccess")
    def put_access(
        self,
        *,
        data_lens: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        metrika: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        serverless: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        web_sql: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param data_lens: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#data_lens MdbClickhouseCluster#data_lens}.
        :param metrika: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#metrika MdbClickhouseCluster#metrika}.
        :param serverless: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#serverless MdbClickhouseCluster#serverless}.
        :param web_sql: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#web_sql MdbClickhouseCluster#web_sql}.
        '''
        value = MdbClickhouseClusterAccess(
            data_lens=data_lens,
            metrika=metrika,
            serverless=serverless,
            web_sql=web_sql,
        )

        return typing.cast(None, jsii.invoke(self, "putAccess", [value]))

    @jsii.member(jsii_name="putBackupWindowStart")
    def put_backup_window_start(
        self,
        *,
        hours: typing.Optional[jsii.Number] = None,
        minutes: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param hours: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#hours MdbClickhouseCluster#hours}.
        :param minutes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#minutes MdbClickhouseCluster#minutes}.
        '''
        value = MdbClickhouseClusterBackupWindowStart(hours=hours, minutes=minutes)

        return typing.cast(None, jsii.invoke(self, "putBackupWindowStart", [value]))

    @jsii.member(jsii_name="putClickhouse")
    def put_clickhouse(
        self,
        *,
        resources: "MdbClickhouseClusterClickhouseResources",
        config: typing.Optional["MdbClickhouseClusterClickhouseConfig"] = None,
    ) -> None:
        '''
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#resources MdbClickhouseCluster#resources}
        :param config: config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#config MdbClickhouseCluster#config}
        '''
        value = MdbClickhouseClusterClickhouse(resources=resources, config=config)

        return typing.cast(None, jsii.invoke(self, "putClickhouse", [value]))

    @jsii.member(jsii_name="putCloudStorage")
    def put_cloud_storage(
        self,
        *,
        enabled: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        '''
        :param enabled: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#enabled MdbClickhouseCluster#enabled}.
        '''
        value = MdbClickhouseClusterCloudStorage(enabled=enabled)

        return typing.cast(None, jsii.invoke(self, "putCloudStorage", [value]))

    @jsii.member(jsii_name="putDatabase")
    def put_database(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["MdbClickhouseClusterDatabase"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putDatabase", [value]))

    @jsii.member(jsii_name="putFormatSchema")
    def put_format_schema(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["MdbClickhouseClusterFormatSchema"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putFormatSchema", [value]))

    @jsii.member(jsii_name="putHost")
    def put_host(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["MdbClickhouseClusterHost"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putHost", [value]))

    @jsii.member(jsii_name="putMaintenanceWindow")
    def put_maintenance_window(
        self,
        *,
        type: builtins.str,
        day: typing.Optional[builtins.str] = None,
        hour: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#type MdbClickhouseCluster#type}.
        :param day: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#day MdbClickhouseCluster#day}.
        :param hour: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#hour MdbClickhouseCluster#hour}.
        '''
        value = MdbClickhouseClusterMaintenanceWindow(type=type, day=day, hour=hour)

        return typing.cast(None, jsii.invoke(self, "putMaintenanceWindow", [value]))

    @jsii.member(jsii_name="putMlModel")
    def put_ml_model(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["MdbClickhouseClusterMlModel"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putMlModel", [value]))

    @jsii.member(jsii_name="putShardGroup")
    def put_shard_group(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["MdbClickhouseClusterShardGroup"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putShardGroup", [value]))

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#create MdbClickhouseCluster#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#delete MdbClickhouseCluster#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#update MdbClickhouseCluster#update}.
        '''
        value = MdbClickhouseClusterTimeouts(
            create=create, delete=delete, update=update
        )

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="putUser")
    def put_user(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["MdbClickhouseClusterUser"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putUser", [value]))

    @jsii.member(jsii_name="putZookeeper")
    def put_zookeeper(
        self,
        *,
        resources: typing.Optional["MdbClickhouseClusterZookeeperResources"] = None,
    ) -> None:
        '''
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#resources MdbClickhouseCluster#resources}
        '''
        value = MdbClickhouseClusterZookeeper(resources=resources)

        return typing.cast(None, jsii.invoke(self, "putZookeeper", [value]))

    @jsii.member(jsii_name="resetAccess")
    def reset_access(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAccess", []))

    @jsii.member(jsii_name="resetAdminPassword")
    def reset_admin_password(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAdminPassword", []))

    @jsii.member(jsii_name="resetBackupWindowStart")
    def reset_backup_window_start(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetBackupWindowStart", []))

    @jsii.member(jsii_name="resetCloudStorage")
    def reset_cloud_storage(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCloudStorage", []))

    @jsii.member(jsii_name="resetCopySchemaOnNewHosts")
    def reset_copy_schema_on_new_hosts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCopySchemaOnNewHosts", []))

    @jsii.member(jsii_name="resetDatabase")
    def reset_database(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDatabase", []))

    @jsii.member(jsii_name="resetDeletionProtection")
    def reset_deletion_protection(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDeletionProtection", []))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetEmbeddedKeeper")
    def reset_embedded_keeper(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEmbeddedKeeper", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetFormatSchema")
    def reset_format_schema(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFormatSchema", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetMaintenanceWindow")
    def reset_maintenance_window(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaintenanceWindow", []))

    @jsii.member(jsii_name="resetMlModel")
    def reset_ml_model(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMlModel", []))

    @jsii.member(jsii_name="resetSecurityGroupIds")
    def reset_security_group_ids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityGroupIds", []))

    @jsii.member(jsii_name="resetServiceAccountId")
    def reset_service_account_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetServiceAccountId", []))

    @jsii.member(jsii_name="resetShardGroup")
    def reset_shard_group(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetShardGroup", []))

    @jsii.member(jsii_name="resetSqlDatabaseManagement")
    def reset_sql_database_management(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSqlDatabaseManagement", []))

    @jsii.member(jsii_name="resetSqlUserManagement")
    def reset_sql_user_management(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSqlUserManagement", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="resetUser")
    def reset_user(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUser", []))

    @jsii.member(jsii_name="resetVersion")
    def reset_version(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetVersion", []))

    @jsii.member(jsii_name="resetZookeeper")
    def reset_zookeeper(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetZookeeper", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="access")
    def access(self) -> "MdbClickhouseClusterAccessOutputReference":
        return typing.cast("MdbClickhouseClusterAccessOutputReference", jsii.get(self, "access"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backupWindowStart")
    def backup_window_start(
        self,
    ) -> "MdbClickhouseClusterBackupWindowStartOutputReference":
        return typing.cast("MdbClickhouseClusterBackupWindowStartOutputReference", jsii.get(self, "backupWindowStart"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clickhouse")
    def clickhouse(self) -> "MdbClickhouseClusterClickhouseOutputReference":
        return typing.cast("MdbClickhouseClusterClickhouseOutputReference", jsii.get(self, "clickhouse"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cloudStorage")
    def cloud_storage(self) -> "MdbClickhouseClusterCloudStorageOutputReference":
        return typing.cast("MdbClickhouseClusterCloudStorageOutputReference", jsii.get(self, "cloudStorage"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="database")
    def database(self) -> "MdbClickhouseClusterDatabaseList":
        return typing.cast("MdbClickhouseClusterDatabaseList", jsii.get(self, "database"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="formatSchema")
    def format_schema(self) -> "MdbClickhouseClusterFormatSchemaList":
        return typing.cast("MdbClickhouseClusterFormatSchemaList", jsii.get(self, "formatSchema"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="health")
    def health(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "health"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="host")
    def host(self) -> "MdbClickhouseClusterHostList":
        return typing.cast("MdbClickhouseClusterHostList", jsii.get(self, "host"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maintenanceWindow")
    def maintenance_window(
        self,
    ) -> "MdbClickhouseClusterMaintenanceWindowOutputReference":
        return typing.cast("MdbClickhouseClusterMaintenanceWindowOutputReference", jsii.get(self, "maintenanceWindow"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mlModel")
    def ml_model(self) -> "MdbClickhouseClusterMlModelList":
        return typing.cast("MdbClickhouseClusterMlModelList", jsii.get(self, "mlModel"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="shardGroup")
    def shard_group(self) -> "MdbClickhouseClusterShardGroupList":
        return typing.cast("MdbClickhouseClusterShardGroupList", jsii.get(self, "shardGroup"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "MdbClickhouseClusterTimeoutsOutputReference":
        return typing.cast("MdbClickhouseClusterTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="user")
    def user(self) -> "MdbClickhouseClusterUserList":
        return typing.cast("MdbClickhouseClusterUserList", jsii.get(self, "user"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zookeeper")
    def zookeeper(self) -> "MdbClickhouseClusterZookeeperOutputReference":
        return typing.cast("MdbClickhouseClusterZookeeperOutputReference", jsii.get(self, "zookeeper"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="accessInput")
    def access_input(self) -> typing.Optional["MdbClickhouseClusterAccess"]:
        return typing.cast(typing.Optional["MdbClickhouseClusterAccess"], jsii.get(self, "accessInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="adminPasswordInput")
    def admin_password_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "adminPasswordInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backupWindowStartInput")
    def backup_window_start_input(
        self,
    ) -> typing.Optional["MdbClickhouseClusterBackupWindowStart"]:
        return typing.cast(typing.Optional["MdbClickhouseClusterBackupWindowStart"], jsii.get(self, "backupWindowStartInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clickhouseInput")
    def clickhouse_input(self) -> typing.Optional["MdbClickhouseClusterClickhouse"]:
        return typing.cast(typing.Optional["MdbClickhouseClusterClickhouse"], jsii.get(self, "clickhouseInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cloudStorageInput")
    def cloud_storage_input(
        self,
    ) -> typing.Optional["MdbClickhouseClusterCloudStorage"]:
        return typing.cast(typing.Optional["MdbClickhouseClusterCloudStorage"], jsii.get(self, "cloudStorageInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="copySchemaOnNewHostsInput")
    def copy_schema_on_new_hosts_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "copySchemaOnNewHostsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databaseInput")
    def database_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterDatabase"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterDatabase"]]], jsii.get(self, "databaseInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtectionInput")
    def deletion_protection_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "deletionProtectionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="embeddedKeeperInput")
    def embedded_keeper_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "embeddedKeeperInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="environmentInput")
    def environment_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "environmentInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="formatSchemaInput")
    def format_schema_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterFormatSchema"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterFormatSchema"]]], jsii.get(self, "formatSchemaInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostInput")
    def host_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterHost"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterHost"]]], jsii.get(self, "hostInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maintenanceWindowInput")
    def maintenance_window_input(
        self,
    ) -> typing.Optional["MdbClickhouseClusterMaintenanceWindow"]:
        return typing.cast(typing.Optional["MdbClickhouseClusterMaintenanceWindow"], jsii.get(self, "maintenanceWindowInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mlModelInput")
    def ml_model_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterMlModel"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterMlModel"]]], jsii.get(self, "mlModelInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkIdInput")
    def network_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "networkIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIdsInput")
    def security_group_ids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "securityGroupIdsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountIdInput")
    def service_account_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceAccountIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="shardGroupInput")
    def shard_group_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterShardGroup"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterShardGroup"]]], jsii.get(self, "shardGroupInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sqlDatabaseManagementInput")
    def sql_database_management_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "sqlDatabaseManagementInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sqlUserManagementInput")
    def sql_user_management_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "sqlUserManagementInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "MdbClickhouseClusterTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "MdbClickhouseClusterTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="userInput")
    def user_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterUser"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterUser"]]], jsii.get(self, "userInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="versionInput")
    def version_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "versionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zookeeperInput")
    def zookeeper_input(self) -> typing.Optional["MdbClickhouseClusterZookeeper"]:
        return typing.cast(typing.Optional["MdbClickhouseClusterZookeeper"], jsii.get(self, "zookeeperInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="adminPassword")
    def admin_password(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "adminPassword"))

    @admin_password.setter
    def admin_password(self, value: builtins.str) -> None:
        jsii.set(self, "adminPassword", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="copySchemaOnNewHosts")
    def copy_schema_on_new_hosts(
        self,
    ) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "copySchemaOnNewHosts"))

    @copy_schema_on_new_hosts.setter
    def copy_schema_on_new_hosts(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "copySchemaOnNewHosts", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtection")
    def deletion_protection(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "deletionProtection"))

    @deletion_protection.setter
    def deletion_protection(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "deletionProtection", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="embeddedKeeper")
    def embedded_keeper(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "embeddedKeeper"))

    @embedded_keeper.setter
    def embedded_keeper(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "embeddedKeeper", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="environment")
    def environment(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "environment"))

    @environment.setter
    def environment(self, value: builtins.str) -> None:
        jsii.set(self, "environment", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @network_id.setter
    def network_id(self, value: builtins.str) -> None:
        jsii.set(self, "networkId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "securityGroupIds"))

    @security_group_ids.setter
    def security_group_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "securityGroupIds", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountId")
    def service_account_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceAccountId"))

    @service_account_id.setter
    def service_account_id(self, value: builtins.str) -> None:
        jsii.set(self, "serviceAccountId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sqlDatabaseManagement")
    def sql_database_management(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "sqlDatabaseManagement"))

    @sql_database_management.setter
    def sql_database_management(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "sqlDatabaseManagement", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sqlUserManagement")
    def sql_user_management(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "sqlUserManagement"))

    @sql_user_management.setter
    def sql_user_management(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "sqlUserManagement", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "version"))

    @version.setter
    def version(self, value: builtins.str) -> None:
        jsii.set(self, "version", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterAccess",
    jsii_struct_bases=[],
    name_mapping={
        "data_lens": "dataLens",
        "metrika": "metrika",
        "serverless": "serverless",
        "web_sql": "webSql",
    },
)
class MdbClickhouseClusterAccess:
    def __init__(
        self,
        *,
        data_lens: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        metrika: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        serverless: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        web_sql: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param data_lens: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#data_lens MdbClickhouseCluster#data_lens}.
        :param metrika: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#metrika MdbClickhouseCluster#metrika}.
        :param serverless: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#serverless MdbClickhouseCluster#serverless}.
        :param web_sql: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#web_sql MdbClickhouseCluster#web_sql}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if data_lens is not None:
            self._values["data_lens"] = data_lens
        if metrika is not None:
            self._values["metrika"] = metrika
        if serverless is not None:
            self._values["serverless"] = serverless
        if web_sql is not None:
            self._values["web_sql"] = web_sql

    @builtins.property
    def data_lens(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#data_lens MdbClickhouseCluster#data_lens}.'''
        result = self._values.get("data_lens")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def metrika(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#metrika MdbClickhouseCluster#metrika}.'''
        result = self._values.get("metrika")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def serverless(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#serverless MdbClickhouseCluster#serverless}.'''
        result = self._values.get("serverless")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def web_sql(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#web_sql MdbClickhouseCluster#web_sql}.'''
        result = self._values.get("web_sql")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbClickhouseClusterAccess(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbClickhouseClusterAccessOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterAccessOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetDataLens")
    def reset_data_lens(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDataLens", []))

    @jsii.member(jsii_name="resetMetrika")
    def reset_metrika(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetrika", []))

    @jsii.member(jsii_name="resetServerless")
    def reset_serverless(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetServerless", []))

    @jsii.member(jsii_name="resetWebSql")
    def reset_web_sql(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetWebSql", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dataLensInput")
    def data_lens_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "dataLensInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metrikaInput")
    def metrika_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "metrikaInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serverlessInput")
    def serverless_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "serverlessInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="webSqlInput")
    def web_sql_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "webSqlInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dataLens")
    def data_lens(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "dataLens"))

    @data_lens.setter
    def data_lens(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "dataLens", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metrika")
    def metrika(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "metrika"))

    @metrika.setter
    def metrika(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "metrika", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serverless")
    def serverless(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "serverless"))

    @serverless.setter
    def serverless(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "serverless", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="webSql")
    def web_sql(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "webSql"))

    @web_sql.setter
    def web_sql(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "webSql", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbClickhouseClusterAccess]:
        return typing.cast(typing.Optional[MdbClickhouseClusterAccess], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbClickhouseClusterAccess],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterBackupWindowStart",
    jsii_struct_bases=[],
    name_mapping={"hours": "hours", "minutes": "minutes"},
)
class MdbClickhouseClusterBackupWindowStart:
    def __init__(
        self,
        *,
        hours: typing.Optional[jsii.Number] = None,
        minutes: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param hours: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#hours MdbClickhouseCluster#hours}.
        :param minutes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#minutes MdbClickhouseCluster#minutes}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if hours is not None:
            self._values["hours"] = hours
        if minutes is not None:
            self._values["minutes"] = minutes

    @builtins.property
    def hours(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#hours MdbClickhouseCluster#hours}.'''
        result = self._values.get("hours")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def minutes(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#minutes MdbClickhouseCluster#minutes}.'''
        result = self._values.get("minutes")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbClickhouseClusterBackupWindowStart(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbClickhouseClusterBackupWindowStartOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterBackupWindowStartOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetHours")
    def reset_hours(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHours", []))

    @jsii.member(jsii_name="resetMinutes")
    def reset_minutes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMinutes", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hoursInput")
    def hours_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "hoursInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minutesInput")
    def minutes_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "minutesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hours")
    def hours(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "hours"))

    @hours.setter
    def hours(self, value: jsii.Number) -> None:
        jsii.set(self, "hours", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minutes")
    def minutes(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minutes"))

    @minutes.setter
    def minutes(self, value: jsii.Number) -> None:
        jsii.set(self, "minutes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbClickhouseClusterBackupWindowStart]:
        return typing.cast(typing.Optional[MdbClickhouseClusterBackupWindowStart], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbClickhouseClusterBackupWindowStart],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterClickhouse",
    jsii_struct_bases=[],
    name_mapping={"resources": "resources", "config": "config"},
)
class MdbClickhouseClusterClickhouse:
    def __init__(
        self,
        *,
        resources: "MdbClickhouseClusterClickhouseResources",
        config: typing.Optional["MdbClickhouseClusterClickhouseConfig"] = None,
    ) -> None:
        '''
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#resources MdbClickhouseCluster#resources}
        :param config: config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#config MdbClickhouseCluster#config}
        '''
        if isinstance(resources, dict):
            resources = MdbClickhouseClusterClickhouseResources(**resources)
        if isinstance(config, dict):
            config = MdbClickhouseClusterClickhouseConfig(**config)
        self._values: typing.Dict[str, typing.Any] = {
            "resources": resources,
        }
        if config is not None:
            self._values["config"] = config

    @builtins.property
    def resources(self) -> "MdbClickhouseClusterClickhouseResources":
        '''resources block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#resources MdbClickhouseCluster#resources}
        '''
        result = self._values.get("resources")
        assert result is not None, "Required property 'resources' is missing"
        return typing.cast("MdbClickhouseClusterClickhouseResources", result)

    @builtins.property
    def config(self) -> typing.Optional["MdbClickhouseClusterClickhouseConfig"]:
        '''config block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#config MdbClickhouseCluster#config}
        '''
        result = self._values.get("config")
        return typing.cast(typing.Optional["MdbClickhouseClusterClickhouseConfig"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbClickhouseClusterClickhouse(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterClickhouseConfig",
    jsii_struct_bases=[],
    name_mapping={
        "background_pool_size": "backgroundPoolSize",
        "background_schedule_pool_size": "backgroundSchedulePoolSize",
        "compression": "compression",
        "geobase_uri": "geobaseUri",
        "graphite_rollup": "graphiteRollup",
        "kafka": "kafka",
        "kafka_topic": "kafkaTopic",
        "keep_alive_timeout": "keepAliveTimeout",
        "log_level": "logLevel",
        "mark_cache_size": "markCacheSize",
        "max_concurrent_queries": "maxConcurrentQueries",
        "max_connections": "maxConnections",
        "max_partition_size_to_drop": "maxPartitionSizeToDrop",
        "max_table_size_to_drop": "maxTableSizeToDrop",
        "merge_tree": "mergeTree",
        "metric_log_enabled": "metricLogEnabled",
        "metric_log_retention_size": "metricLogRetentionSize",
        "metric_log_retention_time": "metricLogRetentionTime",
        "part_log_retention_size": "partLogRetentionSize",
        "part_log_retention_time": "partLogRetentionTime",
        "query_log_retention_size": "queryLogRetentionSize",
        "query_log_retention_time": "queryLogRetentionTime",
        "query_thread_log_enabled": "queryThreadLogEnabled",
        "query_thread_log_retention_size": "queryThreadLogRetentionSize",
        "query_thread_log_retention_time": "queryThreadLogRetentionTime",
        "rabbitmq": "rabbitmq",
        "text_log_enabled": "textLogEnabled",
        "text_log_level": "textLogLevel",
        "text_log_retention_size": "textLogRetentionSize",
        "text_log_retention_time": "textLogRetentionTime",
        "timezone": "timezone",
        "trace_log_enabled": "traceLogEnabled",
        "trace_log_retention_size": "traceLogRetentionSize",
        "trace_log_retention_time": "traceLogRetentionTime",
        "uncompressed_cache_size": "uncompressedCacheSize",
    },
)
class MdbClickhouseClusterClickhouseConfig:
    def __init__(
        self,
        *,
        background_pool_size: typing.Optional[jsii.Number] = None,
        background_schedule_pool_size: typing.Optional[jsii.Number] = None,
        compression: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbClickhouseClusterClickhouseConfigCompression"]]] = None,
        geobase_uri: typing.Optional[builtins.str] = None,
        graphite_rollup: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbClickhouseClusterClickhouseConfigGraphiteRollup"]]] = None,
        kafka: typing.Optional["MdbClickhouseClusterClickhouseConfigKafka"] = None,
        kafka_topic: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbClickhouseClusterClickhouseConfigKafkaTopic"]]] = None,
        keep_alive_timeout: typing.Optional[jsii.Number] = None,
        log_level: typing.Optional[builtins.str] = None,
        mark_cache_size: typing.Optional[jsii.Number] = None,
        max_concurrent_queries: typing.Optional[jsii.Number] = None,
        max_connections: typing.Optional[jsii.Number] = None,
        max_partition_size_to_drop: typing.Optional[jsii.Number] = None,
        max_table_size_to_drop: typing.Optional[jsii.Number] = None,
        merge_tree: typing.Optional["MdbClickhouseClusterClickhouseConfigMergeTree"] = None,
        metric_log_enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        metric_log_retention_size: typing.Optional[jsii.Number] = None,
        metric_log_retention_time: typing.Optional[jsii.Number] = None,
        part_log_retention_size: typing.Optional[jsii.Number] = None,
        part_log_retention_time: typing.Optional[jsii.Number] = None,
        query_log_retention_size: typing.Optional[jsii.Number] = None,
        query_log_retention_time: typing.Optional[jsii.Number] = None,
        query_thread_log_enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        query_thread_log_retention_size: typing.Optional[jsii.Number] = None,
        query_thread_log_retention_time: typing.Optional[jsii.Number] = None,
        rabbitmq: typing.Optional["MdbClickhouseClusterClickhouseConfigRabbitmq"] = None,
        text_log_enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        text_log_level: typing.Optional[builtins.str] = None,
        text_log_retention_size: typing.Optional[jsii.Number] = None,
        text_log_retention_time: typing.Optional[jsii.Number] = None,
        timezone: typing.Optional[builtins.str] = None,
        trace_log_enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        trace_log_retention_size: typing.Optional[jsii.Number] = None,
        trace_log_retention_time: typing.Optional[jsii.Number] = None,
        uncompressed_cache_size: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param background_pool_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#background_pool_size MdbClickhouseCluster#background_pool_size}.
        :param background_schedule_pool_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#background_schedule_pool_size MdbClickhouseCluster#background_schedule_pool_size}.
        :param compression: compression block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#compression MdbClickhouseCluster#compression}
        :param geobase_uri: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#geobase_uri MdbClickhouseCluster#geobase_uri}.
        :param graphite_rollup: graphite_rollup block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#graphite_rollup MdbClickhouseCluster#graphite_rollup}
        :param kafka: kafka block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#kafka MdbClickhouseCluster#kafka}
        :param kafka_topic: kafka_topic block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#kafka_topic MdbClickhouseCluster#kafka_topic}
        :param keep_alive_timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#keep_alive_timeout MdbClickhouseCluster#keep_alive_timeout}.
        :param log_level: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#log_level MdbClickhouseCluster#log_level}.
        :param mark_cache_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#mark_cache_size MdbClickhouseCluster#mark_cache_size}.
        :param max_concurrent_queries: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_concurrent_queries MdbClickhouseCluster#max_concurrent_queries}.
        :param max_connections: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_connections MdbClickhouseCluster#max_connections}.
        :param max_partition_size_to_drop: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_partition_size_to_drop MdbClickhouseCluster#max_partition_size_to_drop}.
        :param max_table_size_to_drop: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_table_size_to_drop MdbClickhouseCluster#max_table_size_to_drop}.
        :param merge_tree: merge_tree block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#merge_tree MdbClickhouseCluster#merge_tree}
        :param metric_log_enabled: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#metric_log_enabled MdbClickhouseCluster#metric_log_enabled}.
        :param metric_log_retention_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#metric_log_retention_size MdbClickhouseCluster#metric_log_retention_size}.
        :param metric_log_retention_time: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#metric_log_retention_time MdbClickhouseCluster#metric_log_retention_time}.
        :param part_log_retention_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#part_log_retention_size MdbClickhouseCluster#part_log_retention_size}.
        :param part_log_retention_time: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#part_log_retention_time MdbClickhouseCluster#part_log_retention_time}.
        :param query_log_retention_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#query_log_retention_size MdbClickhouseCluster#query_log_retention_size}.
        :param query_log_retention_time: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#query_log_retention_time MdbClickhouseCluster#query_log_retention_time}.
        :param query_thread_log_enabled: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#query_thread_log_enabled MdbClickhouseCluster#query_thread_log_enabled}.
        :param query_thread_log_retention_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#query_thread_log_retention_size MdbClickhouseCluster#query_thread_log_retention_size}.
        :param query_thread_log_retention_time: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#query_thread_log_retention_time MdbClickhouseCluster#query_thread_log_retention_time}.
        :param rabbitmq: rabbitmq block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#rabbitmq MdbClickhouseCluster#rabbitmq}
        :param text_log_enabled: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#text_log_enabled MdbClickhouseCluster#text_log_enabled}.
        :param text_log_level: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#text_log_level MdbClickhouseCluster#text_log_level}.
        :param text_log_retention_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#text_log_retention_size MdbClickhouseCluster#text_log_retention_size}.
        :param text_log_retention_time: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#text_log_retention_time MdbClickhouseCluster#text_log_retention_time}.
        :param timezone: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#timezone MdbClickhouseCluster#timezone}.
        :param trace_log_enabled: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#trace_log_enabled MdbClickhouseCluster#trace_log_enabled}.
        :param trace_log_retention_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#trace_log_retention_size MdbClickhouseCluster#trace_log_retention_size}.
        :param trace_log_retention_time: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#trace_log_retention_time MdbClickhouseCluster#trace_log_retention_time}.
        :param uncompressed_cache_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#uncompressed_cache_size MdbClickhouseCluster#uncompressed_cache_size}.
        '''
        if isinstance(kafka, dict):
            kafka = MdbClickhouseClusterClickhouseConfigKafka(**kafka)
        if isinstance(merge_tree, dict):
            merge_tree = MdbClickhouseClusterClickhouseConfigMergeTree(**merge_tree)
        if isinstance(rabbitmq, dict):
            rabbitmq = MdbClickhouseClusterClickhouseConfigRabbitmq(**rabbitmq)
        self._values: typing.Dict[str, typing.Any] = {}
        if background_pool_size is not None:
            self._values["background_pool_size"] = background_pool_size
        if background_schedule_pool_size is not None:
            self._values["background_schedule_pool_size"] = background_schedule_pool_size
        if compression is not None:
            self._values["compression"] = compression
        if geobase_uri is not None:
            self._values["geobase_uri"] = geobase_uri
        if graphite_rollup is not None:
            self._values["graphite_rollup"] = graphite_rollup
        if kafka is not None:
            self._values["kafka"] = kafka
        if kafka_topic is not None:
            self._values["kafka_topic"] = kafka_topic
        if keep_alive_timeout is not None:
            self._values["keep_alive_timeout"] = keep_alive_timeout
        if log_level is not None:
            self._values["log_level"] = log_level
        if mark_cache_size is not None:
            self._values["mark_cache_size"] = mark_cache_size
        if max_concurrent_queries is not None:
            self._values["max_concurrent_queries"] = max_concurrent_queries
        if max_connections is not None:
            self._values["max_connections"] = max_connections
        if max_partition_size_to_drop is not None:
            self._values["max_partition_size_to_drop"] = max_partition_size_to_drop
        if max_table_size_to_drop is not None:
            self._values["max_table_size_to_drop"] = max_table_size_to_drop
        if merge_tree is not None:
            self._values["merge_tree"] = merge_tree
        if metric_log_enabled is not None:
            self._values["metric_log_enabled"] = metric_log_enabled
        if metric_log_retention_size is not None:
            self._values["metric_log_retention_size"] = metric_log_retention_size
        if metric_log_retention_time is not None:
            self._values["metric_log_retention_time"] = metric_log_retention_time
        if part_log_retention_size is not None:
            self._values["part_log_retention_size"] = part_log_retention_size
        if part_log_retention_time is not None:
            self._values["part_log_retention_time"] = part_log_retention_time
        if query_log_retention_size is not None:
            self._values["query_log_retention_size"] = query_log_retention_size
        if query_log_retention_time is not None:
            self._values["query_log_retention_time"] = query_log_retention_time
        if query_thread_log_enabled is not None:
            self._values["query_thread_log_enabled"] = query_thread_log_enabled
        if query_thread_log_retention_size is not None:
            self._values["query_thread_log_retention_size"] = query_thread_log_retention_size
        if query_thread_log_retention_time is not None:
            self._values["query_thread_log_retention_time"] = query_thread_log_retention_time
        if rabbitmq is not None:
            self._values["rabbitmq"] = rabbitmq
        if text_log_enabled is not None:
            self._values["text_log_enabled"] = text_log_enabled
        if text_log_level is not None:
            self._values["text_log_level"] = text_log_level
        if text_log_retention_size is not None:
            self._values["text_log_retention_size"] = text_log_retention_size
        if text_log_retention_time is not None:
            self._values["text_log_retention_time"] = text_log_retention_time
        if timezone is not None:
            self._values["timezone"] = timezone
        if trace_log_enabled is not None:
            self._values["trace_log_enabled"] = trace_log_enabled
        if trace_log_retention_size is not None:
            self._values["trace_log_retention_size"] = trace_log_retention_size
        if trace_log_retention_time is not None:
            self._values["trace_log_retention_time"] = trace_log_retention_time
        if uncompressed_cache_size is not None:
            self._values["uncompressed_cache_size"] = uncompressed_cache_size

    @builtins.property
    def background_pool_size(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#background_pool_size MdbClickhouseCluster#background_pool_size}.'''
        result = self._values.get("background_pool_size")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def background_schedule_pool_size(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#background_schedule_pool_size MdbClickhouseCluster#background_schedule_pool_size}.'''
        result = self._values.get("background_schedule_pool_size")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def compression(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterClickhouseConfigCompression"]]]:
        '''compression block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#compression MdbClickhouseCluster#compression}
        '''
        result = self._values.get("compression")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterClickhouseConfigCompression"]]], result)

    @builtins.property
    def geobase_uri(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#geobase_uri MdbClickhouseCluster#geobase_uri}.'''
        result = self._values.get("geobase_uri")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def graphite_rollup(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterClickhouseConfigGraphiteRollup"]]]:
        '''graphite_rollup block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#graphite_rollup MdbClickhouseCluster#graphite_rollup}
        '''
        result = self._values.get("graphite_rollup")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterClickhouseConfigGraphiteRollup"]]], result)

    @builtins.property
    def kafka(self) -> typing.Optional["MdbClickhouseClusterClickhouseConfigKafka"]:
        '''kafka block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#kafka MdbClickhouseCluster#kafka}
        '''
        result = self._values.get("kafka")
        return typing.cast(typing.Optional["MdbClickhouseClusterClickhouseConfigKafka"], result)

    @builtins.property
    def kafka_topic(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterClickhouseConfigKafkaTopic"]]]:
        '''kafka_topic block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#kafka_topic MdbClickhouseCluster#kafka_topic}
        '''
        result = self._values.get("kafka_topic")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterClickhouseConfigKafkaTopic"]]], result)

    @builtins.property
    def keep_alive_timeout(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#keep_alive_timeout MdbClickhouseCluster#keep_alive_timeout}.'''
        result = self._values.get("keep_alive_timeout")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def log_level(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#log_level MdbClickhouseCluster#log_level}.'''
        result = self._values.get("log_level")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def mark_cache_size(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#mark_cache_size MdbClickhouseCluster#mark_cache_size}.'''
        result = self._values.get("mark_cache_size")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_concurrent_queries(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_concurrent_queries MdbClickhouseCluster#max_concurrent_queries}.'''
        result = self._values.get("max_concurrent_queries")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_connections(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_connections MdbClickhouseCluster#max_connections}.'''
        result = self._values.get("max_connections")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_partition_size_to_drop(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_partition_size_to_drop MdbClickhouseCluster#max_partition_size_to_drop}.'''
        result = self._values.get("max_partition_size_to_drop")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_table_size_to_drop(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_table_size_to_drop MdbClickhouseCluster#max_table_size_to_drop}.'''
        result = self._values.get("max_table_size_to_drop")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def merge_tree(
        self,
    ) -> typing.Optional["MdbClickhouseClusterClickhouseConfigMergeTree"]:
        '''merge_tree block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#merge_tree MdbClickhouseCluster#merge_tree}
        '''
        result = self._values.get("merge_tree")
        return typing.cast(typing.Optional["MdbClickhouseClusterClickhouseConfigMergeTree"], result)

    @builtins.property
    def metric_log_enabled(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#metric_log_enabled MdbClickhouseCluster#metric_log_enabled}.'''
        result = self._values.get("metric_log_enabled")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def metric_log_retention_size(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#metric_log_retention_size MdbClickhouseCluster#metric_log_retention_size}.'''
        result = self._values.get("metric_log_retention_size")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def metric_log_retention_time(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#metric_log_retention_time MdbClickhouseCluster#metric_log_retention_time}.'''
        result = self._values.get("metric_log_retention_time")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def part_log_retention_size(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#part_log_retention_size MdbClickhouseCluster#part_log_retention_size}.'''
        result = self._values.get("part_log_retention_size")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def part_log_retention_time(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#part_log_retention_time MdbClickhouseCluster#part_log_retention_time}.'''
        result = self._values.get("part_log_retention_time")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def query_log_retention_size(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#query_log_retention_size MdbClickhouseCluster#query_log_retention_size}.'''
        result = self._values.get("query_log_retention_size")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def query_log_retention_time(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#query_log_retention_time MdbClickhouseCluster#query_log_retention_time}.'''
        result = self._values.get("query_log_retention_time")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def query_thread_log_enabled(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#query_thread_log_enabled MdbClickhouseCluster#query_thread_log_enabled}.'''
        result = self._values.get("query_thread_log_enabled")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def query_thread_log_retention_size(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#query_thread_log_retention_size MdbClickhouseCluster#query_thread_log_retention_size}.'''
        result = self._values.get("query_thread_log_retention_size")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def query_thread_log_retention_time(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#query_thread_log_retention_time MdbClickhouseCluster#query_thread_log_retention_time}.'''
        result = self._values.get("query_thread_log_retention_time")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def rabbitmq(
        self,
    ) -> typing.Optional["MdbClickhouseClusterClickhouseConfigRabbitmq"]:
        '''rabbitmq block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#rabbitmq MdbClickhouseCluster#rabbitmq}
        '''
        result = self._values.get("rabbitmq")
        return typing.cast(typing.Optional["MdbClickhouseClusterClickhouseConfigRabbitmq"], result)

    @builtins.property
    def text_log_enabled(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#text_log_enabled MdbClickhouseCluster#text_log_enabled}.'''
        result = self._values.get("text_log_enabled")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def text_log_level(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#text_log_level MdbClickhouseCluster#text_log_level}.'''
        result = self._values.get("text_log_level")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def text_log_retention_size(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#text_log_retention_size MdbClickhouseCluster#text_log_retention_size}.'''
        result = self._values.get("text_log_retention_size")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def text_log_retention_time(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#text_log_retention_time MdbClickhouseCluster#text_log_retention_time}.'''
        result = self._values.get("text_log_retention_time")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def timezone(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#timezone MdbClickhouseCluster#timezone}.'''
        result = self._values.get("timezone")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def trace_log_enabled(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#trace_log_enabled MdbClickhouseCluster#trace_log_enabled}.'''
        result = self._values.get("trace_log_enabled")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def trace_log_retention_size(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#trace_log_retention_size MdbClickhouseCluster#trace_log_retention_size}.'''
        result = self._values.get("trace_log_retention_size")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def trace_log_retention_time(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#trace_log_retention_time MdbClickhouseCluster#trace_log_retention_time}.'''
        result = self._values.get("trace_log_retention_time")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def uncompressed_cache_size(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#uncompressed_cache_size MdbClickhouseCluster#uncompressed_cache_size}.'''
        result = self._values.get("uncompressed_cache_size")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbClickhouseClusterClickhouseConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterClickhouseConfigCompression",
    jsii_struct_bases=[],
    name_mapping={
        "method": "method",
        "min_part_size": "minPartSize",
        "min_part_size_ratio": "minPartSizeRatio",
    },
)
class MdbClickhouseClusterClickhouseConfigCompression:
    def __init__(
        self,
        *,
        method: builtins.str,
        min_part_size: jsii.Number,
        min_part_size_ratio: jsii.Number,
    ) -> None:
        '''
        :param method: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#method MdbClickhouseCluster#method}.
        :param min_part_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#min_part_size MdbClickhouseCluster#min_part_size}.
        :param min_part_size_ratio: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#min_part_size_ratio MdbClickhouseCluster#min_part_size_ratio}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "method": method,
            "min_part_size": min_part_size,
            "min_part_size_ratio": min_part_size_ratio,
        }

    @builtins.property
    def method(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#method MdbClickhouseCluster#method}.'''
        result = self._values.get("method")
        assert result is not None, "Required property 'method' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def min_part_size(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#min_part_size MdbClickhouseCluster#min_part_size}.'''
        result = self._values.get("min_part_size")
        assert result is not None, "Required property 'min_part_size' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def min_part_size_ratio(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#min_part_size_ratio MdbClickhouseCluster#min_part_size_ratio}.'''
        result = self._values.get("min_part_size_ratio")
        assert result is not None, "Required property 'min_part_size_ratio' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbClickhouseClusterClickhouseConfigCompression(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbClickhouseClusterClickhouseConfigCompressionList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterClickhouseConfigCompressionList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "MdbClickhouseClusterClickhouseConfigCompressionOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbClickhouseClusterClickhouseConfigCompressionOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterClickhouseConfigCompression]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterClickhouseConfigCompression]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterClickhouseConfigCompression]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbClickhouseClusterClickhouseConfigCompressionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterClickhouseConfigCompressionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="methodInput")
    def method_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "methodInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minPartSizeInput")
    def min_part_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "minPartSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minPartSizeRatioInput")
    def min_part_size_ratio_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "minPartSizeRatioInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="method")
    def method(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "method"))

    @method.setter
    def method(self, value: builtins.str) -> None:
        jsii.set(self, "method", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minPartSize")
    def min_part_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minPartSize"))

    @min_part_size.setter
    def min_part_size(self, value: jsii.Number) -> None:
        jsii.set(self, "minPartSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minPartSizeRatio")
    def min_part_size_ratio(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minPartSizeRatio"))

    @min_part_size_ratio.setter
    def min_part_size_ratio(self, value: jsii.Number) -> None:
        jsii.set(self, "minPartSizeRatio", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterClickhouseConfigCompression]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterClickhouseConfigCompression]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterClickhouseConfigCompression]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterClickhouseConfigGraphiteRollup",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "pattern": "pattern"},
)
class MdbClickhouseClusterClickhouseConfigGraphiteRollup:
    def __init__(
        self,
        *,
        name: builtins.str,
        pattern: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbClickhouseClusterClickhouseConfigGraphiteRollupPattern"]]] = None,
    ) -> None:
        '''
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#name MdbClickhouseCluster#name}.
        :param pattern: pattern block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#pattern MdbClickhouseCluster#pattern}
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }
        if pattern is not None:
            self._values["pattern"] = pattern

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#name MdbClickhouseCluster#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def pattern(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterClickhouseConfigGraphiteRollupPattern"]]]:
        '''pattern block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#pattern MdbClickhouseCluster#pattern}
        '''
        result = self._values.get("pattern")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterClickhouseConfigGraphiteRollupPattern"]]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbClickhouseClusterClickhouseConfigGraphiteRollup(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbClickhouseClusterClickhouseConfigGraphiteRollupList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterClickhouseConfigGraphiteRollupList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "MdbClickhouseClusterClickhouseConfigGraphiteRollupOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbClickhouseClusterClickhouseConfigGraphiteRollupOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterClickhouseConfigGraphiteRollup]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterClickhouseConfigGraphiteRollup]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterClickhouseConfigGraphiteRollup]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbClickhouseClusterClickhouseConfigGraphiteRollupOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterClickhouseConfigGraphiteRollupOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putPattern")
    def put_pattern(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["MdbClickhouseClusterClickhouseConfigGraphiteRollupPattern"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putPattern", [value]))

    @jsii.member(jsii_name="resetPattern")
    def reset_pattern(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPattern", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="pattern")
    def pattern(
        self,
    ) -> "MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternList":
        return typing.cast("MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternList", jsii.get(self, "pattern"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="patternInput")
    def pattern_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterClickhouseConfigGraphiteRollupPattern"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterClickhouseConfigGraphiteRollupPattern"]]], jsii.get(self, "patternInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterClickhouseConfigGraphiteRollup]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterClickhouseConfigGraphiteRollup]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterClickhouseConfigGraphiteRollup]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterClickhouseConfigGraphiteRollupPattern",
    jsii_struct_bases=[],
    name_mapping={
        "function": "function",
        "regexp": "regexp",
        "retention": "retention",
    },
)
class MdbClickhouseClusterClickhouseConfigGraphiteRollupPattern:
    def __init__(
        self,
        *,
        function: builtins.str,
        regexp: typing.Optional[builtins.str] = None,
        retention: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetention"]]] = None,
    ) -> None:
        '''
        :param function: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#function MdbClickhouseCluster#function}.
        :param regexp: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#regexp MdbClickhouseCluster#regexp}.
        :param retention: retention block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#retention MdbClickhouseCluster#retention}
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "function": function,
        }
        if regexp is not None:
            self._values["regexp"] = regexp
        if retention is not None:
            self._values["retention"] = retention

    @builtins.property
    def function(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#function MdbClickhouseCluster#function}.'''
        result = self._values.get("function")
        assert result is not None, "Required property 'function' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def regexp(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#regexp MdbClickhouseCluster#regexp}.'''
        result = self._values.get("regexp")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def retention(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetention"]]]:
        '''retention block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#retention MdbClickhouseCluster#retention}
        '''
        result = self._values.get("retention")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetention"]]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbClickhouseClusterClickhouseConfigGraphiteRollupPattern(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterClickhouseConfigGraphiteRollupPattern]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterClickhouseConfigGraphiteRollupPattern]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterClickhouseConfigGraphiteRollupPattern]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putRetention")
    def put_retention(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetention"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putRetention", [value]))

    @jsii.member(jsii_name="resetRegexp")
    def reset_regexp(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRegexp", []))

    @jsii.member(jsii_name="resetRetention")
    def reset_retention(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRetention", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="retention")
    def retention(
        self,
    ) -> "MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetentionList":
        return typing.cast("MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetentionList", jsii.get(self, "retention"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="functionInput")
    def function_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "functionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="regexpInput")
    def regexp_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "regexpInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="retentionInput")
    def retention_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetention"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetention"]]], jsii.get(self, "retentionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="function")
    def function(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "function"))

    @function.setter
    def function(self, value: builtins.str) -> None:
        jsii.set(self, "function", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="regexp")
    def regexp(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "regexp"))

    @regexp.setter
    def regexp(self, value: builtins.str) -> None:
        jsii.set(self, "regexp", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterClickhouseConfigGraphiteRollupPattern]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterClickhouseConfigGraphiteRollupPattern]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterClickhouseConfigGraphiteRollupPattern]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetention",
    jsii_struct_bases=[],
    name_mapping={"age": "age", "precision": "precision"},
)
class MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetention:
    def __init__(self, *, age: jsii.Number, precision: jsii.Number) -> None:
        '''
        :param age: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#age MdbClickhouseCluster#age}.
        :param precision: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#precision MdbClickhouseCluster#precision}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "age": age,
            "precision": precision,
        }

    @builtins.property
    def age(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#age MdbClickhouseCluster#age}.'''
        result = self._values.get("age")
        assert result is not None, "Required property 'age' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def precision(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#precision MdbClickhouseCluster#precision}.'''
        result = self._values.get("precision")
        assert result is not None, "Required property 'precision' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetention(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetentionList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetentionList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetentionOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetentionOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetention]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetention]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetention]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetentionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetentionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ageInput")
    def age_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "ageInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="precisionInput")
    def precision_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "precisionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="age")
    def age(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "age"))

    @age.setter
    def age(self, value: jsii.Number) -> None:
        jsii.set(self, "age", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="precision")
    def precision(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "precision"))

    @precision.setter
    def precision(self, value: jsii.Number) -> None:
        jsii.set(self, "precision", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetention]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetention]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetention]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterClickhouseConfigKafka",
    jsii_struct_bases=[],
    name_mapping={
        "sasl_mechanism": "saslMechanism",
        "sasl_password": "saslPassword",
        "sasl_username": "saslUsername",
        "security_protocol": "securityProtocol",
    },
)
class MdbClickhouseClusterClickhouseConfigKafka:
    def __init__(
        self,
        *,
        sasl_mechanism: typing.Optional[builtins.str] = None,
        sasl_password: typing.Optional[builtins.str] = None,
        sasl_username: typing.Optional[builtins.str] = None,
        security_protocol: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param sasl_mechanism: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#sasl_mechanism MdbClickhouseCluster#sasl_mechanism}.
        :param sasl_password: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#sasl_password MdbClickhouseCluster#sasl_password}.
        :param sasl_username: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#sasl_username MdbClickhouseCluster#sasl_username}.
        :param security_protocol: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#security_protocol MdbClickhouseCluster#security_protocol}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if sasl_mechanism is not None:
            self._values["sasl_mechanism"] = sasl_mechanism
        if sasl_password is not None:
            self._values["sasl_password"] = sasl_password
        if sasl_username is not None:
            self._values["sasl_username"] = sasl_username
        if security_protocol is not None:
            self._values["security_protocol"] = security_protocol

    @builtins.property
    def sasl_mechanism(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#sasl_mechanism MdbClickhouseCluster#sasl_mechanism}.'''
        result = self._values.get("sasl_mechanism")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def sasl_password(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#sasl_password MdbClickhouseCluster#sasl_password}.'''
        result = self._values.get("sasl_password")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def sasl_username(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#sasl_username MdbClickhouseCluster#sasl_username}.'''
        result = self._values.get("sasl_username")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def security_protocol(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#security_protocol MdbClickhouseCluster#security_protocol}.'''
        result = self._values.get("security_protocol")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbClickhouseClusterClickhouseConfigKafka(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbClickhouseClusterClickhouseConfigKafkaOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterClickhouseConfigKafkaOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetSaslMechanism")
    def reset_sasl_mechanism(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSaslMechanism", []))

    @jsii.member(jsii_name="resetSaslPassword")
    def reset_sasl_password(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSaslPassword", []))

    @jsii.member(jsii_name="resetSaslUsername")
    def reset_sasl_username(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSaslUsername", []))

    @jsii.member(jsii_name="resetSecurityProtocol")
    def reset_security_protocol(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityProtocol", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslMechanismInput")
    def sasl_mechanism_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "saslMechanismInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslPasswordInput")
    def sasl_password_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "saslPasswordInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslUsernameInput")
    def sasl_username_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "saslUsernameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityProtocolInput")
    def security_protocol_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "securityProtocolInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslMechanism")
    def sasl_mechanism(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "saslMechanism"))

    @sasl_mechanism.setter
    def sasl_mechanism(self, value: builtins.str) -> None:
        jsii.set(self, "saslMechanism", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslPassword")
    def sasl_password(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "saslPassword"))

    @sasl_password.setter
    def sasl_password(self, value: builtins.str) -> None:
        jsii.set(self, "saslPassword", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslUsername")
    def sasl_username(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "saslUsername"))

    @sasl_username.setter
    def sasl_username(self, value: builtins.str) -> None:
        jsii.set(self, "saslUsername", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityProtocol")
    def security_protocol(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "securityProtocol"))

    @security_protocol.setter
    def security_protocol(self, value: builtins.str) -> None:
        jsii.set(self, "securityProtocol", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[MdbClickhouseClusterClickhouseConfigKafka]:
        return typing.cast(typing.Optional[MdbClickhouseClusterClickhouseConfigKafka], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbClickhouseClusterClickhouseConfigKafka],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterClickhouseConfigKafkaTopic",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "settings": "settings"},
)
class MdbClickhouseClusterClickhouseConfigKafkaTopic:
    def __init__(
        self,
        *,
        name: builtins.str,
        settings: typing.Optional["MdbClickhouseClusterClickhouseConfigKafkaTopicSettings"] = None,
    ) -> None:
        '''
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#name MdbClickhouseCluster#name}.
        :param settings: settings block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#settings MdbClickhouseCluster#settings}
        '''
        if isinstance(settings, dict):
            settings = MdbClickhouseClusterClickhouseConfigKafkaTopicSettings(**settings)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }
        if settings is not None:
            self._values["settings"] = settings

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#name MdbClickhouseCluster#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def settings(
        self,
    ) -> typing.Optional["MdbClickhouseClusterClickhouseConfigKafkaTopicSettings"]:
        '''settings block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#settings MdbClickhouseCluster#settings}
        '''
        result = self._values.get("settings")
        return typing.cast(typing.Optional["MdbClickhouseClusterClickhouseConfigKafkaTopicSettings"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbClickhouseClusterClickhouseConfigKafkaTopic(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbClickhouseClusterClickhouseConfigKafkaTopicList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterClickhouseConfigKafkaTopicList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "MdbClickhouseClusterClickhouseConfigKafkaTopicOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbClickhouseClusterClickhouseConfigKafkaTopicOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterClickhouseConfigKafkaTopic]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterClickhouseConfigKafkaTopic]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterClickhouseConfigKafkaTopic]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbClickhouseClusterClickhouseConfigKafkaTopicOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterClickhouseConfigKafkaTopicOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSettings")
    def put_settings(
        self,
        *,
        sasl_mechanism: typing.Optional[builtins.str] = None,
        sasl_password: typing.Optional[builtins.str] = None,
        sasl_username: typing.Optional[builtins.str] = None,
        security_protocol: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param sasl_mechanism: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#sasl_mechanism MdbClickhouseCluster#sasl_mechanism}.
        :param sasl_password: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#sasl_password MdbClickhouseCluster#sasl_password}.
        :param sasl_username: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#sasl_username MdbClickhouseCluster#sasl_username}.
        :param security_protocol: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#security_protocol MdbClickhouseCluster#security_protocol}.
        '''
        value = MdbClickhouseClusterClickhouseConfigKafkaTopicSettings(
            sasl_mechanism=sasl_mechanism,
            sasl_password=sasl_password,
            sasl_username=sasl_username,
            security_protocol=security_protocol,
        )

        return typing.cast(None, jsii.invoke(self, "putSettings", [value]))

    @jsii.member(jsii_name="resetSettings")
    def reset_settings(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSettings", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="settings")
    def settings(
        self,
    ) -> "MdbClickhouseClusterClickhouseConfigKafkaTopicSettingsOutputReference":
        return typing.cast("MdbClickhouseClusterClickhouseConfigKafkaTopicSettingsOutputReference", jsii.get(self, "settings"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="settingsInput")
    def settings_input(
        self,
    ) -> typing.Optional["MdbClickhouseClusterClickhouseConfigKafkaTopicSettings"]:
        return typing.cast(typing.Optional["MdbClickhouseClusterClickhouseConfigKafkaTopicSettings"], jsii.get(self, "settingsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterClickhouseConfigKafkaTopic]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterClickhouseConfigKafkaTopic]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterClickhouseConfigKafkaTopic]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterClickhouseConfigKafkaTopicSettings",
    jsii_struct_bases=[],
    name_mapping={
        "sasl_mechanism": "saslMechanism",
        "sasl_password": "saslPassword",
        "sasl_username": "saslUsername",
        "security_protocol": "securityProtocol",
    },
)
class MdbClickhouseClusterClickhouseConfigKafkaTopicSettings:
    def __init__(
        self,
        *,
        sasl_mechanism: typing.Optional[builtins.str] = None,
        sasl_password: typing.Optional[builtins.str] = None,
        sasl_username: typing.Optional[builtins.str] = None,
        security_protocol: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param sasl_mechanism: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#sasl_mechanism MdbClickhouseCluster#sasl_mechanism}.
        :param sasl_password: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#sasl_password MdbClickhouseCluster#sasl_password}.
        :param sasl_username: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#sasl_username MdbClickhouseCluster#sasl_username}.
        :param security_protocol: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#security_protocol MdbClickhouseCluster#security_protocol}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if sasl_mechanism is not None:
            self._values["sasl_mechanism"] = sasl_mechanism
        if sasl_password is not None:
            self._values["sasl_password"] = sasl_password
        if sasl_username is not None:
            self._values["sasl_username"] = sasl_username
        if security_protocol is not None:
            self._values["security_protocol"] = security_protocol

    @builtins.property
    def sasl_mechanism(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#sasl_mechanism MdbClickhouseCluster#sasl_mechanism}.'''
        result = self._values.get("sasl_mechanism")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def sasl_password(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#sasl_password MdbClickhouseCluster#sasl_password}.'''
        result = self._values.get("sasl_password")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def sasl_username(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#sasl_username MdbClickhouseCluster#sasl_username}.'''
        result = self._values.get("sasl_username")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def security_protocol(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#security_protocol MdbClickhouseCluster#security_protocol}.'''
        result = self._values.get("security_protocol")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbClickhouseClusterClickhouseConfigKafkaTopicSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbClickhouseClusterClickhouseConfigKafkaTopicSettingsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterClickhouseConfigKafkaTopicSettingsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetSaslMechanism")
    def reset_sasl_mechanism(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSaslMechanism", []))

    @jsii.member(jsii_name="resetSaslPassword")
    def reset_sasl_password(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSaslPassword", []))

    @jsii.member(jsii_name="resetSaslUsername")
    def reset_sasl_username(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSaslUsername", []))

    @jsii.member(jsii_name="resetSecurityProtocol")
    def reset_security_protocol(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityProtocol", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslMechanismInput")
    def sasl_mechanism_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "saslMechanismInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslPasswordInput")
    def sasl_password_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "saslPasswordInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslUsernameInput")
    def sasl_username_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "saslUsernameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityProtocolInput")
    def security_protocol_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "securityProtocolInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslMechanism")
    def sasl_mechanism(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "saslMechanism"))

    @sasl_mechanism.setter
    def sasl_mechanism(self, value: builtins.str) -> None:
        jsii.set(self, "saslMechanism", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslPassword")
    def sasl_password(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "saslPassword"))

    @sasl_password.setter
    def sasl_password(self, value: builtins.str) -> None:
        jsii.set(self, "saslPassword", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslUsername")
    def sasl_username(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "saslUsername"))

    @sasl_username.setter
    def sasl_username(self, value: builtins.str) -> None:
        jsii.set(self, "saslUsername", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityProtocol")
    def security_protocol(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "securityProtocol"))

    @security_protocol.setter
    def security_protocol(self, value: builtins.str) -> None:
        jsii.set(self, "securityProtocol", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[MdbClickhouseClusterClickhouseConfigKafkaTopicSettings]:
        return typing.cast(typing.Optional[MdbClickhouseClusterClickhouseConfigKafkaTopicSettings], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbClickhouseClusterClickhouseConfigKafkaTopicSettings],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterClickhouseConfigMergeTree",
    jsii_struct_bases=[],
    name_mapping={
        "max_bytes_to_merge_at_min_space_in_pool": "maxBytesToMergeAtMinSpaceInPool",
        "max_replicated_merges_in_queue": "maxReplicatedMergesInQueue",
        "number_of_free_entries_in_pool_to_lower_max_size_of_merge": "numberOfFreeEntriesInPoolToLowerMaxSizeOfMerge",
        "parts_to_delay_insert": "partsToDelayInsert",
        "parts_to_throw_insert": "partsToThrowInsert",
        "replicated_deduplication_window": "replicatedDeduplicationWindow",
        "replicated_deduplication_window_seconds": "replicatedDeduplicationWindowSeconds",
    },
)
class MdbClickhouseClusterClickhouseConfigMergeTree:
    def __init__(
        self,
        *,
        max_bytes_to_merge_at_min_space_in_pool: typing.Optional[jsii.Number] = None,
        max_replicated_merges_in_queue: typing.Optional[jsii.Number] = None,
        number_of_free_entries_in_pool_to_lower_max_size_of_merge: typing.Optional[jsii.Number] = None,
        parts_to_delay_insert: typing.Optional[jsii.Number] = None,
        parts_to_throw_insert: typing.Optional[jsii.Number] = None,
        replicated_deduplication_window: typing.Optional[jsii.Number] = None,
        replicated_deduplication_window_seconds: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param max_bytes_to_merge_at_min_space_in_pool: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_bytes_to_merge_at_min_space_in_pool MdbClickhouseCluster#max_bytes_to_merge_at_min_space_in_pool}.
        :param max_replicated_merges_in_queue: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_replicated_merges_in_queue MdbClickhouseCluster#max_replicated_merges_in_queue}.
        :param number_of_free_entries_in_pool_to_lower_max_size_of_merge: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#number_of_free_entries_in_pool_to_lower_max_size_of_merge MdbClickhouseCluster#number_of_free_entries_in_pool_to_lower_max_size_of_merge}.
        :param parts_to_delay_insert: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#parts_to_delay_insert MdbClickhouseCluster#parts_to_delay_insert}.
        :param parts_to_throw_insert: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#parts_to_throw_insert MdbClickhouseCluster#parts_to_throw_insert}.
        :param replicated_deduplication_window: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#replicated_deduplication_window MdbClickhouseCluster#replicated_deduplication_window}.
        :param replicated_deduplication_window_seconds: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#replicated_deduplication_window_seconds MdbClickhouseCluster#replicated_deduplication_window_seconds}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if max_bytes_to_merge_at_min_space_in_pool is not None:
            self._values["max_bytes_to_merge_at_min_space_in_pool"] = max_bytes_to_merge_at_min_space_in_pool
        if max_replicated_merges_in_queue is not None:
            self._values["max_replicated_merges_in_queue"] = max_replicated_merges_in_queue
        if number_of_free_entries_in_pool_to_lower_max_size_of_merge is not None:
            self._values["number_of_free_entries_in_pool_to_lower_max_size_of_merge"] = number_of_free_entries_in_pool_to_lower_max_size_of_merge
        if parts_to_delay_insert is not None:
            self._values["parts_to_delay_insert"] = parts_to_delay_insert
        if parts_to_throw_insert is not None:
            self._values["parts_to_throw_insert"] = parts_to_throw_insert
        if replicated_deduplication_window is not None:
            self._values["replicated_deduplication_window"] = replicated_deduplication_window
        if replicated_deduplication_window_seconds is not None:
            self._values["replicated_deduplication_window_seconds"] = replicated_deduplication_window_seconds

    @builtins.property
    def max_bytes_to_merge_at_min_space_in_pool(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_bytes_to_merge_at_min_space_in_pool MdbClickhouseCluster#max_bytes_to_merge_at_min_space_in_pool}.'''
        result = self._values.get("max_bytes_to_merge_at_min_space_in_pool")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_replicated_merges_in_queue(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_replicated_merges_in_queue MdbClickhouseCluster#max_replicated_merges_in_queue}.'''
        result = self._values.get("max_replicated_merges_in_queue")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def number_of_free_entries_in_pool_to_lower_max_size_of_merge(
        self,
    ) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#number_of_free_entries_in_pool_to_lower_max_size_of_merge MdbClickhouseCluster#number_of_free_entries_in_pool_to_lower_max_size_of_merge}.'''
        result = self._values.get("number_of_free_entries_in_pool_to_lower_max_size_of_merge")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def parts_to_delay_insert(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#parts_to_delay_insert MdbClickhouseCluster#parts_to_delay_insert}.'''
        result = self._values.get("parts_to_delay_insert")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def parts_to_throw_insert(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#parts_to_throw_insert MdbClickhouseCluster#parts_to_throw_insert}.'''
        result = self._values.get("parts_to_throw_insert")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def replicated_deduplication_window(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#replicated_deduplication_window MdbClickhouseCluster#replicated_deduplication_window}.'''
        result = self._values.get("replicated_deduplication_window")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def replicated_deduplication_window_seconds(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#replicated_deduplication_window_seconds MdbClickhouseCluster#replicated_deduplication_window_seconds}.'''
        result = self._values.get("replicated_deduplication_window_seconds")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbClickhouseClusterClickhouseConfigMergeTree(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbClickhouseClusterClickhouseConfigMergeTreeOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterClickhouseConfigMergeTreeOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetMaxBytesToMergeAtMinSpaceInPool")
    def reset_max_bytes_to_merge_at_min_space_in_pool(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxBytesToMergeAtMinSpaceInPool", []))

    @jsii.member(jsii_name="resetMaxReplicatedMergesInQueue")
    def reset_max_replicated_merges_in_queue(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxReplicatedMergesInQueue", []))

    @jsii.member(jsii_name="resetNumberOfFreeEntriesInPoolToLowerMaxSizeOfMerge")
    def reset_number_of_free_entries_in_pool_to_lower_max_size_of_merge(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNumberOfFreeEntriesInPoolToLowerMaxSizeOfMerge", []))

    @jsii.member(jsii_name="resetPartsToDelayInsert")
    def reset_parts_to_delay_insert(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPartsToDelayInsert", []))

    @jsii.member(jsii_name="resetPartsToThrowInsert")
    def reset_parts_to_throw_insert(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPartsToThrowInsert", []))

    @jsii.member(jsii_name="resetReplicatedDeduplicationWindow")
    def reset_replicated_deduplication_window(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetReplicatedDeduplicationWindow", []))

    @jsii.member(jsii_name="resetReplicatedDeduplicationWindowSeconds")
    def reset_replicated_deduplication_window_seconds(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetReplicatedDeduplicationWindowSeconds", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxBytesToMergeAtMinSpaceInPoolInput")
    def max_bytes_to_merge_at_min_space_in_pool_input(
        self,
    ) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxBytesToMergeAtMinSpaceInPoolInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxReplicatedMergesInQueueInput")
    def max_replicated_merges_in_queue_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxReplicatedMergesInQueueInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="numberOfFreeEntriesInPoolToLowerMaxSizeOfMergeInput")
    def number_of_free_entries_in_pool_to_lower_max_size_of_merge_input(
        self,
    ) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "numberOfFreeEntriesInPoolToLowerMaxSizeOfMergeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="partsToDelayInsertInput")
    def parts_to_delay_insert_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "partsToDelayInsertInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="partsToThrowInsertInput")
    def parts_to_throw_insert_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "partsToThrowInsertInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replicatedDeduplicationWindowInput")
    def replicated_deduplication_window_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "replicatedDeduplicationWindowInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replicatedDeduplicationWindowSecondsInput")
    def replicated_deduplication_window_seconds_input(
        self,
    ) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "replicatedDeduplicationWindowSecondsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxBytesToMergeAtMinSpaceInPool")
    def max_bytes_to_merge_at_min_space_in_pool(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxBytesToMergeAtMinSpaceInPool"))

    @max_bytes_to_merge_at_min_space_in_pool.setter
    def max_bytes_to_merge_at_min_space_in_pool(self, value: jsii.Number) -> None:
        jsii.set(self, "maxBytesToMergeAtMinSpaceInPool", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxReplicatedMergesInQueue")
    def max_replicated_merges_in_queue(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxReplicatedMergesInQueue"))

    @max_replicated_merges_in_queue.setter
    def max_replicated_merges_in_queue(self, value: jsii.Number) -> None:
        jsii.set(self, "maxReplicatedMergesInQueue", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="numberOfFreeEntriesInPoolToLowerMaxSizeOfMerge")
    def number_of_free_entries_in_pool_to_lower_max_size_of_merge(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "numberOfFreeEntriesInPoolToLowerMaxSizeOfMerge"))

    @number_of_free_entries_in_pool_to_lower_max_size_of_merge.setter
    def number_of_free_entries_in_pool_to_lower_max_size_of_merge(
        self,
        value: jsii.Number,
    ) -> None:
        jsii.set(self, "numberOfFreeEntriesInPoolToLowerMaxSizeOfMerge", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="partsToDelayInsert")
    def parts_to_delay_insert(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "partsToDelayInsert"))

    @parts_to_delay_insert.setter
    def parts_to_delay_insert(self, value: jsii.Number) -> None:
        jsii.set(self, "partsToDelayInsert", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="partsToThrowInsert")
    def parts_to_throw_insert(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "partsToThrowInsert"))

    @parts_to_throw_insert.setter
    def parts_to_throw_insert(self, value: jsii.Number) -> None:
        jsii.set(self, "partsToThrowInsert", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replicatedDeduplicationWindow")
    def replicated_deduplication_window(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "replicatedDeduplicationWindow"))

    @replicated_deduplication_window.setter
    def replicated_deduplication_window(self, value: jsii.Number) -> None:
        jsii.set(self, "replicatedDeduplicationWindow", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replicatedDeduplicationWindowSeconds")
    def replicated_deduplication_window_seconds(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "replicatedDeduplicationWindowSeconds"))

    @replicated_deduplication_window_seconds.setter
    def replicated_deduplication_window_seconds(self, value: jsii.Number) -> None:
        jsii.set(self, "replicatedDeduplicationWindowSeconds", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[MdbClickhouseClusterClickhouseConfigMergeTree]:
        return typing.cast(typing.Optional[MdbClickhouseClusterClickhouseConfigMergeTree], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbClickhouseClusterClickhouseConfigMergeTree],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbClickhouseClusterClickhouseConfigOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterClickhouseConfigOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putCompression")
    def put_compression(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence[MdbClickhouseClusterClickhouseConfigCompression]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putCompression", [value]))

    @jsii.member(jsii_name="putGraphiteRollup")
    def put_graphite_rollup(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence[MdbClickhouseClusterClickhouseConfigGraphiteRollup]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putGraphiteRollup", [value]))

    @jsii.member(jsii_name="putKafka")
    def put_kafka(
        self,
        *,
        sasl_mechanism: typing.Optional[builtins.str] = None,
        sasl_password: typing.Optional[builtins.str] = None,
        sasl_username: typing.Optional[builtins.str] = None,
        security_protocol: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param sasl_mechanism: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#sasl_mechanism MdbClickhouseCluster#sasl_mechanism}.
        :param sasl_password: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#sasl_password MdbClickhouseCluster#sasl_password}.
        :param sasl_username: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#sasl_username MdbClickhouseCluster#sasl_username}.
        :param security_protocol: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#security_protocol MdbClickhouseCluster#security_protocol}.
        '''
        value = MdbClickhouseClusterClickhouseConfigKafka(
            sasl_mechanism=sasl_mechanism,
            sasl_password=sasl_password,
            sasl_username=sasl_username,
            security_protocol=security_protocol,
        )

        return typing.cast(None, jsii.invoke(self, "putKafka", [value]))

    @jsii.member(jsii_name="putKafkaTopic")
    def put_kafka_topic(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence[MdbClickhouseClusterClickhouseConfigKafkaTopic]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putKafkaTopic", [value]))

    @jsii.member(jsii_name="putMergeTree")
    def put_merge_tree(
        self,
        *,
        max_bytes_to_merge_at_min_space_in_pool: typing.Optional[jsii.Number] = None,
        max_replicated_merges_in_queue: typing.Optional[jsii.Number] = None,
        number_of_free_entries_in_pool_to_lower_max_size_of_merge: typing.Optional[jsii.Number] = None,
        parts_to_delay_insert: typing.Optional[jsii.Number] = None,
        parts_to_throw_insert: typing.Optional[jsii.Number] = None,
        replicated_deduplication_window: typing.Optional[jsii.Number] = None,
        replicated_deduplication_window_seconds: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param max_bytes_to_merge_at_min_space_in_pool: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_bytes_to_merge_at_min_space_in_pool MdbClickhouseCluster#max_bytes_to_merge_at_min_space_in_pool}.
        :param max_replicated_merges_in_queue: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_replicated_merges_in_queue MdbClickhouseCluster#max_replicated_merges_in_queue}.
        :param number_of_free_entries_in_pool_to_lower_max_size_of_merge: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#number_of_free_entries_in_pool_to_lower_max_size_of_merge MdbClickhouseCluster#number_of_free_entries_in_pool_to_lower_max_size_of_merge}.
        :param parts_to_delay_insert: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#parts_to_delay_insert MdbClickhouseCluster#parts_to_delay_insert}.
        :param parts_to_throw_insert: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#parts_to_throw_insert MdbClickhouseCluster#parts_to_throw_insert}.
        :param replicated_deduplication_window: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#replicated_deduplication_window MdbClickhouseCluster#replicated_deduplication_window}.
        :param replicated_deduplication_window_seconds: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#replicated_deduplication_window_seconds MdbClickhouseCluster#replicated_deduplication_window_seconds}.
        '''
        value = MdbClickhouseClusterClickhouseConfigMergeTree(
            max_bytes_to_merge_at_min_space_in_pool=max_bytes_to_merge_at_min_space_in_pool,
            max_replicated_merges_in_queue=max_replicated_merges_in_queue,
            number_of_free_entries_in_pool_to_lower_max_size_of_merge=number_of_free_entries_in_pool_to_lower_max_size_of_merge,
            parts_to_delay_insert=parts_to_delay_insert,
            parts_to_throw_insert=parts_to_throw_insert,
            replicated_deduplication_window=replicated_deduplication_window,
            replicated_deduplication_window_seconds=replicated_deduplication_window_seconds,
        )

        return typing.cast(None, jsii.invoke(self, "putMergeTree", [value]))

    @jsii.member(jsii_name="putRabbitmq")
    def put_rabbitmq(
        self,
        *,
        password: typing.Optional[builtins.str] = None,
        username: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param password: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#password MdbClickhouseCluster#password}.
        :param username: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#username MdbClickhouseCluster#username}.
        '''
        value = MdbClickhouseClusterClickhouseConfigRabbitmq(
            password=password, username=username
        )

        return typing.cast(None, jsii.invoke(self, "putRabbitmq", [value]))

    @jsii.member(jsii_name="resetBackgroundPoolSize")
    def reset_background_pool_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetBackgroundPoolSize", []))

    @jsii.member(jsii_name="resetBackgroundSchedulePoolSize")
    def reset_background_schedule_pool_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetBackgroundSchedulePoolSize", []))

    @jsii.member(jsii_name="resetCompression")
    def reset_compression(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCompression", []))

    @jsii.member(jsii_name="resetGeobaseUri")
    def reset_geobase_uri(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGeobaseUri", []))

    @jsii.member(jsii_name="resetGraphiteRollup")
    def reset_graphite_rollup(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGraphiteRollup", []))

    @jsii.member(jsii_name="resetKafka")
    def reset_kafka(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetKafka", []))

    @jsii.member(jsii_name="resetKafkaTopic")
    def reset_kafka_topic(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetKafkaTopic", []))

    @jsii.member(jsii_name="resetKeepAliveTimeout")
    def reset_keep_alive_timeout(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetKeepAliveTimeout", []))

    @jsii.member(jsii_name="resetLogLevel")
    def reset_log_level(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogLevel", []))

    @jsii.member(jsii_name="resetMarkCacheSize")
    def reset_mark_cache_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMarkCacheSize", []))

    @jsii.member(jsii_name="resetMaxConcurrentQueries")
    def reset_max_concurrent_queries(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxConcurrentQueries", []))

    @jsii.member(jsii_name="resetMaxConnections")
    def reset_max_connections(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxConnections", []))

    @jsii.member(jsii_name="resetMaxPartitionSizeToDrop")
    def reset_max_partition_size_to_drop(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxPartitionSizeToDrop", []))

    @jsii.member(jsii_name="resetMaxTableSizeToDrop")
    def reset_max_table_size_to_drop(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxTableSizeToDrop", []))

    @jsii.member(jsii_name="resetMergeTree")
    def reset_merge_tree(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMergeTree", []))

    @jsii.member(jsii_name="resetMetricLogEnabled")
    def reset_metric_log_enabled(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetricLogEnabled", []))

    @jsii.member(jsii_name="resetMetricLogRetentionSize")
    def reset_metric_log_retention_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetricLogRetentionSize", []))

    @jsii.member(jsii_name="resetMetricLogRetentionTime")
    def reset_metric_log_retention_time(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMetricLogRetentionTime", []))

    @jsii.member(jsii_name="resetPartLogRetentionSize")
    def reset_part_log_retention_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPartLogRetentionSize", []))

    @jsii.member(jsii_name="resetPartLogRetentionTime")
    def reset_part_log_retention_time(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPartLogRetentionTime", []))

    @jsii.member(jsii_name="resetQueryLogRetentionSize")
    def reset_query_log_retention_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQueryLogRetentionSize", []))

    @jsii.member(jsii_name="resetQueryLogRetentionTime")
    def reset_query_log_retention_time(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQueryLogRetentionTime", []))

    @jsii.member(jsii_name="resetQueryThreadLogEnabled")
    def reset_query_thread_log_enabled(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQueryThreadLogEnabled", []))

    @jsii.member(jsii_name="resetQueryThreadLogRetentionSize")
    def reset_query_thread_log_retention_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQueryThreadLogRetentionSize", []))

    @jsii.member(jsii_name="resetQueryThreadLogRetentionTime")
    def reset_query_thread_log_retention_time(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQueryThreadLogRetentionTime", []))

    @jsii.member(jsii_name="resetRabbitmq")
    def reset_rabbitmq(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRabbitmq", []))

    @jsii.member(jsii_name="resetTextLogEnabled")
    def reset_text_log_enabled(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTextLogEnabled", []))

    @jsii.member(jsii_name="resetTextLogLevel")
    def reset_text_log_level(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTextLogLevel", []))

    @jsii.member(jsii_name="resetTextLogRetentionSize")
    def reset_text_log_retention_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTextLogRetentionSize", []))

    @jsii.member(jsii_name="resetTextLogRetentionTime")
    def reset_text_log_retention_time(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTextLogRetentionTime", []))

    @jsii.member(jsii_name="resetTimezone")
    def reset_timezone(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimezone", []))

    @jsii.member(jsii_name="resetTraceLogEnabled")
    def reset_trace_log_enabled(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTraceLogEnabled", []))

    @jsii.member(jsii_name="resetTraceLogRetentionSize")
    def reset_trace_log_retention_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTraceLogRetentionSize", []))

    @jsii.member(jsii_name="resetTraceLogRetentionTime")
    def reset_trace_log_retention_time(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTraceLogRetentionTime", []))

    @jsii.member(jsii_name="resetUncompressedCacheSize")
    def reset_uncompressed_cache_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUncompressedCacheSize", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="compression")
    def compression(self) -> MdbClickhouseClusterClickhouseConfigCompressionList:
        return typing.cast(MdbClickhouseClusterClickhouseConfigCompressionList, jsii.get(self, "compression"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="graphiteRollup")
    def graphite_rollup(self) -> MdbClickhouseClusterClickhouseConfigGraphiteRollupList:
        return typing.cast(MdbClickhouseClusterClickhouseConfigGraphiteRollupList, jsii.get(self, "graphiteRollup"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="kafka")
    def kafka(self) -> MdbClickhouseClusterClickhouseConfigKafkaOutputReference:
        return typing.cast(MdbClickhouseClusterClickhouseConfigKafkaOutputReference, jsii.get(self, "kafka"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="kafkaTopic")
    def kafka_topic(self) -> MdbClickhouseClusterClickhouseConfigKafkaTopicList:
        return typing.cast(MdbClickhouseClusterClickhouseConfigKafkaTopicList, jsii.get(self, "kafkaTopic"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mergeTree")
    def merge_tree(
        self,
    ) -> MdbClickhouseClusterClickhouseConfigMergeTreeOutputReference:
        return typing.cast(MdbClickhouseClusterClickhouseConfigMergeTreeOutputReference, jsii.get(self, "mergeTree"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="rabbitmq")
    def rabbitmq(self) -> "MdbClickhouseClusterClickhouseConfigRabbitmqOutputReference":
        return typing.cast("MdbClickhouseClusterClickhouseConfigRabbitmqOutputReference", jsii.get(self, "rabbitmq"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backgroundPoolSizeInput")
    def background_pool_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "backgroundPoolSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backgroundSchedulePoolSizeInput")
    def background_schedule_pool_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "backgroundSchedulePoolSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="compressionInput")
    def compression_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterClickhouseConfigCompression]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterClickhouseConfigCompression]]], jsii.get(self, "compressionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="geobaseUriInput")
    def geobase_uri_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "geobaseUriInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="graphiteRollupInput")
    def graphite_rollup_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterClickhouseConfigGraphiteRollup]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterClickhouseConfigGraphiteRollup]]], jsii.get(self, "graphiteRollupInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="kafkaInput")
    def kafka_input(self) -> typing.Optional[MdbClickhouseClusterClickhouseConfigKafka]:
        return typing.cast(typing.Optional[MdbClickhouseClusterClickhouseConfigKafka], jsii.get(self, "kafkaInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="kafkaTopicInput")
    def kafka_topic_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterClickhouseConfigKafkaTopic]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterClickhouseConfigKafkaTopic]]], jsii.get(self, "kafkaTopicInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="keepAliveTimeoutInput")
    def keep_alive_timeout_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "keepAliveTimeoutInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logLevelInput")
    def log_level_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "logLevelInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="markCacheSizeInput")
    def mark_cache_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "markCacheSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxConcurrentQueriesInput")
    def max_concurrent_queries_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxConcurrentQueriesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxConnectionsInput")
    def max_connections_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxConnectionsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxPartitionSizeToDropInput")
    def max_partition_size_to_drop_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxPartitionSizeToDropInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxTableSizeToDropInput")
    def max_table_size_to_drop_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxTableSizeToDropInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mergeTreeInput")
    def merge_tree_input(
        self,
    ) -> typing.Optional[MdbClickhouseClusterClickhouseConfigMergeTree]:
        return typing.cast(typing.Optional[MdbClickhouseClusterClickhouseConfigMergeTree], jsii.get(self, "mergeTreeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricLogEnabledInput")
    def metric_log_enabled_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "metricLogEnabledInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricLogRetentionSizeInput")
    def metric_log_retention_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "metricLogRetentionSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricLogRetentionTimeInput")
    def metric_log_retention_time_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "metricLogRetentionTimeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="partLogRetentionSizeInput")
    def part_log_retention_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "partLogRetentionSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="partLogRetentionTimeInput")
    def part_log_retention_time_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "partLogRetentionTimeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queryLogRetentionSizeInput")
    def query_log_retention_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "queryLogRetentionSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queryLogRetentionTimeInput")
    def query_log_retention_time_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "queryLogRetentionTimeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queryThreadLogEnabledInput")
    def query_thread_log_enabled_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "queryThreadLogEnabledInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queryThreadLogRetentionSizeInput")
    def query_thread_log_retention_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "queryThreadLogRetentionSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queryThreadLogRetentionTimeInput")
    def query_thread_log_retention_time_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "queryThreadLogRetentionTimeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="rabbitmqInput")
    def rabbitmq_input(
        self,
    ) -> typing.Optional["MdbClickhouseClusterClickhouseConfigRabbitmq"]:
        return typing.cast(typing.Optional["MdbClickhouseClusterClickhouseConfigRabbitmq"], jsii.get(self, "rabbitmqInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="textLogEnabledInput")
    def text_log_enabled_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "textLogEnabledInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="textLogLevelInput")
    def text_log_level_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "textLogLevelInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="textLogRetentionSizeInput")
    def text_log_retention_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "textLogRetentionSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="textLogRetentionTimeInput")
    def text_log_retention_time_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "textLogRetentionTimeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timezoneInput")
    def timezone_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "timezoneInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="traceLogEnabledInput")
    def trace_log_enabled_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "traceLogEnabledInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="traceLogRetentionSizeInput")
    def trace_log_retention_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "traceLogRetentionSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="traceLogRetentionTimeInput")
    def trace_log_retention_time_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "traceLogRetentionTimeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="uncompressedCacheSizeInput")
    def uncompressed_cache_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "uncompressedCacheSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backgroundPoolSize")
    def background_pool_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "backgroundPoolSize"))

    @background_pool_size.setter
    def background_pool_size(self, value: jsii.Number) -> None:
        jsii.set(self, "backgroundPoolSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backgroundSchedulePoolSize")
    def background_schedule_pool_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "backgroundSchedulePoolSize"))

    @background_schedule_pool_size.setter
    def background_schedule_pool_size(self, value: jsii.Number) -> None:
        jsii.set(self, "backgroundSchedulePoolSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="geobaseUri")
    def geobase_uri(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "geobaseUri"))

    @geobase_uri.setter
    def geobase_uri(self, value: builtins.str) -> None:
        jsii.set(self, "geobaseUri", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="keepAliveTimeout")
    def keep_alive_timeout(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "keepAliveTimeout"))

    @keep_alive_timeout.setter
    def keep_alive_timeout(self, value: jsii.Number) -> None:
        jsii.set(self, "keepAliveTimeout", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logLevel")
    def log_level(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "logLevel"))

    @log_level.setter
    def log_level(self, value: builtins.str) -> None:
        jsii.set(self, "logLevel", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="markCacheSize")
    def mark_cache_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "markCacheSize"))

    @mark_cache_size.setter
    def mark_cache_size(self, value: jsii.Number) -> None:
        jsii.set(self, "markCacheSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxConcurrentQueries")
    def max_concurrent_queries(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxConcurrentQueries"))

    @max_concurrent_queries.setter
    def max_concurrent_queries(self, value: jsii.Number) -> None:
        jsii.set(self, "maxConcurrentQueries", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxConnections")
    def max_connections(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxConnections"))

    @max_connections.setter
    def max_connections(self, value: jsii.Number) -> None:
        jsii.set(self, "maxConnections", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxPartitionSizeToDrop")
    def max_partition_size_to_drop(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxPartitionSizeToDrop"))

    @max_partition_size_to_drop.setter
    def max_partition_size_to_drop(self, value: jsii.Number) -> None:
        jsii.set(self, "maxPartitionSizeToDrop", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxTableSizeToDrop")
    def max_table_size_to_drop(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxTableSizeToDrop"))

    @max_table_size_to_drop.setter
    def max_table_size_to_drop(self, value: jsii.Number) -> None:
        jsii.set(self, "maxTableSizeToDrop", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricLogEnabled")
    def metric_log_enabled(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "metricLogEnabled"))

    @metric_log_enabled.setter
    def metric_log_enabled(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "metricLogEnabled", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricLogRetentionSize")
    def metric_log_retention_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "metricLogRetentionSize"))

    @metric_log_retention_size.setter
    def metric_log_retention_size(self, value: jsii.Number) -> None:
        jsii.set(self, "metricLogRetentionSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricLogRetentionTime")
    def metric_log_retention_time(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "metricLogRetentionTime"))

    @metric_log_retention_time.setter
    def metric_log_retention_time(self, value: jsii.Number) -> None:
        jsii.set(self, "metricLogRetentionTime", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="partLogRetentionSize")
    def part_log_retention_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "partLogRetentionSize"))

    @part_log_retention_size.setter
    def part_log_retention_size(self, value: jsii.Number) -> None:
        jsii.set(self, "partLogRetentionSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="partLogRetentionTime")
    def part_log_retention_time(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "partLogRetentionTime"))

    @part_log_retention_time.setter
    def part_log_retention_time(self, value: jsii.Number) -> None:
        jsii.set(self, "partLogRetentionTime", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queryLogRetentionSize")
    def query_log_retention_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "queryLogRetentionSize"))

    @query_log_retention_size.setter
    def query_log_retention_size(self, value: jsii.Number) -> None:
        jsii.set(self, "queryLogRetentionSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queryLogRetentionTime")
    def query_log_retention_time(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "queryLogRetentionTime"))

    @query_log_retention_time.setter
    def query_log_retention_time(self, value: jsii.Number) -> None:
        jsii.set(self, "queryLogRetentionTime", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queryThreadLogEnabled")
    def query_thread_log_enabled(
        self,
    ) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "queryThreadLogEnabled"))

    @query_thread_log_enabled.setter
    def query_thread_log_enabled(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "queryThreadLogEnabled", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queryThreadLogRetentionSize")
    def query_thread_log_retention_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "queryThreadLogRetentionSize"))

    @query_thread_log_retention_size.setter
    def query_thread_log_retention_size(self, value: jsii.Number) -> None:
        jsii.set(self, "queryThreadLogRetentionSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queryThreadLogRetentionTime")
    def query_thread_log_retention_time(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "queryThreadLogRetentionTime"))

    @query_thread_log_retention_time.setter
    def query_thread_log_retention_time(self, value: jsii.Number) -> None:
        jsii.set(self, "queryThreadLogRetentionTime", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="textLogEnabled")
    def text_log_enabled(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "textLogEnabled"))

    @text_log_enabled.setter
    def text_log_enabled(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "textLogEnabled", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="textLogLevel")
    def text_log_level(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "textLogLevel"))

    @text_log_level.setter
    def text_log_level(self, value: builtins.str) -> None:
        jsii.set(self, "textLogLevel", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="textLogRetentionSize")
    def text_log_retention_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "textLogRetentionSize"))

    @text_log_retention_size.setter
    def text_log_retention_size(self, value: jsii.Number) -> None:
        jsii.set(self, "textLogRetentionSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="textLogRetentionTime")
    def text_log_retention_time(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "textLogRetentionTime"))

    @text_log_retention_time.setter
    def text_log_retention_time(self, value: jsii.Number) -> None:
        jsii.set(self, "textLogRetentionTime", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timezone")
    def timezone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "timezone"))

    @timezone.setter
    def timezone(self, value: builtins.str) -> None:
        jsii.set(self, "timezone", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="traceLogEnabled")
    def trace_log_enabled(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "traceLogEnabled"))

    @trace_log_enabled.setter
    def trace_log_enabled(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "traceLogEnabled", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="traceLogRetentionSize")
    def trace_log_retention_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "traceLogRetentionSize"))

    @trace_log_retention_size.setter
    def trace_log_retention_size(self, value: jsii.Number) -> None:
        jsii.set(self, "traceLogRetentionSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="traceLogRetentionTime")
    def trace_log_retention_time(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "traceLogRetentionTime"))

    @trace_log_retention_time.setter
    def trace_log_retention_time(self, value: jsii.Number) -> None:
        jsii.set(self, "traceLogRetentionTime", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="uncompressedCacheSize")
    def uncompressed_cache_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "uncompressedCacheSize"))

    @uncompressed_cache_size.setter
    def uncompressed_cache_size(self, value: jsii.Number) -> None:
        jsii.set(self, "uncompressedCacheSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbClickhouseClusterClickhouseConfig]:
        return typing.cast(typing.Optional[MdbClickhouseClusterClickhouseConfig], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbClickhouseClusterClickhouseConfig],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterClickhouseConfigRabbitmq",
    jsii_struct_bases=[],
    name_mapping={"password": "password", "username": "username"},
)
class MdbClickhouseClusterClickhouseConfigRabbitmq:
    def __init__(
        self,
        *,
        password: typing.Optional[builtins.str] = None,
        username: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param password: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#password MdbClickhouseCluster#password}.
        :param username: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#username MdbClickhouseCluster#username}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if password is not None:
            self._values["password"] = password
        if username is not None:
            self._values["username"] = username

    @builtins.property
    def password(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#password MdbClickhouseCluster#password}.'''
        result = self._values.get("password")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def username(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#username MdbClickhouseCluster#username}.'''
        result = self._values.get("username")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbClickhouseClusterClickhouseConfigRabbitmq(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbClickhouseClusterClickhouseConfigRabbitmqOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterClickhouseConfigRabbitmqOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetPassword")
    def reset_password(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPassword", []))

    @jsii.member(jsii_name="resetUsername")
    def reset_username(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUsername", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="passwordInput")
    def password_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "passwordInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="usernameInput")
    def username_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "usernameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="password")
    def password(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "password"))

    @password.setter
    def password(self, value: builtins.str) -> None:
        jsii.set(self, "password", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="username")
    def username(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "username"))

    @username.setter
    def username(self, value: builtins.str) -> None:
        jsii.set(self, "username", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[MdbClickhouseClusterClickhouseConfigRabbitmq]:
        return typing.cast(typing.Optional[MdbClickhouseClusterClickhouseConfigRabbitmq], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbClickhouseClusterClickhouseConfigRabbitmq],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbClickhouseClusterClickhouseOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterClickhouseOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putConfig")
    def put_config(
        self,
        *,
        background_pool_size: typing.Optional[jsii.Number] = None,
        background_schedule_pool_size: typing.Optional[jsii.Number] = None,
        compression: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence[MdbClickhouseClusterClickhouseConfigCompression]]] = None,
        geobase_uri: typing.Optional[builtins.str] = None,
        graphite_rollup: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence[MdbClickhouseClusterClickhouseConfigGraphiteRollup]]] = None,
        kafka: typing.Optional[MdbClickhouseClusterClickhouseConfigKafka] = None,
        kafka_topic: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence[MdbClickhouseClusterClickhouseConfigKafkaTopic]]] = None,
        keep_alive_timeout: typing.Optional[jsii.Number] = None,
        log_level: typing.Optional[builtins.str] = None,
        mark_cache_size: typing.Optional[jsii.Number] = None,
        max_concurrent_queries: typing.Optional[jsii.Number] = None,
        max_connections: typing.Optional[jsii.Number] = None,
        max_partition_size_to_drop: typing.Optional[jsii.Number] = None,
        max_table_size_to_drop: typing.Optional[jsii.Number] = None,
        merge_tree: typing.Optional[MdbClickhouseClusterClickhouseConfigMergeTree] = None,
        metric_log_enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        metric_log_retention_size: typing.Optional[jsii.Number] = None,
        metric_log_retention_time: typing.Optional[jsii.Number] = None,
        part_log_retention_size: typing.Optional[jsii.Number] = None,
        part_log_retention_time: typing.Optional[jsii.Number] = None,
        query_log_retention_size: typing.Optional[jsii.Number] = None,
        query_log_retention_time: typing.Optional[jsii.Number] = None,
        query_thread_log_enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        query_thread_log_retention_size: typing.Optional[jsii.Number] = None,
        query_thread_log_retention_time: typing.Optional[jsii.Number] = None,
        rabbitmq: typing.Optional[MdbClickhouseClusterClickhouseConfigRabbitmq] = None,
        text_log_enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        text_log_level: typing.Optional[builtins.str] = None,
        text_log_retention_size: typing.Optional[jsii.Number] = None,
        text_log_retention_time: typing.Optional[jsii.Number] = None,
        timezone: typing.Optional[builtins.str] = None,
        trace_log_enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        trace_log_retention_size: typing.Optional[jsii.Number] = None,
        trace_log_retention_time: typing.Optional[jsii.Number] = None,
        uncompressed_cache_size: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param background_pool_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#background_pool_size MdbClickhouseCluster#background_pool_size}.
        :param background_schedule_pool_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#background_schedule_pool_size MdbClickhouseCluster#background_schedule_pool_size}.
        :param compression: compression block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#compression MdbClickhouseCluster#compression}
        :param geobase_uri: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#geobase_uri MdbClickhouseCluster#geobase_uri}.
        :param graphite_rollup: graphite_rollup block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#graphite_rollup MdbClickhouseCluster#graphite_rollup}
        :param kafka: kafka block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#kafka MdbClickhouseCluster#kafka}
        :param kafka_topic: kafka_topic block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#kafka_topic MdbClickhouseCluster#kafka_topic}
        :param keep_alive_timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#keep_alive_timeout MdbClickhouseCluster#keep_alive_timeout}.
        :param log_level: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#log_level MdbClickhouseCluster#log_level}.
        :param mark_cache_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#mark_cache_size MdbClickhouseCluster#mark_cache_size}.
        :param max_concurrent_queries: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_concurrent_queries MdbClickhouseCluster#max_concurrent_queries}.
        :param max_connections: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_connections MdbClickhouseCluster#max_connections}.
        :param max_partition_size_to_drop: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_partition_size_to_drop MdbClickhouseCluster#max_partition_size_to_drop}.
        :param max_table_size_to_drop: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_table_size_to_drop MdbClickhouseCluster#max_table_size_to_drop}.
        :param merge_tree: merge_tree block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#merge_tree MdbClickhouseCluster#merge_tree}
        :param metric_log_enabled: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#metric_log_enabled MdbClickhouseCluster#metric_log_enabled}.
        :param metric_log_retention_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#metric_log_retention_size MdbClickhouseCluster#metric_log_retention_size}.
        :param metric_log_retention_time: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#metric_log_retention_time MdbClickhouseCluster#metric_log_retention_time}.
        :param part_log_retention_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#part_log_retention_size MdbClickhouseCluster#part_log_retention_size}.
        :param part_log_retention_time: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#part_log_retention_time MdbClickhouseCluster#part_log_retention_time}.
        :param query_log_retention_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#query_log_retention_size MdbClickhouseCluster#query_log_retention_size}.
        :param query_log_retention_time: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#query_log_retention_time MdbClickhouseCluster#query_log_retention_time}.
        :param query_thread_log_enabled: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#query_thread_log_enabled MdbClickhouseCluster#query_thread_log_enabled}.
        :param query_thread_log_retention_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#query_thread_log_retention_size MdbClickhouseCluster#query_thread_log_retention_size}.
        :param query_thread_log_retention_time: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#query_thread_log_retention_time MdbClickhouseCluster#query_thread_log_retention_time}.
        :param rabbitmq: rabbitmq block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#rabbitmq MdbClickhouseCluster#rabbitmq}
        :param text_log_enabled: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#text_log_enabled MdbClickhouseCluster#text_log_enabled}.
        :param text_log_level: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#text_log_level MdbClickhouseCluster#text_log_level}.
        :param text_log_retention_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#text_log_retention_size MdbClickhouseCluster#text_log_retention_size}.
        :param text_log_retention_time: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#text_log_retention_time MdbClickhouseCluster#text_log_retention_time}.
        :param timezone: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#timezone MdbClickhouseCluster#timezone}.
        :param trace_log_enabled: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#trace_log_enabled MdbClickhouseCluster#trace_log_enabled}.
        :param trace_log_retention_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#trace_log_retention_size MdbClickhouseCluster#trace_log_retention_size}.
        :param trace_log_retention_time: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#trace_log_retention_time MdbClickhouseCluster#trace_log_retention_time}.
        :param uncompressed_cache_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#uncompressed_cache_size MdbClickhouseCluster#uncompressed_cache_size}.
        '''
        value = MdbClickhouseClusterClickhouseConfig(
            background_pool_size=background_pool_size,
            background_schedule_pool_size=background_schedule_pool_size,
            compression=compression,
            geobase_uri=geobase_uri,
            graphite_rollup=graphite_rollup,
            kafka=kafka,
            kafka_topic=kafka_topic,
            keep_alive_timeout=keep_alive_timeout,
            log_level=log_level,
            mark_cache_size=mark_cache_size,
            max_concurrent_queries=max_concurrent_queries,
            max_connections=max_connections,
            max_partition_size_to_drop=max_partition_size_to_drop,
            max_table_size_to_drop=max_table_size_to_drop,
            merge_tree=merge_tree,
            metric_log_enabled=metric_log_enabled,
            metric_log_retention_size=metric_log_retention_size,
            metric_log_retention_time=metric_log_retention_time,
            part_log_retention_size=part_log_retention_size,
            part_log_retention_time=part_log_retention_time,
            query_log_retention_size=query_log_retention_size,
            query_log_retention_time=query_log_retention_time,
            query_thread_log_enabled=query_thread_log_enabled,
            query_thread_log_retention_size=query_thread_log_retention_size,
            query_thread_log_retention_time=query_thread_log_retention_time,
            rabbitmq=rabbitmq,
            text_log_enabled=text_log_enabled,
            text_log_level=text_log_level,
            text_log_retention_size=text_log_retention_size,
            text_log_retention_time=text_log_retention_time,
            timezone=timezone,
            trace_log_enabled=trace_log_enabled,
            trace_log_retention_size=trace_log_retention_size,
            trace_log_retention_time=trace_log_retention_time,
            uncompressed_cache_size=uncompressed_cache_size,
        )

        return typing.cast(None, jsii.invoke(self, "putConfig", [value]))

    @jsii.member(jsii_name="putResources")
    def put_resources(
        self,
        *,
        disk_size: jsii.Number,
        disk_type_id: builtins.str,
        resource_preset_id: builtins.str,
    ) -> None:
        '''
        :param disk_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#disk_size MdbClickhouseCluster#disk_size}.
        :param disk_type_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#disk_type_id MdbClickhouseCluster#disk_type_id}.
        :param resource_preset_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#resource_preset_id MdbClickhouseCluster#resource_preset_id}.
        '''
        value = MdbClickhouseClusterClickhouseResources(
            disk_size=disk_size,
            disk_type_id=disk_type_id,
            resource_preset_id=resource_preset_id,
        )

        return typing.cast(None, jsii.invoke(self, "putResources", [value]))

    @jsii.member(jsii_name="resetConfig")
    def reset_config(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetConfig", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="config")
    def config(self) -> MdbClickhouseClusterClickhouseConfigOutputReference:
        return typing.cast(MdbClickhouseClusterClickhouseConfigOutputReference, jsii.get(self, "config"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resources")
    def resources(self) -> "MdbClickhouseClusterClickhouseResourcesOutputReference":
        return typing.cast("MdbClickhouseClusterClickhouseResourcesOutputReference", jsii.get(self, "resources"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="configInput")
    def config_input(self) -> typing.Optional[MdbClickhouseClusterClickhouseConfig]:
        return typing.cast(typing.Optional[MdbClickhouseClusterClickhouseConfig], jsii.get(self, "configInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcesInput")
    def resources_input(
        self,
    ) -> typing.Optional["MdbClickhouseClusterClickhouseResources"]:
        return typing.cast(typing.Optional["MdbClickhouseClusterClickhouseResources"], jsii.get(self, "resourcesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbClickhouseClusterClickhouse]:
        return typing.cast(typing.Optional[MdbClickhouseClusterClickhouse], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbClickhouseClusterClickhouse],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterClickhouseResources",
    jsii_struct_bases=[],
    name_mapping={
        "disk_size": "diskSize",
        "disk_type_id": "diskTypeId",
        "resource_preset_id": "resourcePresetId",
    },
)
class MdbClickhouseClusterClickhouseResources:
    def __init__(
        self,
        *,
        disk_size: jsii.Number,
        disk_type_id: builtins.str,
        resource_preset_id: builtins.str,
    ) -> None:
        '''
        :param disk_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#disk_size MdbClickhouseCluster#disk_size}.
        :param disk_type_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#disk_type_id MdbClickhouseCluster#disk_type_id}.
        :param resource_preset_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#resource_preset_id MdbClickhouseCluster#resource_preset_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "disk_size": disk_size,
            "disk_type_id": disk_type_id,
            "resource_preset_id": resource_preset_id,
        }

    @builtins.property
    def disk_size(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#disk_size MdbClickhouseCluster#disk_size}.'''
        result = self._values.get("disk_size")
        assert result is not None, "Required property 'disk_size' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def disk_type_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#disk_type_id MdbClickhouseCluster#disk_type_id}.'''
        result = self._values.get("disk_type_id")
        assert result is not None, "Required property 'disk_type_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def resource_preset_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#resource_preset_id MdbClickhouseCluster#resource_preset_id}.'''
        result = self._values.get("resource_preset_id")
        assert result is not None, "Required property 'resource_preset_id' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbClickhouseClusterClickhouseResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbClickhouseClusterClickhouseResourcesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterClickhouseResourcesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSizeInput")
    def disk_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "diskSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeIdInput")
    def disk_type_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "diskTypeIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetIdInput")
    def resource_preset_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourcePresetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSize")
    def disk_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "diskSize"))

    @disk_size.setter
    def disk_size(self, value: jsii.Number) -> None:
        jsii.set(self, "diskSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeId")
    def disk_type_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskTypeId"))

    @disk_type_id.setter
    def disk_type_id(self, value: builtins.str) -> None:
        jsii.set(self, "diskTypeId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetId")
    def resource_preset_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourcePresetId"))

    @resource_preset_id.setter
    def resource_preset_id(self, value: builtins.str) -> None:
        jsii.set(self, "resourcePresetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[MdbClickhouseClusterClickhouseResources]:
        return typing.cast(typing.Optional[MdbClickhouseClusterClickhouseResources], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbClickhouseClusterClickhouseResources],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterCloudStorage",
    jsii_struct_bases=[],
    name_mapping={"enabled": "enabled"},
)
class MdbClickhouseClusterCloudStorage:
    def __init__(
        self,
        *,
        enabled: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        '''
        :param enabled: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#enabled MdbClickhouseCluster#enabled}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
        }

    @builtins.property
    def enabled(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#enabled MdbClickhouseCluster#enabled}.'''
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbClickhouseClusterCloudStorage(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbClickhouseClusterCloudStorageOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterCloudStorageOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="enabledInput")
    def enabled_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "enabledInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "enabled"))

    @enabled.setter
    def enabled(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbClickhouseClusterCloudStorage]:
        return typing.cast(typing.Optional[MdbClickhouseClusterCloudStorage], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbClickhouseClusterCloudStorage],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "clickhouse": "clickhouse",
        "environment": "environment",
        "host": "host",
        "name": "name",
        "network_id": "networkId",
        "access": "access",
        "admin_password": "adminPassword",
        "backup_window_start": "backupWindowStart",
        "cloud_storage": "cloudStorage",
        "copy_schema_on_new_hosts": "copySchemaOnNewHosts",
        "database": "database",
        "deletion_protection": "deletionProtection",
        "description": "description",
        "embedded_keeper": "embeddedKeeper",
        "folder_id": "folderId",
        "format_schema": "formatSchema",
        "id": "id",
        "labels": "labels",
        "maintenance_window": "maintenanceWindow",
        "ml_model": "mlModel",
        "security_group_ids": "securityGroupIds",
        "service_account_id": "serviceAccountId",
        "shard_group": "shardGroup",
        "sql_database_management": "sqlDatabaseManagement",
        "sql_user_management": "sqlUserManagement",
        "timeouts": "timeouts",
        "user": "user",
        "version": "version",
        "zookeeper": "zookeeper",
    },
)
class MdbClickhouseClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        clickhouse: MdbClickhouseClusterClickhouse,
        environment: builtins.str,
        host: typing.Union[cdktf.IResolvable, typing.Sequence["MdbClickhouseClusterHost"]],
        name: builtins.str,
        network_id: builtins.str,
        access: typing.Optional[MdbClickhouseClusterAccess] = None,
        admin_password: typing.Optional[builtins.str] = None,
        backup_window_start: typing.Optional[MdbClickhouseClusterBackupWindowStart] = None,
        cloud_storage: typing.Optional[MdbClickhouseClusterCloudStorage] = None,
        copy_schema_on_new_hosts: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        database: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbClickhouseClusterDatabase"]]] = None,
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        description: typing.Optional[builtins.str] = None,
        embedded_keeper: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        folder_id: typing.Optional[builtins.str] = None,
        format_schema: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbClickhouseClusterFormatSchema"]]] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        maintenance_window: typing.Optional["MdbClickhouseClusterMaintenanceWindow"] = None,
        ml_model: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbClickhouseClusterMlModel"]]] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        service_account_id: typing.Optional[builtins.str] = None,
        shard_group: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbClickhouseClusterShardGroup"]]] = None,
        sql_database_management: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        sql_user_management: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        timeouts: typing.Optional["MdbClickhouseClusterTimeouts"] = None,
        user: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbClickhouseClusterUser"]]] = None,
        version: typing.Optional[builtins.str] = None,
        zookeeper: typing.Optional["MdbClickhouseClusterZookeeper"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param clickhouse: clickhouse block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#clickhouse MdbClickhouseCluster#clickhouse}
        :param environment: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#environment MdbClickhouseCluster#environment}.
        :param host: host block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#host MdbClickhouseCluster#host}
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#name MdbClickhouseCluster#name}.
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#network_id MdbClickhouseCluster#network_id}.
        :param access: access block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#access MdbClickhouseCluster#access}
        :param admin_password: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#admin_password MdbClickhouseCluster#admin_password}.
        :param backup_window_start: backup_window_start block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#backup_window_start MdbClickhouseCluster#backup_window_start}
        :param cloud_storage: cloud_storage block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#cloud_storage MdbClickhouseCluster#cloud_storage}
        :param copy_schema_on_new_hosts: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#copy_schema_on_new_hosts MdbClickhouseCluster#copy_schema_on_new_hosts}.
        :param database: database block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#database MdbClickhouseCluster#database}
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#deletion_protection MdbClickhouseCluster#deletion_protection}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#description MdbClickhouseCluster#description}.
        :param embedded_keeper: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#embedded_keeper MdbClickhouseCluster#embedded_keeper}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#folder_id MdbClickhouseCluster#folder_id}.
        :param format_schema: format_schema block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#format_schema MdbClickhouseCluster#format_schema}
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#id MdbClickhouseCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#labels MdbClickhouseCluster#labels}.
        :param maintenance_window: maintenance_window block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#maintenance_window MdbClickhouseCluster#maintenance_window}
        :param ml_model: ml_model block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#ml_model MdbClickhouseCluster#ml_model}
        :param security_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#security_group_ids MdbClickhouseCluster#security_group_ids}.
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#service_account_id MdbClickhouseCluster#service_account_id}.
        :param shard_group: shard_group block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#shard_group MdbClickhouseCluster#shard_group}
        :param sql_database_management: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#sql_database_management MdbClickhouseCluster#sql_database_management}.
        :param sql_user_management: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#sql_user_management MdbClickhouseCluster#sql_user_management}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#timeouts MdbClickhouseCluster#timeouts}
        :param user: user block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#user MdbClickhouseCluster#user}
        :param version: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#version MdbClickhouseCluster#version}.
        :param zookeeper: zookeeper block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#zookeeper MdbClickhouseCluster#zookeeper}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(clickhouse, dict):
            clickhouse = MdbClickhouseClusterClickhouse(**clickhouse)
        if isinstance(access, dict):
            access = MdbClickhouseClusterAccess(**access)
        if isinstance(backup_window_start, dict):
            backup_window_start = MdbClickhouseClusterBackupWindowStart(**backup_window_start)
        if isinstance(cloud_storage, dict):
            cloud_storage = MdbClickhouseClusterCloudStorage(**cloud_storage)
        if isinstance(maintenance_window, dict):
            maintenance_window = MdbClickhouseClusterMaintenanceWindow(**maintenance_window)
        if isinstance(timeouts, dict):
            timeouts = MdbClickhouseClusterTimeouts(**timeouts)
        if isinstance(zookeeper, dict):
            zookeeper = MdbClickhouseClusterZookeeper(**zookeeper)
        self._values: typing.Dict[str, typing.Any] = {
            "clickhouse": clickhouse,
            "environment": environment,
            "host": host,
            "name": name,
            "network_id": network_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if access is not None:
            self._values["access"] = access
        if admin_password is not None:
            self._values["admin_password"] = admin_password
        if backup_window_start is not None:
            self._values["backup_window_start"] = backup_window_start
        if cloud_storage is not None:
            self._values["cloud_storage"] = cloud_storage
        if copy_schema_on_new_hosts is not None:
            self._values["copy_schema_on_new_hosts"] = copy_schema_on_new_hosts
        if database is not None:
            self._values["database"] = database
        if deletion_protection is not None:
            self._values["deletion_protection"] = deletion_protection
        if description is not None:
            self._values["description"] = description
        if embedded_keeper is not None:
            self._values["embedded_keeper"] = embedded_keeper
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if format_schema is not None:
            self._values["format_schema"] = format_schema
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if maintenance_window is not None:
            self._values["maintenance_window"] = maintenance_window
        if ml_model is not None:
            self._values["ml_model"] = ml_model
        if security_group_ids is not None:
            self._values["security_group_ids"] = security_group_ids
        if service_account_id is not None:
            self._values["service_account_id"] = service_account_id
        if shard_group is not None:
            self._values["shard_group"] = shard_group
        if sql_database_management is not None:
            self._values["sql_database_management"] = sql_database_management
        if sql_user_management is not None:
            self._values["sql_user_management"] = sql_user_management
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if user is not None:
            self._values["user"] = user
        if version is not None:
            self._values["version"] = version
        if zookeeper is not None:
            self._values["zookeeper"] = zookeeper

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def clickhouse(self) -> MdbClickhouseClusterClickhouse:
        '''clickhouse block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#clickhouse MdbClickhouseCluster#clickhouse}
        '''
        result = self._values.get("clickhouse")
        assert result is not None, "Required property 'clickhouse' is missing"
        return typing.cast(MdbClickhouseClusterClickhouse, result)

    @builtins.property
    def environment(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#environment MdbClickhouseCluster#environment}.'''
        result = self._values.get("environment")
        assert result is not None, "Required property 'environment' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def host(
        self,
    ) -> typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterHost"]]:
        '''host block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#host MdbClickhouseCluster#host}
        '''
        result = self._values.get("host")
        assert result is not None, "Required property 'host' is missing"
        return typing.cast(typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterHost"]], result)

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#name MdbClickhouseCluster#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def network_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#network_id MdbClickhouseCluster#network_id}.'''
        result = self._values.get("network_id")
        assert result is not None, "Required property 'network_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def access(self) -> typing.Optional[MdbClickhouseClusterAccess]:
        '''access block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#access MdbClickhouseCluster#access}
        '''
        result = self._values.get("access")
        return typing.cast(typing.Optional[MdbClickhouseClusterAccess], result)

    @builtins.property
    def admin_password(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#admin_password MdbClickhouseCluster#admin_password}.'''
        result = self._values.get("admin_password")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def backup_window_start(
        self,
    ) -> typing.Optional[MdbClickhouseClusterBackupWindowStart]:
        '''backup_window_start block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#backup_window_start MdbClickhouseCluster#backup_window_start}
        '''
        result = self._values.get("backup_window_start")
        return typing.cast(typing.Optional[MdbClickhouseClusterBackupWindowStart], result)

    @builtins.property
    def cloud_storage(self) -> typing.Optional[MdbClickhouseClusterCloudStorage]:
        '''cloud_storage block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#cloud_storage MdbClickhouseCluster#cloud_storage}
        '''
        result = self._values.get("cloud_storage")
        return typing.cast(typing.Optional[MdbClickhouseClusterCloudStorage], result)

    @builtins.property
    def copy_schema_on_new_hosts(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#copy_schema_on_new_hosts MdbClickhouseCluster#copy_schema_on_new_hosts}.'''
        result = self._values.get("copy_schema_on_new_hosts")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def database(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterDatabase"]]]:
        '''database block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#database MdbClickhouseCluster#database}
        '''
        result = self._values.get("database")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterDatabase"]]], result)

    @builtins.property
    def deletion_protection(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#deletion_protection MdbClickhouseCluster#deletion_protection}.'''
        result = self._values.get("deletion_protection")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#description MdbClickhouseCluster#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def embedded_keeper(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#embedded_keeper MdbClickhouseCluster#embedded_keeper}.'''
        result = self._values.get("embedded_keeper")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#folder_id MdbClickhouseCluster#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def format_schema(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterFormatSchema"]]]:
        '''format_schema block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#format_schema MdbClickhouseCluster#format_schema}
        '''
        result = self._values.get("format_schema")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterFormatSchema"]]], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#id MdbClickhouseCluster#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#labels MdbClickhouseCluster#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def maintenance_window(
        self,
    ) -> typing.Optional["MdbClickhouseClusterMaintenanceWindow"]:
        '''maintenance_window block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#maintenance_window MdbClickhouseCluster#maintenance_window}
        '''
        result = self._values.get("maintenance_window")
        return typing.cast(typing.Optional["MdbClickhouseClusterMaintenanceWindow"], result)

    @builtins.property
    def ml_model(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterMlModel"]]]:
        '''ml_model block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#ml_model MdbClickhouseCluster#ml_model}
        '''
        result = self._values.get("ml_model")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterMlModel"]]], result)

    @builtins.property
    def security_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#security_group_ids MdbClickhouseCluster#security_group_ids}.'''
        result = self._values.get("security_group_ids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def service_account_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#service_account_id MdbClickhouseCluster#service_account_id}.'''
        result = self._values.get("service_account_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def shard_group(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterShardGroup"]]]:
        '''shard_group block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#shard_group MdbClickhouseCluster#shard_group}
        '''
        result = self._values.get("shard_group")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterShardGroup"]]], result)

    @builtins.property
    def sql_database_management(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#sql_database_management MdbClickhouseCluster#sql_database_management}.'''
        result = self._values.get("sql_database_management")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def sql_user_management(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#sql_user_management MdbClickhouseCluster#sql_user_management}.'''
        result = self._values.get("sql_user_management")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["MdbClickhouseClusterTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#timeouts MdbClickhouseCluster#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["MdbClickhouseClusterTimeouts"], result)

    @builtins.property
    def user(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterUser"]]]:
        '''user block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#user MdbClickhouseCluster#user}
        '''
        result = self._values.get("user")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterUser"]]], result)

    @builtins.property
    def version(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#version MdbClickhouseCluster#version}.'''
        result = self._values.get("version")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def zookeeper(self) -> typing.Optional["MdbClickhouseClusterZookeeper"]:
        '''zookeeper block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#zookeeper MdbClickhouseCluster#zookeeper}
        '''
        result = self._values.get("zookeeper")
        return typing.cast(typing.Optional["MdbClickhouseClusterZookeeper"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbClickhouseClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterDatabase",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class MdbClickhouseClusterDatabase:
    def __init__(self, *, name: builtins.str) -> None:
        '''
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#name MdbClickhouseCluster#name}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#name MdbClickhouseCluster#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbClickhouseClusterDatabase(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbClickhouseClusterDatabaseList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterDatabaseList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "MdbClickhouseClusterDatabaseOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbClickhouseClusterDatabaseOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterDatabase]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterDatabase]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterDatabase]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbClickhouseClusterDatabaseOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterDatabaseOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterDatabase]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterDatabase]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterDatabase]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterFormatSchema",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "type": "type", "uri": "uri"},
)
class MdbClickhouseClusterFormatSchema:
    def __init__(
        self,
        *,
        name: builtins.str,
        type: builtins.str,
        uri: builtins.str,
    ) -> None:
        '''
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#name MdbClickhouseCluster#name}.
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#type MdbClickhouseCluster#type}.
        :param uri: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#uri MdbClickhouseCluster#uri}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "type": type,
            "uri": uri,
        }

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#name MdbClickhouseCluster#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def type(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#type MdbClickhouseCluster#type}.'''
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def uri(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#uri MdbClickhouseCluster#uri}.'''
        result = self._values.get("uri")
        assert result is not None, "Required property 'uri' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbClickhouseClusterFormatSchema(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbClickhouseClusterFormatSchemaList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterFormatSchemaList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "MdbClickhouseClusterFormatSchemaOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbClickhouseClusterFormatSchemaOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterFormatSchema]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterFormatSchema]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterFormatSchema]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbClickhouseClusterFormatSchemaOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterFormatSchemaOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="typeInput")
    def type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "typeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="uriInput")
    def uri_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "uriInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @type.setter
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="uri")
    def uri(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "uri"))

    @uri.setter
    def uri(self, value: builtins.str) -> None:
        jsii.set(self, "uri", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterFormatSchema]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterFormatSchema]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterFormatSchema]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterHost",
    jsii_struct_bases=[],
    name_mapping={
        "type": "type",
        "zone": "zone",
        "assign_public_ip": "assignPublicIp",
        "shard_name": "shardName",
        "subnet_id": "subnetId",
    },
)
class MdbClickhouseClusterHost:
    def __init__(
        self,
        *,
        type: builtins.str,
        zone: builtins.str,
        assign_public_ip: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        shard_name: typing.Optional[builtins.str] = None,
        subnet_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#type MdbClickhouseCluster#type}.
        :param zone: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#zone MdbClickhouseCluster#zone}.
        :param assign_public_ip: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#assign_public_ip MdbClickhouseCluster#assign_public_ip}.
        :param shard_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#shard_name MdbClickhouseCluster#shard_name}.
        :param subnet_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#subnet_id MdbClickhouseCluster#subnet_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
            "zone": zone,
        }
        if assign_public_ip is not None:
            self._values["assign_public_ip"] = assign_public_ip
        if shard_name is not None:
            self._values["shard_name"] = shard_name
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id

    @builtins.property
    def type(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#type MdbClickhouseCluster#type}.'''
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def zone(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#zone MdbClickhouseCluster#zone}.'''
        result = self._values.get("zone")
        assert result is not None, "Required property 'zone' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def assign_public_ip(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#assign_public_ip MdbClickhouseCluster#assign_public_ip}.'''
        result = self._values.get("assign_public_ip")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def shard_name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#shard_name MdbClickhouseCluster#shard_name}.'''
        result = self._values.get("shard_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#subnet_id MdbClickhouseCluster#subnet_id}.'''
        result = self._values.get("subnet_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbClickhouseClusterHost(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbClickhouseClusterHostList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterHostList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "MdbClickhouseClusterHostOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbClickhouseClusterHostOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterHost]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterHost]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterHost]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbClickhouseClusterHostOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterHostOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetAssignPublicIp")
    def reset_assign_public_ip(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAssignPublicIp", []))

    @jsii.member(jsii_name="resetShardName")
    def reset_shard_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetShardName", []))

    @jsii.member(jsii_name="resetSubnetId")
    def reset_subnet_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSubnetId", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fqdn"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIpInput")
    def assign_public_ip_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "assignPublicIpInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="shardNameInput")
    def shard_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "shardNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIdInput")
    def subnet_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "subnetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="typeInput")
    def type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "typeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneInput")
    def zone_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "zoneInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIp")
    def assign_public_ip(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "assignPublicIp"))

    @assign_public_ip.setter
    def assign_public_ip(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "assignPublicIp", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="shardName")
    def shard_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "shardName"))

    @shard_name.setter
    def shard_name(self, value: builtins.str) -> None:
        jsii.set(self, "shardName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @subnet_id.setter
    def subnet_id(self, value: builtins.str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @type.setter
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zone")
    def zone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zone"))

    @zone.setter
    def zone(self, value: builtins.str) -> None:
        jsii.set(self, "zone", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterHost]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterHost]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterHost]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterMaintenanceWindow",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "day": "day", "hour": "hour"},
)
class MdbClickhouseClusterMaintenanceWindow:
    def __init__(
        self,
        *,
        type: builtins.str,
        day: typing.Optional[builtins.str] = None,
        hour: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#type MdbClickhouseCluster#type}.
        :param day: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#day MdbClickhouseCluster#day}.
        :param hour: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#hour MdbClickhouseCluster#hour}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }
        if day is not None:
            self._values["day"] = day
        if hour is not None:
            self._values["hour"] = hour

    @builtins.property
    def type(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#type MdbClickhouseCluster#type}.'''
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def day(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#day MdbClickhouseCluster#day}.'''
        result = self._values.get("day")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def hour(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#hour MdbClickhouseCluster#hour}.'''
        result = self._values.get("hour")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbClickhouseClusterMaintenanceWindow(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbClickhouseClusterMaintenanceWindowOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterMaintenanceWindowOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetDay")
    def reset_day(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDay", []))

    @jsii.member(jsii_name="resetHour")
    def reset_hour(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHour", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dayInput")
    def day_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dayInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hourInput")
    def hour_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "hourInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="typeInput")
    def type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "typeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="day")
    def day(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "day"))

    @day.setter
    def day(self, value: builtins.str) -> None:
        jsii.set(self, "day", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hour")
    def hour(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "hour"))

    @hour.setter
    def hour(self, value: jsii.Number) -> None:
        jsii.set(self, "hour", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @type.setter
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbClickhouseClusterMaintenanceWindow]:
        return typing.cast(typing.Optional[MdbClickhouseClusterMaintenanceWindow], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbClickhouseClusterMaintenanceWindow],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterMlModel",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "type": "type", "uri": "uri"},
)
class MdbClickhouseClusterMlModel:
    def __init__(
        self,
        *,
        name: builtins.str,
        type: builtins.str,
        uri: builtins.str,
    ) -> None:
        '''
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#name MdbClickhouseCluster#name}.
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#type MdbClickhouseCluster#type}.
        :param uri: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#uri MdbClickhouseCluster#uri}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "type": type,
            "uri": uri,
        }

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#name MdbClickhouseCluster#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def type(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#type MdbClickhouseCluster#type}.'''
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def uri(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#uri MdbClickhouseCluster#uri}.'''
        result = self._values.get("uri")
        assert result is not None, "Required property 'uri' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbClickhouseClusterMlModel(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbClickhouseClusterMlModelList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterMlModelList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "MdbClickhouseClusterMlModelOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbClickhouseClusterMlModelOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterMlModel]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterMlModel]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterMlModel]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbClickhouseClusterMlModelOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterMlModelOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="typeInput")
    def type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "typeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="uriInput")
    def uri_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "uriInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @type.setter
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="uri")
    def uri(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "uri"))

    @uri.setter
    def uri(self, value: builtins.str) -> None:
        jsii.set(self, "uri", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterMlModel]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterMlModel]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterMlModel]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterShardGroup",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "shard_names": "shardNames",
        "description": "description",
    },
)
class MdbClickhouseClusterShardGroup:
    def __init__(
        self,
        *,
        name: builtins.str,
        shard_names: typing.Sequence[builtins.str],
        description: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#name MdbClickhouseCluster#name}.
        :param shard_names: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#shard_names MdbClickhouseCluster#shard_names}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#description MdbClickhouseCluster#description}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "shard_names": shard_names,
        }
        if description is not None:
            self._values["description"] = description

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#name MdbClickhouseCluster#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def shard_names(self) -> typing.List[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#shard_names MdbClickhouseCluster#shard_names}.'''
        result = self._values.get("shard_names")
        assert result is not None, "Required property 'shard_names' is missing"
        return typing.cast(typing.List[builtins.str], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#description MdbClickhouseCluster#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbClickhouseClusterShardGroup(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbClickhouseClusterShardGroupList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterShardGroupList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "MdbClickhouseClusterShardGroupOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbClickhouseClusterShardGroupOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterShardGroup]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterShardGroup]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterShardGroup]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbClickhouseClusterShardGroupOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterShardGroupOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="shardNamesInput")
    def shard_names_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "shardNamesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="shardNames")
    def shard_names(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "shardNames"))

    @shard_names.setter
    def shard_names(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "shardNames", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterShardGroup]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterShardGroup]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterShardGroup]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class MdbClickhouseClusterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#create MdbClickhouseCluster#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#delete MdbClickhouseCluster#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#update MdbClickhouseCluster#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#create MdbClickhouseCluster#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#delete MdbClickhouseCluster#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#update MdbClickhouseCluster#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbClickhouseClusterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbClickhouseClusterTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterUser",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "password": "password",
        "permission": "permission",
        "quota": "quota",
        "settings": "settings",
    },
)
class MdbClickhouseClusterUser:
    def __init__(
        self,
        *,
        name: builtins.str,
        password: builtins.str,
        permission: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbClickhouseClusterUserPermission"]]] = None,
        quota: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbClickhouseClusterUserQuota"]]] = None,
        settings: typing.Optional["MdbClickhouseClusterUserSettings"] = None,
    ) -> None:
        '''
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#name MdbClickhouseCluster#name}.
        :param password: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#password MdbClickhouseCluster#password}.
        :param permission: permission block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#permission MdbClickhouseCluster#permission}
        :param quota: quota block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#quota MdbClickhouseCluster#quota}
        :param settings: settings block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#settings MdbClickhouseCluster#settings}
        '''
        if isinstance(settings, dict):
            settings = MdbClickhouseClusterUserSettings(**settings)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "password": password,
        }
        if permission is not None:
            self._values["permission"] = permission
        if quota is not None:
            self._values["quota"] = quota
        if settings is not None:
            self._values["settings"] = settings

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#name MdbClickhouseCluster#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def password(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#password MdbClickhouseCluster#password}.'''
        result = self._values.get("password")
        assert result is not None, "Required property 'password' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def permission(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterUserPermission"]]]:
        '''permission block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#permission MdbClickhouseCluster#permission}
        '''
        result = self._values.get("permission")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterUserPermission"]]], result)

    @builtins.property
    def quota(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterUserQuota"]]]:
        '''quota block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#quota MdbClickhouseCluster#quota}
        '''
        result = self._values.get("quota")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterUserQuota"]]], result)

    @builtins.property
    def settings(self) -> typing.Optional["MdbClickhouseClusterUserSettings"]:
        '''settings block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#settings MdbClickhouseCluster#settings}
        '''
        result = self._values.get("settings")
        return typing.cast(typing.Optional["MdbClickhouseClusterUserSettings"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbClickhouseClusterUser(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbClickhouseClusterUserList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterUserList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "MdbClickhouseClusterUserOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbClickhouseClusterUserOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterUser]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterUser]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterUser]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbClickhouseClusterUserOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterUserOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putPermission")
    def put_permission(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["MdbClickhouseClusterUserPermission"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putPermission", [value]))

    @jsii.member(jsii_name="putQuota")
    def put_quota(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["MdbClickhouseClusterUserQuota"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putQuota", [value]))

    @jsii.member(jsii_name="putSettings")
    def put_settings(
        self,
        *,
        add_http_cors_header: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        allow_ddl: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        compile: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        compile_expressions: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        connect_timeout: typing.Optional[jsii.Number] = None,
        count_distinct_implementation: typing.Optional[builtins.str] = None,
        distinct_overflow_mode: typing.Optional[builtins.str] = None,
        distributed_aggregation_memory_efficient: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        distributed_ddl_task_timeout: typing.Optional[jsii.Number] = None,
        distributed_product_mode: typing.Optional[builtins.str] = None,
        empty_result_for_aggregation_by_empty_set: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        enable_http_compression: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        fallback_to_stale_replicas_for_distributed_queries: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        force_index_by_date: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        force_primary_key: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        group_by_overflow_mode: typing.Optional[builtins.str] = None,
        group_by_two_level_threshold: typing.Optional[jsii.Number] = None,
        group_by_two_level_threshold_bytes: typing.Optional[jsii.Number] = None,
        http_connection_timeout: typing.Optional[jsii.Number] = None,
        http_headers_progress_interval: typing.Optional[jsii.Number] = None,
        http_receive_timeout: typing.Optional[jsii.Number] = None,
        http_send_timeout: typing.Optional[jsii.Number] = None,
        input_format_defaults_for_omitted_fields: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        input_format_values_interpret_expressions: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        insert_quorum: typing.Optional[jsii.Number] = None,
        insert_quorum_timeout: typing.Optional[jsii.Number] = None,
        joined_subquery_requires_alias: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        join_overflow_mode: typing.Optional[builtins.str] = None,
        join_use_nulls: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        low_cardinality_allow_in_native_format: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        max_ast_depth: typing.Optional[jsii.Number] = None,
        max_ast_elements: typing.Optional[jsii.Number] = None,
        max_block_size: typing.Optional[jsii.Number] = None,
        max_bytes_before_external_group_by: typing.Optional[jsii.Number] = None,
        max_bytes_before_external_sort: typing.Optional[jsii.Number] = None,
        max_bytes_in_distinct: typing.Optional[jsii.Number] = None,
        max_bytes_in_join: typing.Optional[jsii.Number] = None,
        max_bytes_in_set: typing.Optional[jsii.Number] = None,
        max_bytes_to_read: typing.Optional[jsii.Number] = None,
        max_bytes_to_sort: typing.Optional[jsii.Number] = None,
        max_bytes_to_transfer: typing.Optional[jsii.Number] = None,
        max_columns_to_read: typing.Optional[jsii.Number] = None,
        max_execution_time: typing.Optional[jsii.Number] = None,
        max_expanded_ast_elements: typing.Optional[jsii.Number] = None,
        max_insert_block_size: typing.Optional[jsii.Number] = None,
        max_memory_usage: typing.Optional[jsii.Number] = None,
        max_memory_usage_for_user: typing.Optional[jsii.Number] = None,
        max_network_bandwidth: typing.Optional[jsii.Number] = None,
        max_network_bandwidth_for_user: typing.Optional[jsii.Number] = None,
        max_query_size: typing.Optional[jsii.Number] = None,
        max_replica_delay_for_distributed_queries: typing.Optional[jsii.Number] = None,
        max_result_bytes: typing.Optional[jsii.Number] = None,
        max_result_rows: typing.Optional[jsii.Number] = None,
        max_rows_in_distinct: typing.Optional[jsii.Number] = None,
        max_rows_in_join: typing.Optional[jsii.Number] = None,
        max_rows_in_set: typing.Optional[jsii.Number] = None,
        max_rows_to_group_by: typing.Optional[jsii.Number] = None,
        max_rows_to_read: typing.Optional[jsii.Number] = None,
        max_rows_to_sort: typing.Optional[jsii.Number] = None,
        max_rows_to_transfer: typing.Optional[jsii.Number] = None,
        max_temporary_columns: typing.Optional[jsii.Number] = None,
        max_temporary_non_const_columns: typing.Optional[jsii.Number] = None,
        max_threads: typing.Optional[jsii.Number] = None,
        merge_tree_max_bytes_to_use_cache: typing.Optional[jsii.Number] = None,
        merge_tree_max_rows_to_use_cache: typing.Optional[jsii.Number] = None,
        merge_tree_min_bytes_for_concurrent_read: typing.Optional[jsii.Number] = None,
        merge_tree_min_rows_for_concurrent_read: typing.Optional[jsii.Number] = None,
        min_bytes_to_use_direct_io: typing.Optional[jsii.Number] = None,
        min_count_to_compile: typing.Optional[jsii.Number] = None,
        min_count_to_compile_expression: typing.Optional[jsii.Number] = None,
        min_execution_speed: typing.Optional[jsii.Number] = None,
        min_execution_speed_bytes: typing.Optional[jsii.Number] = None,
        min_insert_block_size_bytes: typing.Optional[jsii.Number] = None,
        min_insert_block_size_rows: typing.Optional[jsii.Number] = None,
        output_format_json_quote64_bit_integers: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        output_format_json_quote_denormals: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        priority: typing.Optional[jsii.Number] = None,
        quota_mode: typing.Optional[builtins.str] = None,
        readonly: typing.Optional[jsii.Number] = None,
        read_overflow_mode: typing.Optional[builtins.str] = None,
        receive_timeout: typing.Optional[jsii.Number] = None,
        replication_alter_partitions_sync: typing.Optional[jsii.Number] = None,
        result_overflow_mode: typing.Optional[builtins.str] = None,
        select_sequential_consistency: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        send_progress_in_http_headers: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        send_timeout: typing.Optional[jsii.Number] = None,
        set_overflow_mode: typing.Optional[builtins.str] = None,
        skip_unavailable_shards: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        sort_overflow_mode: typing.Optional[builtins.str] = None,
        timeout_overflow_mode: typing.Optional[builtins.str] = None,
        transfer_overflow_mode: typing.Optional[builtins.str] = None,
        transform_null_in: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        use_uncompressed_cache: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param add_http_cors_header: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#add_http_cors_header MdbClickhouseCluster#add_http_cors_header}.
        :param allow_ddl: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#allow_ddl MdbClickhouseCluster#allow_ddl}.
        :param compile: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#compile MdbClickhouseCluster#compile}.
        :param compile_expressions: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#compile_expressions MdbClickhouseCluster#compile_expressions}.
        :param connect_timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#connect_timeout MdbClickhouseCluster#connect_timeout}.
        :param count_distinct_implementation: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#count_distinct_implementation MdbClickhouseCluster#count_distinct_implementation}.
        :param distinct_overflow_mode: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#distinct_overflow_mode MdbClickhouseCluster#distinct_overflow_mode}.
        :param distributed_aggregation_memory_efficient: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#distributed_aggregation_memory_efficient MdbClickhouseCluster#distributed_aggregation_memory_efficient}.
        :param distributed_ddl_task_timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#distributed_ddl_task_timeout MdbClickhouseCluster#distributed_ddl_task_timeout}.
        :param distributed_product_mode: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#distributed_product_mode MdbClickhouseCluster#distributed_product_mode}.
        :param empty_result_for_aggregation_by_empty_set: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#empty_result_for_aggregation_by_empty_set MdbClickhouseCluster#empty_result_for_aggregation_by_empty_set}.
        :param enable_http_compression: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#enable_http_compression MdbClickhouseCluster#enable_http_compression}.
        :param fallback_to_stale_replicas_for_distributed_queries: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#fallback_to_stale_replicas_for_distributed_queries MdbClickhouseCluster#fallback_to_stale_replicas_for_distributed_queries}.
        :param force_index_by_date: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#force_index_by_date MdbClickhouseCluster#force_index_by_date}.
        :param force_primary_key: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#force_primary_key MdbClickhouseCluster#force_primary_key}.
        :param group_by_overflow_mode: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#group_by_overflow_mode MdbClickhouseCluster#group_by_overflow_mode}.
        :param group_by_two_level_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#group_by_two_level_threshold MdbClickhouseCluster#group_by_two_level_threshold}.
        :param group_by_two_level_threshold_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#group_by_two_level_threshold_bytes MdbClickhouseCluster#group_by_two_level_threshold_bytes}.
        :param http_connection_timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#http_connection_timeout MdbClickhouseCluster#http_connection_timeout}.
        :param http_headers_progress_interval: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#http_headers_progress_interval MdbClickhouseCluster#http_headers_progress_interval}.
        :param http_receive_timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#http_receive_timeout MdbClickhouseCluster#http_receive_timeout}.
        :param http_send_timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#http_send_timeout MdbClickhouseCluster#http_send_timeout}.
        :param input_format_defaults_for_omitted_fields: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#input_format_defaults_for_omitted_fields MdbClickhouseCluster#input_format_defaults_for_omitted_fields}.
        :param input_format_values_interpret_expressions: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#input_format_values_interpret_expressions MdbClickhouseCluster#input_format_values_interpret_expressions}.
        :param insert_quorum: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#insert_quorum MdbClickhouseCluster#insert_quorum}.
        :param insert_quorum_timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#insert_quorum_timeout MdbClickhouseCluster#insert_quorum_timeout}.
        :param joined_subquery_requires_alias: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#joined_subquery_requires_alias MdbClickhouseCluster#joined_subquery_requires_alias}.
        :param join_overflow_mode: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#join_overflow_mode MdbClickhouseCluster#join_overflow_mode}.
        :param join_use_nulls: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#join_use_nulls MdbClickhouseCluster#join_use_nulls}.
        :param low_cardinality_allow_in_native_format: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#low_cardinality_allow_in_native_format MdbClickhouseCluster#low_cardinality_allow_in_native_format}.
        :param max_ast_depth: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_ast_depth MdbClickhouseCluster#max_ast_depth}.
        :param max_ast_elements: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_ast_elements MdbClickhouseCluster#max_ast_elements}.
        :param max_block_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_block_size MdbClickhouseCluster#max_block_size}.
        :param max_bytes_before_external_group_by: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_bytes_before_external_group_by MdbClickhouseCluster#max_bytes_before_external_group_by}.
        :param max_bytes_before_external_sort: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_bytes_before_external_sort MdbClickhouseCluster#max_bytes_before_external_sort}.
        :param max_bytes_in_distinct: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_bytes_in_distinct MdbClickhouseCluster#max_bytes_in_distinct}.
        :param max_bytes_in_join: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_bytes_in_join MdbClickhouseCluster#max_bytes_in_join}.
        :param max_bytes_in_set: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_bytes_in_set MdbClickhouseCluster#max_bytes_in_set}.
        :param max_bytes_to_read: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_bytes_to_read MdbClickhouseCluster#max_bytes_to_read}.
        :param max_bytes_to_sort: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_bytes_to_sort MdbClickhouseCluster#max_bytes_to_sort}.
        :param max_bytes_to_transfer: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_bytes_to_transfer MdbClickhouseCluster#max_bytes_to_transfer}.
        :param max_columns_to_read: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_columns_to_read MdbClickhouseCluster#max_columns_to_read}.
        :param max_execution_time: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_execution_time MdbClickhouseCluster#max_execution_time}.
        :param max_expanded_ast_elements: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_expanded_ast_elements MdbClickhouseCluster#max_expanded_ast_elements}.
        :param max_insert_block_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_insert_block_size MdbClickhouseCluster#max_insert_block_size}.
        :param max_memory_usage: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_memory_usage MdbClickhouseCluster#max_memory_usage}.
        :param max_memory_usage_for_user: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_memory_usage_for_user MdbClickhouseCluster#max_memory_usage_for_user}.
        :param max_network_bandwidth: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_network_bandwidth MdbClickhouseCluster#max_network_bandwidth}.
        :param max_network_bandwidth_for_user: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_network_bandwidth_for_user MdbClickhouseCluster#max_network_bandwidth_for_user}.
        :param max_query_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_query_size MdbClickhouseCluster#max_query_size}.
        :param max_replica_delay_for_distributed_queries: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_replica_delay_for_distributed_queries MdbClickhouseCluster#max_replica_delay_for_distributed_queries}.
        :param max_result_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_result_bytes MdbClickhouseCluster#max_result_bytes}.
        :param max_result_rows: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_result_rows MdbClickhouseCluster#max_result_rows}.
        :param max_rows_in_distinct: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_rows_in_distinct MdbClickhouseCluster#max_rows_in_distinct}.
        :param max_rows_in_join: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_rows_in_join MdbClickhouseCluster#max_rows_in_join}.
        :param max_rows_in_set: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_rows_in_set MdbClickhouseCluster#max_rows_in_set}.
        :param max_rows_to_group_by: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_rows_to_group_by MdbClickhouseCluster#max_rows_to_group_by}.
        :param max_rows_to_read: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_rows_to_read MdbClickhouseCluster#max_rows_to_read}.
        :param max_rows_to_sort: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_rows_to_sort MdbClickhouseCluster#max_rows_to_sort}.
        :param max_rows_to_transfer: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_rows_to_transfer MdbClickhouseCluster#max_rows_to_transfer}.
        :param max_temporary_columns: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_temporary_columns MdbClickhouseCluster#max_temporary_columns}.
        :param max_temporary_non_const_columns: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_temporary_non_const_columns MdbClickhouseCluster#max_temporary_non_const_columns}.
        :param max_threads: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_threads MdbClickhouseCluster#max_threads}.
        :param merge_tree_max_bytes_to_use_cache: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#merge_tree_max_bytes_to_use_cache MdbClickhouseCluster#merge_tree_max_bytes_to_use_cache}.
        :param merge_tree_max_rows_to_use_cache: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#merge_tree_max_rows_to_use_cache MdbClickhouseCluster#merge_tree_max_rows_to_use_cache}.
        :param merge_tree_min_bytes_for_concurrent_read: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#merge_tree_min_bytes_for_concurrent_read MdbClickhouseCluster#merge_tree_min_bytes_for_concurrent_read}.
        :param merge_tree_min_rows_for_concurrent_read: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#merge_tree_min_rows_for_concurrent_read MdbClickhouseCluster#merge_tree_min_rows_for_concurrent_read}.
        :param min_bytes_to_use_direct_io: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#min_bytes_to_use_direct_io MdbClickhouseCluster#min_bytes_to_use_direct_io}.
        :param min_count_to_compile: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#min_count_to_compile MdbClickhouseCluster#min_count_to_compile}.
        :param min_count_to_compile_expression: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#min_count_to_compile_expression MdbClickhouseCluster#min_count_to_compile_expression}.
        :param min_execution_speed: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#min_execution_speed MdbClickhouseCluster#min_execution_speed}.
        :param min_execution_speed_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#min_execution_speed_bytes MdbClickhouseCluster#min_execution_speed_bytes}.
        :param min_insert_block_size_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#min_insert_block_size_bytes MdbClickhouseCluster#min_insert_block_size_bytes}.
        :param min_insert_block_size_rows: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#min_insert_block_size_rows MdbClickhouseCluster#min_insert_block_size_rows}.
        :param output_format_json_quote64_bit_integers: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#output_format_json_quote_64bit_integers MdbClickhouseCluster#output_format_json_quote_64bit_integers}.
        :param output_format_json_quote_denormals: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#output_format_json_quote_denormals MdbClickhouseCluster#output_format_json_quote_denormals}.
        :param priority: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#priority MdbClickhouseCluster#priority}.
        :param quota_mode: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#quota_mode MdbClickhouseCluster#quota_mode}.
        :param readonly: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#readonly MdbClickhouseCluster#readonly}.
        :param read_overflow_mode: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#read_overflow_mode MdbClickhouseCluster#read_overflow_mode}.
        :param receive_timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#receive_timeout MdbClickhouseCluster#receive_timeout}.
        :param replication_alter_partitions_sync: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#replication_alter_partitions_sync MdbClickhouseCluster#replication_alter_partitions_sync}.
        :param result_overflow_mode: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#result_overflow_mode MdbClickhouseCluster#result_overflow_mode}.
        :param select_sequential_consistency: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#select_sequential_consistency MdbClickhouseCluster#select_sequential_consistency}.
        :param send_progress_in_http_headers: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#send_progress_in_http_headers MdbClickhouseCluster#send_progress_in_http_headers}.
        :param send_timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#send_timeout MdbClickhouseCluster#send_timeout}.
        :param set_overflow_mode: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#set_overflow_mode MdbClickhouseCluster#set_overflow_mode}.
        :param skip_unavailable_shards: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#skip_unavailable_shards MdbClickhouseCluster#skip_unavailable_shards}.
        :param sort_overflow_mode: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#sort_overflow_mode MdbClickhouseCluster#sort_overflow_mode}.
        :param timeout_overflow_mode: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#timeout_overflow_mode MdbClickhouseCluster#timeout_overflow_mode}.
        :param transfer_overflow_mode: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#transfer_overflow_mode MdbClickhouseCluster#transfer_overflow_mode}.
        :param transform_null_in: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#transform_null_in MdbClickhouseCluster#transform_null_in}.
        :param use_uncompressed_cache: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#use_uncompressed_cache MdbClickhouseCluster#use_uncompressed_cache}.
        '''
        value = MdbClickhouseClusterUserSettings(
            add_http_cors_header=add_http_cors_header,
            allow_ddl=allow_ddl,
            compile=compile,
            compile_expressions=compile_expressions,
            connect_timeout=connect_timeout,
            count_distinct_implementation=count_distinct_implementation,
            distinct_overflow_mode=distinct_overflow_mode,
            distributed_aggregation_memory_efficient=distributed_aggregation_memory_efficient,
            distributed_ddl_task_timeout=distributed_ddl_task_timeout,
            distributed_product_mode=distributed_product_mode,
            empty_result_for_aggregation_by_empty_set=empty_result_for_aggregation_by_empty_set,
            enable_http_compression=enable_http_compression,
            fallback_to_stale_replicas_for_distributed_queries=fallback_to_stale_replicas_for_distributed_queries,
            force_index_by_date=force_index_by_date,
            force_primary_key=force_primary_key,
            group_by_overflow_mode=group_by_overflow_mode,
            group_by_two_level_threshold=group_by_two_level_threshold,
            group_by_two_level_threshold_bytes=group_by_two_level_threshold_bytes,
            http_connection_timeout=http_connection_timeout,
            http_headers_progress_interval=http_headers_progress_interval,
            http_receive_timeout=http_receive_timeout,
            http_send_timeout=http_send_timeout,
            input_format_defaults_for_omitted_fields=input_format_defaults_for_omitted_fields,
            input_format_values_interpret_expressions=input_format_values_interpret_expressions,
            insert_quorum=insert_quorum,
            insert_quorum_timeout=insert_quorum_timeout,
            joined_subquery_requires_alias=joined_subquery_requires_alias,
            join_overflow_mode=join_overflow_mode,
            join_use_nulls=join_use_nulls,
            low_cardinality_allow_in_native_format=low_cardinality_allow_in_native_format,
            max_ast_depth=max_ast_depth,
            max_ast_elements=max_ast_elements,
            max_block_size=max_block_size,
            max_bytes_before_external_group_by=max_bytes_before_external_group_by,
            max_bytes_before_external_sort=max_bytes_before_external_sort,
            max_bytes_in_distinct=max_bytes_in_distinct,
            max_bytes_in_join=max_bytes_in_join,
            max_bytes_in_set=max_bytes_in_set,
            max_bytes_to_read=max_bytes_to_read,
            max_bytes_to_sort=max_bytes_to_sort,
            max_bytes_to_transfer=max_bytes_to_transfer,
            max_columns_to_read=max_columns_to_read,
            max_execution_time=max_execution_time,
            max_expanded_ast_elements=max_expanded_ast_elements,
            max_insert_block_size=max_insert_block_size,
            max_memory_usage=max_memory_usage,
            max_memory_usage_for_user=max_memory_usage_for_user,
            max_network_bandwidth=max_network_bandwidth,
            max_network_bandwidth_for_user=max_network_bandwidth_for_user,
            max_query_size=max_query_size,
            max_replica_delay_for_distributed_queries=max_replica_delay_for_distributed_queries,
            max_result_bytes=max_result_bytes,
            max_result_rows=max_result_rows,
            max_rows_in_distinct=max_rows_in_distinct,
            max_rows_in_join=max_rows_in_join,
            max_rows_in_set=max_rows_in_set,
            max_rows_to_group_by=max_rows_to_group_by,
            max_rows_to_read=max_rows_to_read,
            max_rows_to_sort=max_rows_to_sort,
            max_rows_to_transfer=max_rows_to_transfer,
            max_temporary_columns=max_temporary_columns,
            max_temporary_non_const_columns=max_temporary_non_const_columns,
            max_threads=max_threads,
            merge_tree_max_bytes_to_use_cache=merge_tree_max_bytes_to_use_cache,
            merge_tree_max_rows_to_use_cache=merge_tree_max_rows_to_use_cache,
            merge_tree_min_bytes_for_concurrent_read=merge_tree_min_bytes_for_concurrent_read,
            merge_tree_min_rows_for_concurrent_read=merge_tree_min_rows_for_concurrent_read,
            min_bytes_to_use_direct_io=min_bytes_to_use_direct_io,
            min_count_to_compile=min_count_to_compile,
            min_count_to_compile_expression=min_count_to_compile_expression,
            min_execution_speed=min_execution_speed,
            min_execution_speed_bytes=min_execution_speed_bytes,
            min_insert_block_size_bytes=min_insert_block_size_bytes,
            min_insert_block_size_rows=min_insert_block_size_rows,
            output_format_json_quote64_bit_integers=output_format_json_quote64_bit_integers,
            output_format_json_quote_denormals=output_format_json_quote_denormals,
            priority=priority,
            quota_mode=quota_mode,
            readonly=readonly,
            read_overflow_mode=read_overflow_mode,
            receive_timeout=receive_timeout,
            replication_alter_partitions_sync=replication_alter_partitions_sync,
            result_overflow_mode=result_overflow_mode,
            select_sequential_consistency=select_sequential_consistency,
            send_progress_in_http_headers=send_progress_in_http_headers,
            send_timeout=send_timeout,
            set_overflow_mode=set_overflow_mode,
            skip_unavailable_shards=skip_unavailable_shards,
            sort_overflow_mode=sort_overflow_mode,
            timeout_overflow_mode=timeout_overflow_mode,
            transfer_overflow_mode=transfer_overflow_mode,
            transform_null_in=transform_null_in,
            use_uncompressed_cache=use_uncompressed_cache,
        )

        return typing.cast(None, jsii.invoke(self, "putSettings", [value]))

    @jsii.member(jsii_name="resetPermission")
    def reset_permission(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPermission", []))

    @jsii.member(jsii_name="resetQuota")
    def reset_quota(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQuota", []))

    @jsii.member(jsii_name="resetSettings")
    def reset_settings(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSettings", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="permission")
    def permission(self) -> "MdbClickhouseClusterUserPermissionList":
        return typing.cast("MdbClickhouseClusterUserPermissionList", jsii.get(self, "permission"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="quota")
    def quota(self) -> "MdbClickhouseClusterUserQuotaList":
        return typing.cast("MdbClickhouseClusterUserQuotaList", jsii.get(self, "quota"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="settings")
    def settings(self) -> "MdbClickhouseClusterUserSettingsOutputReference":
        return typing.cast("MdbClickhouseClusterUserSettingsOutputReference", jsii.get(self, "settings"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="passwordInput")
    def password_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "passwordInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="permissionInput")
    def permission_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterUserPermission"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterUserPermission"]]], jsii.get(self, "permissionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="quotaInput")
    def quota_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterUserQuota"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbClickhouseClusterUserQuota"]]], jsii.get(self, "quotaInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="settingsInput")
    def settings_input(self) -> typing.Optional["MdbClickhouseClusterUserSettings"]:
        return typing.cast(typing.Optional["MdbClickhouseClusterUserSettings"], jsii.get(self, "settingsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="password")
    def password(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "password"))

    @password.setter
    def password(self, value: builtins.str) -> None:
        jsii.set(self, "password", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterUser]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterUser]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterUser]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterUserPermission",
    jsii_struct_bases=[],
    name_mapping={"database_name": "databaseName"},
)
class MdbClickhouseClusterUserPermission:
    def __init__(self, *, database_name: builtins.str) -> None:
        '''
        :param database_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#database_name MdbClickhouseCluster#database_name}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "database_name": database_name,
        }

    @builtins.property
    def database_name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#database_name MdbClickhouseCluster#database_name}.'''
        result = self._values.get("database_name")
        assert result is not None, "Required property 'database_name' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbClickhouseClusterUserPermission(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbClickhouseClusterUserPermissionList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterUserPermissionList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "MdbClickhouseClusterUserPermissionOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbClickhouseClusterUserPermissionOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterUserPermission]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterUserPermission]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterUserPermission]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbClickhouseClusterUserPermissionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterUserPermissionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databaseNameInput")
    def database_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "databaseNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databaseName")
    def database_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "databaseName"))

    @database_name.setter
    def database_name(self, value: builtins.str) -> None:
        jsii.set(self, "databaseName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterUserPermission]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterUserPermission]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterUserPermission]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterUserQuota",
    jsii_struct_bases=[],
    name_mapping={
        "interval_duration": "intervalDuration",
        "errors": "errors",
        "execution_time": "executionTime",
        "queries": "queries",
        "read_rows": "readRows",
        "result_rows": "resultRows",
    },
)
class MdbClickhouseClusterUserQuota:
    def __init__(
        self,
        *,
        interval_duration: jsii.Number,
        errors: typing.Optional[jsii.Number] = None,
        execution_time: typing.Optional[jsii.Number] = None,
        queries: typing.Optional[jsii.Number] = None,
        read_rows: typing.Optional[jsii.Number] = None,
        result_rows: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param interval_duration: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#interval_duration MdbClickhouseCluster#interval_duration}.
        :param errors: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#errors MdbClickhouseCluster#errors}.
        :param execution_time: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#execution_time MdbClickhouseCluster#execution_time}.
        :param queries: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#queries MdbClickhouseCluster#queries}.
        :param read_rows: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#read_rows MdbClickhouseCluster#read_rows}.
        :param result_rows: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#result_rows MdbClickhouseCluster#result_rows}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "interval_duration": interval_duration,
        }
        if errors is not None:
            self._values["errors"] = errors
        if execution_time is not None:
            self._values["execution_time"] = execution_time
        if queries is not None:
            self._values["queries"] = queries
        if read_rows is not None:
            self._values["read_rows"] = read_rows
        if result_rows is not None:
            self._values["result_rows"] = result_rows

    @builtins.property
    def interval_duration(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#interval_duration MdbClickhouseCluster#interval_duration}.'''
        result = self._values.get("interval_duration")
        assert result is not None, "Required property 'interval_duration' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def errors(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#errors MdbClickhouseCluster#errors}.'''
        result = self._values.get("errors")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def execution_time(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#execution_time MdbClickhouseCluster#execution_time}.'''
        result = self._values.get("execution_time")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def queries(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#queries MdbClickhouseCluster#queries}.'''
        result = self._values.get("queries")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def read_rows(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#read_rows MdbClickhouseCluster#read_rows}.'''
        result = self._values.get("read_rows")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def result_rows(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#result_rows MdbClickhouseCluster#result_rows}.'''
        result = self._values.get("result_rows")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbClickhouseClusterUserQuota(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbClickhouseClusterUserQuotaList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterUserQuotaList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "MdbClickhouseClusterUserQuotaOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbClickhouseClusterUserQuotaOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterUserQuota]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterUserQuota]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbClickhouseClusterUserQuota]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbClickhouseClusterUserQuotaOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterUserQuotaOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetErrors")
    def reset_errors(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetErrors", []))

    @jsii.member(jsii_name="resetExecutionTime")
    def reset_execution_time(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetExecutionTime", []))

    @jsii.member(jsii_name="resetQueries")
    def reset_queries(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQueries", []))

    @jsii.member(jsii_name="resetReadRows")
    def reset_read_rows(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetReadRows", []))

    @jsii.member(jsii_name="resetResultRows")
    def reset_result_rows(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetResultRows", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errorsInput")
    def errors_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "errorsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="executionTimeInput")
    def execution_time_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "executionTimeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="intervalDurationInput")
    def interval_duration_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "intervalDurationInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queriesInput")
    def queries_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "queriesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="readRowsInput")
    def read_rows_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "readRowsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resultRowsInput")
    def result_rows_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "resultRowsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errors")
    def errors(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "errors"))

    @errors.setter
    def errors(self, value: jsii.Number) -> None:
        jsii.set(self, "errors", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="executionTime")
    def execution_time(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "executionTime"))

    @execution_time.setter
    def execution_time(self, value: jsii.Number) -> None:
        jsii.set(self, "executionTime", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="intervalDuration")
    def interval_duration(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "intervalDuration"))

    @interval_duration.setter
    def interval_duration(self, value: jsii.Number) -> None:
        jsii.set(self, "intervalDuration", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queries")
    def queries(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "queries"))

    @queries.setter
    def queries(self, value: jsii.Number) -> None:
        jsii.set(self, "queries", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="readRows")
    def read_rows(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "readRows"))

    @read_rows.setter
    def read_rows(self, value: jsii.Number) -> None:
        jsii.set(self, "readRows", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resultRows")
    def result_rows(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "resultRows"))

    @result_rows.setter
    def result_rows(self, value: jsii.Number) -> None:
        jsii.set(self, "resultRows", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterUserQuota]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterUserQuota]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbClickhouseClusterUserQuota]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterUserSettings",
    jsii_struct_bases=[],
    name_mapping={
        "add_http_cors_header": "addHttpCorsHeader",
        "allow_ddl": "allowDdl",
        "compile": "compile",
        "compile_expressions": "compileExpressions",
        "connect_timeout": "connectTimeout",
        "count_distinct_implementation": "countDistinctImplementation",
        "distinct_overflow_mode": "distinctOverflowMode",
        "distributed_aggregation_memory_efficient": "distributedAggregationMemoryEfficient",
        "distributed_ddl_task_timeout": "distributedDdlTaskTimeout",
        "distributed_product_mode": "distributedProductMode",
        "empty_result_for_aggregation_by_empty_set": "emptyResultForAggregationByEmptySet",
        "enable_http_compression": "enableHttpCompression",
        "fallback_to_stale_replicas_for_distributed_queries": "fallbackToStaleReplicasForDistributedQueries",
        "force_index_by_date": "forceIndexByDate",
        "force_primary_key": "forcePrimaryKey",
        "group_by_overflow_mode": "groupByOverflowMode",
        "group_by_two_level_threshold": "groupByTwoLevelThreshold",
        "group_by_two_level_threshold_bytes": "groupByTwoLevelThresholdBytes",
        "http_connection_timeout": "httpConnectionTimeout",
        "http_headers_progress_interval": "httpHeadersProgressInterval",
        "http_receive_timeout": "httpReceiveTimeout",
        "http_send_timeout": "httpSendTimeout",
        "input_format_defaults_for_omitted_fields": "inputFormatDefaultsForOmittedFields",
        "input_format_values_interpret_expressions": "inputFormatValuesInterpretExpressions",
        "insert_quorum": "insertQuorum",
        "insert_quorum_timeout": "insertQuorumTimeout",
        "joined_subquery_requires_alias": "joinedSubqueryRequiresAlias",
        "join_overflow_mode": "joinOverflowMode",
        "join_use_nulls": "joinUseNulls",
        "low_cardinality_allow_in_native_format": "lowCardinalityAllowInNativeFormat",
        "max_ast_depth": "maxAstDepth",
        "max_ast_elements": "maxAstElements",
        "max_block_size": "maxBlockSize",
        "max_bytes_before_external_group_by": "maxBytesBeforeExternalGroupBy",
        "max_bytes_before_external_sort": "maxBytesBeforeExternalSort",
        "max_bytes_in_distinct": "maxBytesInDistinct",
        "max_bytes_in_join": "maxBytesInJoin",
        "max_bytes_in_set": "maxBytesInSet",
        "max_bytes_to_read": "maxBytesToRead",
        "max_bytes_to_sort": "maxBytesToSort",
        "max_bytes_to_transfer": "maxBytesToTransfer",
        "max_columns_to_read": "maxColumnsToRead",
        "max_execution_time": "maxExecutionTime",
        "max_expanded_ast_elements": "maxExpandedAstElements",
        "max_insert_block_size": "maxInsertBlockSize",
        "max_memory_usage": "maxMemoryUsage",
        "max_memory_usage_for_user": "maxMemoryUsageForUser",
        "max_network_bandwidth": "maxNetworkBandwidth",
        "max_network_bandwidth_for_user": "maxNetworkBandwidthForUser",
        "max_query_size": "maxQuerySize",
        "max_replica_delay_for_distributed_queries": "maxReplicaDelayForDistributedQueries",
        "max_result_bytes": "maxResultBytes",
        "max_result_rows": "maxResultRows",
        "max_rows_in_distinct": "maxRowsInDistinct",
        "max_rows_in_join": "maxRowsInJoin",
        "max_rows_in_set": "maxRowsInSet",
        "max_rows_to_group_by": "maxRowsToGroupBy",
        "max_rows_to_read": "maxRowsToRead",
        "max_rows_to_sort": "maxRowsToSort",
        "max_rows_to_transfer": "maxRowsToTransfer",
        "max_temporary_columns": "maxTemporaryColumns",
        "max_temporary_non_const_columns": "maxTemporaryNonConstColumns",
        "max_threads": "maxThreads",
        "merge_tree_max_bytes_to_use_cache": "mergeTreeMaxBytesToUseCache",
        "merge_tree_max_rows_to_use_cache": "mergeTreeMaxRowsToUseCache",
        "merge_tree_min_bytes_for_concurrent_read": "mergeTreeMinBytesForConcurrentRead",
        "merge_tree_min_rows_for_concurrent_read": "mergeTreeMinRowsForConcurrentRead",
        "min_bytes_to_use_direct_io": "minBytesToUseDirectIo",
        "min_count_to_compile": "minCountToCompile",
        "min_count_to_compile_expression": "minCountToCompileExpression",
        "min_execution_speed": "minExecutionSpeed",
        "min_execution_speed_bytes": "minExecutionSpeedBytes",
        "min_insert_block_size_bytes": "minInsertBlockSizeBytes",
        "min_insert_block_size_rows": "minInsertBlockSizeRows",
        "output_format_json_quote64_bit_integers": "outputFormatJsonQuote64BitIntegers",
        "output_format_json_quote_denormals": "outputFormatJsonQuoteDenormals",
        "priority": "priority",
        "quota_mode": "quotaMode",
        "readonly": "readonly",
        "read_overflow_mode": "readOverflowMode",
        "receive_timeout": "receiveTimeout",
        "replication_alter_partitions_sync": "replicationAlterPartitionsSync",
        "result_overflow_mode": "resultOverflowMode",
        "select_sequential_consistency": "selectSequentialConsistency",
        "send_progress_in_http_headers": "sendProgressInHttpHeaders",
        "send_timeout": "sendTimeout",
        "set_overflow_mode": "setOverflowMode",
        "skip_unavailable_shards": "skipUnavailableShards",
        "sort_overflow_mode": "sortOverflowMode",
        "timeout_overflow_mode": "timeoutOverflowMode",
        "transfer_overflow_mode": "transferOverflowMode",
        "transform_null_in": "transformNullIn",
        "use_uncompressed_cache": "useUncompressedCache",
    },
)
class MdbClickhouseClusterUserSettings:
    def __init__(
        self,
        *,
        add_http_cors_header: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        allow_ddl: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        compile: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        compile_expressions: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        connect_timeout: typing.Optional[jsii.Number] = None,
        count_distinct_implementation: typing.Optional[builtins.str] = None,
        distinct_overflow_mode: typing.Optional[builtins.str] = None,
        distributed_aggregation_memory_efficient: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        distributed_ddl_task_timeout: typing.Optional[jsii.Number] = None,
        distributed_product_mode: typing.Optional[builtins.str] = None,
        empty_result_for_aggregation_by_empty_set: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        enable_http_compression: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        fallback_to_stale_replicas_for_distributed_queries: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        force_index_by_date: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        force_primary_key: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        group_by_overflow_mode: typing.Optional[builtins.str] = None,
        group_by_two_level_threshold: typing.Optional[jsii.Number] = None,
        group_by_two_level_threshold_bytes: typing.Optional[jsii.Number] = None,
        http_connection_timeout: typing.Optional[jsii.Number] = None,
        http_headers_progress_interval: typing.Optional[jsii.Number] = None,
        http_receive_timeout: typing.Optional[jsii.Number] = None,
        http_send_timeout: typing.Optional[jsii.Number] = None,
        input_format_defaults_for_omitted_fields: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        input_format_values_interpret_expressions: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        insert_quorum: typing.Optional[jsii.Number] = None,
        insert_quorum_timeout: typing.Optional[jsii.Number] = None,
        joined_subquery_requires_alias: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        join_overflow_mode: typing.Optional[builtins.str] = None,
        join_use_nulls: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        low_cardinality_allow_in_native_format: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        max_ast_depth: typing.Optional[jsii.Number] = None,
        max_ast_elements: typing.Optional[jsii.Number] = None,
        max_block_size: typing.Optional[jsii.Number] = None,
        max_bytes_before_external_group_by: typing.Optional[jsii.Number] = None,
        max_bytes_before_external_sort: typing.Optional[jsii.Number] = None,
        max_bytes_in_distinct: typing.Optional[jsii.Number] = None,
        max_bytes_in_join: typing.Optional[jsii.Number] = None,
        max_bytes_in_set: typing.Optional[jsii.Number] = None,
        max_bytes_to_read: typing.Optional[jsii.Number] = None,
        max_bytes_to_sort: typing.Optional[jsii.Number] = None,
        max_bytes_to_transfer: typing.Optional[jsii.Number] = None,
        max_columns_to_read: typing.Optional[jsii.Number] = None,
        max_execution_time: typing.Optional[jsii.Number] = None,
        max_expanded_ast_elements: typing.Optional[jsii.Number] = None,
        max_insert_block_size: typing.Optional[jsii.Number] = None,
        max_memory_usage: typing.Optional[jsii.Number] = None,
        max_memory_usage_for_user: typing.Optional[jsii.Number] = None,
        max_network_bandwidth: typing.Optional[jsii.Number] = None,
        max_network_bandwidth_for_user: typing.Optional[jsii.Number] = None,
        max_query_size: typing.Optional[jsii.Number] = None,
        max_replica_delay_for_distributed_queries: typing.Optional[jsii.Number] = None,
        max_result_bytes: typing.Optional[jsii.Number] = None,
        max_result_rows: typing.Optional[jsii.Number] = None,
        max_rows_in_distinct: typing.Optional[jsii.Number] = None,
        max_rows_in_join: typing.Optional[jsii.Number] = None,
        max_rows_in_set: typing.Optional[jsii.Number] = None,
        max_rows_to_group_by: typing.Optional[jsii.Number] = None,
        max_rows_to_read: typing.Optional[jsii.Number] = None,
        max_rows_to_sort: typing.Optional[jsii.Number] = None,
        max_rows_to_transfer: typing.Optional[jsii.Number] = None,
        max_temporary_columns: typing.Optional[jsii.Number] = None,
        max_temporary_non_const_columns: typing.Optional[jsii.Number] = None,
        max_threads: typing.Optional[jsii.Number] = None,
        merge_tree_max_bytes_to_use_cache: typing.Optional[jsii.Number] = None,
        merge_tree_max_rows_to_use_cache: typing.Optional[jsii.Number] = None,
        merge_tree_min_bytes_for_concurrent_read: typing.Optional[jsii.Number] = None,
        merge_tree_min_rows_for_concurrent_read: typing.Optional[jsii.Number] = None,
        min_bytes_to_use_direct_io: typing.Optional[jsii.Number] = None,
        min_count_to_compile: typing.Optional[jsii.Number] = None,
        min_count_to_compile_expression: typing.Optional[jsii.Number] = None,
        min_execution_speed: typing.Optional[jsii.Number] = None,
        min_execution_speed_bytes: typing.Optional[jsii.Number] = None,
        min_insert_block_size_bytes: typing.Optional[jsii.Number] = None,
        min_insert_block_size_rows: typing.Optional[jsii.Number] = None,
        output_format_json_quote64_bit_integers: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        output_format_json_quote_denormals: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        priority: typing.Optional[jsii.Number] = None,
        quota_mode: typing.Optional[builtins.str] = None,
        readonly: typing.Optional[jsii.Number] = None,
        read_overflow_mode: typing.Optional[builtins.str] = None,
        receive_timeout: typing.Optional[jsii.Number] = None,
        replication_alter_partitions_sync: typing.Optional[jsii.Number] = None,
        result_overflow_mode: typing.Optional[builtins.str] = None,
        select_sequential_consistency: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        send_progress_in_http_headers: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        send_timeout: typing.Optional[jsii.Number] = None,
        set_overflow_mode: typing.Optional[builtins.str] = None,
        skip_unavailable_shards: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        sort_overflow_mode: typing.Optional[builtins.str] = None,
        timeout_overflow_mode: typing.Optional[builtins.str] = None,
        transfer_overflow_mode: typing.Optional[builtins.str] = None,
        transform_null_in: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        use_uncompressed_cache: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param add_http_cors_header: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#add_http_cors_header MdbClickhouseCluster#add_http_cors_header}.
        :param allow_ddl: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#allow_ddl MdbClickhouseCluster#allow_ddl}.
        :param compile: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#compile MdbClickhouseCluster#compile}.
        :param compile_expressions: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#compile_expressions MdbClickhouseCluster#compile_expressions}.
        :param connect_timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#connect_timeout MdbClickhouseCluster#connect_timeout}.
        :param count_distinct_implementation: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#count_distinct_implementation MdbClickhouseCluster#count_distinct_implementation}.
        :param distinct_overflow_mode: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#distinct_overflow_mode MdbClickhouseCluster#distinct_overflow_mode}.
        :param distributed_aggregation_memory_efficient: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#distributed_aggregation_memory_efficient MdbClickhouseCluster#distributed_aggregation_memory_efficient}.
        :param distributed_ddl_task_timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#distributed_ddl_task_timeout MdbClickhouseCluster#distributed_ddl_task_timeout}.
        :param distributed_product_mode: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#distributed_product_mode MdbClickhouseCluster#distributed_product_mode}.
        :param empty_result_for_aggregation_by_empty_set: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#empty_result_for_aggregation_by_empty_set MdbClickhouseCluster#empty_result_for_aggregation_by_empty_set}.
        :param enable_http_compression: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#enable_http_compression MdbClickhouseCluster#enable_http_compression}.
        :param fallback_to_stale_replicas_for_distributed_queries: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#fallback_to_stale_replicas_for_distributed_queries MdbClickhouseCluster#fallback_to_stale_replicas_for_distributed_queries}.
        :param force_index_by_date: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#force_index_by_date MdbClickhouseCluster#force_index_by_date}.
        :param force_primary_key: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#force_primary_key MdbClickhouseCluster#force_primary_key}.
        :param group_by_overflow_mode: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#group_by_overflow_mode MdbClickhouseCluster#group_by_overflow_mode}.
        :param group_by_two_level_threshold: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#group_by_two_level_threshold MdbClickhouseCluster#group_by_two_level_threshold}.
        :param group_by_two_level_threshold_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#group_by_two_level_threshold_bytes MdbClickhouseCluster#group_by_two_level_threshold_bytes}.
        :param http_connection_timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#http_connection_timeout MdbClickhouseCluster#http_connection_timeout}.
        :param http_headers_progress_interval: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#http_headers_progress_interval MdbClickhouseCluster#http_headers_progress_interval}.
        :param http_receive_timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#http_receive_timeout MdbClickhouseCluster#http_receive_timeout}.
        :param http_send_timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#http_send_timeout MdbClickhouseCluster#http_send_timeout}.
        :param input_format_defaults_for_omitted_fields: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#input_format_defaults_for_omitted_fields MdbClickhouseCluster#input_format_defaults_for_omitted_fields}.
        :param input_format_values_interpret_expressions: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#input_format_values_interpret_expressions MdbClickhouseCluster#input_format_values_interpret_expressions}.
        :param insert_quorum: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#insert_quorum MdbClickhouseCluster#insert_quorum}.
        :param insert_quorum_timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#insert_quorum_timeout MdbClickhouseCluster#insert_quorum_timeout}.
        :param joined_subquery_requires_alias: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#joined_subquery_requires_alias MdbClickhouseCluster#joined_subquery_requires_alias}.
        :param join_overflow_mode: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#join_overflow_mode MdbClickhouseCluster#join_overflow_mode}.
        :param join_use_nulls: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#join_use_nulls MdbClickhouseCluster#join_use_nulls}.
        :param low_cardinality_allow_in_native_format: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#low_cardinality_allow_in_native_format MdbClickhouseCluster#low_cardinality_allow_in_native_format}.
        :param max_ast_depth: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_ast_depth MdbClickhouseCluster#max_ast_depth}.
        :param max_ast_elements: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_ast_elements MdbClickhouseCluster#max_ast_elements}.
        :param max_block_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_block_size MdbClickhouseCluster#max_block_size}.
        :param max_bytes_before_external_group_by: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_bytes_before_external_group_by MdbClickhouseCluster#max_bytes_before_external_group_by}.
        :param max_bytes_before_external_sort: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_bytes_before_external_sort MdbClickhouseCluster#max_bytes_before_external_sort}.
        :param max_bytes_in_distinct: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_bytes_in_distinct MdbClickhouseCluster#max_bytes_in_distinct}.
        :param max_bytes_in_join: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_bytes_in_join MdbClickhouseCluster#max_bytes_in_join}.
        :param max_bytes_in_set: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_bytes_in_set MdbClickhouseCluster#max_bytes_in_set}.
        :param max_bytes_to_read: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_bytes_to_read MdbClickhouseCluster#max_bytes_to_read}.
        :param max_bytes_to_sort: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_bytes_to_sort MdbClickhouseCluster#max_bytes_to_sort}.
        :param max_bytes_to_transfer: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_bytes_to_transfer MdbClickhouseCluster#max_bytes_to_transfer}.
        :param max_columns_to_read: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_columns_to_read MdbClickhouseCluster#max_columns_to_read}.
        :param max_execution_time: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_execution_time MdbClickhouseCluster#max_execution_time}.
        :param max_expanded_ast_elements: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_expanded_ast_elements MdbClickhouseCluster#max_expanded_ast_elements}.
        :param max_insert_block_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_insert_block_size MdbClickhouseCluster#max_insert_block_size}.
        :param max_memory_usage: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_memory_usage MdbClickhouseCluster#max_memory_usage}.
        :param max_memory_usage_for_user: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_memory_usage_for_user MdbClickhouseCluster#max_memory_usage_for_user}.
        :param max_network_bandwidth: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_network_bandwidth MdbClickhouseCluster#max_network_bandwidth}.
        :param max_network_bandwidth_for_user: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_network_bandwidth_for_user MdbClickhouseCluster#max_network_bandwidth_for_user}.
        :param max_query_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_query_size MdbClickhouseCluster#max_query_size}.
        :param max_replica_delay_for_distributed_queries: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_replica_delay_for_distributed_queries MdbClickhouseCluster#max_replica_delay_for_distributed_queries}.
        :param max_result_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_result_bytes MdbClickhouseCluster#max_result_bytes}.
        :param max_result_rows: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_result_rows MdbClickhouseCluster#max_result_rows}.
        :param max_rows_in_distinct: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_rows_in_distinct MdbClickhouseCluster#max_rows_in_distinct}.
        :param max_rows_in_join: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_rows_in_join MdbClickhouseCluster#max_rows_in_join}.
        :param max_rows_in_set: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_rows_in_set MdbClickhouseCluster#max_rows_in_set}.
        :param max_rows_to_group_by: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_rows_to_group_by MdbClickhouseCluster#max_rows_to_group_by}.
        :param max_rows_to_read: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_rows_to_read MdbClickhouseCluster#max_rows_to_read}.
        :param max_rows_to_sort: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_rows_to_sort MdbClickhouseCluster#max_rows_to_sort}.
        :param max_rows_to_transfer: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_rows_to_transfer MdbClickhouseCluster#max_rows_to_transfer}.
        :param max_temporary_columns: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_temporary_columns MdbClickhouseCluster#max_temporary_columns}.
        :param max_temporary_non_const_columns: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_temporary_non_const_columns MdbClickhouseCluster#max_temporary_non_const_columns}.
        :param max_threads: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_threads MdbClickhouseCluster#max_threads}.
        :param merge_tree_max_bytes_to_use_cache: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#merge_tree_max_bytes_to_use_cache MdbClickhouseCluster#merge_tree_max_bytes_to_use_cache}.
        :param merge_tree_max_rows_to_use_cache: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#merge_tree_max_rows_to_use_cache MdbClickhouseCluster#merge_tree_max_rows_to_use_cache}.
        :param merge_tree_min_bytes_for_concurrent_read: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#merge_tree_min_bytes_for_concurrent_read MdbClickhouseCluster#merge_tree_min_bytes_for_concurrent_read}.
        :param merge_tree_min_rows_for_concurrent_read: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#merge_tree_min_rows_for_concurrent_read MdbClickhouseCluster#merge_tree_min_rows_for_concurrent_read}.
        :param min_bytes_to_use_direct_io: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#min_bytes_to_use_direct_io MdbClickhouseCluster#min_bytes_to_use_direct_io}.
        :param min_count_to_compile: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#min_count_to_compile MdbClickhouseCluster#min_count_to_compile}.
        :param min_count_to_compile_expression: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#min_count_to_compile_expression MdbClickhouseCluster#min_count_to_compile_expression}.
        :param min_execution_speed: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#min_execution_speed MdbClickhouseCluster#min_execution_speed}.
        :param min_execution_speed_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#min_execution_speed_bytes MdbClickhouseCluster#min_execution_speed_bytes}.
        :param min_insert_block_size_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#min_insert_block_size_bytes MdbClickhouseCluster#min_insert_block_size_bytes}.
        :param min_insert_block_size_rows: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#min_insert_block_size_rows MdbClickhouseCluster#min_insert_block_size_rows}.
        :param output_format_json_quote64_bit_integers: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#output_format_json_quote_64bit_integers MdbClickhouseCluster#output_format_json_quote_64bit_integers}.
        :param output_format_json_quote_denormals: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#output_format_json_quote_denormals MdbClickhouseCluster#output_format_json_quote_denormals}.
        :param priority: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#priority MdbClickhouseCluster#priority}.
        :param quota_mode: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#quota_mode MdbClickhouseCluster#quota_mode}.
        :param readonly: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#readonly MdbClickhouseCluster#readonly}.
        :param read_overflow_mode: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#read_overflow_mode MdbClickhouseCluster#read_overflow_mode}.
        :param receive_timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#receive_timeout MdbClickhouseCluster#receive_timeout}.
        :param replication_alter_partitions_sync: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#replication_alter_partitions_sync MdbClickhouseCluster#replication_alter_partitions_sync}.
        :param result_overflow_mode: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#result_overflow_mode MdbClickhouseCluster#result_overflow_mode}.
        :param select_sequential_consistency: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#select_sequential_consistency MdbClickhouseCluster#select_sequential_consistency}.
        :param send_progress_in_http_headers: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#send_progress_in_http_headers MdbClickhouseCluster#send_progress_in_http_headers}.
        :param send_timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#send_timeout MdbClickhouseCluster#send_timeout}.
        :param set_overflow_mode: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#set_overflow_mode MdbClickhouseCluster#set_overflow_mode}.
        :param skip_unavailable_shards: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#skip_unavailable_shards MdbClickhouseCluster#skip_unavailable_shards}.
        :param sort_overflow_mode: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#sort_overflow_mode MdbClickhouseCluster#sort_overflow_mode}.
        :param timeout_overflow_mode: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#timeout_overflow_mode MdbClickhouseCluster#timeout_overflow_mode}.
        :param transfer_overflow_mode: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#transfer_overflow_mode MdbClickhouseCluster#transfer_overflow_mode}.
        :param transform_null_in: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#transform_null_in MdbClickhouseCluster#transform_null_in}.
        :param use_uncompressed_cache: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#use_uncompressed_cache MdbClickhouseCluster#use_uncompressed_cache}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if add_http_cors_header is not None:
            self._values["add_http_cors_header"] = add_http_cors_header
        if allow_ddl is not None:
            self._values["allow_ddl"] = allow_ddl
        if compile is not None:
            self._values["compile"] = compile
        if compile_expressions is not None:
            self._values["compile_expressions"] = compile_expressions
        if connect_timeout is not None:
            self._values["connect_timeout"] = connect_timeout
        if count_distinct_implementation is not None:
            self._values["count_distinct_implementation"] = count_distinct_implementation
        if distinct_overflow_mode is not None:
            self._values["distinct_overflow_mode"] = distinct_overflow_mode
        if distributed_aggregation_memory_efficient is not None:
            self._values["distributed_aggregation_memory_efficient"] = distributed_aggregation_memory_efficient
        if distributed_ddl_task_timeout is not None:
            self._values["distributed_ddl_task_timeout"] = distributed_ddl_task_timeout
        if distributed_product_mode is not None:
            self._values["distributed_product_mode"] = distributed_product_mode
        if empty_result_for_aggregation_by_empty_set is not None:
            self._values["empty_result_for_aggregation_by_empty_set"] = empty_result_for_aggregation_by_empty_set
        if enable_http_compression is not None:
            self._values["enable_http_compression"] = enable_http_compression
        if fallback_to_stale_replicas_for_distributed_queries is not None:
            self._values["fallback_to_stale_replicas_for_distributed_queries"] = fallback_to_stale_replicas_for_distributed_queries
        if force_index_by_date is not None:
            self._values["force_index_by_date"] = force_index_by_date
        if force_primary_key is not None:
            self._values["force_primary_key"] = force_primary_key
        if group_by_overflow_mode is not None:
            self._values["group_by_overflow_mode"] = group_by_overflow_mode
        if group_by_two_level_threshold is not None:
            self._values["group_by_two_level_threshold"] = group_by_two_level_threshold
        if group_by_two_level_threshold_bytes is not None:
            self._values["group_by_two_level_threshold_bytes"] = group_by_two_level_threshold_bytes
        if http_connection_timeout is not None:
            self._values["http_connection_timeout"] = http_connection_timeout
        if http_headers_progress_interval is not None:
            self._values["http_headers_progress_interval"] = http_headers_progress_interval
        if http_receive_timeout is not None:
            self._values["http_receive_timeout"] = http_receive_timeout
        if http_send_timeout is not None:
            self._values["http_send_timeout"] = http_send_timeout
        if input_format_defaults_for_omitted_fields is not None:
            self._values["input_format_defaults_for_omitted_fields"] = input_format_defaults_for_omitted_fields
        if input_format_values_interpret_expressions is not None:
            self._values["input_format_values_interpret_expressions"] = input_format_values_interpret_expressions
        if insert_quorum is not None:
            self._values["insert_quorum"] = insert_quorum
        if insert_quorum_timeout is not None:
            self._values["insert_quorum_timeout"] = insert_quorum_timeout
        if joined_subquery_requires_alias is not None:
            self._values["joined_subquery_requires_alias"] = joined_subquery_requires_alias
        if join_overflow_mode is not None:
            self._values["join_overflow_mode"] = join_overflow_mode
        if join_use_nulls is not None:
            self._values["join_use_nulls"] = join_use_nulls
        if low_cardinality_allow_in_native_format is not None:
            self._values["low_cardinality_allow_in_native_format"] = low_cardinality_allow_in_native_format
        if max_ast_depth is not None:
            self._values["max_ast_depth"] = max_ast_depth
        if max_ast_elements is not None:
            self._values["max_ast_elements"] = max_ast_elements
        if max_block_size is not None:
            self._values["max_block_size"] = max_block_size
        if max_bytes_before_external_group_by is not None:
            self._values["max_bytes_before_external_group_by"] = max_bytes_before_external_group_by
        if max_bytes_before_external_sort is not None:
            self._values["max_bytes_before_external_sort"] = max_bytes_before_external_sort
        if max_bytes_in_distinct is not None:
            self._values["max_bytes_in_distinct"] = max_bytes_in_distinct
        if max_bytes_in_join is not None:
            self._values["max_bytes_in_join"] = max_bytes_in_join
        if max_bytes_in_set is not None:
            self._values["max_bytes_in_set"] = max_bytes_in_set
        if max_bytes_to_read is not None:
            self._values["max_bytes_to_read"] = max_bytes_to_read
        if max_bytes_to_sort is not None:
            self._values["max_bytes_to_sort"] = max_bytes_to_sort
        if max_bytes_to_transfer is not None:
            self._values["max_bytes_to_transfer"] = max_bytes_to_transfer
        if max_columns_to_read is not None:
            self._values["max_columns_to_read"] = max_columns_to_read
        if max_execution_time is not None:
            self._values["max_execution_time"] = max_execution_time
        if max_expanded_ast_elements is not None:
            self._values["max_expanded_ast_elements"] = max_expanded_ast_elements
        if max_insert_block_size is not None:
            self._values["max_insert_block_size"] = max_insert_block_size
        if max_memory_usage is not None:
            self._values["max_memory_usage"] = max_memory_usage
        if max_memory_usage_for_user is not None:
            self._values["max_memory_usage_for_user"] = max_memory_usage_for_user
        if max_network_bandwidth is not None:
            self._values["max_network_bandwidth"] = max_network_bandwidth
        if max_network_bandwidth_for_user is not None:
            self._values["max_network_bandwidth_for_user"] = max_network_bandwidth_for_user
        if max_query_size is not None:
            self._values["max_query_size"] = max_query_size
        if max_replica_delay_for_distributed_queries is not None:
            self._values["max_replica_delay_for_distributed_queries"] = max_replica_delay_for_distributed_queries
        if max_result_bytes is not None:
            self._values["max_result_bytes"] = max_result_bytes
        if max_result_rows is not None:
            self._values["max_result_rows"] = max_result_rows
        if max_rows_in_distinct is not None:
            self._values["max_rows_in_distinct"] = max_rows_in_distinct
        if max_rows_in_join is not None:
            self._values["max_rows_in_join"] = max_rows_in_join
        if max_rows_in_set is not None:
            self._values["max_rows_in_set"] = max_rows_in_set
        if max_rows_to_group_by is not None:
            self._values["max_rows_to_group_by"] = max_rows_to_group_by
        if max_rows_to_read is not None:
            self._values["max_rows_to_read"] = max_rows_to_read
        if max_rows_to_sort is not None:
            self._values["max_rows_to_sort"] = max_rows_to_sort
        if max_rows_to_transfer is not None:
            self._values["max_rows_to_transfer"] = max_rows_to_transfer
        if max_temporary_columns is not None:
            self._values["max_temporary_columns"] = max_temporary_columns
        if max_temporary_non_const_columns is not None:
            self._values["max_temporary_non_const_columns"] = max_temporary_non_const_columns
        if max_threads is not None:
            self._values["max_threads"] = max_threads
        if merge_tree_max_bytes_to_use_cache is not None:
            self._values["merge_tree_max_bytes_to_use_cache"] = merge_tree_max_bytes_to_use_cache
        if merge_tree_max_rows_to_use_cache is not None:
            self._values["merge_tree_max_rows_to_use_cache"] = merge_tree_max_rows_to_use_cache
        if merge_tree_min_bytes_for_concurrent_read is not None:
            self._values["merge_tree_min_bytes_for_concurrent_read"] = merge_tree_min_bytes_for_concurrent_read
        if merge_tree_min_rows_for_concurrent_read is not None:
            self._values["merge_tree_min_rows_for_concurrent_read"] = merge_tree_min_rows_for_concurrent_read
        if min_bytes_to_use_direct_io is not None:
            self._values["min_bytes_to_use_direct_io"] = min_bytes_to_use_direct_io
        if min_count_to_compile is not None:
            self._values["min_count_to_compile"] = min_count_to_compile
        if min_count_to_compile_expression is not None:
            self._values["min_count_to_compile_expression"] = min_count_to_compile_expression
        if min_execution_speed is not None:
            self._values["min_execution_speed"] = min_execution_speed
        if min_execution_speed_bytes is not None:
            self._values["min_execution_speed_bytes"] = min_execution_speed_bytes
        if min_insert_block_size_bytes is not None:
            self._values["min_insert_block_size_bytes"] = min_insert_block_size_bytes
        if min_insert_block_size_rows is not None:
            self._values["min_insert_block_size_rows"] = min_insert_block_size_rows
        if output_format_json_quote64_bit_integers is not None:
            self._values["output_format_json_quote64_bit_integers"] = output_format_json_quote64_bit_integers
        if output_format_json_quote_denormals is not None:
            self._values["output_format_json_quote_denormals"] = output_format_json_quote_denormals
        if priority is not None:
            self._values["priority"] = priority
        if quota_mode is not None:
            self._values["quota_mode"] = quota_mode
        if readonly is not None:
            self._values["readonly"] = readonly
        if read_overflow_mode is not None:
            self._values["read_overflow_mode"] = read_overflow_mode
        if receive_timeout is not None:
            self._values["receive_timeout"] = receive_timeout
        if replication_alter_partitions_sync is not None:
            self._values["replication_alter_partitions_sync"] = replication_alter_partitions_sync
        if result_overflow_mode is not None:
            self._values["result_overflow_mode"] = result_overflow_mode
        if select_sequential_consistency is not None:
            self._values["select_sequential_consistency"] = select_sequential_consistency
        if send_progress_in_http_headers is not None:
            self._values["send_progress_in_http_headers"] = send_progress_in_http_headers
        if send_timeout is not None:
            self._values["send_timeout"] = send_timeout
        if set_overflow_mode is not None:
            self._values["set_overflow_mode"] = set_overflow_mode
        if skip_unavailable_shards is not None:
            self._values["skip_unavailable_shards"] = skip_unavailable_shards
        if sort_overflow_mode is not None:
            self._values["sort_overflow_mode"] = sort_overflow_mode
        if timeout_overflow_mode is not None:
            self._values["timeout_overflow_mode"] = timeout_overflow_mode
        if transfer_overflow_mode is not None:
            self._values["transfer_overflow_mode"] = transfer_overflow_mode
        if transform_null_in is not None:
            self._values["transform_null_in"] = transform_null_in
        if use_uncompressed_cache is not None:
            self._values["use_uncompressed_cache"] = use_uncompressed_cache

    @builtins.property
    def add_http_cors_header(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#add_http_cors_header MdbClickhouseCluster#add_http_cors_header}.'''
        result = self._values.get("add_http_cors_header")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def allow_ddl(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#allow_ddl MdbClickhouseCluster#allow_ddl}.'''
        result = self._values.get("allow_ddl")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def compile(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#compile MdbClickhouseCluster#compile}.'''
        result = self._values.get("compile")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def compile_expressions(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#compile_expressions MdbClickhouseCluster#compile_expressions}.'''
        result = self._values.get("compile_expressions")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def connect_timeout(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#connect_timeout MdbClickhouseCluster#connect_timeout}.'''
        result = self._values.get("connect_timeout")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def count_distinct_implementation(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#count_distinct_implementation MdbClickhouseCluster#count_distinct_implementation}.'''
        result = self._values.get("count_distinct_implementation")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def distinct_overflow_mode(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#distinct_overflow_mode MdbClickhouseCluster#distinct_overflow_mode}.'''
        result = self._values.get("distinct_overflow_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def distributed_aggregation_memory_efficient(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#distributed_aggregation_memory_efficient MdbClickhouseCluster#distributed_aggregation_memory_efficient}.'''
        result = self._values.get("distributed_aggregation_memory_efficient")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def distributed_ddl_task_timeout(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#distributed_ddl_task_timeout MdbClickhouseCluster#distributed_ddl_task_timeout}.'''
        result = self._values.get("distributed_ddl_task_timeout")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def distributed_product_mode(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#distributed_product_mode MdbClickhouseCluster#distributed_product_mode}.'''
        result = self._values.get("distributed_product_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def empty_result_for_aggregation_by_empty_set(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#empty_result_for_aggregation_by_empty_set MdbClickhouseCluster#empty_result_for_aggregation_by_empty_set}.'''
        result = self._values.get("empty_result_for_aggregation_by_empty_set")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def enable_http_compression(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#enable_http_compression MdbClickhouseCluster#enable_http_compression}.'''
        result = self._values.get("enable_http_compression")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def fallback_to_stale_replicas_for_distributed_queries(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#fallback_to_stale_replicas_for_distributed_queries MdbClickhouseCluster#fallback_to_stale_replicas_for_distributed_queries}.'''
        result = self._values.get("fallback_to_stale_replicas_for_distributed_queries")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def force_index_by_date(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#force_index_by_date MdbClickhouseCluster#force_index_by_date}.'''
        result = self._values.get("force_index_by_date")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def force_primary_key(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#force_primary_key MdbClickhouseCluster#force_primary_key}.'''
        result = self._values.get("force_primary_key")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def group_by_overflow_mode(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#group_by_overflow_mode MdbClickhouseCluster#group_by_overflow_mode}.'''
        result = self._values.get("group_by_overflow_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def group_by_two_level_threshold(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#group_by_two_level_threshold MdbClickhouseCluster#group_by_two_level_threshold}.'''
        result = self._values.get("group_by_two_level_threshold")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def group_by_two_level_threshold_bytes(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#group_by_two_level_threshold_bytes MdbClickhouseCluster#group_by_two_level_threshold_bytes}.'''
        result = self._values.get("group_by_two_level_threshold_bytes")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def http_connection_timeout(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#http_connection_timeout MdbClickhouseCluster#http_connection_timeout}.'''
        result = self._values.get("http_connection_timeout")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def http_headers_progress_interval(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#http_headers_progress_interval MdbClickhouseCluster#http_headers_progress_interval}.'''
        result = self._values.get("http_headers_progress_interval")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def http_receive_timeout(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#http_receive_timeout MdbClickhouseCluster#http_receive_timeout}.'''
        result = self._values.get("http_receive_timeout")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def http_send_timeout(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#http_send_timeout MdbClickhouseCluster#http_send_timeout}.'''
        result = self._values.get("http_send_timeout")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def input_format_defaults_for_omitted_fields(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#input_format_defaults_for_omitted_fields MdbClickhouseCluster#input_format_defaults_for_omitted_fields}.'''
        result = self._values.get("input_format_defaults_for_omitted_fields")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def input_format_values_interpret_expressions(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#input_format_values_interpret_expressions MdbClickhouseCluster#input_format_values_interpret_expressions}.'''
        result = self._values.get("input_format_values_interpret_expressions")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def insert_quorum(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#insert_quorum MdbClickhouseCluster#insert_quorum}.'''
        result = self._values.get("insert_quorum")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def insert_quorum_timeout(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#insert_quorum_timeout MdbClickhouseCluster#insert_quorum_timeout}.'''
        result = self._values.get("insert_quorum_timeout")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def joined_subquery_requires_alias(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#joined_subquery_requires_alias MdbClickhouseCluster#joined_subquery_requires_alias}.'''
        result = self._values.get("joined_subquery_requires_alias")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def join_overflow_mode(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#join_overflow_mode MdbClickhouseCluster#join_overflow_mode}.'''
        result = self._values.get("join_overflow_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def join_use_nulls(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#join_use_nulls MdbClickhouseCluster#join_use_nulls}.'''
        result = self._values.get("join_use_nulls")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def low_cardinality_allow_in_native_format(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#low_cardinality_allow_in_native_format MdbClickhouseCluster#low_cardinality_allow_in_native_format}.'''
        result = self._values.get("low_cardinality_allow_in_native_format")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def max_ast_depth(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_ast_depth MdbClickhouseCluster#max_ast_depth}.'''
        result = self._values.get("max_ast_depth")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_ast_elements(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_ast_elements MdbClickhouseCluster#max_ast_elements}.'''
        result = self._values.get("max_ast_elements")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_block_size(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_block_size MdbClickhouseCluster#max_block_size}.'''
        result = self._values.get("max_block_size")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_bytes_before_external_group_by(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_bytes_before_external_group_by MdbClickhouseCluster#max_bytes_before_external_group_by}.'''
        result = self._values.get("max_bytes_before_external_group_by")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_bytes_before_external_sort(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_bytes_before_external_sort MdbClickhouseCluster#max_bytes_before_external_sort}.'''
        result = self._values.get("max_bytes_before_external_sort")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_bytes_in_distinct(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_bytes_in_distinct MdbClickhouseCluster#max_bytes_in_distinct}.'''
        result = self._values.get("max_bytes_in_distinct")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_bytes_in_join(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_bytes_in_join MdbClickhouseCluster#max_bytes_in_join}.'''
        result = self._values.get("max_bytes_in_join")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_bytes_in_set(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_bytes_in_set MdbClickhouseCluster#max_bytes_in_set}.'''
        result = self._values.get("max_bytes_in_set")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_bytes_to_read(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_bytes_to_read MdbClickhouseCluster#max_bytes_to_read}.'''
        result = self._values.get("max_bytes_to_read")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_bytes_to_sort(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_bytes_to_sort MdbClickhouseCluster#max_bytes_to_sort}.'''
        result = self._values.get("max_bytes_to_sort")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_bytes_to_transfer(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_bytes_to_transfer MdbClickhouseCluster#max_bytes_to_transfer}.'''
        result = self._values.get("max_bytes_to_transfer")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_columns_to_read(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_columns_to_read MdbClickhouseCluster#max_columns_to_read}.'''
        result = self._values.get("max_columns_to_read")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_execution_time(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_execution_time MdbClickhouseCluster#max_execution_time}.'''
        result = self._values.get("max_execution_time")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_expanded_ast_elements(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_expanded_ast_elements MdbClickhouseCluster#max_expanded_ast_elements}.'''
        result = self._values.get("max_expanded_ast_elements")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_insert_block_size(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_insert_block_size MdbClickhouseCluster#max_insert_block_size}.'''
        result = self._values.get("max_insert_block_size")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_memory_usage(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_memory_usage MdbClickhouseCluster#max_memory_usage}.'''
        result = self._values.get("max_memory_usage")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_memory_usage_for_user(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_memory_usage_for_user MdbClickhouseCluster#max_memory_usage_for_user}.'''
        result = self._values.get("max_memory_usage_for_user")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_network_bandwidth(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_network_bandwidth MdbClickhouseCluster#max_network_bandwidth}.'''
        result = self._values.get("max_network_bandwidth")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_network_bandwidth_for_user(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_network_bandwidth_for_user MdbClickhouseCluster#max_network_bandwidth_for_user}.'''
        result = self._values.get("max_network_bandwidth_for_user")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_query_size(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_query_size MdbClickhouseCluster#max_query_size}.'''
        result = self._values.get("max_query_size")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_replica_delay_for_distributed_queries(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_replica_delay_for_distributed_queries MdbClickhouseCluster#max_replica_delay_for_distributed_queries}.'''
        result = self._values.get("max_replica_delay_for_distributed_queries")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_result_bytes(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_result_bytes MdbClickhouseCluster#max_result_bytes}.'''
        result = self._values.get("max_result_bytes")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_result_rows(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_result_rows MdbClickhouseCluster#max_result_rows}.'''
        result = self._values.get("max_result_rows")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_rows_in_distinct(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_rows_in_distinct MdbClickhouseCluster#max_rows_in_distinct}.'''
        result = self._values.get("max_rows_in_distinct")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_rows_in_join(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_rows_in_join MdbClickhouseCluster#max_rows_in_join}.'''
        result = self._values.get("max_rows_in_join")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_rows_in_set(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_rows_in_set MdbClickhouseCluster#max_rows_in_set}.'''
        result = self._values.get("max_rows_in_set")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_rows_to_group_by(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_rows_to_group_by MdbClickhouseCluster#max_rows_to_group_by}.'''
        result = self._values.get("max_rows_to_group_by")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_rows_to_read(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_rows_to_read MdbClickhouseCluster#max_rows_to_read}.'''
        result = self._values.get("max_rows_to_read")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_rows_to_sort(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_rows_to_sort MdbClickhouseCluster#max_rows_to_sort}.'''
        result = self._values.get("max_rows_to_sort")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_rows_to_transfer(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_rows_to_transfer MdbClickhouseCluster#max_rows_to_transfer}.'''
        result = self._values.get("max_rows_to_transfer")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_temporary_columns(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_temporary_columns MdbClickhouseCluster#max_temporary_columns}.'''
        result = self._values.get("max_temporary_columns")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_temporary_non_const_columns(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_temporary_non_const_columns MdbClickhouseCluster#max_temporary_non_const_columns}.'''
        result = self._values.get("max_temporary_non_const_columns")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_threads(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#max_threads MdbClickhouseCluster#max_threads}.'''
        result = self._values.get("max_threads")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def merge_tree_max_bytes_to_use_cache(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#merge_tree_max_bytes_to_use_cache MdbClickhouseCluster#merge_tree_max_bytes_to_use_cache}.'''
        result = self._values.get("merge_tree_max_bytes_to_use_cache")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def merge_tree_max_rows_to_use_cache(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#merge_tree_max_rows_to_use_cache MdbClickhouseCluster#merge_tree_max_rows_to_use_cache}.'''
        result = self._values.get("merge_tree_max_rows_to_use_cache")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def merge_tree_min_bytes_for_concurrent_read(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#merge_tree_min_bytes_for_concurrent_read MdbClickhouseCluster#merge_tree_min_bytes_for_concurrent_read}.'''
        result = self._values.get("merge_tree_min_bytes_for_concurrent_read")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def merge_tree_min_rows_for_concurrent_read(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#merge_tree_min_rows_for_concurrent_read MdbClickhouseCluster#merge_tree_min_rows_for_concurrent_read}.'''
        result = self._values.get("merge_tree_min_rows_for_concurrent_read")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def min_bytes_to_use_direct_io(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#min_bytes_to_use_direct_io MdbClickhouseCluster#min_bytes_to_use_direct_io}.'''
        result = self._values.get("min_bytes_to_use_direct_io")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def min_count_to_compile(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#min_count_to_compile MdbClickhouseCluster#min_count_to_compile}.'''
        result = self._values.get("min_count_to_compile")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def min_count_to_compile_expression(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#min_count_to_compile_expression MdbClickhouseCluster#min_count_to_compile_expression}.'''
        result = self._values.get("min_count_to_compile_expression")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def min_execution_speed(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#min_execution_speed MdbClickhouseCluster#min_execution_speed}.'''
        result = self._values.get("min_execution_speed")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def min_execution_speed_bytes(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#min_execution_speed_bytes MdbClickhouseCluster#min_execution_speed_bytes}.'''
        result = self._values.get("min_execution_speed_bytes")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def min_insert_block_size_bytes(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#min_insert_block_size_bytes MdbClickhouseCluster#min_insert_block_size_bytes}.'''
        result = self._values.get("min_insert_block_size_bytes")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def min_insert_block_size_rows(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#min_insert_block_size_rows MdbClickhouseCluster#min_insert_block_size_rows}.'''
        result = self._values.get("min_insert_block_size_rows")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def output_format_json_quote64_bit_integers(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#output_format_json_quote_64bit_integers MdbClickhouseCluster#output_format_json_quote_64bit_integers}.'''
        result = self._values.get("output_format_json_quote64_bit_integers")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def output_format_json_quote_denormals(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#output_format_json_quote_denormals MdbClickhouseCluster#output_format_json_quote_denormals}.'''
        result = self._values.get("output_format_json_quote_denormals")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def priority(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#priority MdbClickhouseCluster#priority}.'''
        result = self._values.get("priority")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def quota_mode(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#quota_mode MdbClickhouseCluster#quota_mode}.'''
        result = self._values.get("quota_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def readonly(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#readonly MdbClickhouseCluster#readonly}.'''
        result = self._values.get("readonly")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def read_overflow_mode(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#read_overflow_mode MdbClickhouseCluster#read_overflow_mode}.'''
        result = self._values.get("read_overflow_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def receive_timeout(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#receive_timeout MdbClickhouseCluster#receive_timeout}.'''
        result = self._values.get("receive_timeout")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def replication_alter_partitions_sync(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#replication_alter_partitions_sync MdbClickhouseCluster#replication_alter_partitions_sync}.'''
        result = self._values.get("replication_alter_partitions_sync")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def result_overflow_mode(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#result_overflow_mode MdbClickhouseCluster#result_overflow_mode}.'''
        result = self._values.get("result_overflow_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def select_sequential_consistency(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#select_sequential_consistency MdbClickhouseCluster#select_sequential_consistency}.'''
        result = self._values.get("select_sequential_consistency")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def send_progress_in_http_headers(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#send_progress_in_http_headers MdbClickhouseCluster#send_progress_in_http_headers}.'''
        result = self._values.get("send_progress_in_http_headers")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def send_timeout(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#send_timeout MdbClickhouseCluster#send_timeout}.'''
        result = self._values.get("send_timeout")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def set_overflow_mode(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#set_overflow_mode MdbClickhouseCluster#set_overflow_mode}.'''
        result = self._values.get("set_overflow_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def skip_unavailable_shards(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#skip_unavailable_shards MdbClickhouseCluster#skip_unavailable_shards}.'''
        result = self._values.get("skip_unavailable_shards")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def sort_overflow_mode(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#sort_overflow_mode MdbClickhouseCluster#sort_overflow_mode}.'''
        result = self._values.get("sort_overflow_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeout_overflow_mode(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#timeout_overflow_mode MdbClickhouseCluster#timeout_overflow_mode}.'''
        result = self._values.get("timeout_overflow_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def transfer_overflow_mode(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#transfer_overflow_mode MdbClickhouseCluster#transfer_overflow_mode}.'''
        result = self._values.get("transfer_overflow_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def transform_null_in(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#transform_null_in MdbClickhouseCluster#transform_null_in}.'''
        result = self._values.get("transform_null_in")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def use_uncompressed_cache(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#use_uncompressed_cache MdbClickhouseCluster#use_uncompressed_cache}.'''
        result = self._values.get("use_uncompressed_cache")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbClickhouseClusterUserSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbClickhouseClusterUserSettingsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterUserSettingsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAddHttpCorsHeader")
    def reset_add_http_cors_header(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAddHttpCorsHeader", []))

    @jsii.member(jsii_name="resetAllowDdl")
    def reset_allow_ddl(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAllowDdl", []))

    @jsii.member(jsii_name="resetCompile")
    def reset_compile(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCompile", []))

    @jsii.member(jsii_name="resetCompileExpressions")
    def reset_compile_expressions(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCompileExpressions", []))

    @jsii.member(jsii_name="resetConnectTimeout")
    def reset_connect_timeout(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetConnectTimeout", []))

    @jsii.member(jsii_name="resetCountDistinctImplementation")
    def reset_count_distinct_implementation(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCountDistinctImplementation", []))

    @jsii.member(jsii_name="resetDistinctOverflowMode")
    def reset_distinct_overflow_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDistinctOverflowMode", []))

    @jsii.member(jsii_name="resetDistributedAggregationMemoryEfficient")
    def reset_distributed_aggregation_memory_efficient(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDistributedAggregationMemoryEfficient", []))

    @jsii.member(jsii_name="resetDistributedDdlTaskTimeout")
    def reset_distributed_ddl_task_timeout(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDistributedDdlTaskTimeout", []))

    @jsii.member(jsii_name="resetDistributedProductMode")
    def reset_distributed_product_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDistributedProductMode", []))

    @jsii.member(jsii_name="resetEmptyResultForAggregationByEmptySet")
    def reset_empty_result_for_aggregation_by_empty_set(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEmptyResultForAggregationByEmptySet", []))

    @jsii.member(jsii_name="resetEnableHttpCompression")
    def reset_enable_http_compression(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEnableHttpCompression", []))

    @jsii.member(jsii_name="resetFallbackToStaleReplicasForDistributedQueries")
    def reset_fallback_to_stale_replicas_for_distributed_queries(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFallbackToStaleReplicasForDistributedQueries", []))

    @jsii.member(jsii_name="resetForceIndexByDate")
    def reset_force_index_by_date(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetForceIndexByDate", []))

    @jsii.member(jsii_name="resetForcePrimaryKey")
    def reset_force_primary_key(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetForcePrimaryKey", []))

    @jsii.member(jsii_name="resetGroupByOverflowMode")
    def reset_group_by_overflow_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupByOverflowMode", []))

    @jsii.member(jsii_name="resetGroupByTwoLevelThreshold")
    def reset_group_by_two_level_threshold(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupByTwoLevelThreshold", []))

    @jsii.member(jsii_name="resetGroupByTwoLevelThresholdBytes")
    def reset_group_by_two_level_threshold_bytes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGroupByTwoLevelThresholdBytes", []))

    @jsii.member(jsii_name="resetHttpConnectionTimeout")
    def reset_http_connection_timeout(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttpConnectionTimeout", []))

    @jsii.member(jsii_name="resetHttpHeadersProgressInterval")
    def reset_http_headers_progress_interval(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttpHeadersProgressInterval", []))

    @jsii.member(jsii_name="resetHttpReceiveTimeout")
    def reset_http_receive_timeout(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttpReceiveTimeout", []))

    @jsii.member(jsii_name="resetHttpSendTimeout")
    def reset_http_send_timeout(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHttpSendTimeout", []))

    @jsii.member(jsii_name="resetInputFormatDefaultsForOmittedFields")
    def reset_input_format_defaults_for_omitted_fields(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInputFormatDefaultsForOmittedFields", []))

    @jsii.member(jsii_name="resetInputFormatValuesInterpretExpressions")
    def reset_input_format_values_interpret_expressions(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInputFormatValuesInterpretExpressions", []))

    @jsii.member(jsii_name="resetInsertQuorum")
    def reset_insert_quorum(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInsertQuorum", []))

    @jsii.member(jsii_name="resetInsertQuorumTimeout")
    def reset_insert_quorum_timeout(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInsertQuorumTimeout", []))

    @jsii.member(jsii_name="resetJoinedSubqueryRequiresAlias")
    def reset_joined_subquery_requires_alias(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetJoinedSubqueryRequiresAlias", []))

    @jsii.member(jsii_name="resetJoinOverflowMode")
    def reset_join_overflow_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetJoinOverflowMode", []))

    @jsii.member(jsii_name="resetJoinUseNulls")
    def reset_join_use_nulls(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetJoinUseNulls", []))

    @jsii.member(jsii_name="resetLowCardinalityAllowInNativeFormat")
    def reset_low_cardinality_allow_in_native_format(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLowCardinalityAllowInNativeFormat", []))

    @jsii.member(jsii_name="resetMaxAstDepth")
    def reset_max_ast_depth(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxAstDepth", []))

    @jsii.member(jsii_name="resetMaxAstElements")
    def reset_max_ast_elements(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxAstElements", []))

    @jsii.member(jsii_name="resetMaxBlockSize")
    def reset_max_block_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxBlockSize", []))

    @jsii.member(jsii_name="resetMaxBytesBeforeExternalGroupBy")
    def reset_max_bytes_before_external_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxBytesBeforeExternalGroupBy", []))

    @jsii.member(jsii_name="resetMaxBytesBeforeExternalSort")
    def reset_max_bytes_before_external_sort(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxBytesBeforeExternalSort", []))

    @jsii.member(jsii_name="resetMaxBytesInDistinct")
    def reset_max_bytes_in_distinct(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxBytesInDistinct", []))

    @jsii.member(jsii_name="resetMaxBytesInJoin")
    def reset_max_bytes_in_join(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxBytesInJoin", []))

    @jsii.member(jsii_name="resetMaxBytesInSet")
    def reset_max_bytes_in_set(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxBytesInSet", []))

    @jsii.member(jsii_name="resetMaxBytesToRead")
    def reset_max_bytes_to_read(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxBytesToRead", []))

    @jsii.member(jsii_name="resetMaxBytesToSort")
    def reset_max_bytes_to_sort(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxBytesToSort", []))

    @jsii.member(jsii_name="resetMaxBytesToTransfer")
    def reset_max_bytes_to_transfer(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxBytesToTransfer", []))

    @jsii.member(jsii_name="resetMaxColumnsToRead")
    def reset_max_columns_to_read(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxColumnsToRead", []))

    @jsii.member(jsii_name="resetMaxExecutionTime")
    def reset_max_execution_time(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxExecutionTime", []))

    @jsii.member(jsii_name="resetMaxExpandedAstElements")
    def reset_max_expanded_ast_elements(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxExpandedAstElements", []))

    @jsii.member(jsii_name="resetMaxInsertBlockSize")
    def reset_max_insert_block_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxInsertBlockSize", []))

    @jsii.member(jsii_name="resetMaxMemoryUsage")
    def reset_max_memory_usage(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxMemoryUsage", []))

    @jsii.member(jsii_name="resetMaxMemoryUsageForUser")
    def reset_max_memory_usage_for_user(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxMemoryUsageForUser", []))

    @jsii.member(jsii_name="resetMaxNetworkBandwidth")
    def reset_max_network_bandwidth(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxNetworkBandwidth", []))

    @jsii.member(jsii_name="resetMaxNetworkBandwidthForUser")
    def reset_max_network_bandwidth_for_user(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxNetworkBandwidthForUser", []))

    @jsii.member(jsii_name="resetMaxQuerySize")
    def reset_max_query_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxQuerySize", []))

    @jsii.member(jsii_name="resetMaxReplicaDelayForDistributedQueries")
    def reset_max_replica_delay_for_distributed_queries(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxReplicaDelayForDistributedQueries", []))

    @jsii.member(jsii_name="resetMaxResultBytes")
    def reset_max_result_bytes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxResultBytes", []))

    @jsii.member(jsii_name="resetMaxResultRows")
    def reset_max_result_rows(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxResultRows", []))

    @jsii.member(jsii_name="resetMaxRowsInDistinct")
    def reset_max_rows_in_distinct(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxRowsInDistinct", []))

    @jsii.member(jsii_name="resetMaxRowsInJoin")
    def reset_max_rows_in_join(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxRowsInJoin", []))

    @jsii.member(jsii_name="resetMaxRowsInSet")
    def reset_max_rows_in_set(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxRowsInSet", []))

    @jsii.member(jsii_name="resetMaxRowsToGroupBy")
    def reset_max_rows_to_group_by(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxRowsToGroupBy", []))

    @jsii.member(jsii_name="resetMaxRowsToRead")
    def reset_max_rows_to_read(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxRowsToRead", []))

    @jsii.member(jsii_name="resetMaxRowsToSort")
    def reset_max_rows_to_sort(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxRowsToSort", []))

    @jsii.member(jsii_name="resetMaxRowsToTransfer")
    def reset_max_rows_to_transfer(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxRowsToTransfer", []))

    @jsii.member(jsii_name="resetMaxTemporaryColumns")
    def reset_max_temporary_columns(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxTemporaryColumns", []))

    @jsii.member(jsii_name="resetMaxTemporaryNonConstColumns")
    def reset_max_temporary_non_const_columns(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxTemporaryNonConstColumns", []))

    @jsii.member(jsii_name="resetMaxThreads")
    def reset_max_threads(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxThreads", []))

    @jsii.member(jsii_name="resetMergeTreeMaxBytesToUseCache")
    def reset_merge_tree_max_bytes_to_use_cache(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMergeTreeMaxBytesToUseCache", []))

    @jsii.member(jsii_name="resetMergeTreeMaxRowsToUseCache")
    def reset_merge_tree_max_rows_to_use_cache(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMergeTreeMaxRowsToUseCache", []))

    @jsii.member(jsii_name="resetMergeTreeMinBytesForConcurrentRead")
    def reset_merge_tree_min_bytes_for_concurrent_read(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMergeTreeMinBytesForConcurrentRead", []))

    @jsii.member(jsii_name="resetMergeTreeMinRowsForConcurrentRead")
    def reset_merge_tree_min_rows_for_concurrent_read(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMergeTreeMinRowsForConcurrentRead", []))

    @jsii.member(jsii_name="resetMinBytesToUseDirectIo")
    def reset_min_bytes_to_use_direct_io(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMinBytesToUseDirectIo", []))

    @jsii.member(jsii_name="resetMinCountToCompile")
    def reset_min_count_to_compile(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMinCountToCompile", []))

    @jsii.member(jsii_name="resetMinCountToCompileExpression")
    def reset_min_count_to_compile_expression(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMinCountToCompileExpression", []))

    @jsii.member(jsii_name="resetMinExecutionSpeed")
    def reset_min_execution_speed(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMinExecutionSpeed", []))

    @jsii.member(jsii_name="resetMinExecutionSpeedBytes")
    def reset_min_execution_speed_bytes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMinExecutionSpeedBytes", []))

    @jsii.member(jsii_name="resetMinInsertBlockSizeBytes")
    def reset_min_insert_block_size_bytes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMinInsertBlockSizeBytes", []))

    @jsii.member(jsii_name="resetMinInsertBlockSizeRows")
    def reset_min_insert_block_size_rows(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMinInsertBlockSizeRows", []))

    @jsii.member(jsii_name="resetOutputFormatJsonQuote64BitIntegers")
    def reset_output_format_json_quote64_bit_integers(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOutputFormatJsonQuote64BitIntegers", []))

    @jsii.member(jsii_name="resetOutputFormatJsonQuoteDenormals")
    def reset_output_format_json_quote_denormals(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOutputFormatJsonQuoteDenormals", []))

    @jsii.member(jsii_name="resetPriority")
    def reset_priority(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPriority", []))

    @jsii.member(jsii_name="resetQuotaMode")
    def reset_quota_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetQuotaMode", []))

    @jsii.member(jsii_name="resetReadonly")
    def reset_readonly(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetReadonly", []))

    @jsii.member(jsii_name="resetReadOverflowMode")
    def reset_read_overflow_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetReadOverflowMode", []))

    @jsii.member(jsii_name="resetReceiveTimeout")
    def reset_receive_timeout(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetReceiveTimeout", []))

    @jsii.member(jsii_name="resetReplicationAlterPartitionsSync")
    def reset_replication_alter_partitions_sync(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetReplicationAlterPartitionsSync", []))

    @jsii.member(jsii_name="resetResultOverflowMode")
    def reset_result_overflow_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetResultOverflowMode", []))

    @jsii.member(jsii_name="resetSelectSequentialConsistency")
    def reset_select_sequential_consistency(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSelectSequentialConsistency", []))

    @jsii.member(jsii_name="resetSendProgressInHttpHeaders")
    def reset_send_progress_in_http_headers(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSendProgressInHttpHeaders", []))

    @jsii.member(jsii_name="resetSendTimeout")
    def reset_send_timeout(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSendTimeout", []))

    @jsii.member(jsii_name="resetSetOverflowMode")
    def reset_set_overflow_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSetOverflowMode", []))

    @jsii.member(jsii_name="resetSkipUnavailableShards")
    def reset_skip_unavailable_shards(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSkipUnavailableShards", []))

    @jsii.member(jsii_name="resetSortOverflowMode")
    def reset_sort_overflow_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSortOverflowMode", []))

    @jsii.member(jsii_name="resetTimeoutOverflowMode")
    def reset_timeout_overflow_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeoutOverflowMode", []))

    @jsii.member(jsii_name="resetTransferOverflowMode")
    def reset_transfer_overflow_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTransferOverflowMode", []))

    @jsii.member(jsii_name="resetTransformNullIn")
    def reset_transform_null_in(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTransformNullIn", []))

    @jsii.member(jsii_name="resetUseUncompressedCache")
    def reset_use_uncompressed_cache(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUseUncompressedCache", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="addHttpCorsHeaderInput")
    def add_http_cors_header_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "addHttpCorsHeaderInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allowDdlInput")
    def allow_ddl_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "allowDdlInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="compileExpressionsInput")
    def compile_expressions_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "compileExpressionsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="compileInput")
    def compile_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "compileInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="connectTimeoutInput")
    def connect_timeout_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "connectTimeoutInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="countDistinctImplementationInput")
    def count_distinct_implementation_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "countDistinctImplementationInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="distinctOverflowModeInput")
    def distinct_overflow_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "distinctOverflowModeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="distributedAggregationMemoryEfficientInput")
    def distributed_aggregation_memory_efficient_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "distributedAggregationMemoryEfficientInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="distributedDdlTaskTimeoutInput")
    def distributed_ddl_task_timeout_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "distributedDdlTaskTimeoutInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="distributedProductModeInput")
    def distributed_product_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "distributedProductModeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="emptyResultForAggregationByEmptySetInput")
    def empty_result_for_aggregation_by_empty_set_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "emptyResultForAggregationByEmptySetInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="enableHttpCompressionInput")
    def enable_http_compression_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "enableHttpCompressionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fallbackToStaleReplicasForDistributedQueriesInput")
    def fallback_to_stale_replicas_for_distributed_queries_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "fallbackToStaleReplicasForDistributedQueriesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="forceIndexByDateInput")
    def force_index_by_date_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "forceIndexByDateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="forcePrimaryKeyInput")
    def force_primary_key_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "forcePrimaryKeyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="groupByOverflowModeInput")
    def group_by_overflow_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "groupByOverflowModeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="groupByTwoLevelThresholdBytesInput")
    def group_by_two_level_threshold_bytes_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "groupByTwoLevelThresholdBytesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="groupByTwoLevelThresholdInput")
    def group_by_two_level_threshold_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "groupByTwoLevelThresholdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpConnectionTimeoutInput")
    def http_connection_timeout_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "httpConnectionTimeoutInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpHeadersProgressIntervalInput")
    def http_headers_progress_interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "httpHeadersProgressIntervalInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpReceiveTimeoutInput")
    def http_receive_timeout_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "httpReceiveTimeoutInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpSendTimeoutInput")
    def http_send_timeout_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "httpSendTimeoutInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="inputFormatDefaultsForOmittedFieldsInput")
    def input_format_defaults_for_omitted_fields_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "inputFormatDefaultsForOmittedFieldsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="inputFormatValuesInterpretExpressionsInput")
    def input_format_values_interpret_expressions_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "inputFormatValuesInterpretExpressionsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="insertQuorumInput")
    def insert_quorum_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "insertQuorumInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="insertQuorumTimeoutInput")
    def insert_quorum_timeout_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "insertQuorumTimeoutInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="joinedSubqueryRequiresAliasInput")
    def joined_subquery_requires_alias_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "joinedSubqueryRequiresAliasInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="joinOverflowModeInput")
    def join_overflow_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "joinOverflowModeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="joinUseNullsInput")
    def join_use_nulls_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "joinUseNullsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="lowCardinalityAllowInNativeFormatInput")
    def low_cardinality_allow_in_native_format_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "lowCardinalityAllowInNativeFormatInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxAstDepthInput")
    def max_ast_depth_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxAstDepthInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxAstElementsInput")
    def max_ast_elements_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxAstElementsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxBlockSizeInput")
    def max_block_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxBlockSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxBytesBeforeExternalGroupByInput")
    def max_bytes_before_external_group_by_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxBytesBeforeExternalGroupByInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxBytesBeforeExternalSortInput")
    def max_bytes_before_external_sort_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxBytesBeforeExternalSortInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxBytesInDistinctInput")
    def max_bytes_in_distinct_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxBytesInDistinctInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxBytesInJoinInput")
    def max_bytes_in_join_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxBytesInJoinInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxBytesInSetInput")
    def max_bytes_in_set_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxBytesInSetInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxBytesToReadInput")
    def max_bytes_to_read_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxBytesToReadInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxBytesToSortInput")
    def max_bytes_to_sort_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxBytesToSortInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxBytesToTransferInput")
    def max_bytes_to_transfer_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxBytesToTransferInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxColumnsToReadInput")
    def max_columns_to_read_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxColumnsToReadInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxExecutionTimeInput")
    def max_execution_time_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxExecutionTimeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxExpandedAstElementsInput")
    def max_expanded_ast_elements_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxExpandedAstElementsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxInsertBlockSizeInput")
    def max_insert_block_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxInsertBlockSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxMemoryUsageForUserInput")
    def max_memory_usage_for_user_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxMemoryUsageForUserInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxMemoryUsageInput")
    def max_memory_usage_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxMemoryUsageInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxNetworkBandwidthForUserInput")
    def max_network_bandwidth_for_user_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxNetworkBandwidthForUserInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxNetworkBandwidthInput")
    def max_network_bandwidth_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxNetworkBandwidthInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxQuerySizeInput")
    def max_query_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxQuerySizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxReplicaDelayForDistributedQueriesInput")
    def max_replica_delay_for_distributed_queries_input(
        self,
    ) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxReplicaDelayForDistributedQueriesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxResultBytesInput")
    def max_result_bytes_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxResultBytesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxResultRowsInput")
    def max_result_rows_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxResultRowsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxRowsInDistinctInput")
    def max_rows_in_distinct_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxRowsInDistinctInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxRowsInJoinInput")
    def max_rows_in_join_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxRowsInJoinInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxRowsInSetInput")
    def max_rows_in_set_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxRowsInSetInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxRowsToGroupByInput")
    def max_rows_to_group_by_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxRowsToGroupByInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxRowsToReadInput")
    def max_rows_to_read_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxRowsToReadInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxRowsToSortInput")
    def max_rows_to_sort_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxRowsToSortInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxRowsToTransferInput")
    def max_rows_to_transfer_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxRowsToTransferInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxTemporaryColumnsInput")
    def max_temporary_columns_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxTemporaryColumnsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxTemporaryNonConstColumnsInput")
    def max_temporary_non_const_columns_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxTemporaryNonConstColumnsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxThreadsInput")
    def max_threads_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxThreadsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mergeTreeMaxBytesToUseCacheInput")
    def merge_tree_max_bytes_to_use_cache_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "mergeTreeMaxBytesToUseCacheInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mergeTreeMaxRowsToUseCacheInput")
    def merge_tree_max_rows_to_use_cache_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "mergeTreeMaxRowsToUseCacheInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mergeTreeMinBytesForConcurrentReadInput")
    def merge_tree_min_bytes_for_concurrent_read_input(
        self,
    ) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "mergeTreeMinBytesForConcurrentReadInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mergeTreeMinRowsForConcurrentReadInput")
    def merge_tree_min_rows_for_concurrent_read_input(
        self,
    ) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "mergeTreeMinRowsForConcurrentReadInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minBytesToUseDirectIoInput")
    def min_bytes_to_use_direct_io_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "minBytesToUseDirectIoInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minCountToCompileExpressionInput")
    def min_count_to_compile_expression_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "minCountToCompileExpressionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minCountToCompileInput")
    def min_count_to_compile_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "minCountToCompileInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minExecutionSpeedBytesInput")
    def min_execution_speed_bytes_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "minExecutionSpeedBytesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minExecutionSpeedInput")
    def min_execution_speed_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "minExecutionSpeedInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minInsertBlockSizeBytesInput")
    def min_insert_block_size_bytes_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "minInsertBlockSizeBytesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minInsertBlockSizeRowsInput")
    def min_insert_block_size_rows_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "minInsertBlockSizeRowsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="outputFormatJsonQuote64BitIntegersInput")
    def output_format_json_quote64_bit_integers_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "outputFormatJsonQuote64BitIntegersInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="outputFormatJsonQuoteDenormalsInput")
    def output_format_json_quote_denormals_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "outputFormatJsonQuoteDenormalsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="priorityInput")
    def priority_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "priorityInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="quotaModeInput")
    def quota_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "quotaModeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="readonlyInput")
    def readonly_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "readonlyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="readOverflowModeInput")
    def read_overflow_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "readOverflowModeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="receiveTimeoutInput")
    def receive_timeout_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "receiveTimeoutInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replicationAlterPartitionsSyncInput")
    def replication_alter_partitions_sync_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "replicationAlterPartitionsSyncInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resultOverflowModeInput")
    def result_overflow_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resultOverflowModeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="selectSequentialConsistencyInput")
    def select_sequential_consistency_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "selectSequentialConsistencyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sendProgressInHttpHeadersInput")
    def send_progress_in_http_headers_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "sendProgressInHttpHeadersInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sendTimeoutInput")
    def send_timeout_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "sendTimeoutInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="setOverflowModeInput")
    def set_overflow_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "setOverflowModeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="skipUnavailableShardsInput")
    def skip_unavailable_shards_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "skipUnavailableShardsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sortOverflowModeInput")
    def sort_overflow_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sortOverflowModeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutOverflowModeInput")
    def timeout_overflow_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "timeoutOverflowModeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="transferOverflowModeInput")
    def transfer_overflow_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "transferOverflowModeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="transformNullInInput")
    def transform_null_in_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "transformNullInInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="useUncompressedCacheInput")
    def use_uncompressed_cache_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "useUncompressedCacheInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="addHttpCorsHeader")
    def add_http_cors_header(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "addHttpCorsHeader"))

    @add_http_cors_header.setter
    def add_http_cors_header(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "addHttpCorsHeader", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allowDdl")
    def allow_ddl(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "allowDdl"))

    @allow_ddl.setter
    def allow_ddl(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "allowDdl", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="compile")
    def compile(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "compile"))

    @compile.setter
    def compile(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "compile", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="compileExpressions")
    def compile_expressions(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "compileExpressions"))

    @compile_expressions.setter
    def compile_expressions(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "compileExpressions", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="connectTimeout")
    def connect_timeout(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "connectTimeout"))

    @connect_timeout.setter
    def connect_timeout(self, value: jsii.Number) -> None:
        jsii.set(self, "connectTimeout", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="countDistinctImplementation")
    def count_distinct_implementation(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "countDistinctImplementation"))

    @count_distinct_implementation.setter
    def count_distinct_implementation(self, value: builtins.str) -> None:
        jsii.set(self, "countDistinctImplementation", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="distinctOverflowMode")
    def distinct_overflow_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "distinctOverflowMode"))

    @distinct_overflow_mode.setter
    def distinct_overflow_mode(self, value: builtins.str) -> None:
        jsii.set(self, "distinctOverflowMode", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="distributedAggregationMemoryEfficient")
    def distributed_aggregation_memory_efficient(
        self,
    ) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "distributedAggregationMemoryEfficient"))

    @distributed_aggregation_memory_efficient.setter
    def distributed_aggregation_memory_efficient(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "distributedAggregationMemoryEfficient", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="distributedDdlTaskTimeout")
    def distributed_ddl_task_timeout(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "distributedDdlTaskTimeout"))

    @distributed_ddl_task_timeout.setter
    def distributed_ddl_task_timeout(self, value: jsii.Number) -> None:
        jsii.set(self, "distributedDdlTaskTimeout", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="distributedProductMode")
    def distributed_product_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "distributedProductMode"))

    @distributed_product_mode.setter
    def distributed_product_mode(self, value: builtins.str) -> None:
        jsii.set(self, "distributedProductMode", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="emptyResultForAggregationByEmptySet")
    def empty_result_for_aggregation_by_empty_set(
        self,
    ) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "emptyResultForAggregationByEmptySet"))

    @empty_result_for_aggregation_by_empty_set.setter
    def empty_result_for_aggregation_by_empty_set(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "emptyResultForAggregationByEmptySet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="enableHttpCompression")
    def enable_http_compression(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "enableHttpCompression"))

    @enable_http_compression.setter
    def enable_http_compression(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "enableHttpCompression", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fallbackToStaleReplicasForDistributedQueries")
    def fallback_to_stale_replicas_for_distributed_queries(
        self,
    ) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "fallbackToStaleReplicasForDistributedQueries"))

    @fallback_to_stale_replicas_for_distributed_queries.setter
    def fallback_to_stale_replicas_for_distributed_queries(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "fallbackToStaleReplicasForDistributedQueries", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="forceIndexByDate")
    def force_index_by_date(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "forceIndexByDate"))

    @force_index_by_date.setter
    def force_index_by_date(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "forceIndexByDate", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="forcePrimaryKey")
    def force_primary_key(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "forcePrimaryKey"))

    @force_primary_key.setter
    def force_primary_key(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "forcePrimaryKey", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="groupByOverflowMode")
    def group_by_overflow_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "groupByOverflowMode"))

    @group_by_overflow_mode.setter
    def group_by_overflow_mode(self, value: builtins.str) -> None:
        jsii.set(self, "groupByOverflowMode", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="groupByTwoLevelThreshold")
    def group_by_two_level_threshold(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "groupByTwoLevelThreshold"))

    @group_by_two_level_threshold.setter
    def group_by_two_level_threshold(self, value: jsii.Number) -> None:
        jsii.set(self, "groupByTwoLevelThreshold", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="groupByTwoLevelThresholdBytes")
    def group_by_two_level_threshold_bytes(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "groupByTwoLevelThresholdBytes"))

    @group_by_two_level_threshold_bytes.setter
    def group_by_two_level_threshold_bytes(self, value: jsii.Number) -> None:
        jsii.set(self, "groupByTwoLevelThresholdBytes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpConnectionTimeout")
    def http_connection_timeout(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "httpConnectionTimeout"))

    @http_connection_timeout.setter
    def http_connection_timeout(self, value: jsii.Number) -> None:
        jsii.set(self, "httpConnectionTimeout", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpHeadersProgressInterval")
    def http_headers_progress_interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "httpHeadersProgressInterval"))

    @http_headers_progress_interval.setter
    def http_headers_progress_interval(self, value: jsii.Number) -> None:
        jsii.set(self, "httpHeadersProgressInterval", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpReceiveTimeout")
    def http_receive_timeout(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "httpReceiveTimeout"))

    @http_receive_timeout.setter
    def http_receive_timeout(self, value: jsii.Number) -> None:
        jsii.set(self, "httpReceiveTimeout", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="httpSendTimeout")
    def http_send_timeout(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "httpSendTimeout"))

    @http_send_timeout.setter
    def http_send_timeout(self, value: jsii.Number) -> None:
        jsii.set(self, "httpSendTimeout", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="inputFormatDefaultsForOmittedFields")
    def input_format_defaults_for_omitted_fields(
        self,
    ) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "inputFormatDefaultsForOmittedFields"))

    @input_format_defaults_for_omitted_fields.setter
    def input_format_defaults_for_omitted_fields(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "inputFormatDefaultsForOmittedFields", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="inputFormatValuesInterpretExpressions")
    def input_format_values_interpret_expressions(
        self,
    ) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "inputFormatValuesInterpretExpressions"))

    @input_format_values_interpret_expressions.setter
    def input_format_values_interpret_expressions(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "inputFormatValuesInterpretExpressions", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="insertQuorum")
    def insert_quorum(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "insertQuorum"))

    @insert_quorum.setter
    def insert_quorum(self, value: jsii.Number) -> None:
        jsii.set(self, "insertQuorum", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="insertQuorumTimeout")
    def insert_quorum_timeout(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "insertQuorumTimeout"))

    @insert_quorum_timeout.setter
    def insert_quorum_timeout(self, value: jsii.Number) -> None:
        jsii.set(self, "insertQuorumTimeout", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="joinedSubqueryRequiresAlias")
    def joined_subquery_requires_alias(
        self,
    ) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "joinedSubqueryRequiresAlias"))

    @joined_subquery_requires_alias.setter
    def joined_subquery_requires_alias(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "joinedSubqueryRequiresAlias", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="joinOverflowMode")
    def join_overflow_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "joinOverflowMode"))

    @join_overflow_mode.setter
    def join_overflow_mode(self, value: builtins.str) -> None:
        jsii.set(self, "joinOverflowMode", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="joinUseNulls")
    def join_use_nulls(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "joinUseNulls"))

    @join_use_nulls.setter
    def join_use_nulls(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "joinUseNulls", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="lowCardinalityAllowInNativeFormat")
    def low_cardinality_allow_in_native_format(
        self,
    ) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "lowCardinalityAllowInNativeFormat"))

    @low_cardinality_allow_in_native_format.setter
    def low_cardinality_allow_in_native_format(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "lowCardinalityAllowInNativeFormat", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxAstDepth")
    def max_ast_depth(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxAstDepth"))

    @max_ast_depth.setter
    def max_ast_depth(self, value: jsii.Number) -> None:
        jsii.set(self, "maxAstDepth", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxAstElements")
    def max_ast_elements(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxAstElements"))

    @max_ast_elements.setter
    def max_ast_elements(self, value: jsii.Number) -> None:
        jsii.set(self, "maxAstElements", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxBlockSize")
    def max_block_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxBlockSize"))

    @max_block_size.setter
    def max_block_size(self, value: jsii.Number) -> None:
        jsii.set(self, "maxBlockSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxBytesBeforeExternalGroupBy")
    def max_bytes_before_external_group_by(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxBytesBeforeExternalGroupBy"))

    @max_bytes_before_external_group_by.setter
    def max_bytes_before_external_group_by(self, value: jsii.Number) -> None:
        jsii.set(self, "maxBytesBeforeExternalGroupBy", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxBytesBeforeExternalSort")
    def max_bytes_before_external_sort(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxBytesBeforeExternalSort"))

    @max_bytes_before_external_sort.setter
    def max_bytes_before_external_sort(self, value: jsii.Number) -> None:
        jsii.set(self, "maxBytesBeforeExternalSort", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxBytesInDistinct")
    def max_bytes_in_distinct(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxBytesInDistinct"))

    @max_bytes_in_distinct.setter
    def max_bytes_in_distinct(self, value: jsii.Number) -> None:
        jsii.set(self, "maxBytesInDistinct", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxBytesInJoin")
    def max_bytes_in_join(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxBytesInJoin"))

    @max_bytes_in_join.setter
    def max_bytes_in_join(self, value: jsii.Number) -> None:
        jsii.set(self, "maxBytesInJoin", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxBytesInSet")
    def max_bytes_in_set(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxBytesInSet"))

    @max_bytes_in_set.setter
    def max_bytes_in_set(self, value: jsii.Number) -> None:
        jsii.set(self, "maxBytesInSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxBytesToRead")
    def max_bytes_to_read(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxBytesToRead"))

    @max_bytes_to_read.setter
    def max_bytes_to_read(self, value: jsii.Number) -> None:
        jsii.set(self, "maxBytesToRead", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxBytesToSort")
    def max_bytes_to_sort(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxBytesToSort"))

    @max_bytes_to_sort.setter
    def max_bytes_to_sort(self, value: jsii.Number) -> None:
        jsii.set(self, "maxBytesToSort", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxBytesToTransfer")
    def max_bytes_to_transfer(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxBytesToTransfer"))

    @max_bytes_to_transfer.setter
    def max_bytes_to_transfer(self, value: jsii.Number) -> None:
        jsii.set(self, "maxBytesToTransfer", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxColumnsToRead")
    def max_columns_to_read(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxColumnsToRead"))

    @max_columns_to_read.setter
    def max_columns_to_read(self, value: jsii.Number) -> None:
        jsii.set(self, "maxColumnsToRead", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxExecutionTime")
    def max_execution_time(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxExecutionTime"))

    @max_execution_time.setter
    def max_execution_time(self, value: jsii.Number) -> None:
        jsii.set(self, "maxExecutionTime", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxExpandedAstElements")
    def max_expanded_ast_elements(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxExpandedAstElements"))

    @max_expanded_ast_elements.setter
    def max_expanded_ast_elements(self, value: jsii.Number) -> None:
        jsii.set(self, "maxExpandedAstElements", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxInsertBlockSize")
    def max_insert_block_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxInsertBlockSize"))

    @max_insert_block_size.setter
    def max_insert_block_size(self, value: jsii.Number) -> None:
        jsii.set(self, "maxInsertBlockSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxMemoryUsage")
    def max_memory_usage(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxMemoryUsage"))

    @max_memory_usage.setter
    def max_memory_usage(self, value: jsii.Number) -> None:
        jsii.set(self, "maxMemoryUsage", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxMemoryUsageForUser")
    def max_memory_usage_for_user(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxMemoryUsageForUser"))

    @max_memory_usage_for_user.setter
    def max_memory_usage_for_user(self, value: jsii.Number) -> None:
        jsii.set(self, "maxMemoryUsageForUser", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxNetworkBandwidth")
    def max_network_bandwidth(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxNetworkBandwidth"))

    @max_network_bandwidth.setter
    def max_network_bandwidth(self, value: jsii.Number) -> None:
        jsii.set(self, "maxNetworkBandwidth", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxNetworkBandwidthForUser")
    def max_network_bandwidth_for_user(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxNetworkBandwidthForUser"))

    @max_network_bandwidth_for_user.setter
    def max_network_bandwidth_for_user(self, value: jsii.Number) -> None:
        jsii.set(self, "maxNetworkBandwidthForUser", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxQuerySize")
    def max_query_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxQuerySize"))

    @max_query_size.setter
    def max_query_size(self, value: jsii.Number) -> None:
        jsii.set(self, "maxQuerySize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxReplicaDelayForDistributedQueries")
    def max_replica_delay_for_distributed_queries(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxReplicaDelayForDistributedQueries"))

    @max_replica_delay_for_distributed_queries.setter
    def max_replica_delay_for_distributed_queries(self, value: jsii.Number) -> None:
        jsii.set(self, "maxReplicaDelayForDistributedQueries", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxResultBytes")
    def max_result_bytes(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxResultBytes"))

    @max_result_bytes.setter
    def max_result_bytes(self, value: jsii.Number) -> None:
        jsii.set(self, "maxResultBytes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxResultRows")
    def max_result_rows(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxResultRows"))

    @max_result_rows.setter
    def max_result_rows(self, value: jsii.Number) -> None:
        jsii.set(self, "maxResultRows", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxRowsInDistinct")
    def max_rows_in_distinct(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxRowsInDistinct"))

    @max_rows_in_distinct.setter
    def max_rows_in_distinct(self, value: jsii.Number) -> None:
        jsii.set(self, "maxRowsInDistinct", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxRowsInJoin")
    def max_rows_in_join(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxRowsInJoin"))

    @max_rows_in_join.setter
    def max_rows_in_join(self, value: jsii.Number) -> None:
        jsii.set(self, "maxRowsInJoin", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxRowsInSet")
    def max_rows_in_set(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxRowsInSet"))

    @max_rows_in_set.setter
    def max_rows_in_set(self, value: jsii.Number) -> None:
        jsii.set(self, "maxRowsInSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxRowsToGroupBy")
    def max_rows_to_group_by(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxRowsToGroupBy"))

    @max_rows_to_group_by.setter
    def max_rows_to_group_by(self, value: jsii.Number) -> None:
        jsii.set(self, "maxRowsToGroupBy", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxRowsToRead")
    def max_rows_to_read(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxRowsToRead"))

    @max_rows_to_read.setter
    def max_rows_to_read(self, value: jsii.Number) -> None:
        jsii.set(self, "maxRowsToRead", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxRowsToSort")
    def max_rows_to_sort(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxRowsToSort"))

    @max_rows_to_sort.setter
    def max_rows_to_sort(self, value: jsii.Number) -> None:
        jsii.set(self, "maxRowsToSort", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxRowsToTransfer")
    def max_rows_to_transfer(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxRowsToTransfer"))

    @max_rows_to_transfer.setter
    def max_rows_to_transfer(self, value: jsii.Number) -> None:
        jsii.set(self, "maxRowsToTransfer", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxTemporaryColumns")
    def max_temporary_columns(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxTemporaryColumns"))

    @max_temporary_columns.setter
    def max_temporary_columns(self, value: jsii.Number) -> None:
        jsii.set(self, "maxTemporaryColumns", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxTemporaryNonConstColumns")
    def max_temporary_non_const_columns(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxTemporaryNonConstColumns"))

    @max_temporary_non_const_columns.setter
    def max_temporary_non_const_columns(self, value: jsii.Number) -> None:
        jsii.set(self, "maxTemporaryNonConstColumns", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxThreads")
    def max_threads(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxThreads"))

    @max_threads.setter
    def max_threads(self, value: jsii.Number) -> None:
        jsii.set(self, "maxThreads", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mergeTreeMaxBytesToUseCache")
    def merge_tree_max_bytes_to_use_cache(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "mergeTreeMaxBytesToUseCache"))

    @merge_tree_max_bytes_to_use_cache.setter
    def merge_tree_max_bytes_to_use_cache(self, value: jsii.Number) -> None:
        jsii.set(self, "mergeTreeMaxBytesToUseCache", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mergeTreeMaxRowsToUseCache")
    def merge_tree_max_rows_to_use_cache(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "mergeTreeMaxRowsToUseCache"))

    @merge_tree_max_rows_to_use_cache.setter
    def merge_tree_max_rows_to_use_cache(self, value: jsii.Number) -> None:
        jsii.set(self, "mergeTreeMaxRowsToUseCache", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mergeTreeMinBytesForConcurrentRead")
    def merge_tree_min_bytes_for_concurrent_read(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "mergeTreeMinBytesForConcurrentRead"))

    @merge_tree_min_bytes_for_concurrent_read.setter
    def merge_tree_min_bytes_for_concurrent_read(self, value: jsii.Number) -> None:
        jsii.set(self, "mergeTreeMinBytesForConcurrentRead", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mergeTreeMinRowsForConcurrentRead")
    def merge_tree_min_rows_for_concurrent_read(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "mergeTreeMinRowsForConcurrentRead"))

    @merge_tree_min_rows_for_concurrent_read.setter
    def merge_tree_min_rows_for_concurrent_read(self, value: jsii.Number) -> None:
        jsii.set(self, "mergeTreeMinRowsForConcurrentRead", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minBytesToUseDirectIo")
    def min_bytes_to_use_direct_io(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minBytesToUseDirectIo"))

    @min_bytes_to_use_direct_io.setter
    def min_bytes_to_use_direct_io(self, value: jsii.Number) -> None:
        jsii.set(self, "minBytesToUseDirectIo", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minCountToCompile")
    def min_count_to_compile(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minCountToCompile"))

    @min_count_to_compile.setter
    def min_count_to_compile(self, value: jsii.Number) -> None:
        jsii.set(self, "minCountToCompile", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minCountToCompileExpression")
    def min_count_to_compile_expression(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minCountToCompileExpression"))

    @min_count_to_compile_expression.setter
    def min_count_to_compile_expression(self, value: jsii.Number) -> None:
        jsii.set(self, "minCountToCompileExpression", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minExecutionSpeed")
    def min_execution_speed(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minExecutionSpeed"))

    @min_execution_speed.setter
    def min_execution_speed(self, value: jsii.Number) -> None:
        jsii.set(self, "minExecutionSpeed", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minExecutionSpeedBytes")
    def min_execution_speed_bytes(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minExecutionSpeedBytes"))

    @min_execution_speed_bytes.setter
    def min_execution_speed_bytes(self, value: jsii.Number) -> None:
        jsii.set(self, "minExecutionSpeedBytes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minInsertBlockSizeBytes")
    def min_insert_block_size_bytes(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minInsertBlockSizeBytes"))

    @min_insert_block_size_bytes.setter
    def min_insert_block_size_bytes(self, value: jsii.Number) -> None:
        jsii.set(self, "minInsertBlockSizeBytes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minInsertBlockSizeRows")
    def min_insert_block_size_rows(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minInsertBlockSizeRows"))

    @min_insert_block_size_rows.setter
    def min_insert_block_size_rows(self, value: jsii.Number) -> None:
        jsii.set(self, "minInsertBlockSizeRows", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="outputFormatJsonQuote64BitIntegers")
    def output_format_json_quote64_bit_integers(
        self,
    ) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "outputFormatJsonQuote64BitIntegers"))

    @output_format_json_quote64_bit_integers.setter
    def output_format_json_quote64_bit_integers(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "outputFormatJsonQuote64BitIntegers", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="outputFormatJsonQuoteDenormals")
    def output_format_json_quote_denormals(
        self,
    ) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "outputFormatJsonQuoteDenormals"))

    @output_format_json_quote_denormals.setter
    def output_format_json_quote_denormals(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "outputFormatJsonQuoteDenormals", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="priority")
    def priority(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "priority"))

    @priority.setter
    def priority(self, value: jsii.Number) -> None:
        jsii.set(self, "priority", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="quotaMode")
    def quota_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "quotaMode"))

    @quota_mode.setter
    def quota_mode(self, value: builtins.str) -> None:
        jsii.set(self, "quotaMode", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="readonly")
    def readonly(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "readonly"))

    @readonly.setter
    def readonly(self, value: jsii.Number) -> None:
        jsii.set(self, "readonly", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="readOverflowMode")
    def read_overflow_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "readOverflowMode"))

    @read_overflow_mode.setter
    def read_overflow_mode(self, value: builtins.str) -> None:
        jsii.set(self, "readOverflowMode", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="receiveTimeout")
    def receive_timeout(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "receiveTimeout"))

    @receive_timeout.setter
    def receive_timeout(self, value: jsii.Number) -> None:
        jsii.set(self, "receiveTimeout", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replicationAlterPartitionsSync")
    def replication_alter_partitions_sync(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "replicationAlterPartitionsSync"))

    @replication_alter_partitions_sync.setter
    def replication_alter_partitions_sync(self, value: jsii.Number) -> None:
        jsii.set(self, "replicationAlterPartitionsSync", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resultOverflowMode")
    def result_overflow_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resultOverflowMode"))

    @result_overflow_mode.setter
    def result_overflow_mode(self, value: builtins.str) -> None:
        jsii.set(self, "resultOverflowMode", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="selectSequentialConsistency")
    def select_sequential_consistency(
        self,
    ) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "selectSequentialConsistency"))

    @select_sequential_consistency.setter
    def select_sequential_consistency(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "selectSequentialConsistency", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sendProgressInHttpHeaders")
    def send_progress_in_http_headers(
        self,
    ) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "sendProgressInHttpHeaders"))

    @send_progress_in_http_headers.setter
    def send_progress_in_http_headers(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "sendProgressInHttpHeaders", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sendTimeout")
    def send_timeout(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "sendTimeout"))

    @send_timeout.setter
    def send_timeout(self, value: jsii.Number) -> None:
        jsii.set(self, "sendTimeout", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="setOverflowMode")
    def set_overflow_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "setOverflowMode"))

    @set_overflow_mode.setter
    def set_overflow_mode(self, value: builtins.str) -> None:
        jsii.set(self, "setOverflowMode", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="skipUnavailableShards")
    def skip_unavailable_shards(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "skipUnavailableShards"))

    @skip_unavailable_shards.setter
    def skip_unavailable_shards(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "skipUnavailableShards", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sortOverflowMode")
    def sort_overflow_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sortOverflowMode"))

    @sort_overflow_mode.setter
    def sort_overflow_mode(self, value: builtins.str) -> None:
        jsii.set(self, "sortOverflowMode", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutOverflowMode")
    def timeout_overflow_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "timeoutOverflowMode"))

    @timeout_overflow_mode.setter
    def timeout_overflow_mode(self, value: builtins.str) -> None:
        jsii.set(self, "timeoutOverflowMode", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="transferOverflowMode")
    def transfer_overflow_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "transferOverflowMode"))

    @transfer_overflow_mode.setter
    def transfer_overflow_mode(self, value: builtins.str) -> None:
        jsii.set(self, "transferOverflowMode", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="transformNullIn")
    def transform_null_in(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "transformNullIn"))

    @transform_null_in.setter
    def transform_null_in(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "transformNullIn", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="useUncompressedCache")
    def use_uncompressed_cache(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "useUncompressedCache"))

    @use_uncompressed_cache.setter
    def use_uncompressed_cache(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "useUncompressedCache", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbClickhouseClusterUserSettings]:
        return typing.cast(typing.Optional[MdbClickhouseClusterUserSettings], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbClickhouseClusterUserSettings],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterZookeeper",
    jsii_struct_bases=[],
    name_mapping={"resources": "resources"},
)
class MdbClickhouseClusterZookeeper:
    def __init__(
        self,
        *,
        resources: typing.Optional["MdbClickhouseClusterZookeeperResources"] = None,
    ) -> None:
        '''
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#resources MdbClickhouseCluster#resources}
        '''
        if isinstance(resources, dict):
            resources = MdbClickhouseClusterZookeeperResources(**resources)
        self._values: typing.Dict[str, typing.Any] = {}
        if resources is not None:
            self._values["resources"] = resources

    @builtins.property
    def resources(self) -> typing.Optional["MdbClickhouseClusterZookeeperResources"]:
        '''resources block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#resources MdbClickhouseCluster#resources}
        '''
        result = self._values.get("resources")
        return typing.cast(typing.Optional["MdbClickhouseClusterZookeeperResources"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbClickhouseClusterZookeeper(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbClickhouseClusterZookeeperOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterZookeeperOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putResources")
    def put_resources(
        self,
        *,
        disk_size: typing.Optional[jsii.Number] = None,
        disk_type_id: typing.Optional[builtins.str] = None,
        resource_preset_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param disk_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#disk_size MdbClickhouseCluster#disk_size}.
        :param disk_type_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#disk_type_id MdbClickhouseCluster#disk_type_id}.
        :param resource_preset_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#resource_preset_id MdbClickhouseCluster#resource_preset_id}.
        '''
        value = MdbClickhouseClusterZookeeperResources(
            disk_size=disk_size,
            disk_type_id=disk_type_id,
            resource_preset_id=resource_preset_id,
        )

        return typing.cast(None, jsii.invoke(self, "putResources", [value]))

    @jsii.member(jsii_name="resetResources")
    def reset_resources(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetResources", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resources")
    def resources(self) -> "MdbClickhouseClusterZookeeperResourcesOutputReference":
        return typing.cast("MdbClickhouseClusterZookeeperResourcesOutputReference", jsii.get(self, "resources"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcesInput")
    def resources_input(
        self,
    ) -> typing.Optional["MdbClickhouseClusterZookeeperResources"]:
        return typing.cast(typing.Optional["MdbClickhouseClusterZookeeperResources"], jsii.get(self, "resourcesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbClickhouseClusterZookeeper]:
        return typing.cast(typing.Optional[MdbClickhouseClusterZookeeper], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbClickhouseClusterZookeeper],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterZookeeperResources",
    jsii_struct_bases=[],
    name_mapping={
        "disk_size": "diskSize",
        "disk_type_id": "diskTypeId",
        "resource_preset_id": "resourcePresetId",
    },
)
class MdbClickhouseClusterZookeeperResources:
    def __init__(
        self,
        *,
        disk_size: typing.Optional[jsii.Number] = None,
        disk_type_id: typing.Optional[builtins.str] = None,
        resource_preset_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param disk_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#disk_size MdbClickhouseCluster#disk_size}.
        :param disk_type_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#disk_type_id MdbClickhouseCluster#disk_type_id}.
        :param resource_preset_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#resource_preset_id MdbClickhouseCluster#resource_preset_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if disk_size is not None:
            self._values["disk_size"] = disk_size
        if disk_type_id is not None:
            self._values["disk_type_id"] = disk_type_id
        if resource_preset_id is not None:
            self._values["resource_preset_id"] = resource_preset_id

    @builtins.property
    def disk_size(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#disk_size MdbClickhouseCluster#disk_size}.'''
        result = self._values.get("disk_size")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def disk_type_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#disk_type_id MdbClickhouseCluster#disk_type_id}.'''
        result = self._values.get("disk_type_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def resource_preset_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_clickhouse_cluster#resource_preset_id MdbClickhouseCluster#resource_preset_id}.'''
        result = self._values.get("resource_preset_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbClickhouseClusterZookeeperResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbClickhouseClusterZookeeperResourcesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbClickhouseClusterZookeeperResourcesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetDiskSize")
    def reset_disk_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDiskSize", []))

    @jsii.member(jsii_name="resetDiskTypeId")
    def reset_disk_type_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDiskTypeId", []))

    @jsii.member(jsii_name="resetResourcePresetId")
    def reset_resource_preset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetResourcePresetId", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSizeInput")
    def disk_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "diskSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeIdInput")
    def disk_type_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "diskTypeIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetIdInput")
    def resource_preset_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourcePresetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSize")
    def disk_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "diskSize"))

    @disk_size.setter
    def disk_size(self, value: jsii.Number) -> None:
        jsii.set(self, "diskSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeId")
    def disk_type_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskTypeId"))

    @disk_type_id.setter
    def disk_type_id(self, value: builtins.str) -> None:
        jsii.set(self, "diskTypeId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetId")
    def resource_preset_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourcePresetId"))

    @resource_preset_id.setter
    def resource_preset_id(self, value: builtins.str) -> None:
        jsii.set(self, "resourcePresetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbClickhouseClusterZookeeperResources]:
        return typing.cast(typing.Optional[MdbClickhouseClusterZookeeperResources], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbClickhouseClusterZookeeperResources],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbElasticsearchCluster(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbElasticsearchCluster",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster yandex_mdb_elasticsearch_cluster}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        config: "MdbElasticsearchClusterConfigA",
        environment: builtins.str,
        name: builtins.str,
        network_id: builtins.str,
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        host: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbElasticsearchClusterHost"]]] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        maintenance_window: typing.Optional["MdbElasticsearchClusterMaintenanceWindow"] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        service_account_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["MdbElasticsearchClusterTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster yandex_mdb_elasticsearch_cluster} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param config: config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#config MdbElasticsearchCluster#config}
        :param environment: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#environment MdbElasticsearchCluster#environment}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#name MdbElasticsearchCluster#name}.
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#network_id MdbElasticsearchCluster#network_id}.
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#deletion_protection MdbElasticsearchCluster#deletion_protection}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#description MdbElasticsearchCluster#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#folder_id MdbElasticsearchCluster#folder_id}.
        :param host: host block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#host MdbElasticsearchCluster#host}
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#id MdbElasticsearchCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#labels MdbElasticsearchCluster#labels}.
        :param maintenance_window: maintenance_window block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#maintenance_window MdbElasticsearchCluster#maintenance_window}
        :param security_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#security_group_ids MdbElasticsearchCluster#security_group_ids}.
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#service_account_id MdbElasticsearchCluster#service_account_id}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#timeouts MdbElasticsearchCluster#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config_ = MdbElasticsearchClusterConfig(
            config=config,
            environment=environment,
            name=name,
            network_id=network_id,
            deletion_protection=deletion_protection,
            description=description,
            folder_id=folder_id,
            host=host,
            id=id,
            labels=labels,
            maintenance_window=maintenance_window,
            security_group_ids=security_group_ids,
            service_account_id=service_account_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config_])

    @jsii.member(jsii_name="putConfig")
    def put_config(
        self,
        *,
        admin_password: builtins.str,
        data_node: "MdbElasticsearchClusterConfigDataNode",
        edition: typing.Optional[builtins.str] = None,
        master_node: typing.Optional["MdbElasticsearchClusterConfigMasterNode"] = None,
        plugins: typing.Optional[typing.Sequence[builtins.str]] = None,
        version: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param admin_password: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#admin_password MdbElasticsearchCluster#admin_password}.
        :param data_node: data_node block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#data_node MdbElasticsearchCluster#data_node}
        :param edition: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#edition MdbElasticsearchCluster#edition}.
        :param master_node: master_node block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#master_node MdbElasticsearchCluster#master_node}
        :param plugins: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#plugins MdbElasticsearchCluster#plugins}.
        :param version: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#version MdbElasticsearchCluster#version}.
        '''
        value = MdbElasticsearchClusterConfigA(
            admin_password=admin_password,
            data_node=data_node,
            edition=edition,
            master_node=master_node,
            plugins=plugins,
            version=version,
        )

        return typing.cast(None, jsii.invoke(self, "putConfig", [value]))

    @jsii.member(jsii_name="putHost")
    def put_host(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["MdbElasticsearchClusterHost"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putHost", [value]))

    @jsii.member(jsii_name="putMaintenanceWindow")
    def put_maintenance_window(
        self,
        *,
        type: builtins.str,
        day: typing.Optional[builtins.str] = None,
        hour: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#type MdbElasticsearchCluster#type}.
        :param day: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#day MdbElasticsearchCluster#day}.
        :param hour: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#hour MdbElasticsearchCluster#hour}.
        '''
        value = MdbElasticsearchClusterMaintenanceWindow(type=type, day=day, hour=hour)

        return typing.cast(None, jsii.invoke(self, "putMaintenanceWindow", [value]))

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#create MdbElasticsearchCluster#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#delete MdbElasticsearchCluster#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#update MdbElasticsearchCluster#update}.
        '''
        value = MdbElasticsearchClusterTimeouts(
            create=create, delete=delete, update=update
        )

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetDeletionProtection")
    def reset_deletion_protection(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDeletionProtection", []))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetHost")
    def reset_host(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHost", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetMaintenanceWindow")
    def reset_maintenance_window(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaintenanceWindow", []))

    @jsii.member(jsii_name="resetSecurityGroupIds")
    def reset_security_group_ids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityGroupIds", []))

    @jsii.member(jsii_name="resetServiceAccountId")
    def reset_service_account_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetServiceAccountId", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="config")
    def config(self) -> "MdbElasticsearchClusterConfigAOutputReference":
        return typing.cast("MdbElasticsearchClusterConfigAOutputReference", jsii.get(self, "config"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="health")
    def health(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "health"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="host")
    def host(self) -> "MdbElasticsearchClusterHostList":
        return typing.cast("MdbElasticsearchClusterHostList", jsii.get(self, "host"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maintenanceWindow")
    def maintenance_window(
        self,
    ) -> "MdbElasticsearchClusterMaintenanceWindowOutputReference":
        return typing.cast("MdbElasticsearchClusterMaintenanceWindowOutputReference", jsii.get(self, "maintenanceWindow"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "MdbElasticsearchClusterTimeoutsOutputReference":
        return typing.cast("MdbElasticsearchClusterTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="configInput")
    def config_input(self) -> typing.Optional["MdbElasticsearchClusterConfigA"]:
        return typing.cast(typing.Optional["MdbElasticsearchClusterConfigA"], jsii.get(self, "configInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtectionInput")
    def deletion_protection_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "deletionProtectionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="environmentInput")
    def environment_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "environmentInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostInput")
    def host_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbElasticsearchClusterHost"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbElasticsearchClusterHost"]]], jsii.get(self, "hostInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maintenanceWindowInput")
    def maintenance_window_input(
        self,
    ) -> typing.Optional["MdbElasticsearchClusterMaintenanceWindow"]:
        return typing.cast(typing.Optional["MdbElasticsearchClusterMaintenanceWindow"], jsii.get(self, "maintenanceWindowInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkIdInput")
    def network_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "networkIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIdsInput")
    def security_group_ids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "securityGroupIdsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountIdInput")
    def service_account_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceAccountIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "MdbElasticsearchClusterTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "MdbElasticsearchClusterTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtection")
    def deletion_protection(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "deletionProtection"))

    @deletion_protection.setter
    def deletion_protection(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "deletionProtection", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="environment")
    def environment(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "environment"))

    @environment.setter
    def environment(self, value: builtins.str) -> None:
        jsii.set(self, "environment", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @network_id.setter
    def network_id(self, value: builtins.str) -> None:
        jsii.set(self, "networkId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "securityGroupIds"))

    @security_group_ids.setter
    def security_group_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "securityGroupIds", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountId")
    def service_account_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceAccountId"))

    @service_account_id.setter
    def service_account_id(self, value: builtins.str) -> None:
        jsii.set(self, "serviceAccountId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbElasticsearchClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "config": "config",
        "environment": "environment",
        "name": "name",
        "network_id": "networkId",
        "deletion_protection": "deletionProtection",
        "description": "description",
        "folder_id": "folderId",
        "host": "host",
        "id": "id",
        "labels": "labels",
        "maintenance_window": "maintenanceWindow",
        "security_group_ids": "securityGroupIds",
        "service_account_id": "serviceAccountId",
        "timeouts": "timeouts",
    },
)
class MdbElasticsearchClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        config: "MdbElasticsearchClusterConfigA",
        environment: builtins.str,
        name: builtins.str,
        network_id: builtins.str,
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        host: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbElasticsearchClusterHost"]]] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        maintenance_window: typing.Optional["MdbElasticsearchClusterMaintenanceWindow"] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        service_account_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["MdbElasticsearchClusterTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param config: config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#config MdbElasticsearchCluster#config}
        :param environment: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#environment MdbElasticsearchCluster#environment}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#name MdbElasticsearchCluster#name}.
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#network_id MdbElasticsearchCluster#network_id}.
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#deletion_protection MdbElasticsearchCluster#deletion_protection}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#description MdbElasticsearchCluster#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#folder_id MdbElasticsearchCluster#folder_id}.
        :param host: host block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#host MdbElasticsearchCluster#host}
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#id MdbElasticsearchCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#labels MdbElasticsearchCluster#labels}.
        :param maintenance_window: maintenance_window block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#maintenance_window MdbElasticsearchCluster#maintenance_window}
        :param security_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#security_group_ids MdbElasticsearchCluster#security_group_ids}.
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#service_account_id MdbElasticsearchCluster#service_account_id}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#timeouts MdbElasticsearchCluster#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(config, dict):
            config = MdbElasticsearchClusterConfigA(**config)
        if isinstance(maintenance_window, dict):
            maintenance_window = MdbElasticsearchClusterMaintenanceWindow(**maintenance_window)
        if isinstance(timeouts, dict):
            timeouts = MdbElasticsearchClusterTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "config": config,
            "environment": environment,
            "name": name,
            "network_id": network_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if deletion_protection is not None:
            self._values["deletion_protection"] = deletion_protection
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if host is not None:
            self._values["host"] = host
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if maintenance_window is not None:
            self._values["maintenance_window"] = maintenance_window
        if security_group_ids is not None:
            self._values["security_group_ids"] = security_group_ids
        if service_account_id is not None:
            self._values["service_account_id"] = service_account_id
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def config(self) -> "MdbElasticsearchClusterConfigA":
        '''config block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#config MdbElasticsearchCluster#config}
        '''
        result = self._values.get("config")
        assert result is not None, "Required property 'config' is missing"
        return typing.cast("MdbElasticsearchClusterConfigA", result)

    @builtins.property
    def environment(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#environment MdbElasticsearchCluster#environment}.'''
        result = self._values.get("environment")
        assert result is not None, "Required property 'environment' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#name MdbElasticsearchCluster#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def network_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#network_id MdbElasticsearchCluster#network_id}.'''
        result = self._values.get("network_id")
        assert result is not None, "Required property 'network_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def deletion_protection(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#deletion_protection MdbElasticsearchCluster#deletion_protection}.'''
        result = self._values.get("deletion_protection")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#description MdbElasticsearchCluster#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#folder_id MdbElasticsearchCluster#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def host(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbElasticsearchClusterHost"]]]:
        '''host block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#host MdbElasticsearchCluster#host}
        '''
        result = self._values.get("host")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbElasticsearchClusterHost"]]], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#id MdbElasticsearchCluster#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#labels MdbElasticsearchCluster#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def maintenance_window(
        self,
    ) -> typing.Optional["MdbElasticsearchClusterMaintenanceWindow"]:
        '''maintenance_window block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#maintenance_window MdbElasticsearchCluster#maintenance_window}
        '''
        result = self._values.get("maintenance_window")
        return typing.cast(typing.Optional["MdbElasticsearchClusterMaintenanceWindow"], result)

    @builtins.property
    def security_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#security_group_ids MdbElasticsearchCluster#security_group_ids}.'''
        result = self._values.get("security_group_ids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def service_account_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#service_account_id MdbElasticsearchCluster#service_account_id}.'''
        result = self._values.get("service_account_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["MdbElasticsearchClusterTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#timeouts MdbElasticsearchCluster#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["MdbElasticsearchClusterTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbElasticsearchClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbElasticsearchClusterConfigA",
    jsii_struct_bases=[],
    name_mapping={
        "admin_password": "adminPassword",
        "data_node": "dataNode",
        "edition": "edition",
        "master_node": "masterNode",
        "plugins": "plugins",
        "version": "version",
    },
)
class MdbElasticsearchClusterConfigA:
    def __init__(
        self,
        *,
        admin_password: builtins.str,
        data_node: "MdbElasticsearchClusterConfigDataNode",
        edition: typing.Optional[builtins.str] = None,
        master_node: typing.Optional["MdbElasticsearchClusterConfigMasterNode"] = None,
        plugins: typing.Optional[typing.Sequence[builtins.str]] = None,
        version: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param admin_password: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#admin_password MdbElasticsearchCluster#admin_password}.
        :param data_node: data_node block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#data_node MdbElasticsearchCluster#data_node}
        :param edition: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#edition MdbElasticsearchCluster#edition}.
        :param master_node: master_node block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#master_node MdbElasticsearchCluster#master_node}
        :param plugins: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#plugins MdbElasticsearchCluster#plugins}.
        :param version: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#version MdbElasticsearchCluster#version}.
        '''
        if isinstance(data_node, dict):
            data_node = MdbElasticsearchClusterConfigDataNode(**data_node)
        if isinstance(master_node, dict):
            master_node = MdbElasticsearchClusterConfigMasterNode(**master_node)
        self._values: typing.Dict[str, typing.Any] = {
            "admin_password": admin_password,
            "data_node": data_node,
        }
        if edition is not None:
            self._values["edition"] = edition
        if master_node is not None:
            self._values["master_node"] = master_node
        if plugins is not None:
            self._values["plugins"] = plugins
        if version is not None:
            self._values["version"] = version

    @builtins.property
    def admin_password(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#admin_password MdbElasticsearchCluster#admin_password}.'''
        result = self._values.get("admin_password")
        assert result is not None, "Required property 'admin_password' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def data_node(self) -> "MdbElasticsearchClusterConfigDataNode":
        '''data_node block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#data_node MdbElasticsearchCluster#data_node}
        '''
        result = self._values.get("data_node")
        assert result is not None, "Required property 'data_node' is missing"
        return typing.cast("MdbElasticsearchClusterConfigDataNode", result)

    @builtins.property
    def edition(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#edition MdbElasticsearchCluster#edition}.'''
        result = self._values.get("edition")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def master_node(self) -> typing.Optional["MdbElasticsearchClusterConfigMasterNode"]:
        '''master_node block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#master_node MdbElasticsearchCluster#master_node}
        '''
        result = self._values.get("master_node")
        return typing.cast(typing.Optional["MdbElasticsearchClusterConfigMasterNode"], result)

    @builtins.property
    def plugins(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#plugins MdbElasticsearchCluster#plugins}.'''
        result = self._values.get("plugins")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def version(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#version MdbElasticsearchCluster#version}.'''
        result = self._values.get("version")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbElasticsearchClusterConfigA(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbElasticsearchClusterConfigAOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbElasticsearchClusterConfigAOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putDataNode")
    def put_data_node(
        self,
        *,
        resources: "MdbElasticsearchClusterConfigDataNodeResources",
    ) -> None:
        '''
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#resources MdbElasticsearchCluster#resources}
        '''
        value = MdbElasticsearchClusterConfigDataNode(resources=resources)

        return typing.cast(None, jsii.invoke(self, "putDataNode", [value]))

    @jsii.member(jsii_name="putMasterNode")
    def put_master_node(
        self,
        *,
        resources: "MdbElasticsearchClusterConfigMasterNodeResources",
    ) -> None:
        '''
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#resources MdbElasticsearchCluster#resources}
        '''
        value = MdbElasticsearchClusterConfigMasterNode(resources=resources)

        return typing.cast(None, jsii.invoke(self, "putMasterNode", [value]))

    @jsii.member(jsii_name="resetEdition")
    def reset_edition(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEdition", []))

    @jsii.member(jsii_name="resetMasterNode")
    def reset_master_node(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMasterNode", []))

    @jsii.member(jsii_name="resetPlugins")
    def reset_plugins(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPlugins", []))

    @jsii.member(jsii_name="resetVersion")
    def reset_version(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetVersion", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dataNode")
    def data_node(self) -> "MdbElasticsearchClusterConfigDataNodeOutputReference":
        return typing.cast("MdbElasticsearchClusterConfigDataNodeOutputReference", jsii.get(self, "dataNode"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="masterNode")
    def master_node(self) -> "MdbElasticsearchClusterConfigMasterNodeOutputReference":
        return typing.cast("MdbElasticsearchClusterConfigMasterNodeOutputReference", jsii.get(self, "masterNode"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="adminPasswordInput")
    def admin_password_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "adminPasswordInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dataNodeInput")
    def data_node_input(
        self,
    ) -> typing.Optional["MdbElasticsearchClusterConfigDataNode"]:
        return typing.cast(typing.Optional["MdbElasticsearchClusterConfigDataNode"], jsii.get(self, "dataNodeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="editionInput")
    def edition_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "editionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="masterNodeInput")
    def master_node_input(
        self,
    ) -> typing.Optional["MdbElasticsearchClusterConfigMasterNode"]:
        return typing.cast(typing.Optional["MdbElasticsearchClusterConfigMasterNode"], jsii.get(self, "masterNodeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="pluginsInput")
    def plugins_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "pluginsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="versionInput")
    def version_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "versionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="adminPassword")
    def admin_password(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "adminPassword"))

    @admin_password.setter
    def admin_password(self, value: builtins.str) -> None:
        jsii.set(self, "adminPassword", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="edition")
    def edition(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "edition"))

    @edition.setter
    def edition(self, value: builtins.str) -> None:
        jsii.set(self, "edition", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="plugins")
    def plugins(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "plugins"))

    @plugins.setter
    def plugins(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "plugins", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "version"))

    @version.setter
    def version(self, value: builtins.str) -> None:
        jsii.set(self, "version", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbElasticsearchClusterConfigA]:
        return typing.cast(typing.Optional[MdbElasticsearchClusterConfigA], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbElasticsearchClusterConfigA],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbElasticsearchClusterConfigDataNode",
    jsii_struct_bases=[],
    name_mapping={"resources": "resources"},
)
class MdbElasticsearchClusterConfigDataNode:
    def __init__(
        self,
        *,
        resources: "MdbElasticsearchClusterConfigDataNodeResources",
    ) -> None:
        '''
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#resources MdbElasticsearchCluster#resources}
        '''
        if isinstance(resources, dict):
            resources = MdbElasticsearchClusterConfigDataNodeResources(**resources)
        self._values: typing.Dict[str, typing.Any] = {
            "resources": resources,
        }

    @builtins.property
    def resources(self) -> "MdbElasticsearchClusterConfigDataNodeResources":
        '''resources block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#resources MdbElasticsearchCluster#resources}
        '''
        result = self._values.get("resources")
        assert result is not None, "Required property 'resources' is missing"
        return typing.cast("MdbElasticsearchClusterConfigDataNodeResources", result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbElasticsearchClusterConfigDataNode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbElasticsearchClusterConfigDataNodeOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbElasticsearchClusterConfigDataNodeOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putResources")
    def put_resources(
        self,
        *,
        disk_size: jsii.Number,
        disk_type_id: builtins.str,
        resource_preset_id: builtins.str,
    ) -> None:
        '''
        :param disk_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#disk_size MdbElasticsearchCluster#disk_size}.
        :param disk_type_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#disk_type_id MdbElasticsearchCluster#disk_type_id}.
        :param resource_preset_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#resource_preset_id MdbElasticsearchCluster#resource_preset_id}.
        '''
        value = MdbElasticsearchClusterConfigDataNodeResources(
            disk_size=disk_size,
            disk_type_id=disk_type_id,
            resource_preset_id=resource_preset_id,
        )

        return typing.cast(None, jsii.invoke(self, "putResources", [value]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resources")
    def resources(
        self,
    ) -> "MdbElasticsearchClusterConfigDataNodeResourcesOutputReference":
        return typing.cast("MdbElasticsearchClusterConfigDataNodeResourcesOutputReference", jsii.get(self, "resources"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcesInput")
    def resources_input(
        self,
    ) -> typing.Optional["MdbElasticsearchClusterConfigDataNodeResources"]:
        return typing.cast(typing.Optional["MdbElasticsearchClusterConfigDataNodeResources"], jsii.get(self, "resourcesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbElasticsearchClusterConfigDataNode]:
        return typing.cast(typing.Optional[MdbElasticsearchClusterConfigDataNode], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbElasticsearchClusterConfigDataNode],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbElasticsearchClusterConfigDataNodeResources",
    jsii_struct_bases=[],
    name_mapping={
        "disk_size": "diskSize",
        "disk_type_id": "diskTypeId",
        "resource_preset_id": "resourcePresetId",
    },
)
class MdbElasticsearchClusterConfigDataNodeResources:
    def __init__(
        self,
        *,
        disk_size: jsii.Number,
        disk_type_id: builtins.str,
        resource_preset_id: builtins.str,
    ) -> None:
        '''
        :param disk_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#disk_size MdbElasticsearchCluster#disk_size}.
        :param disk_type_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#disk_type_id MdbElasticsearchCluster#disk_type_id}.
        :param resource_preset_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#resource_preset_id MdbElasticsearchCluster#resource_preset_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "disk_size": disk_size,
            "disk_type_id": disk_type_id,
            "resource_preset_id": resource_preset_id,
        }

    @builtins.property
    def disk_size(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#disk_size MdbElasticsearchCluster#disk_size}.'''
        result = self._values.get("disk_size")
        assert result is not None, "Required property 'disk_size' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def disk_type_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#disk_type_id MdbElasticsearchCluster#disk_type_id}.'''
        result = self._values.get("disk_type_id")
        assert result is not None, "Required property 'disk_type_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def resource_preset_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#resource_preset_id MdbElasticsearchCluster#resource_preset_id}.'''
        result = self._values.get("resource_preset_id")
        assert result is not None, "Required property 'resource_preset_id' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbElasticsearchClusterConfigDataNodeResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbElasticsearchClusterConfigDataNodeResourcesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbElasticsearchClusterConfigDataNodeResourcesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSizeInput")
    def disk_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "diskSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeIdInput")
    def disk_type_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "diskTypeIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetIdInput")
    def resource_preset_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourcePresetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSize")
    def disk_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "diskSize"))

    @disk_size.setter
    def disk_size(self, value: jsii.Number) -> None:
        jsii.set(self, "diskSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeId")
    def disk_type_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskTypeId"))

    @disk_type_id.setter
    def disk_type_id(self, value: builtins.str) -> None:
        jsii.set(self, "diskTypeId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetId")
    def resource_preset_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourcePresetId"))

    @resource_preset_id.setter
    def resource_preset_id(self, value: builtins.str) -> None:
        jsii.set(self, "resourcePresetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[MdbElasticsearchClusterConfigDataNodeResources]:
        return typing.cast(typing.Optional[MdbElasticsearchClusterConfigDataNodeResources], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbElasticsearchClusterConfigDataNodeResources],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbElasticsearchClusterConfigMasterNode",
    jsii_struct_bases=[],
    name_mapping={"resources": "resources"},
)
class MdbElasticsearchClusterConfigMasterNode:
    def __init__(
        self,
        *,
        resources: "MdbElasticsearchClusterConfigMasterNodeResources",
    ) -> None:
        '''
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#resources MdbElasticsearchCluster#resources}
        '''
        if isinstance(resources, dict):
            resources = MdbElasticsearchClusterConfigMasterNodeResources(**resources)
        self._values: typing.Dict[str, typing.Any] = {
            "resources": resources,
        }

    @builtins.property
    def resources(self) -> "MdbElasticsearchClusterConfigMasterNodeResources":
        '''resources block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#resources MdbElasticsearchCluster#resources}
        '''
        result = self._values.get("resources")
        assert result is not None, "Required property 'resources' is missing"
        return typing.cast("MdbElasticsearchClusterConfigMasterNodeResources", result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbElasticsearchClusterConfigMasterNode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbElasticsearchClusterConfigMasterNodeOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbElasticsearchClusterConfigMasterNodeOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putResources")
    def put_resources(
        self,
        *,
        disk_size: jsii.Number,
        disk_type_id: builtins.str,
        resource_preset_id: builtins.str,
    ) -> None:
        '''
        :param disk_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#disk_size MdbElasticsearchCluster#disk_size}.
        :param disk_type_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#disk_type_id MdbElasticsearchCluster#disk_type_id}.
        :param resource_preset_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#resource_preset_id MdbElasticsearchCluster#resource_preset_id}.
        '''
        value = MdbElasticsearchClusterConfigMasterNodeResources(
            disk_size=disk_size,
            disk_type_id=disk_type_id,
            resource_preset_id=resource_preset_id,
        )

        return typing.cast(None, jsii.invoke(self, "putResources", [value]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resources")
    def resources(
        self,
    ) -> "MdbElasticsearchClusterConfigMasterNodeResourcesOutputReference":
        return typing.cast("MdbElasticsearchClusterConfigMasterNodeResourcesOutputReference", jsii.get(self, "resources"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcesInput")
    def resources_input(
        self,
    ) -> typing.Optional["MdbElasticsearchClusterConfigMasterNodeResources"]:
        return typing.cast(typing.Optional["MdbElasticsearchClusterConfigMasterNodeResources"], jsii.get(self, "resourcesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[MdbElasticsearchClusterConfigMasterNode]:
        return typing.cast(typing.Optional[MdbElasticsearchClusterConfigMasterNode], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbElasticsearchClusterConfigMasterNode],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbElasticsearchClusterConfigMasterNodeResources",
    jsii_struct_bases=[],
    name_mapping={
        "disk_size": "diskSize",
        "disk_type_id": "diskTypeId",
        "resource_preset_id": "resourcePresetId",
    },
)
class MdbElasticsearchClusterConfigMasterNodeResources:
    def __init__(
        self,
        *,
        disk_size: jsii.Number,
        disk_type_id: builtins.str,
        resource_preset_id: builtins.str,
    ) -> None:
        '''
        :param disk_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#disk_size MdbElasticsearchCluster#disk_size}.
        :param disk_type_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#disk_type_id MdbElasticsearchCluster#disk_type_id}.
        :param resource_preset_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#resource_preset_id MdbElasticsearchCluster#resource_preset_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "disk_size": disk_size,
            "disk_type_id": disk_type_id,
            "resource_preset_id": resource_preset_id,
        }

    @builtins.property
    def disk_size(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#disk_size MdbElasticsearchCluster#disk_size}.'''
        result = self._values.get("disk_size")
        assert result is not None, "Required property 'disk_size' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def disk_type_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#disk_type_id MdbElasticsearchCluster#disk_type_id}.'''
        result = self._values.get("disk_type_id")
        assert result is not None, "Required property 'disk_type_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def resource_preset_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#resource_preset_id MdbElasticsearchCluster#resource_preset_id}.'''
        result = self._values.get("resource_preset_id")
        assert result is not None, "Required property 'resource_preset_id' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbElasticsearchClusterConfigMasterNodeResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbElasticsearchClusterConfigMasterNodeResourcesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbElasticsearchClusterConfigMasterNodeResourcesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSizeInput")
    def disk_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "diskSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeIdInput")
    def disk_type_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "diskTypeIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetIdInput")
    def resource_preset_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourcePresetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSize")
    def disk_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "diskSize"))

    @disk_size.setter
    def disk_size(self, value: jsii.Number) -> None:
        jsii.set(self, "diskSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeId")
    def disk_type_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskTypeId"))

    @disk_type_id.setter
    def disk_type_id(self, value: builtins.str) -> None:
        jsii.set(self, "diskTypeId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetId")
    def resource_preset_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourcePresetId"))

    @resource_preset_id.setter
    def resource_preset_id(self, value: builtins.str) -> None:
        jsii.set(self, "resourcePresetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[MdbElasticsearchClusterConfigMasterNodeResources]:
        return typing.cast(typing.Optional[MdbElasticsearchClusterConfigMasterNodeResources], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbElasticsearchClusterConfigMasterNodeResources],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbElasticsearchClusterHost",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "type": "type",
        "zone": "zone",
        "assign_public_ip": "assignPublicIp",
        "subnet_id": "subnetId",
    },
)
class MdbElasticsearchClusterHost:
    def __init__(
        self,
        *,
        name: builtins.str,
        type: builtins.str,
        zone: builtins.str,
        assign_public_ip: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        subnet_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#name MdbElasticsearchCluster#name}.
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#type MdbElasticsearchCluster#type}.
        :param zone: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#zone MdbElasticsearchCluster#zone}.
        :param assign_public_ip: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#assign_public_ip MdbElasticsearchCluster#assign_public_ip}.
        :param subnet_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#subnet_id MdbElasticsearchCluster#subnet_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "type": type,
            "zone": zone,
        }
        if assign_public_ip is not None:
            self._values["assign_public_ip"] = assign_public_ip
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#name MdbElasticsearchCluster#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def type(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#type MdbElasticsearchCluster#type}.'''
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def zone(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#zone MdbElasticsearchCluster#zone}.'''
        result = self._values.get("zone")
        assert result is not None, "Required property 'zone' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def assign_public_ip(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#assign_public_ip MdbElasticsearchCluster#assign_public_ip}.'''
        result = self._values.get("assign_public_ip")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#subnet_id MdbElasticsearchCluster#subnet_id}.'''
        result = self._values.get("subnet_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbElasticsearchClusterHost(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbElasticsearchClusterHostList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbElasticsearchClusterHostList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "MdbElasticsearchClusterHostOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbElasticsearchClusterHostOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbElasticsearchClusterHost]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbElasticsearchClusterHost]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbElasticsearchClusterHost]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbElasticsearchClusterHostOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbElasticsearchClusterHostOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetAssignPublicIp")
    def reset_assign_public_ip(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAssignPublicIp", []))

    @jsii.member(jsii_name="resetSubnetId")
    def reset_subnet_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSubnetId", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fqdn"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIpInput")
    def assign_public_ip_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "assignPublicIpInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIdInput")
    def subnet_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "subnetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="typeInput")
    def type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "typeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneInput")
    def zone_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "zoneInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIp")
    def assign_public_ip(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "assignPublicIp"))

    @assign_public_ip.setter
    def assign_public_ip(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "assignPublicIp", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @subnet_id.setter
    def subnet_id(self, value: builtins.str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @type.setter
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zone")
    def zone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zone"))

    @zone.setter
    def zone(self, value: builtins.str) -> None:
        jsii.set(self, "zone", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbElasticsearchClusterHost]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbElasticsearchClusterHost]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbElasticsearchClusterHost]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbElasticsearchClusterMaintenanceWindow",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "day": "day", "hour": "hour"},
)
class MdbElasticsearchClusterMaintenanceWindow:
    def __init__(
        self,
        *,
        type: builtins.str,
        day: typing.Optional[builtins.str] = None,
        hour: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#type MdbElasticsearchCluster#type}.
        :param day: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#day MdbElasticsearchCluster#day}.
        :param hour: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#hour MdbElasticsearchCluster#hour}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }
        if day is not None:
            self._values["day"] = day
        if hour is not None:
            self._values["hour"] = hour

    @builtins.property
    def type(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#type MdbElasticsearchCluster#type}.'''
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def day(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#day MdbElasticsearchCluster#day}.'''
        result = self._values.get("day")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def hour(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#hour MdbElasticsearchCluster#hour}.'''
        result = self._values.get("hour")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbElasticsearchClusterMaintenanceWindow(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbElasticsearchClusterMaintenanceWindowOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbElasticsearchClusterMaintenanceWindowOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetDay")
    def reset_day(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDay", []))

    @jsii.member(jsii_name="resetHour")
    def reset_hour(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHour", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dayInput")
    def day_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dayInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hourInput")
    def hour_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "hourInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="typeInput")
    def type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "typeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="day")
    def day(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "day"))

    @day.setter
    def day(self, value: builtins.str) -> None:
        jsii.set(self, "day", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hour")
    def hour(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "hour"))

    @hour.setter
    def hour(self, value: jsii.Number) -> None:
        jsii.set(self, "hour", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @type.setter
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[MdbElasticsearchClusterMaintenanceWindow]:
        return typing.cast(typing.Optional[MdbElasticsearchClusterMaintenanceWindow], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbElasticsearchClusterMaintenanceWindow],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbElasticsearchClusterTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class MdbElasticsearchClusterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#create MdbElasticsearchCluster#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#delete MdbElasticsearchCluster#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#update MdbElasticsearchCluster#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#create MdbElasticsearchCluster#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#delete MdbElasticsearchCluster#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_elasticsearch_cluster#update MdbElasticsearchCluster#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbElasticsearchClusterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbElasticsearchClusterTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbElasticsearchClusterTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbElasticsearchClusterTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbElasticsearchClusterTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbElasticsearchClusterTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbGreenplumCluster(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbGreenplumCluster",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster yandex_mdb_greenplum_cluster}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        assign_public_ip: typing.Union[builtins.bool, cdktf.IResolvable],
        environment: builtins.str,
        master_host_count: jsii.Number,
        master_subcluster: "MdbGreenplumClusterMasterSubcluster",
        name: builtins.str,
        network_id: builtins.str,
        segment_host_count: jsii.Number,
        segment_in_host: jsii.Number,
        segment_subcluster: "MdbGreenplumClusterSegmentSubcluster",
        subnet_id: builtins.str,
        user_name: builtins.str,
        user_password: builtins.str,
        version: builtins.str,
        zone: builtins.str,
        access: typing.Optional["MdbGreenplumClusterAccess"] = None,
        backup_window_start: typing.Optional["MdbGreenplumClusterBackupWindowStart"] = None,
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        timeouts: typing.Optional["MdbGreenplumClusterTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster yandex_mdb_greenplum_cluster} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param assign_public_ip: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#assign_public_ip MdbGreenplumCluster#assign_public_ip}.
        :param environment: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#environment MdbGreenplumCluster#environment}.
        :param master_host_count: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#master_host_count MdbGreenplumCluster#master_host_count}.
        :param master_subcluster: master_subcluster block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#master_subcluster MdbGreenplumCluster#master_subcluster}
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#name MdbGreenplumCluster#name}.
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#network_id MdbGreenplumCluster#network_id}.
        :param segment_host_count: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#segment_host_count MdbGreenplumCluster#segment_host_count}.
        :param segment_in_host: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#segment_in_host MdbGreenplumCluster#segment_in_host}.
        :param segment_subcluster: segment_subcluster block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#segment_subcluster MdbGreenplumCluster#segment_subcluster}
        :param subnet_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#subnet_id MdbGreenplumCluster#subnet_id}.
        :param user_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#user_name MdbGreenplumCluster#user_name}.
        :param user_password: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#user_password MdbGreenplumCluster#user_password}.
        :param version: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#version MdbGreenplumCluster#version}.
        :param zone: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#zone MdbGreenplumCluster#zone}.
        :param access: access block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#access MdbGreenplumCluster#access}
        :param backup_window_start: backup_window_start block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#backup_window_start MdbGreenplumCluster#backup_window_start}
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#deletion_protection MdbGreenplumCluster#deletion_protection}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#description MdbGreenplumCluster#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#folder_id MdbGreenplumCluster#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#id MdbGreenplumCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#labels MdbGreenplumCluster#labels}.
        :param security_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#security_group_ids MdbGreenplumCluster#security_group_ids}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#timeouts MdbGreenplumCluster#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = MdbGreenplumClusterConfig(
            assign_public_ip=assign_public_ip,
            environment=environment,
            master_host_count=master_host_count,
            master_subcluster=master_subcluster,
            name=name,
            network_id=network_id,
            segment_host_count=segment_host_count,
            segment_in_host=segment_in_host,
            segment_subcluster=segment_subcluster,
            subnet_id=subnet_id,
            user_name=user_name,
            user_password=user_password,
            version=version,
            zone=zone,
            access=access,
            backup_window_start=backup_window_start,
            deletion_protection=deletion_protection,
            description=description,
            folder_id=folder_id,
            id=id,
            labels=labels,
            security_group_ids=security_group_ids,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putAccess")
    def put_access(
        self,
        *,
        data_lens: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        web_sql: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param data_lens: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#data_lens MdbGreenplumCluster#data_lens}.
        :param web_sql: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#web_sql MdbGreenplumCluster#web_sql}.
        '''
        value = MdbGreenplumClusterAccess(data_lens=data_lens, web_sql=web_sql)

        return typing.cast(None, jsii.invoke(self, "putAccess", [value]))

    @jsii.member(jsii_name="putBackupWindowStart")
    def put_backup_window_start(
        self,
        *,
        hours: typing.Optional[jsii.Number] = None,
        minutes: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param hours: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#hours MdbGreenplumCluster#hours}.
        :param minutes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#minutes MdbGreenplumCluster#minutes}.
        '''
        value = MdbGreenplumClusterBackupWindowStart(hours=hours, minutes=minutes)

        return typing.cast(None, jsii.invoke(self, "putBackupWindowStart", [value]))

    @jsii.member(jsii_name="putMasterSubcluster")
    def put_master_subcluster(
        self,
        *,
        resources: "MdbGreenplumClusterMasterSubclusterResources",
    ) -> None:
        '''
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#resources MdbGreenplumCluster#resources}
        '''
        value = MdbGreenplumClusterMasterSubcluster(resources=resources)

        return typing.cast(None, jsii.invoke(self, "putMasterSubcluster", [value]))

    @jsii.member(jsii_name="putSegmentSubcluster")
    def put_segment_subcluster(
        self,
        *,
        resources: "MdbGreenplumClusterSegmentSubclusterResources",
    ) -> None:
        '''
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#resources MdbGreenplumCluster#resources}
        '''
        value = MdbGreenplumClusterSegmentSubcluster(resources=resources)

        return typing.cast(None, jsii.invoke(self, "putSegmentSubcluster", [value]))

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#create MdbGreenplumCluster#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#delete MdbGreenplumCluster#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#update MdbGreenplumCluster#update}.
        '''
        value = MdbGreenplumClusterTimeouts(
            create=create, delete=delete, update=update
        )

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetAccess")
    def reset_access(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAccess", []))

    @jsii.member(jsii_name="resetBackupWindowStart")
    def reset_backup_window_start(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetBackupWindowStart", []))

    @jsii.member(jsii_name="resetDeletionProtection")
    def reset_deletion_protection(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDeletionProtection", []))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetSecurityGroupIds")
    def reset_security_group_ids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityGroupIds", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="access")
    def access(self) -> "MdbGreenplumClusterAccessOutputReference":
        return typing.cast("MdbGreenplumClusterAccessOutputReference", jsii.get(self, "access"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backupWindowStart")
    def backup_window_start(
        self,
    ) -> "MdbGreenplumClusterBackupWindowStartOutputReference":
        return typing.cast("MdbGreenplumClusterBackupWindowStartOutputReference", jsii.get(self, "backupWindowStart"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="health")
    def health(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "health"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="masterHosts")
    def master_hosts(self) -> "MdbGreenplumClusterMasterHostsList":
        return typing.cast("MdbGreenplumClusterMasterHostsList", jsii.get(self, "masterHosts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="masterSubcluster")
    def master_subcluster(self) -> "MdbGreenplumClusterMasterSubclusterOutputReference":
        return typing.cast("MdbGreenplumClusterMasterSubclusterOutputReference", jsii.get(self, "masterSubcluster"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="segmentHosts")
    def segment_hosts(self) -> "MdbGreenplumClusterSegmentHostsList":
        return typing.cast("MdbGreenplumClusterSegmentHostsList", jsii.get(self, "segmentHosts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="segmentSubcluster")
    def segment_subcluster(
        self,
    ) -> "MdbGreenplumClusterSegmentSubclusterOutputReference":
        return typing.cast("MdbGreenplumClusterSegmentSubclusterOutputReference", jsii.get(self, "segmentSubcluster"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "MdbGreenplumClusterTimeoutsOutputReference":
        return typing.cast("MdbGreenplumClusterTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="accessInput")
    def access_input(self) -> typing.Optional["MdbGreenplumClusterAccess"]:
        return typing.cast(typing.Optional["MdbGreenplumClusterAccess"], jsii.get(self, "accessInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIpInput")
    def assign_public_ip_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "assignPublicIpInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backupWindowStartInput")
    def backup_window_start_input(
        self,
    ) -> typing.Optional["MdbGreenplumClusterBackupWindowStart"]:
        return typing.cast(typing.Optional["MdbGreenplumClusterBackupWindowStart"], jsii.get(self, "backupWindowStartInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtectionInput")
    def deletion_protection_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "deletionProtectionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="environmentInput")
    def environment_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "environmentInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="masterHostCountInput")
    def master_host_count_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "masterHostCountInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="masterSubclusterInput")
    def master_subcluster_input(
        self,
    ) -> typing.Optional["MdbGreenplumClusterMasterSubcluster"]:
        return typing.cast(typing.Optional["MdbGreenplumClusterMasterSubcluster"], jsii.get(self, "masterSubclusterInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkIdInput")
    def network_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "networkIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIdsInput")
    def security_group_ids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "securityGroupIdsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="segmentHostCountInput")
    def segment_host_count_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "segmentHostCountInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="segmentInHostInput")
    def segment_in_host_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "segmentInHostInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="segmentSubclusterInput")
    def segment_subcluster_input(
        self,
    ) -> typing.Optional["MdbGreenplumClusterSegmentSubcluster"]:
        return typing.cast(typing.Optional["MdbGreenplumClusterSegmentSubcluster"], jsii.get(self, "segmentSubclusterInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIdInput")
    def subnet_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "subnetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "MdbGreenplumClusterTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "MdbGreenplumClusterTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="userNameInput")
    def user_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "userNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="userPasswordInput")
    def user_password_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "userPasswordInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="versionInput")
    def version_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "versionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneInput")
    def zone_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "zoneInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIp")
    def assign_public_ip(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "assignPublicIp"))

    @assign_public_ip.setter
    def assign_public_ip(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "assignPublicIp", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtection")
    def deletion_protection(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "deletionProtection"))

    @deletion_protection.setter
    def deletion_protection(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "deletionProtection", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="environment")
    def environment(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "environment"))

    @environment.setter
    def environment(self, value: builtins.str) -> None:
        jsii.set(self, "environment", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="masterHostCount")
    def master_host_count(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "masterHostCount"))

    @master_host_count.setter
    def master_host_count(self, value: jsii.Number) -> None:
        jsii.set(self, "masterHostCount", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @network_id.setter
    def network_id(self, value: builtins.str) -> None:
        jsii.set(self, "networkId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "securityGroupIds"))

    @security_group_ids.setter
    def security_group_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "securityGroupIds", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="segmentHostCount")
    def segment_host_count(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "segmentHostCount"))

    @segment_host_count.setter
    def segment_host_count(self, value: jsii.Number) -> None:
        jsii.set(self, "segmentHostCount", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="segmentInHost")
    def segment_in_host(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "segmentInHost"))

    @segment_in_host.setter
    def segment_in_host(self, value: jsii.Number) -> None:
        jsii.set(self, "segmentInHost", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @subnet_id.setter
    def subnet_id(self, value: builtins.str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="userName")
    def user_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "userName"))

    @user_name.setter
    def user_name(self, value: builtins.str) -> None:
        jsii.set(self, "userName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="userPassword")
    def user_password(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "userPassword"))

    @user_password.setter
    def user_password(self, value: builtins.str) -> None:
        jsii.set(self, "userPassword", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "version"))

    @version.setter
    def version(self, value: builtins.str) -> None:
        jsii.set(self, "version", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zone")
    def zone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zone"))

    @zone.setter
    def zone(self, value: builtins.str) -> None:
        jsii.set(self, "zone", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbGreenplumClusterAccess",
    jsii_struct_bases=[],
    name_mapping={"data_lens": "dataLens", "web_sql": "webSql"},
)
class MdbGreenplumClusterAccess:
    def __init__(
        self,
        *,
        data_lens: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        web_sql: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param data_lens: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#data_lens MdbGreenplumCluster#data_lens}.
        :param web_sql: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#web_sql MdbGreenplumCluster#web_sql}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if data_lens is not None:
            self._values["data_lens"] = data_lens
        if web_sql is not None:
            self._values["web_sql"] = web_sql

    @builtins.property
    def data_lens(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#data_lens MdbGreenplumCluster#data_lens}.'''
        result = self._values.get("data_lens")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def web_sql(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#web_sql MdbGreenplumCluster#web_sql}.'''
        result = self._values.get("web_sql")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbGreenplumClusterAccess(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbGreenplumClusterAccessOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbGreenplumClusterAccessOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetDataLens")
    def reset_data_lens(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDataLens", []))

    @jsii.member(jsii_name="resetWebSql")
    def reset_web_sql(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetWebSql", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dataLensInput")
    def data_lens_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "dataLensInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="webSqlInput")
    def web_sql_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "webSqlInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dataLens")
    def data_lens(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "dataLens"))

    @data_lens.setter
    def data_lens(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "dataLens", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="webSql")
    def web_sql(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "webSql"))

    @web_sql.setter
    def web_sql(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "webSql", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbGreenplumClusterAccess]:
        return typing.cast(typing.Optional[MdbGreenplumClusterAccess], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(self, value: typing.Optional[MdbGreenplumClusterAccess]) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbGreenplumClusterBackupWindowStart",
    jsii_struct_bases=[],
    name_mapping={"hours": "hours", "minutes": "minutes"},
)
class MdbGreenplumClusterBackupWindowStart:
    def __init__(
        self,
        *,
        hours: typing.Optional[jsii.Number] = None,
        minutes: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param hours: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#hours MdbGreenplumCluster#hours}.
        :param minutes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#minutes MdbGreenplumCluster#minutes}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if hours is not None:
            self._values["hours"] = hours
        if minutes is not None:
            self._values["minutes"] = minutes

    @builtins.property
    def hours(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#hours MdbGreenplumCluster#hours}.'''
        result = self._values.get("hours")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def minutes(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#minutes MdbGreenplumCluster#minutes}.'''
        result = self._values.get("minutes")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbGreenplumClusterBackupWindowStart(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbGreenplumClusterBackupWindowStartOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbGreenplumClusterBackupWindowStartOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetHours")
    def reset_hours(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHours", []))

    @jsii.member(jsii_name="resetMinutes")
    def reset_minutes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMinutes", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hoursInput")
    def hours_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "hoursInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minutesInput")
    def minutes_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "minutesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hours")
    def hours(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "hours"))

    @hours.setter
    def hours(self, value: jsii.Number) -> None:
        jsii.set(self, "hours", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minutes")
    def minutes(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minutes"))

    @minutes.setter
    def minutes(self, value: jsii.Number) -> None:
        jsii.set(self, "minutes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbGreenplumClusterBackupWindowStart]:
        return typing.cast(typing.Optional[MdbGreenplumClusterBackupWindowStart], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbGreenplumClusterBackupWindowStart],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbGreenplumClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "assign_public_ip": "assignPublicIp",
        "environment": "environment",
        "master_host_count": "masterHostCount",
        "master_subcluster": "masterSubcluster",
        "name": "name",
        "network_id": "networkId",
        "segment_host_count": "segmentHostCount",
        "segment_in_host": "segmentInHost",
        "segment_subcluster": "segmentSubcluster",
        "subnet_id": "subnetId",
        "user_name": "userName",
        "user_password": "userPassword",
        "version": "version",
        "zone": "zone",
        "access": "access",
        "backup_window_start": "backupWindowStart",
        "deletion_protection": "deletionProtection",
        "description": "description",
        "folder_id": "folderId",
        "id": "id",
        "labels": "labels",
        "security_group_ids": "securityGroupIds",
        "timeouts": "timeouts",
    },
)
class MdbGreenplumClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        assign_public_ip: typing.Union[builtins.bool, cdktf.IResolvable],
        environment: builtins.str,
        master_host_count: jsii.Number,
        master_subcluster: "MdbGreenplumClusterMasterSubcluster",
        name: builtins.str,
        network_id: builtins.str,
        segment_host_count: jsii.Number,
        segment_in_host: jsii.Number,
        segment_subcluster: "MdbGreenplumClusterSegmentSubcluster",
        subnet_id: builtins.str,
        user_name: builtins.str,
        user_password: builtins.str,
        version: builtins.str,
        zone: builtins.str,
        access: typing.Optional[MdbGreenplumClusterAccess] = None,
        backup_window_start: typing.Optional[MdbGreenplumClusterBackupWindowStart] = None,
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        timeouts: typing.Optional["MdbGreenplumClusterTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param assign_public_ip: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#assign_public_ip MdbGreenplumCluster#assign_public_ip}.
        :param environment: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#environment MdbGreenplumCluster#environment}.
        :param master_host_count: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#master_host_count MdbGreenplumCluster#master_host_count}.
        :param master_subcluster: master_subcluster block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#master_subcluster MdbGreenplumCluster#master_subcluster}
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#name MdbGreenplumCluster#name}.
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#network_id MdbGreenplumCluster#network_id}.
        :param segment_host_count: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#segment_host_count MdbGreenplumCluster#segment_host_count}.
        :param segment_in_host: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#segment_in_host MdbGreenplumCluster#segment_in_host}.
        :param segment_subcluster: segment_subcluster block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#segment_subcluster MdbGreenplumCluster#segment_subcluster}
        :param subnet_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#subnet_id MdbGreenplumCluster#subnet_id}.
        :param user_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#user_name MdbGreenplumCluster#user_name}.
        :param user_password: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#user_password MdbGreenplumCluster#user_password}.
        :param version: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#version MdbGreenplumCluster#version}.
        :param zone: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#zone MdbGreenplumCluster#zone}.
        :param access: access block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#access MdbGreenplumCluster#access}
        :param backup_window_start: backup_window_start block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#backup_window_start MdbGreenplumCluster#backup_window_start}
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#deletion_protection MdbGreenplumCluster#deletion_protection}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#description MdbGreenplumCluster#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#folder_id MdbGreenplumCluster#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#id MdbGreenplumCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#labels MdbGreenplumCluster#labels}.
        :param security_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#security_group_ids MdbGreenplumCluster#security_group_ids}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#timeouts MdbGreenplumCluster#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(master_subcluster, dict):
            master_subcluster = MdbGreenplumClusterMasterSubcluster(**master_subcluster)
        if isinstance(segment_subcluster, dict):
            segment_subcluster = MdbGreenplumClusterSegmentSubcluster(**segment_subcluster)
        if isinstance(access, dict):
            access = MdbGreenplumClusterAccess(**access)
        if isinstance(backup_window_start, dict):
            backup_window_start = MdbGreenplumClusterBackupWindowStart(**backup_window_start)
        if isinstance(timeouts, dict):
            timeouts = MdbGreenplumClusterTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "assign_public_ip": assign_public_ip,
            "environment": environment,
            "master_host_count": master_host_count,
            "master_subcluster": master_subcluster,
            "name": name,
            "network_id": network_id,
            "segment_host_count": segment_host_count,
            "segment_in_host": segment_in_host,
            "segment_subcluster": segment_subcluster,
            "subnet_id": subnet_id,
            "user_name": user_name,
            "user_password": user_password,
            "version": version,
            "zone": zone,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if access is not None:
            self._values["access"] = access
        if backup_window_start is not None:
            self._values["backup_window_start"] = backup_window_start
        if deletion_protection is not None:
            self._values["deletion_protection"] = deletion_protection
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if security_group_ids is not None:
            self._values["security_group_ids"] = security_group_ids
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def assign_public_ip(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#assign_public_ip MdbGreenplumCluster#assign_public_ip}.'''
        result = self._values.get("assign_public_ip")
        assert result is not None, "Required property 'assign_public_ip' is missing"
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], result)

    @builtins.property
    def environment(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#environment MdbGreenplumCluster#environment}.'''
        result = self._values.get("environment")
        assert result is not None, "Required property 'environment' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def master_host_count(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#master_host_count MdbGreenplumCluster#master_host_count}.'''
        result = self._values.get("master_host_count")
        assert result is not None, "Required property 'master_host_count' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def master_subcluster(self) -> "MdbGreenplumClusterMasterSubcluster":
        '''master_subcluster block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#master_subcluster MdbGreenplumCluster#master_subcluster}
        '''
        result = self._values.get("master_subcluster")
        assert result is not None, "Required property 'master_subcluster' is missing"
        return typing.cast("MdbGreenplumClusterMasterSubcluster", result)

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#name MdbGreenplumCluster#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def network_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#network_id MdbGreenplumCluster#network_id}.'''
        result = self._values.get("network_id")
        assert result is not None, "Required property 'network_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def segment_host_count(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#segment_host_count MdbGreenplumCluster#segment_host_count}.'''
        result = self._values.get("segment_host_count")
        assert result is not None, "Required property 'segment_host_count' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def segment_in_host(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#segment_in_host MdbGreenplumCluster#segment_in_host}.'''
        result = self._values.get("segment_in_host")
        assert result is not None, "Required property 'segment_in_host' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def segment_subcluster(self) -> "MdbGreenplumClusterSegmentSubcluster":
        '''segment_subcluster block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#segment_subcluster MdbGreenplumCluster#segment_subcluster}
        '''
        result = self._values.get("segment_subcluster")
        assert result is not None, "Required property 'segment_subcluster' is missing"
        return typing.cast("MdbGreenplumClusterSegmentSubcluster", result)

    @builtins.property
    def subnet_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#subnet_id MdbGreenplumCluster#subnet_id}.'''
        result = self._values.get("subnet_id")
        assert result is not None, "Required property 'subnet_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def user_name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#user_name MdbGreenplumCluster#user_name}.'''
        result = self._values.get("user_name")
        assert result is not None, "Required property 'user_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def user_password(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#user_password MdbGreenplumCluster#user_password}.'''
        result = self._values.get("user_password")
        assert result is not None, "Required property 'user_password' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def version(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#version MdbGreenplumCluster#version}.'''
        result = self._values.get("version")
        assert result is not None, "Required property 'version' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def zone(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#zone MdbGreenplumCluster#zone}.'''
        result = self._values.get("zone")
        assert result is not None, "Required property 'zone' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def access(self) -> typing.Optional[MdbGreenplumClusterAccess]:
        '''access block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#access MdbGreenplumCluster#access}
        '''
        result = self._values.get("access")
        return typing.cast(typing.Optional[MdbGreenplumClusterAccess], result)

    @builtins.property
    def backup_window_start(
        self,
    ) -> typing.Optional[MdbGreenplumClusterBackupWindowStart]:
        '''backup_window_start block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#backup_window_start MdbGreenplumCluster#backup_window_start}
        '''
        result = self._values.get("backup_window_start")
        return typing.cast(typing.Optional[MdbGreenplumClusterBackupWindowStart], result)

    @builtins.property
    def deletion_protection(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#deletion_protection MdbGreenplumCluster#deletion_protection}.'''
        result = self._values.get("deletion_protection")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#description MdbGreenplumCluster#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#folder_id MdbGreenplumCluster#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#id MdbGreenplumCluster#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#labels MdbGreenplumCluster#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def security_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#security_group_ids MdbGreenplumCluster#security_group_ids}.'''
        result = self._values.get("security_group_ids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["MdbGreenplumClusterTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#timeouts MdbGreenplumCluster#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["MdbGreenplumClusterTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbGreenplumClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbGreenplumClusterMasterHosts",
    jsii_struct_bases=[],
    name_mapping={},
)
class MdbGreenplumClusterMasterHosts:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbGreenplumClusterMasterHosts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbGreenplumClusterMasterHostsList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbGreenplumClusterMasterHostsList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "MdbGreenplumClusterMasterHostsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbGreenplumClusterMasterHostsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class MdbGreenplumClusterMasterHostsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbGreenplumClusterMasterHostsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIp")
    def assign_public_ip(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "assignPublicIp"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fqdn"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbGreenplumClusterMasterHosts]:
        return typing.cast(typing.Optional[MdbGreenplumClusterMasterHosts], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbGreenplumClusterMasterHosts],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbGreenplumClusterMasterSubcluster",
    jsii_struct_bases=[],
    name_mapping={"resources": "resources"},
)
class MdbGreenplumClusterMasterSubcluster:
    def __init__(
        self,
        *,
        resources: "MdbGreenplumClusterMasterSubclusterResources",
    ) -> None:
        '''
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#resources MdbGreenplumCluster#resources}
        '''
        if isinstance(resources, dict):
            resources = MdbGreenplumClusterMasterSubclusterResources(**resources)
        self._values: typing.Dict[str, typing.Any] = {
            "resources": resources,
        }

    @builtins.property
    def resources(self) -> "MdbGreenplumClusterMasterSubclusterResources":
        '''resources block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#resources MdbGreenplumCluster#resources}
        '''
        result = self._values.get("resources")
        assert result is not None, "Required property 'resources' is missing"
        return typing.cast("MdbGreenplumClusterMasterSubclusterResources", result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbGreenplumClusterMasterSubcluster(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbGreenplumClusterMasterSubclusterOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbGreenplumClusterMasterSubclusterOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putResources")
    def put_resources(
        self,
        *,
        disk_size: jsii.Number,
        disk_type_id: builtins.str,
        resource_preset_id: builtins.str,
    ) -> None:
        '''
        :param disk_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#disk_size MdbGreenplumCluster#disk_size}.
        :param disk_type_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#disk_type_id MdbGreenplumCluster#disk_type_id}.
        :param resource_preset_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#resource_preset_id MdbGreenplumCluster#resource_preset_id}.
        '''
        value = MdbGreenplumClusterMasterSubclusterResources(
            disk_size=disk_size,
            disk_type_id=disk_type_id,
            resource_preset_id=resource_preset_id,
        )

        return typing.cast(None, jsii.invoke(self, "putResources", [value]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resources")
    def resources(
        self,
    ) -> "MdbGreenplumClusterMasterSubclusterResourcesOutputReference":
        return typing.cast("MdbGreenplumClusterMasterSubclusterResourcesOutputReference", jsii.get(self, "resources"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcesInput")
    def resources_input(
        self,
    ) -> typing.Optional["MdbGreenplumClusterMasterSubclusterResources"]:
        return typing.cast(typing.Optional["MdbGreenplumClusterMasterSubclusterResources"], jsii.get(self, "resourcesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbGreenplumClusterMasterSubcluster]:
        return typing.cast(typing.Optional[MdbGreenplumClusterMasterSubcluster], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbGreenplumClusterMasterSubcluster],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbGreenplumClusterMasterSubclusterResources",
    jsii_struct_bases=[],
    name_mapping={
        "disk_size": "diskSize",
        "disk_type_id": "diskTypeId",
        "resource_preset_id": "resourcePresetId",
    },
)
class MdbGreenplumClusterMasterSubclusterResources:
    def __init__(
        self,
        *,
        disk_size: jsii.Number,
        disk_type_id: builtins.str,
        resource_preset_id: builtins.str,
    ) -> None:
        '''
        :param disk_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#disk_size MdbGreenplumCluster#disk_size}.
        :param disk_type_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#disk_type_id MdbGreenplumCluster#disk_type_id}.
        :param resource_preset_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#resource_preset_id MdbGreenplumCluster#resource_preset_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "disk_size": disk_size,
            "disk_type_id": disk_type_id,
            "resource_preset_id": resource_preset_id,
        }

    @builtins.property
    def disk_size(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#disk_size MdbGreenplumCluster#disk_size}.'''
        result = self._values.get("disk_size")
        assert result is not None, "Required property 'disk_size' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def disk_type_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#disk_type_id MdbGreenplumCluster#disk_type_id}.'''
        result = self._values.get("disk_type_id")
        assert result is not None, "Required property 'disk_type_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def resource_preset_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#resource_preset_id MdbGreenplumCluster#resource_preset_id}.'''
        result = self._values.get("resource_preset_id")
        assert result is not None, "Required property 'resource_preset_id' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbGreenplumClusterMasterSubclusterResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbGreenplumClusterMasterSubclusterResourcesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbGreenplumClusterMasterSubclusterResourcesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSizeInput")
    def disk_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "diskSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeIdInput")
    def disk_type_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "diskTypeIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetIdInput")
    def resource_preset_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourcePresetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSize")
    def disk_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "diskSize"))

    @disk_size.setter
    def disk_size(self, value: jsii.Number) -> None:
        jsii.set(self, "diskSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeId")
    def disk_type_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskTypeId"))

    @disk_type_id.setter
    def disk_type_id(self, value: builtins.str) -> None:
        jsii.set(self, "diskTypeId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetId")
    def resource_preset_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourcePresetId"))

    @resource_preset_id.setter
    def resource_preset_id(self, value: builtins.str) -> None:
        jsii.set(self, "resourcePresetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[MdbGreenplumClusterMasterSubclusterResources]:
        return typing.cast(typing.Optional[MdbGreenplumClusterMasterSubclusterResources], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbGreenplumClusterMasterSubclusterResources],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbGreenplumClusterSegmentHosts",
    jsii_struct_bases=[],
    name_mapping={},
)
class MdbGreenplumClusterSegmentHosts:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbGreenplumClusterSegmentHosts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbGreenplumClusterSegmentHostsList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbGreenplumClusterSegmentHostsList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "MdbGreenplumClusterSegmentHostsOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbGreenplumClusterSegmentHostsOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class MdbGreenplumClusterSegmentHostsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbGreenplumClusterSegmentHostsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fqdn"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbGreenplumClusterSegmentHosts]:
        return typing.cast(typing.Optional[MdbGreenplumClusterSegmentHosts], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbGreenplumClusterSegmentHosts],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbGreenplumClusterSegmentSubcluster",
    jsii_struct_bases=[],
    name_mapping={"resources": "resources"},
)
class MdbGreenplumClusterSegmentSubcluster:
    def __init__(
        self,
        *,
        resources: "MdbGreenplumClusterSegmentSubclusterResources",
    ) -> None:
        '''
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#resources MdbGreenplumCluster#resources}
        '''
        if isinstance(resources, dict):
            resources = MdbGreenplumClusterSegmentSubclusterResources(**resources)
        self._values: typing.Dict[str, typing.Any] = {
            "resources": resources,
        }

    @builtins.property
    def resources(self) -> "MdbGreenplumClusterSegmentSubclusterResources":
        '''resources block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#resources MdbGreenplumCluster#resources}
        '''
        result = self._values.get("resources")
        assert result is not None, "Required property 'resources' is missing"
        return typing.cast("MdbGreenplumClusterSegmentSubclusterResources", result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbGreenplumClusterSegmentSubcluster(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbGreenplumClusterSegmentSubclusterOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbGreenplumClusterSegmentSubclusterOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putResources")
    def put_resources(
        self,
        *,
        disk_size: jsii.Number,
        disk_type_id: builtins.str,
        resource_preset_id: builtins.str,
    ) -> None:
        '''
        :param disk_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#disk_size MdbGreenplumCluster#disk_size}.
        :param disk_type_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#disk_type_id MdbGreenplumCluster#disk_type_id}.
        :param resource_preset_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#resource_preset_id MdbGreenplumCluster#resource_preset_id}.
        '''
        value = MdbGreenplumClusterSegmentSubclusterResources(
            disk_size=disk_size,
            disk_type_id=disk_type_id,
            resource_preset_id=resource_preset_id,
        )

        return typing.cast(None, jsii.invoke(self, "putResources", [value]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resources")
    def resources(
        self,
    ) -> "MdbGreenplumClusterSegmentSubclusterResourcesOutputReference":
        return typing.cast("MdbGreenplumClusterSegmentSubclusterResourcesOutputReference", jsii.get(self, "resources"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcesInput")
    def resources_input(
        self,
    ) -> typing.Optional["MdbGreenplumClusterSegmentSubclusterResources"]:
        return typing.cast(typing.Optional["MdbGreenplumClusterSegmentSubclusterResources"], jsii.get(self, "resourcesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbGreenplumClusterSegmentSubcluster]:
        return typing.cast(typing.Optional[MdbGreenplumClusterSegmentSubcluster], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbGreenplumClusterSegmentSubcluster],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbGreenplumClusterSegmentSubclusterResources",
    jsii_struct_bases=[],
    name_mapping={
        "disk_size": "diskSize",
        "disk_type_id": "diskTypeId",
        "resource_preset_id": "resourcePresetId",
    },
)
class MdbGreenplumClusterSegmentSubclusterResources:
    def __init__(
        self,
        *,
        disk_size: jsii.Number,
        disk_type_id: builtins.str,
        resource_preset_id: builtins.str,
    ) -> None:
        '''
        :param disk_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#disk_size MdbGreenplumCluster#disk_size}.
        :param disk_type_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#disk_type_id MdbGreenplumCluster#disk_type_id}.
        :param resource_preset_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#resource_preset_id MdbGreenplumCluster#resource_preset_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "disk_size": disk_size,
            "disk_type_id": disk_type_id,
            "resource_preset_id": resource_preset_id,
        }

    @builtins.property
    def disk_size(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#disk_size MdbGreenplumCluster#disk_size}.'''
        result = self._values.get("disk_size")
        assert result is not None, "Required property 'disk_size' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def disk_type_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#disk_type_id MdbGreenplumCluster#disk_type_id}.'''
        result = self._values.get("disk_type_id")
        assert result is not None, "Required property 'disk_type_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def resource_preset_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#resource_preset_id MdbGreenplumCluster#resource_preset_id}.'''
        result = self._values.get("resource_preset_id")
        assert result is not None, "Required property 'resource_preset_id' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbGreenplumClusterSegmentSubclusterResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbGreenplumClusterSegmentSubclusterResourcesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbGreenplumClusterSegmentSubclusterResourcesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSizeInput")
    def disk_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "diskSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeIdInput")
    def disk_type_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "diskTypeIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetIdInput")
    def resource_preset_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourcePresetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSize")
    def disk_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "diskSize"))

    @disk_size.setter
    def disk_size(self, value: jsii.Number) -> None:
        jsii.set(self, "diskSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeId")
    def disk_type_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskTypeId"))

    @disk_type_id.setter
    def disk_type_id(self, value: builtins.str) -> None:
        jsii.set(self, "diskTypeId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetId")
    def resource_preset_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourcePresetId"))

    @resource_preset_id.setter
    def resource_preset_id(self, value: builtins.str) -> None:
        jsii.set(self, "resourcePresetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[MdbGreenplumClusterSegmentSubclusterResources]:
        return typing.cast(typing.Optional[MdbGreenplumClusterSegmentSubclusterResources], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbGreenplumClusterSegmentSubclusterResources],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbGreenplumClusterTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class MdbGreenplumClusterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#create MdbGreenplumCluster#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#delete MdbGreenplumCluster#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#update MdbGreenplumCluster#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#create MdbGreenplumCluster#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#delete MdbGreenplumCluster#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_greenplum_cluster#update MdbGreenplumCluster#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbGreenplumClusterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbGreenplumClusterTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbGreenplumClusterTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbGreenplumClusterTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbGreenplumClusterTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbGreenplumClusterTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbKafkaCluster(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbKafkaCluster",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster yandex_mdb_kafka_cluster}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        config: "MdbKafkaClusterConfigA",
        name: builtins.str,
        network_id: builtins.str,
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        description: typing.Optional[builtins.str] = None,
        environment: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        host_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        maintenance_window: typing.Optional["MdbKafkaClusterMaintenanceWindow"] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        subnet_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        timeouts: typing.Optional["MdbKafkaClusterTimeouts"] = None,
        topic: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbKafkaClusterTopic"]]] = None,
        user: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbKafkaClusterUser"]]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster yandex_mdb_kafka_cluster} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param config: config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#config MdbKafkaCluster#config}
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#name MdbKafkaCluster#name}.
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#network_id MdbKafkaCluster#network_id}.
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#deletion_protection MdbKafkaCluster#deletion_protection}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#description MdbKafkaCluster#description}.
        :param environment: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#environment MdbKafkaCluster#environment}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#folder_id MdbKafkaCluster#folder_id}.
        :param host_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#host_group_ids MdbKafkaCluster#host_group_ids}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#id MdbKafkaCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#labels MdbKafkaCluster#labels}.
        :param maintenance_window: maintenance_window block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#maintenance_window MdbKafkaCluster#maintenance_window}
        :param security_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#security_group_ids MdbKafkaCluster#security_group_ids}.
        :param subnet_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#subnet_ids MdbKafkaCluster#subnet_ids}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#timeouts MdbKafkaCluster#timeouts}
        :param topic: topic block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#topic MdbKafkaCluster#topic}
        :param user: user block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#user MdbKafkaCluster#user}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config_ = MdbKafkaClusterConfig(
            config=config,
            name=name,
            network_id=network_id,
            deletion_protection=deletion_protection,
            description=description,
            environment=environment,
            folder_id=folder_id,
            host_group_ids=host_group_ids,
            id=id,
            labels=labels,
            maintenance_window=maintenance_window,
            security_group_ids=security_group_ids,
            subnet_ids=subnet_ids,
            timeouts=timeouts,
            topic=topic,
            user=user,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config_])

    @jsii.member(jsii_name="putConfig")
    def put_config(
        self,
        *,
        kafka: "MdbKafkaClusterConfigKafka",
        version: builtins.str,
        zones: typing.Sequence[builtins.str],
        assign_public_ip: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        brokers_count: typing.Optional[jsii.Number] = None,
        schema_registry: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        unmanaged_topics: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        zookeeper: typing.Optional["MdbKafkaClusterConfigZookeeper"] = None,
    ) -> None:
        '''
        :param kafka: kafka block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#kafka MdbKafkaCluster#kafka}
        :param version: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#version MdbKafkaCluster#version}.
        :param zones: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#zones MdbKafkaCluster#zones}.
        :param assign_public_ip: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#assign_public_ip MdbKafkaCluster#assign_public_ip}.
        :param brokers_count: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#brokers_count MdbKafkaCluster#brokers_count}.
        :param schema_registry: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#schema_registry MdbKafkaCluster#schema_registry}.
        :param unmanaged_topics: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#unmanaged_topics MdbKafkaCluster#unmanaged_topics}.
        :param zookeeper: zookeeper block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#zookeeper MdbKafkaCluster#zookeeper}
        '''
        value = MdbKafkaClusterConfigA(
            kafka=kafka,
            version=version,
            zones=zones,
            assign_public_ip=assign_public_ip,
            brokers_count=brokers_count,
            schema_registry=schema_registry,
            unmanaged_topics=unmanaged_topics,
            zookeeper=zookeeper,
        )

        return typing.cast(None, jsii.invoke(self, "putConfig", [value]))

    @jsii.member(jsii_name="putMaintenanceWindow")
    def put_maintenance_window(
        self,
        *,
        type: builtins.str,
        day: typing.Optional[builtins.str] = None,
        hour: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#type MdbKafkaCluster#type}.
        :param day: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#day MdbKafkaCluster#day}.
        :param hour: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#hour MdbKafkaCluster#hour}.
        '''
        value = MdbKafkaClusterMaintenanceWindow(type=type, day=day, hour=hour)

        return typing.cast(None, jsii.invoke(self, "putMaintenanceWindow", [value]))

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#create MdbKafkaCluster#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#delete MdbKafkaCluster#delete}.
        :param read: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#read MdbKafkaCluster#read}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#update MdbKafkaCluster#update}.
        '''
        value = MdbKafkaClusterTimeouts(
            create=create, delete=delete, read=read, update=update
        )

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="putTopic")
    def put_topic(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["MdbKafkaClusterTopic"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putTopic", [value]))

    @jsii.member(jsii_name="putUser")
    def put_user(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["MdbKafkaClusterUser"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putUser", [value]))

    @jsii.member(jsii_name="resetDeletionProtection")
    def reset_deletion_protection(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDeletionProtection", []))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetEnvironment")
    def reset_environment(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEnvironment", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetHostGroupIds")
    def reset_host_group_ids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHostGroupIds", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetMaintenanceWindow")
    def reset_maintenance_window(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaintenanceWindow", []))

    @jsii.member(jsii_name="resetSecurityGroupIds")
    def reset_security_group_ids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityGroupIds", []))

    @jsii.member(jsii_name="resetSubnetIds")
    def reset_subnet_ids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSubnetIds", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="resetTopic")
    def reset_topic(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTopic", []))

    @jsii.member(jsii_name="resetUser")
    def reset_user(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUser", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="config")
    def config(self) -> "MdbKafkaClusterConfigAOutputReference":
        return typing.cast("MdbKafkaClusterConfigAOutputReference", jsii.get(self, "config"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="health")
    def health(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "health"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="host")
    def host(self) -> "MdbKafkaClusterHostList":
        return typing.cast("MdbKafkaClusterHostList", jsii.get(self, "host"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maintenanceWindow")
    def maintenance_window(self) -> "MdbKafkaClusterMaintenanceWindowOutputReference":
        return typing.cast("MdbKafkaClusterMaintenanceWindowOutputReference", jsii.get(self, "maintenanceWindow"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "MdbKafkaClusterTimeoutsOutputReference":
        return typing.cast("MdbKafkaClusterTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="topic")
    def topic(self) -> "MdbKafkaClusterTopicList":
        return typing.cast("MdbKafkaClusterTopicList", jsii.get(self, "topic"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="user")
    def user(self) -> "MdbKafkaClusterUserList":
        return typing.cast("MdbKafkaClusterUserList", jsii.get(self, "user"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="configInput")
    def config_input(self) -> typing.Optional["MdbKafkaClusterConfigA"]:
        return typing.cast(typing.Optional["MdbKafkaClusterConfigA"], jsii.get(self, "configInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtectionInput")
    def deletion_protection_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "deletionProtectionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="environmentInput")
    def environment_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "environmentInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostGroupIdsInput")
    def host_group_ids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "hostGroupIdsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maintenanceWindowInput")
    def maintenance_window_input(
        self,
    ) -> typing.Optional["MdbKafkaClusterMaintenanceWindow"]:
        return typing.cast(typing.Optional["MdbKafkaClusterMaintenanceWindow"], jsii.get(self, "maintenanceWindowInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkIdInput")
    def network_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "networkIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIdsInput")
    def security_group_ids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "securityGroupIdsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIdsInput")
    def subnet_ids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "subnetIdsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "MdbKafkaClusterTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "MdbKafkaClusterTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="topicInput")
    def topic_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbKafkaClusterTopic"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbKafkaClusterTopic"]]], jsii.get(self, "topicInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="userInput")
    def user_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbKafkaClusterUser"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbKafkaClusterUser"]]], jsii.get(self, "userInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtection")
    def deletion_protection(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "deletionProtection"))

    @deletion_protection.setter
    def deletion_protection(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "deletionProtection", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="environment")
    def environment(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "environment"))

    @environment.setter
    def environment(self, value: builtins.str) -> None:
        jsii.set(self, "environment", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostGroupIds")
    def host_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "hostGroupIds"))

    @host_group_ids.setter
    def host_group_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "hostGroupIds", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @network_id.setter
    def network_id(self, value: builtins.str) -> None:
        jsii.set(self, "networkId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "securityGroupIds"))

    @security_group_ids.setter
    def security_group_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "securityGroupIds", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "subnetIds"))

    @subnet_ids.setter
    def subnet_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "subnetIds", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbKafkaClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "config": "config",
        "name": "name",
        "network_id": "networkId",
        "deletion_protection": "deletionProtection",
        "description": "description",
        "environment": "environment",
        "folder_id": "folderId",
        "host_group_ids": "hostGroupIds",
        "id": "id",
        "labels": "labels",
        "maintenance_window": "maintenanceWindow",
        "security_group_ids": "securityGroupIds",
        "subnet_ids": "subnetIds",
        "timeouts": "timeouts",
        "topic": "topic",
        "user": "user",
    },
)
class MdbKafkaClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        config: "MdbKafkaClusterConfigA",
        name: builtins.str,
        network_id: builtins.str,
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        description: typing.Optional[builtins.str] = None,
        environment: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        host_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        maintenance_window: typing.Optional["MdbKafkaClusterMaintenanceWindow"] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        subnet_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        timeouts: typing.Optional["MdbKafkaClusterTimeouts"] = None,
        topic: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbKafkaClusterTopic"]]] = None,
        user: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbKafkaClusterUser"]]] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param config: config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#config MdbKafkaCluster#config}
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#name MdbKafkaCluster#name}.
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#network_id MdbKafkaCluster#network_id}.
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#deletion_protection MdbKafkaCluster#deletion_protection}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#description MdbKafkaCluster#description}.
        :param environment: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#environment MdbKafkaCluster#environment}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#folder_id MdbKafkaCluster#folder_id}.
        :param host_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#host_group_ids MdbKafkaCluster#host_group_ids}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#id MdbKafkaCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#labels MdbKafkaCluster#labels}.
        :param maintenance_window: maintenance_window block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#maintenance_window MdbKafkaCluster#maintenance_window}
        :param security_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#security_group_ids MdbKafkaCluster#security_group_ids}.
        :param subnet_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#subnet_ids MdbKafkaCluster#subnet_ids}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#timeouts MdbKafkaCluster#timeouts}
        :param topic: topic block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#topic MdbKafkaCluster#topic}
        :param user: user block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#user MdbKafkaCluster#user}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(config, dict):
            config = MdbKafkaClusterConfigA(**config)
        if isinstance(maintenance_window, dict):
            maintenance_window = MdbKafkaClusterMaintenanceWindow(**maintenance_window)
        if isinstance(timeouts, dict):
            timeouts = MdbKafkaClusterTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "config": config,
            "name": name,
            "network_id": network_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if deletion_protection is not None:
            self._values["deletion_protection"] = deletion_protection
        if description is not None:
            self._values["description"] = description
        if environment is not None:
            self._values["environment"] = environment
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if host_group_ids is not None:
            self._values["host_group_ids"] = host_group_ids
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if maintenance_window is not None:
            self._values["maintenance_window"] = maintenance_window
        if security_group_ids is not None:
            self._values["security_group_ids"] = security_group_ids
        if subnet_ids is not None:
            self._values["subnet_ids"] = subnet_ids
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if topic is not None:
            self._values["topic"] = topic
        if user is not None:
            self._values["user"] = user

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def config(self) -> "MdbKafkaClusterConfigA":
        '''config block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#config MdbKafkaCluster#config}
        '''
        result = self._values.get("config")
        assert result is not None, "Required property 'config' is missing"
        return typing.cast("MdbKafkaClusterConfigA", result)

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#name MdbKafkaCluster#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def network_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#network_id MdbKafkaCluster#network_id}.'''
        result = self._values.get("network_id")
        assert result is not None, "Required property 'network_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def deletion_protection(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#deletion_protection MdbKafkaCluster#deletion_protection}.'''
        result = self._values.get("deletion_protection")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#description MdbKafkaCluster#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def environment(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#environment MdbKafkaCluster#environment}.'''
        result = self._values.get("environment")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#folder_id MdbKafkaCluster#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def host_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#host_group_ids MdbKafkaCluster#host_group_ids}.'''
        result = self._values.get("host_group_ids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#id MdbKafkaCluster#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#labels MdbKafkaCluster#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def maintenance_window(self) -> typing.Optional["MdbKafkaClusterMaintenanceWindow"]:
        '''maintenance_window block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#maintenance_window MdbKafkaCluster#maintenance_window}
        '''
        result = self._values.get("maintenance_window")
        return typing.cast(typing.Optional["MdbKafkaClusterMaintenanceWindow"], result)

    @builtins.property
    def security_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#security_group_ids MdbKafkaCluster#security_group_ids}.'''
        result = self._values.get("security_group_ids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def subnet_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#subnet_ids MdbKafkaCluster#subnet_ids}.'''
        result = self._values.get("subnet_ids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["MdbKafkaClusterTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#timeouts MdbKafkaCluster#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["MdbKafkaClusterTimeouts"], result)

    @builtins.property
    def topic(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbKafkaClusterTopic"]]]:
        '''topic block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#topic MdbKafkaCluster#topic}
        '''
        result = self._values.get("topic")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbKafkaClusterTopic"]]], result)

    @builtins.property
    def user(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbKafkaClusterUser"]]]:
        '''user block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#user MdbKafkaCluster#user}
        '''
        result = self._values.get("user")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbKafkaClusterUser"]]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbKafkaClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbKafkaClusterConfigA",
    jsii_struct_bases=[],
    name_mapping={
        "kafka": "kafka",
        "version": "version",
        "zones": "zones",
        "assign_public_ip": "assignPublicIp",
        "brokers_count": "brokersCount",
        "schema_registry": "schemaRegistry",
        "unmanaged_topics": "unmanagedTopics",
        "zookeeper": "zookeeper",
    },
)
class MdbKafkaClusterConfigA:
    def __init__(
        self,
        *,
        kafka: "MdbKafkaClusterConfigKafka",
        version: builtins.str,
        zones: typing.Sequence[builtins.str],
        assign_public_ip: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        brokers_count: typing.Optional[jsii.Number] = None,
        schema_registry: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        unmanaged_topics: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        zookeeper: typing.Optional["MdbKafkaClusterConfigZookeeper"] = None,
    ) -> None:
        '''
        :param kafka: kafka block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#kafka MdbKafkaCluster#kafka}
        :param version: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#version MdbKafkaCluster#version}.
        :param zones: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#zones MdbKafkaCluster#zones}.
        :param assign_public_ip: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#assign_public_ip MdbKafkaCluster#assign_public_ip}.
        :param brokers_count: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#brokers_count MdbKafkaCluster#brokers_count}.
        :param schema_registry: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#schema_registry MdbKafkaCluster#schema_registry}.
        :param unmanaged_topics: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#unmanaged_topics MdbKafkaCluster#unmanaged_topics}.
        :param zookeeper: zookeeper block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#zookeeper MdbKafkaCluster#zookeeper}
        '''
        if isinstance(kafka, dict):
            kafka = MdbKafkaClusterConfigKafka(**kafka)
        if isinstance(zookeeper, dict):
            zookeeper = MdbKafkaClusterConfigZookeeper(**zookeeper)
        self._values: typing.Dict[str, typing.Any] = {
            "kafka": kafka,
            "version": version,
            "zones": zones,
        }
        if assign_public_ip is not None:
            self._values["assign_public_ip"] = assign_public_ip
        if brokers_count is not None:
            self._values["brokers_count"] = brokers_count
        if schema_registry is not None:
            self._values["schema_registry"] = schema_registry
        if unmanaged_topics is not None:
            self._values["unmanaged_topics"] = unmanaged_topics
        if zookeeper is not None:
            self._values["zookeeper"] = zookeeper

    @builtins.property
    def kafka(self) -> "MdbKafkaClusterConfigKafka":
        '''kafka block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#kafka MdbKafkaCluster#kafka}
        '''
        result = self._values.get("kafka")
        assert result is not None, "Required property 'kafka' is missing"
        return typing.cast("MdbKafkaClusterConfigKafka", result)

    @builtins.property
    def version(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#version MdbKafkaCluster#version}.'''
        result = self._values.get("version")
        assert result is not None, "Required property 'version' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def zones(self) -> typing.List[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#zones MdbKafkaCluster#zones}.'''
        result = self._values.get("zones")
        assert result is not None, "Required property 'zones' is missing"
        return typing.cast(typing.List[builtins.str], result)

    @builtins.property
    def assign_public_ip(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#assign_public_ip MdbKafkaCluster#assign_public_ip}.'''
        result = self._values.get("assign_public_ip")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def brokers_count(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#brokers_count MdbKafkaCluster#brokers_count}.'''
        result = self._values.get("brokers_count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def schema_registry(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#schema_registry MdbKafkaCluster#schema_registry}.'''
        result = self._values.get("schema_registry")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def unmanaged_topics(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#unmanaged_topics MdbKafkaCluster#unmanaged_topics}.'''
        result = self._values.get("unmanaged_topics")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def zookeeper(self) -> typing.Optional["MdbKafkaClusterConfigZookeeper"]:
        '''zookeeper block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#zookeeper MdbKafkaCluster#zookeeper}
        '''
        result = self._values.get("zookeeper")
        return typing.cast(typing.Optional["MdbKafkaClusterConfigZookeeper"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbKafkaClusterConfigA(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbKafkaClusterConfigAOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbKafkaClusterConfigAOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putKafka")
    def put_kafka(
        self,
        *,
        resources: "MdbKafkaClusterConfigKafkaResources",
        kafka_config: typing.Optional["MdbKafkaClusterConfigKafkaKafkaConfig"] = None,
    ) -> None:
        '''
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#resources MdbKafkaCluster#resources}
        :param kafka_config: kafka_config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#kafka_config MdbKafkaCluster#kafka_config}
        '''
        value = MdbKafkaClusterConfigKafka(
            resources=resources, kafka_config=kafka_config
        )

        return typing.cast(None, jsii.invoke(self, "putKafka", [value]))

    @jsii.member(jsii_name="putZookeeper")
    def put_zookeeper(
        self,
        *,
        resources: typing.Optional["MdbKafkaClusterConfigZookeeperResources"] = None,
    ) -> None:
        '''
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#resources MdbKafkaCluster#resources}
        '''
        value = MdbKafkaClusterConfigZookeeper(resources=resources)

        return typing.cast(None, jsii.invoke(self, "putZookeeper", [value]))

    @jsii.member(jsii_name="resetAssignPublicIp")
    def reset_assign_public_ip(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAssignPublicIp", []))

    @jsii.member(jsii_name="resetBrokersCount")
    def reset_brokers_count(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetBrokersCount", []))

    @jsii.member(jsii_name="resetSchemaRegistry")
    def reset_schema_registry(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSchemaRegistry", []))

    @jsii.member(jsii_name="resetUnmanagedTopics")
    def reset_unmanaged_topics(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUnmanagedTopics", []))

    @jsii.member(jsii_name="resetZookeeper")
    def reset_zookeeper(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetZookeeper", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="kafka")
    def kafka(self) -> "MdbKafkaClusterConfigKafkaOutputReference":
        return typing.cast("MdbKafkaClusterConfigKafkaOutputReference", jsii.get(self, "kafka"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zookeeper")
    def zookeeper(self) -> "MdbKafkaClusterConfigZookeeperOutputReference":
        return typing.cast("MdbKafkaClusterConfigZookeeperOutputReference", jsii.get(self, "zookeeper"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIpInput")
    def assign_public_ip_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "assignPublicIpInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="brokersCountInput")
    def brokers_count_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "brokersCountInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="kafkaInput")
    def kafka_input(self) -> typing.Optional["MdbKafkaClusterConfigKafka"]:
        return typing.cast(typing.Optional["MdbKafkaClusterConfigKafka"], jsii.get(self, "kafkaInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="schemaRegistryInput")
    def schema_registry_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "schemaRegistryInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="unmanagedTopicsInput")
    def unmanaged_topics_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "unmanagedTopicsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="versionInput")
    def version_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "versionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zonesInput")
    def zones_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "zonesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zookeeperInput")
    def zookeeper_input(self) -> typing.Optional["MdbKafkaClusterConfigZookeeper"]:
        return typing.cast(typing.Optional["MdbKafkaClusterConfigZookeeper"], jsii.get(self, "zookeeperInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIp")
    def assign_public_ip(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "assignPublicIp"))

    @assign_public_ip.setter
    def assign_public_ip(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "assignPublicIp", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="brokersCount")
    def brokers_count(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "brokersCount"))

    @brokers_count.setter
    def brokers_count(self, value: jsii.Number) -> None:
        jsii.set(self, "brokersCount", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="schemaRegistry")
    def schema_registry(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "schemaRegistry"))

    @schema_registry.setter
    def schema_registry(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "schemaRegistry", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="unmanagedTopics")
    def unmanaged_topics(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "unmanagedTopics"))

    @unmanaged_topics.setter
    def unmanaged_topics(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "unmanagedTopics", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "version"))

    @version.setter
    def version(self, value: builtins.str) -> None:
        jsii.set(self, "version", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zones")
    def zones(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "zones"))

    @zones.setter
    def zones(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "zones", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbKafkaClusterConfigA]:
        return typing.cast(typing.Optional[MdbKafkaClusterConfigA], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(self, value: typing.Optional[MdbKafkaClusterConfigA]) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbKafkaClusterConfigKafka",
    jsii_struct_bases=[],
    name_mapping={"resources": "resources", "kafka_config": "kafkaConfig"},
)
class MdbKafkaClusterConfigKafka:
    def __init__(
        self,
        *,
        resources: "MdbKafkaClusterConfigKafkaResources",
        kafka_config: typing.Optional["MdbKafkaClusterConfigKafkaKafkaConfig"] = None,
    ) -> None:
        '''
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#resources MdbKafkaCluster#resources}
        :param kafka_config: kafka_config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#kafka_config MdbKafkaCluster#kafka_config}
        '''
        if isinstance(resources, dict):
            resources = MdbKafkaClusterConfigKafkaResources(**resources)
        if isinstance(kafka_config, dict):
            kafka_config = MdbKafkaClusterConfigKafkaKafkaConfig(**kafka_config)
        self._values: typing.Dict[str, typing.Any] = {
            "resources": resources,
        }
        if kafka_config is not None:
            self._values["kafka_config"] = kafka_config

    @builtins.property
    def resources(self) -> "MdbKafkaClusterConfigKafkaResources":
        '''resources block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#resources MdbKafkaCluster#resources}
        '''
        result = self._values.get("resources")
        assert result is not None, "Required property 'resources' is missing"
        return typing.cast("MdbKafkaClusterConfigKafkaResources", result)

    @builtins.property
    def kafka_config(self) -> typing.Optional["MdbKafkaClusterConfigKafkaKafkaConfig"]:
        '''kafka_config block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#kafka_config MdbKafkaCluster#kafka_config}
        '''
        result = self._values.get("kafka_config")
        return typing.cast(typing.Optional["MdbKafkaClusterConfigKafkaKafkaConfig"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbKafkaClusterConfigKafka(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbKafkaClusterConfigKafkaKafkaConfig",
    jsii_struct_bases=[],
    name_mapping={
        "auto_create_topics_enable": "autoCreateTopicsEnable",
        "compression_type": "compressionType",
        "default_replication_factor": "defaultReplicationFactor",
        "log_flush_interval_messages": "logFlushIntervalMessages",
        "log_flush_interval_ms": "logFlushIntervalMs",
        "log_flush_scheduler_interval_ms": "logFlushSchedulerIntervalMs",
        "log_preallocate": "logPreallocate",
        "log_retention_bytes": "logRetentionBytes",
        "log_retention_hours": "logRetentionHours",
        "log_retention_minutes": "logRetentionMinutes",
        "log_retention_ms": "logRetentionMs",
        "log_segment_bytes": "logSegmentBytes",
        "num_partitions": "numPartitions",
        "socket_receive_buffer_bytes": "socketReceiveBufferBytes",
        "socket_send_buffer_bytes": "socketSendBufferBytes",
    },
)
class MdbKafkaClusterConfigKafkaKafkaConfig:
    def __init__(
        self,
        *,
        auto_create_topics_enable: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        compression_type: typing.Optional[builtins.str] = None,
        default_replication_factor: typing.Optional[builtins.str] = None,
        log_flush_interval_messages: typing.Optional[builtins.str] = None,
        log_flush_interval_ms: typing.Optional[builtins.str] = None,
        log_flush_scheduler_interval_ms: typing.Optional[builtins.str] = None,
        log_preallocate: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        log_retention_bytes: typing.Optional[builtins.str] = None,
        log_retention_hours: typing.Optional[builtins.str] = None,
        log_retention_minutes: typing.Optional[builtins.str] = None,
        log_retention_ms: typing.Optional[builtins.str] = None,
        log_segment_bytes: typing.Optional[builtins.str] = None,
        num_partitions: typing.Optional[builtins.str] = None,
        socket_receive_buffer_bytes: typing.Optional[builtins.str] = None,
        socket_send_buffer_bytes: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param auto_create_topics_enable: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#auto_create_topics_enable MdbKafkaCluster#auto_create_topics_enable}.
        :param compression_type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#compression_type MdbKafkaCluster#compression_type}.
        :param default_replication_factor: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#default_replication_factor MdbKafkaCluster#default_replication_factor}.
        :param log_flush_interval_messages: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#log_flush_interval_messages MdbKafkaCluster#log_flush_interval_messages}.
        :param log_flush_interval_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#log_flush_interval_ms MdbKafkaCluster#log_flush_interval_ms}.
        :param log_flush_scheduler_interval_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#log_flush_scheduler_interval_ms MdbKafkaCluster#log_flush_scheduler_interval_ms}.
        :param log_preallocate: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#log_preallocate MdbKafkaCluster#log_preallocate}.
        :param log_retention_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#log_retention_bytes MdbKafkaCluster#log_retention_bytes}.
        :param log_retention_hours: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#log_retention_hours MdbKafkaCluster#log_retention_hours}.
        :param log_retention_minutes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#log_retention_minutes MdbKafkaCluster#log_retention_minutes}.
        :param log_retention_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#log_retention_ms MdbKafkaCluster#log_retention_ms}.
        :param log_segment_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#log_segment_bytes MdbKafkaCluster#log_segment_bytes}.
        :param num_partitions: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#num_partitions MdbKafkaCluster#num_partitions}.
        :param socket_receive_buffer_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#socket_receive_buffer_bytes MdbKafkaCluster#socket_receive_buffer_bytes}.
        :param socket_send_buffer_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#socket_send_buffer_bytes MdbKafkaCluster#socket_send_buffer_bytes}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if auto_create_topics_enable is not None:
            self._values["auto_create_topics_enable"] = auto_create_topics_enable
        if compression_type is not None:
            self._values["compression_type"] = compression_type
        if default_replication_factor is not None:
            self._values["default_replication_factor"] = default_replication_factor
        if log_flush_interval_messages is not None:
            self._values["log_flush_interval_messages"] = log_flush_interval_messages
        if log_flush_interval_ms is not None:
            self._values["log_flush_interval_ms"] = log_flush_interval_ms
        if log_flush_scheduler_interval_ms is not None:
            self._values["log_flush_scheduler_interval_ms"] = log_flush_scheduler_interval_ms
        if log_preallocate is not None:
            self._values["log_preallocate"] = log_preallocate
        if log_retention_bytes is not None:
            self._values["log_retention_bytes"] = log_retention_bytes
        if log_retention_hours is not None:
            self._values["log_retention_hours"] = log_retention_hours
        if log_retention_minutes is not None:
            self._values["log_retention_minutes"] = log_retention_minutes
        if log_retention_ms is not None:
            self._values["log_retention_ms"] = log_retention_ms
        if log_segment_bytes is not None:
            self._values["log_segment_bytes"] = log_segment_bytes
        if num_partitions is not None:
            self._values["num_partitions"] = num_partitions
        if socket_receive_buffer_bytes is not None:
            self._values["socket_receive_buffer_bytes"] = socket_receive_buffer_bytes
        if socket_send_buffer_bytes is not None:
            self._values["socket_send_buffer_bytes"] = socket_send_buffer_bytes

    @builtins.property
    def auto_create_topics_enable(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#auto_create_topics_enable MdbKafkaCluster#auto_create_topics_enable}.'''
        result = self._values.get("auto_create_topics_enable")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def compression_type(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#compression_type MdbKafkaCluster#compression_type}.'''
        result = self._values.get("compression_type")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def default_replication_factor(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#default_replication_factor MdbKafkaCluster#default_replication_factor}.'''
        result = self._values.get("default_replication_factor")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def log_flush_interval_messages(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#log_flush_interval_messages MdbKafkaCluster#log_flush_interval_messages}.'''
        result = self._values.get("log_flush_interval_messages")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def log_flush_interval_ms(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#log_flush_interval_ms MdbKafkaCluster#log_flush_interval_ms}.'''
        result = self._values.get("log_flush_interval_ms")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def log_flush_scheduler_interval_ms(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#log_flush_scheduler_interval_ms MdbKafkaCluster#log_flush_scheduler_interval_ms}.'''
        result = self._values.get("log_flush_scheduler_interval_ms")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def log_preallocate(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#log_preallocate MdbKafkaCluster#log_preallocate}.'''
        result = self._values.get("log_preallocate")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def log_retention_bytes(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#log_retention_bytes MdbKafkaCluster#log_retention_bytes}.'''
        result = self._values.get("log_retention_bytes")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def log_retention_hours(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#log_retention_hours MdbKafkaCluster#log_retention_hours}.'''
        result = self._values.get("log_retention_hours")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def log_retention_minutes(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#log_retention_minutes MdbKafkaCluster#log_retention_minutes}.'''
        result = self._values.get("log_retention_minutes")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def log_retention_ms(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#log_retention_ms MdbKafkaCluster#log_retention_ms}.'''
        result = self._values.get("log_retention_ms")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def log_segment_bytes(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#log_segment_bytes MdbKafkaCluster#log_segment_bytes}.'''
        result = self._values.get("log_segment_bytes")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def num_partitions(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#num_partitions MdbKafkaCluster#num_partitions}.'''
        result = self._values.get("num_partitions")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def socket_receive_buffer_bytes(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#socket_receive_buffer_bytes MdbKafkaCluster#socket_receive_buffer_bytes}.'''
        result = self._values.get("socket_receive_buffer_bytes")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def socket_send_buffer_bytes(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#socket_send_buffer_bytes MdbKafkaCluster#socket_send_buffer_bytes}.'''
        result = self._values.get("socket_send_buffer_bytes")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbKafkaClusterConfigKafkaKafkaConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbKafkaClusterConfigKafkaKafkaConfigOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbKafkaClusterConfigKafkaKafkaConfigOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetAutoCreateTopicsEnable")
    def reset_auto_create_topics_enable(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAutoCreateTopicsEnable", []))

    @jsii.member(jsii_name="resetCompressionType")
    def reset_compression_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCompressionType", []))

    @jsii.member(jsii_name="resetDefaultReplicationFactor")
    def reset_default_replication_factor(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDefaultReplicationFactor", []))

    @jsii.member(jsii_name="resetLogFlushIntervalMessages")
    def reset_log_flush_interval_messages(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogFlushIntervalMessages", []))

    @jsii.member(jsii_name="resetLogFlushIntervalMs")
    def reset_log_flush_interval_ms(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogFlushIntervalMs", []))

    @jsii.member(jsii_name="resetLogFlushSchedulerIntervalMs")
    def reset_log_flush_scheduler_interval_ms(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogFlushSchedulerIntervalMs", []))

    @jsii.member(jsii_name="resetLogPreallocate")
    def reset_log_preallocate(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogPreallocate", []))

    @jsii.member(jsii_name="resetLogRetentionBytes")
    def reset_log_retention_bytes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogRetentionBytes", []))

    @jsii.member(jsii_name="resetLogRetentionHours")
    def reset_log_retention_hours(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogRetentionHours", []))

    @jsii.member(jsii_name="resetLogRetentionMinutes")
    def reset_log_retention_minutes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogRetentionMinutes", []))

    @jsii.member(jsii_name="resetLogRetentionMs")
    def reset_log_retention_ms(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogRetentionMs", []))

    @jsii.member(jsii_name="resetLogSegmentBytes")
    def reset_log_segment_bytes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogSegmentBytes", []))

    @jsii.member(jsii_name="resetNumPartitions")
    def reset_num_partitions(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNumPartitions", []))

    @jsii.member(jsii_name="resetSocketReceiveBufferBytes")
    def reset_socket_receive_buffer_bytes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSocketReceiveBufferBytes", []))

    @jsii.member(jsii_name="resetSocketSendBufferBytes")
    def reset_socket_send_buffer_bytes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSocketSendBufferBytes", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoCreateTopicsEnableInput")
    def auto_create_topics_enable_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "autoCreateTopicsEnableInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="compressionTypeInput")
    def compression_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "compressionTypeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="defaultReplicationFactorInput")
    def default_replication_factor_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "defaultReplicationFactorInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logFlushIntervalMessagesInput")
    def log_flush_interval_messages_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "logFlushIntervalMessagesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logFlushIntervalMsInput")
    def log_flush_interval_ms_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "logFlushIntervalMsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logFlushSchedulerIntervalMsInput")
    def log_flush_scheduler_interval_ms_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "logFlushSchedulerIntervalMsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logPreallocateInput")
    def log_preallocate_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "logPreallocateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logRetentionBytesInput")
    def log_retention_bytes_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "logRetentionBytesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logRetentionHoursInput")
    def log_retention_hours_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "logRetentionHoursInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logRetentionMinutesInput")
    def log_retention_minutes_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "logRetentionMinutesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logRetentionMsInput")
    def log_retention_ms_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "logRetentionMsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logSegmentBytesInput")
    def log_segment_bytes_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "logSegmentBytesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="numPartitionsInput")
    def num_partitions_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "numPartitionsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="socketReceiveBufferBytesInput")
    def socket_receive_buffer_bytes_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "socketReceiveBufferBytesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="socketSendBufferBytesInput")
    def socket_send_buffer_bytes_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "socketSendBufferBytesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoCreateTopicsEnable")
    def auto_create_topics_enable(
        self,
    ) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "autoCreateTopicsEnable"))

    @auto_create_topics_enable.setter
    def auto_create_topics_enable(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "autoCreateTopicsEnable", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="compressionType")
    def compression_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "compressionType"))

    @compression_type.setter
    def compression_type(self, value: builtins.str) -> None:
        jsii.set(self, "compressionType", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="defaultReplicationFactor")
    def default_replication_factor(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "defaultReplicationFactor"))

    @default_replication_factor.setter
    def default_replication_factor(self, value: builtins.str) -> None:
        jsii.set(self, "defaultReplicationFactor", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logFlushIntervalMessages")
    def log_flush_interval_messages(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "logFlushIntervalMessages"))

    @log_flush_interval_messages.setter
    def log_flush_interval_messages(self, value: builtins.str) -> None:
        jsii.set(self, "logFlushIntervalMessages", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logFlushIntervalMs")
    def log_flush_interval_ms(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "logFlushIntervalMs"))

    @log_flush_interval_ms.setter
    def log_flush_interval_ms(self, value: builtins.str) -> None:
        jsii.set(self, "logFlushIntervalMs", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logFlushSchedulerIntervalMs")
    def log_flush_scheduler_interval_ms(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "logFlushSchedulerIntervalMs"))

    @log_flush_scheduler_interval_ms.setter
    def log_flush_scheduler_interval_ms(self, value: builtins.str) -> None:
        jsii.set(self, "logFlushSchedulerIntervalMs", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logPreallocate")
    def log_preallocate(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "logPreallocate"))

    @log_preallocate.setter
    def log_preallocate(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "logPreallocate", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logRetentionBytes")
    def log_retention_bytes(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "logRetentionBytes"))

    @log_retention_bytes.setter
    def log_retention_bytes(self, value: builtins.str) -> None:
        jsii.set(self, "logRetentionBytes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logRetentionHours")
    def log_retention_hours(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "logRetentionHours"))

    @log_retention_hours.setter
    def log_retention_hours(self, value: builtins.str) -> None:
        jsii.set(self, "logRetentionHours", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logRetentionMinutes")
    def log_retention_minutes(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "logRetentionMinutes"))

    @log_retention_minutes.setter
    def log_retention_minutes(self, value: builtins.str) -> None:
        jsii.set(self, "logRetentionMinutes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logRetentionMs")
    def log_retention_ms(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "logRetentionMs"))

    @log_retention_ms.setter
    def log_retention_ms(self, value: builtins.str) -> None:
        jsii.set(self, "logRetentionMs", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logSegmentBytes")
    def log_segment_bytes(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "logSegmentBytes"))

    @log_segment_bytes.setter
    def log_segment_bytes(self, value: builtins.str) -> None:
        jsii.set(self, "logSegmentBytes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="numPartitions")
    def num_partitions(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "numPartitions"))

    @num_partitions.setter
    def num_partitions(self, value: builtins.str) -> None:
        jsii.set(self, "numPartitions", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="socketReceiveBufferBytes")
    def socket_receive_buffer_bytes(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "socketReceiveBufferBytes"))

    @socket_receive_buffer_bytes.setter
    def socket_receive_buffer_bytes(self, value: builtins.str) -> None:
        jsii.set(self, "socketReceiveBufferBytes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="socketSendBufferBytes")
    def socket_send_buffer_bytes(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "socketSendBufferBytes"))

    @socket_send_buffer_bytes.setter
    def socket_send_buffer_bytes(self, value: builtins.str) -> None:
        jsii.set(self, "socketSendBufferBytes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbKafkaClusterConfigKafkaKafkaConfig]:
        return typing.cast(typing.Optional[MdbKafkaClusterConfigKafkaKafkaConfig], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbKafkaClusterConfigKafkaKafkaConfig],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbKafkaClusterConfigKafkaOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbKafkaClusterConfigKafkaOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putKafkaConfig")
    def put_kafka_config(
        self,
        *,
        auto_create_topics_enable: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        compression_type: typing.Optional[builtins.str] = None,
        default_replication_factor: typing.Optional[builtins.str] = None,
        log_flush_interval_messages: typing.Optional[builtins.str] = None,
        log_flush_interval_ms: typing.Optional[builtins.str] = None,
        log_flush_scheduler_interval_ms: typing.Optional[builtins.str] = None,
        log_preallocate: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        log_retention_bytes: typing.Optional[builtins.str] = None,
        log_retention_hours: typing.Optional[builtins.str] = None,
        log_retention_minutes: typing.Optional[builtins.str] = None,
        log_retention_ms: typing.Optional[builtins.str] = None,
        log_segment_bytes: typing.Optional[builtins.str] = None,
        num_partitions: typing.Optional[builtins.str] = None,
        socket_receive_buffer_bytes: typing.Optional[builtins.str] = None,
        socket_send_buffer_bytes: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param auto_create_topics_enable: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#auto_create_topics_enable MdbKafkaCluster#auto_create_topics_enable}.
        :param compression_type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#compression_type MdbKafkaCluster#compression_type}.
        :param default_replication_factor: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#default_replication_factor MdbKafkaCluster#default_replication_factor}.
        :param log_flush_interval_messages: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#log_flush_interval_messages MdbKafkaCluster#log_flush_interval_messages}.
        :param log_flush_interval_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#log_flush_interval_ms MdbKafkaCluster#log_flush_interval_ms}.
        :param log_flush_scheduler_interval_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#log_flush_scheduler_interval_ms MdbKafkaCluster#log_flush_scheduler_interval_ms}.
        :param log_preallocate: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#log_preallocate MdbKafkaCluster#log_preallocate}.
        :param log_retention_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#log_retention_bytes MdbKafkaCluster#log_retention_bytes}.
        :param log_retention_hours: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#log_retention_hours MdbKafkaCluster#log_retention_hours}.
        :param log_retention_minutes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#log_retention_minutes MdbKafkaCluster#log_retention_minutes}.
        :param log_retention_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#log_retention_ms MdbKafkaCluster#log_retention_ms}.
        :param log_segment_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#log_segment_bytes MdbKafkaCluster#log_segment_bytes}.
        :param num_partitions: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#num_partitions MdbKafkaCluster#num_partitions}.
        :param socket_receive_buffer_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#socket_receive_buffer_bytes MdbKafkaCluster#socket_receive_buffer_bytes}.
        :param socket_send_buffer_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#socket_send_buffer_bytes MdbKafkaCluster#socket_send_buffer_bytes}.
        '''
        value = MdbKafkaClusterConfigKafkaKafkaConfig(
            auto_create_topics_enable=auto_create_topics_enable,
            compression_type=compression_type,
            default_replication_factor=default_replication_factor,
            log_flush_interval_messages=log_flush_interval_messages,
            log_flush_interval_ms=log_flush_interval_ms,
            log_flush_scheduler_interval_ms=log_flush_scheduler_interval_ms,
            log_preallocate=log_preallocate,
            log_retention_bytes=log_retention_bytes,
            log_retention_hours=log_retention_hours,
            log_retention_minutes=log_retention_minutes,
            log_retention_ms=log_retention_ms,
            log_segment_bytes=log_segment_bytes,
            num_partitions=num_partitions,
            socket_receive_buffer_bytes=socket_receive_buffer_bytes,
            socket_send_buffer_bytes=socket_send_buffer_bytes,
        )

        return typing.cast(None, jsii.invoke(self, "putKafkaConfig", [value]))

    @jsii.member(jsii_name="putResources")
    def put_resources(
        self,
        *,
        disk_size: jsii.Number,
        disk_type_id: builtins.str,
        resource_preset_id: builtins.str,
    ) -> None:
        '''
        :param disk_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#disk_size MdbKafkaCluster#disk_size}.
        :param disk_type_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#disk_type_id MdbKafkaCluster#disk_type_id}.
        :param resource_preset_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#resource_preset_id MdbKafkaCluster#resource_preset_id}.
        '''
        value = MdbKafkaClusterConfigKafkaResources(
            disk_size=disk_size,
            disk_type_id=disk_type_id,
            resource_preset_id=resource_preset_id,
        )

        return typing.cast(None, jsii.invoke(self, "putResources", [value]))

    @jsii.member(jsii_name="resetKafkaConfig")
    def reset_kafka_config(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetKafkaConfig", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="kafkaConfig")
    def kafka_config(self) -> MdbKafkaClusterConfigKafkaKafkaConfigOutputReference:
        return typing.cast(MdbKafkaClusterConfigKafkaKafkaConfigOutputReference, jsii.get(self, "kafkaConfig"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resources")
    def resources(self) -> "MdbKafkaClusterConfigKafkaResourcesOutputReference":
        return typing.cast("MdbKafkaClusterConfigKafkaResourcesOutputReference", jsii.get(self, "resources"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="kafkaConfigInput")
    def kafka_config_input(
        self,
    ) -> typing.Optional[MdbKafkaClusterConfigKafkaKafkaConfig]:
        return typing.cast(typing.Optional[MdbKafkaClusterConfigKafkaKafkaConfig], jsii.get(self, "kafkaConfigInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcesInput")
    def resources_input(self) -> typing.Optional["MdbKafkaClusterConfigKafkaResources"]:
        return typing.cast(typing.Optional["MdbKafkaClusterConfigKafkaResources"], jsii.get(self, "resourcesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbKafkaClusterConfigKafka]:
        return typing.cast(typing.Optional[MdbKafkaClusterConfigKafka], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbKafkaClusterConfigKafka],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbKafkaClusterConfigKafkaResources",
    jsii_struct_bases=[],
    name_mapping={
        "disk_size": "diskSize",
        "disk_type_id": "diskTypeId",
        "resource_preset_id": "resourcePresetId",
    },
)
class MdbKafkaClusterConfigKafkaResources:
    def __init__(
        self,
        *,
        disk_size: jsii.Number,
        disk_type_id: builtins.str,
        resource_preset_id: builtins.str,
    ) -> None:
        '''
        :param disk_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#disk_size MdbKafkaCluster#disk_size}.
        :param disk_type_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#disk_type_id MdbKafkaCluster#disk_type_id}.
        :param resource_preset_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#resource_preset_id MdbKafkaCluster#resource_preset_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "disk_size": disk_size,
            "disk_type_id": disk_type_id,
            "resource_preset_id": resource_preset_id,
        }

    @builtins.property
    def disk_size(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#disk_size MdbKafkaCluster#disk_size}.'''
        result = self._values.get("disk_size")
        assert result is not None, "Required property 'disk_size' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def disk_type_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#disk_type_id MdbKafkaCluster#disk_type_id}.'''
        result = self._values.get("disk_type_id")
        assert result is not None, "Required property 'disk_type_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def resource_preset_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#resource_preset_id MdbKafkaCluster#resource_preset_id}.'''
        result = self._values.get("resource_preset_id")
        assert result is not None, "Required property 'resource_preset_id' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbKafkaClusterConfigKafkaResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbKafkaClusterConfigKafkaResourcesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbKafkaClusterConfigKafkaResourcesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSizeInput")
    def disk_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "diskSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeIdInput")
    def disk_type_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "diskTypeIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetIdInput")
    def resource_preset_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourcePresetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSize")
    def disk_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "diskSize"))

    @disk_size.setter
    def disk_size(self, value: jsii.Number) -> None:
        jsii.set(self, "diskSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeId")
    def disk_type_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskTypeId"))

    @disk_type_id.setter
    def disk_type_id(self, value: builtins.str) -> None:
        jsii.set(self, "diskTypeId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetId")
    def resource_preset_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourcePresetId"))

    @resource_preset_id.setter
    def resource_preset_id(self, value: builtins.str) -> None:
        jsii.set(self, "resourcePresetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbKafkaClusterConfigKafkaResources]:
        return typing.cast(typing.Optional[MdbKafkaClusterConfigKafkaResources], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbKafkaClusterConfigKafkaResources],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbKafkaClusterConfigZookeeper",
    jsii_struct_bases=[],
    name_mapping={"resources": "resources"},
)
class MdbKafkaClusterConfigZookeeper:
    def __init__(
        self,
        *,
        resources: typing.Optional["MdbKafkaClusterConfigZookeeperResources"] = None,
    ) -> None:
        '''
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#resources MdbKafkaCluster#resources}
        '''
        if isinstance(resources, dict):
            resources = MdbKafkaClusterConfigZookeeperResources(**resources)
        self._values: typing.Dict[str, typing.Any] = {}
        if resources is not None:
            self._values["resources"] = resources

    @builtins.property
    def resources(self) -> typing.Optional["MdbKafkaClusterConfigZookeeperResources"]:
        '''resources block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#resources MdbKafkaCluster#resources}
        '''
        result = self._values.get("resources")
        return typing.cast(typing.Optional["MdbKafkaClusterConfigZookeeperResources"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbKafkaClusterConfigZookeeper(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbKafkaClusterConfigZookeeperOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbKafkaClusterConfigZookeeperOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putResources")
    def put_resources(
        self,
        *,
        disk_size: typing.Optional[jsii.Number] = None,
        disk_type_id: typing.Optional[builtins.str] = None,
        resource_preset_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param disk_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#disk_size MdbKafkaCluster#disk_size}.
        :param disk_type_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#disk_type_id MdbKafkaCluster#disk_type_id}.
        :param resource_preset_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#resource_preset_id MdbKafkaCluster#resource_preset_id}.
        '''
        value = MdbKafkaClusterConfigZookeeperResources(
            disk_size=disk_size,
            disk_type_id=disk_type_id,
            resource_preset_id=resource_preset_id,
        )

        return typing.cast(None, jsii.invoke(self, "putResources", [value]))

    @jsii.member(jsii_name="resetResources")
    def reset_resources(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetResources", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resources")
    def resources(self) -> "MdbKafkaClusterConfigZookeeperResourcesOutputReference":
        return typing.cast("MdbKafkaClusterConfigZookeeperResourcesOutputReference", jsii.get(self, "resources"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcesInput")
    def resources_input(
        self,
    ) -> typing.Optional["MdbKafkaClusterConfigZookeeperResources"]:
        return typing.cast(typing.Optional["MdbKafkaClusterConfigZookeeperResources"], jsii.get(self, "resourcesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbKafkaClusterConfigZookeeper]:
        return typing.cast(typing.Optional[MdbKafkaClusterConfigZookeeper], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbKafkaClusterConfigZookeeper],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbKafkaClusterConfigZookeeperResources",
    jsii_struct_bases=[],
    name_mapping={
        "disk_size": "diskSize",
        "disk_type_id": "diskTypeId",
        "resource_preset_id": "resourcePresetId",
    },
)
class MdbKafkaClusterConfigZookeeperResources:
    def __init__(
        self,
        *,
        disk_size: typing.Optional[jsii.Number] = None,
        disk_type_id: typing.Optional[builtins.str] = None,
        resource_preset_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param disk_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#disk_size MdbKafkaCluster#disk_size}.
        :param disk_type_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#disk_type_id MdbKafkaCluster#disk_type_id}.
        :param resource_preset_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#resource_preset_id MdbKafkaCluster#resource_preset_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if disk_size is not None:
            self._values["disk_size"] = disk_size
        if disk_type_id is not None:
            self._values["disk_type_id"] = disk_type_id
        if resource_preset_id is not None:
            self._values["resource_preset_id"] = resource_preset_id

    @builtins.property
    def disk_size(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#disk_size MdbKafkaCluster#disk_size}.'''
        result = self._values.get("disk_size")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def disk_type_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#disk_type_id MdbKafkaCluster#disk_type_id}.'''
        result = self._values.get("disk_type_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def resource_preset_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#resource_preset_id MdbKafkaCluster#resource_preset_id}.'''
        result = self._values.get("resource_preset_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbKafkaClusterConfigZookeeperResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbKafkaClusterConfigZookeeperResourcesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbKafkaClusterConfigZookeeperResourcesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetDiskSize")
    def reset_disk_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDiskSize", []))

    @jsii.member(jsii_name="resetDiskTypeId")
    def reset_disk_type_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDiskTypeId", []))

    @jsii.member(jsii_name="resetResourcePresetId")
    def reset_resource_preset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetResourcePresetId", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSizeInput")
    def disk_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "diskSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeIdInput")
    def disk_type_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "diskTypeIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetIdInput")
    def resource_preset_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourcePresetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSize")
    def disk_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "diskSize"))

    @disk_size.setter
    def disk_size(self, value: jsii.Number) -> None:
        jsii.set(self, "diskSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeId")
    def disk_type_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskTypeId"))

    @disk_type_id.setter
    def disk_type_id(self, value: builtins.str) -> None:
        jsii.set(self, "diskTypeId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetId")
    def resource_preset_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourcePresetId"))

    @resource_preset_id.setter
    def resource_preset_id(self, value: builtins.str) -> None:
        jsii.set(self, "resourcePresetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[MdbKafkaClusterConfigZookeeperResources]:
        return typing.cast(typing.Optional[MdbKafkaClusterConfigZookeeperResources], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbKafkaClusterConfigZookeeperResources],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbKafkaClusterHost",
    jsii_struct_bases=[],
    name_mapping={},
)
class MdbKafkaClusterHost:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbKafkaClusterHost(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbKafkaClusterHostList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbKafkaClusterHostList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "MdbKafkaClusterHostOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbKafkaClusterHostOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)


class MdbKafkaClusterHostOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbKafkaClusterHostOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIp")
    def assign_public_ip(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "assignPublicIp"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="health")
    def health(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "health"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="role")
    def role(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "role"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneId")
    def zone_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zoneId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbKafkaClusterHost]:
        return typing.cast(typing.Optional[MdbKafkaClusterHost], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(self, value: typing.Optional[MdbKafkaClusterHost]) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbKafkaClusterMaintenanceWindow",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "day": "day", "hour": "hour"},
)
class MdbKafkaClusterMaintenanceWindow:
    def __init__(
        self,
        *,
        type: builtins.str,
        day: typing.Optional[builtins.str] = None,
        hour: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#type MdbKafkaCluster#type}.
        :param day: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#day MdbKafkaCluster#day}.
        :param hour: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#hour MdbKafkaCluster#hour}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }
        if day is not None:
            self._values["day"] = day
        if hour is not None:
            self._values["hour"] = hour

    @builtins.property
    def type(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#type MdbKafkaCluster#type}.'''
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def day(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#day MdbKafkaCluster#day}.'''
        result = self._values.get("day")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def hour(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#hour MdbKafkaCluster#hour}.'''
        result = self._values.get("hour")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbKafkaClusterMaintenanceWindow(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbKafkaClusterMaintenanceWindowOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbKafkaClusterMaintenanceWindowOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetDay")
    def reset_day(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDay", []))

    @jsii.member(jsii_name="resetHour")
    def reset_hour(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHour", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dayInput")
    def day_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dayInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hourInput")
    def hour_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "hourInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="typeInput")
    def type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "typeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="day")
    def day(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "day"))

    @day.setter
    def day(self, value: builtins.str) -> None:
        jsii.set(self, "day", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hour")
    def hour(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "hour"))

    @hour.setter
    def hour(self, value: jsii.Number) -> None:
        jsii.set(self, "hour", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @type.setter
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbKafkaClusterMaintenanceWindow]:
        return typing.cast(typing.Optional[MdbKafkaClusterMaintenanceWindow], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbKafkaClusterMaintenanceWindow],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbKafkaClusterTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class MdbKafkaClusterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#create MdbKafkaCluster#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#delete MdbKafkaCluster#delete}.
        :param read: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#read MdbKafkaCluster#read}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#update MdbKafkaCluster#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#create MdbKafkaCluster#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#delete MdbKafkaCluster#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#read MdbKafkaCluster#read}.'''
        result = self._values.get("read")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#update MdbKafkaCluster#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbKafkaClusterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbKafkaClusterTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbKafkaClusterTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetRead")
    def reset_read(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRead", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="readInput")
    def read_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "readInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="read")
    def read(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "read"))

    @read.setter
    def read(self, value: builtins.str) -> None:
        jsii.set(self, "read", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbKafkaClusterTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbKafkaClusterTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbKafkaClusterTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbKafkaClusterTopic",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "partitions": "partitions",
        "replication_factor": "replicationFactor",
        "topic_config": "topicConfig",
    },
)
class MdbKafkaClusterTopic:
    def __init__(
        self,
        *,
        name: builtins.str,
        partitions: jsii.Number,
        replication_factor: jsii.Number,
        topic_config: typing.Optional["MdbKafkaClusterTopicTopicConfig"] = None,
    ) -> None:
        '''
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#name MdbKafkaCluster#name}.
        :param partitions: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#partitions MdbKafkaCluster#partitions}.
        :param replication_factor: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#replication_factor MdbKafkaCluster#replication_factor}.
        :param topic_config: topic_config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#topic_config MdbKafkaCluster#topic_config}
        '''
        if isinstance(topic_config, dict):
            topic_config = MdbKafkaClusterTopicTopicConfig(**topic_config)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "partitions": partitions,
            "replication_factor": replication_factor,
        }
        if topic_config is not None:
            self._values["topic_config"] = topic_config

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#name MdbKafkaCluster#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def partitions(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#partitions MdbKafkaCluster#partitions}.'''
        result = self._values.get("partitions")
        assert result is not None, "Required property 'partitions' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def replication_factor(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#replication_factor MdbKafkaCluster#replication_factor}.'''
        result = self._values.get("replication_factor")
        assert result is not None, "Required property 'replication_factor' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def topic_config(self) -> typing.Optional["MdbKafkaClusterTopicTopicConfig"]:
        '''topic_config block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#topic_config MdbKafkaCluster#topic_config}
        '''
        result = self._values.get("topic_config")
        return typing.cast(typing.Optional["MdbKafkaClusterTopicTopicConfig"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbKafkaClusterTopic(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbKafkaClusterTopicList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbKafkaClusterTopicList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "MdbKafkaClusterTopicOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbKafkaClusterTopicOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbKafkaClusterTopic]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbKafkaClusterTopic]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbKafkaClusterTopic]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbKafkaClusterTopicOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbKafkaClusterTopicOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putTopicConfig")
    def put_topic_config(
        self,
        *,
        cleanup_policy: typing.Optional[builtins.str] = None,
        compression_type: typing.Optional[builtins.str] = None,
        delete_retention_ms: typing.Optional[builtins.str] = None,
        file_delete_delay_ms: typing.Optional[builtins.str] = None,
        flush_messages: typing.Optional[builtins.str] = None,
        flush_ms: typing.Optional[builtins.str] = None,
        max_message_bytes: typing.Optional[builtins.str] = None,
        min_compaction_lag_ms: typing.Optional[builtins.str] = None,
        min_insync_replicas: typing.Optional[builtins.str] = None,
        preallocate: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        retention_bytes: typing.Optional[builtins.str] = None,
        retention_ms: typing.Optional[builtins.str] = None,
        segment_bytes: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param cleanup_policy: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#cleanup_policy MdbKafkaCluster#cleanup_policy}.
        :param compression_type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#compression_type MdbKafkaCluster#compression_type}.
        :param delete_retention_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#delete_retention_ms MdbKafkaCluster#delete_retention_ms}.
        :param file_delete_delay_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#file_delete_delay_ms MdbKafkaCluster#file_delete_delay_ms}.
        :param flush_messages: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#flush_messages MdbKafkaCluster#flush_messages}.
        :param flush_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#flush_ms MdbKafkaCluster#flush_ms}.
        :param max_message_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#max_message_bytes MdbKafkaCluster#max_message_bytes}.
        :param min_compaction_lag_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#min_compaction_lag_ms MdbKafkaCluster#min_compaction_lag_ms}.
        :param min_insync_replicas: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#min_insync_replicas MdbKafkaCluster#min_insync_replicas}.
        :param preallocate: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#preallocate MdbKafkaCluster#preallocate}.
        :param retention_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#retention_bytes MdbKafkaCluster#retention_bytes}.
        :param retention_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#retention_ms MdbKafkaCluster#retention_ms}.
        :param segment_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#segment_bytes MdbKafkaCluster#segment_bytes}.
        '''
        value = MdbKafkaClusterTopicTopicConfig(
            cleanup_policy=cleanup_policy,
            compression_type=compression_type,
            delete_retention_ms=delete_retention_ms,
            file_delete_delay_ms=file_delete_delay_ms,
            flush_messages=flush_messages,
            flush_ms=flush_ms,
            max_message_bytes=max_message_bytes,
            min_compaction_lag_ms=min_compaction_lag_ms,
            min_insync_replicas=min_insync_replicas,
            preallocate=preallocate,
            retention_bytes=retention_bytes,
            retention_ms=retention_ms,
            segment_bytes=segment_bytes,
        )

        return typing.cast(None, jsii.invoke(self, "putTopicConfig", [value]))

    @jsii.member(jsii_name="resetTopicConfig")
    def reset_topic_config(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTopicConfig", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="topicConfig")
    def topic_config(self) -> "MdbKafkaClusterTopicTopicConfigOutputReference":
        return typing.cast("MdbKafkaClusterTopicTopicConfigOutputReference", jsii.get(self, "topicConfig"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="partitionsInput")
    def partitions_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "partitionsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replicationFactorInput")
    def replication_factor_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "replicationFactorInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="topicConfigInput")
    def topic_config_input(self) -> typing.Optional["MdbKafkaClusterTopicTopicConfig"]:
        return typing.cast(typing.Optional["MdbKafkaClusterTopicTopicConfig"], jsii.get(self, "topicConfigInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="partitions")
    def partitions(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "partitions"))

    @partitions.setter
    def partitions(self, value: jsii.Number) -> None:
        jsii.set(self, "partitions", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replicationFactor")
    def replication_factor(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "replicationFactor"))

    @replication_factor.setter
    def replication_factor(self, value: jsii.Number) -> None:
        jsii.set(self, "replicationFactor", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbKafkaClusterTopic]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbKafkaClusterTopic]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbKafkaClusterTopic]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbKafkaClusterTopicTopicConfig",
    jsii_struct_bases=[],
    name_mapping={
        "cleanup_policy": "cleanupPolicy",
        "compression_type": "compressionType",
        "delete_retention_ms": "deleteRetentionMs",
        "file_delete_delay_ms": "fileDeleteDelayMs",
        "flush_messages": "flushMessages",
        "flush_ms": "flushMs",
        "max_message_bytes": "maxMessageBytes",
        "min_compaction_lag_ms": "minCompactionLagMs",
        "min_insync_replicas": "minInsyncReplicas",
        "preallocate": "preallocate",
        "retention_bytes": "retentionBytes",
        "retention_ms": "retentionMs",
        "segment_bytes": "segmentBytes",
    },
)
class MdbKafkaClusterTopicTopicConfig:
    def __init__(
        self,
        *,
        cleanup_policy: typing.Optional[builtins.str] = None,
        compression_type: typing.Optional[builtins.str] = None,
        delete_retention_ms: typing.Optional[builtins.str] = None,
        file_delete_delay_ms: typing.Optional[builtins.str] = None,
        flush_messages: typing.Optional[builtins.str] = None,
        flush_ms: typing.Optional[builtins.str] = None,
        max_message_bytes: typing.Optional[builtins.str] = None,
        min_compaction_lag_ms: typing.Optional[builtins.str] = None,
        min_insync_replicas: typing.Optional[builtins.str] = None,
        preallocate: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        retention_bytes: typing.Optional[builtins.str] = None,
        retention_ms: typing.Optional[builtins.str] = None,
        segment_bytes: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param cleanup_policy: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#cleanup_policy MdbKafkaCluster#cleanup_policy}.
        :param compression_type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#compression_type MdbKafkaCluster#compression_type}.
        :param delete_retention_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#delete_retention_ms MdbKafkaCluster#delete_retention_ms}.
        :param file_delete_delay_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#file_delete_delay_ms MdbKafkaCluster#file_delete_delay_ms}.
        :param flush_messages: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#flush_messages MdbKafkaCluster#flush_messages}.
        :param flush_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#flush_ms MdbKafkaCluster#flush_ms}.
        :param max_message_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#max_message_bytes MdbKafkaCluster#max_message_bytes}.
        :param min_compaction_lag_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#min_compaction_lag_ms MdbKafkaCluster#min_compaction_lag_ms}.
        :param min_insync_replicas: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#min_insync_replicas MdbKafkaCluster#min_insync_replicas}.
        :param preallocate: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#preallocate MdbKafkaCluster#preallocate}.
        :param retention_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#retention_bytes MdbKafkaCluster#retention_bytes}.
        :param retention_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#retention_ms MdbKafkaCluster#retention_ms}.
        :param segment_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#segment_bytes MdbKafkaCluster#segment_bytes}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if cleanup_policy is not None:
            self._values["cleanup_policy"] = cleanup_policy
        if compression_type is not None:
            self._values["compression_type"] = compression_type
        if delete_retention_ms is not None:
            self._values["delete_retention_ms"] = delete_retention_ms
        if file_delete_delay_ms is not None:
            self._values["file_delete_delay_ms"] = file_delete_delay_ms
        if flush_messages is not None:
            self._values["flush_messages"] = flush_messages
        if flush_ms is not None:
            self._values["flush_ms"] = flush_ms
        if max_message_bytes is not None:
            self._values["max_message_bytes"] = max_message_bytes
        if min_compaction_lag_ms is not None:
            self._values["min_compaction_lag_ms"] = min_compaction_lag_ms
        if min_insync_replicas is not None:
            self._values["min_insync_replicas"] = min_insync_replicas
        if preallocate is not None:
            self._values["preallocate"] = preallocate
        if retention_bytes is not None:
            self._values["retention_bytes"] = retention_bytes
        if retention_ms is not None:
            self._values["retention_ms"] = retention_ms
        if segment_bytes is not None:
            self._values["segment_bytes"] = segment_bytes

    @builtins.property
    def cleanup_policy(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#cleanup_policy MdbKafkaCluster#cleanup_policy}.'''
        result = self._values.get("cleanup_policy")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def compression_type(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#compression_type MdbKafkaCluster#compression_type}.'''
        result = self._values.get("compression_type")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete_retention_ms(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#delete_retention_ms MdbKafkaCluster#delete_retention_ms}.'''
        result = self._values.get("delete_retention_ms")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def file_delete_delay_ms(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#file_delete_delay_ms MdbKafkaCluster#file_delete_delay_ms}.'''
        result = self._values.get("file_delete_delay_ms")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def flush_messages(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#flush_messages MdbKafkaCluster#flush_messages}.'''
        result = self._values.get("flush_messages")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def flush_ms(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#flush_ms MdbKafkaCluster#flush_ms}.'''
        result = self._values.get("flush_ms")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def max_message_bytes(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#max_message_bytes MdbKafkaCluster#max_message_bytes}.'''
        result = self._values.get("max_message_bytes")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def min_compaction_lag_ms(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#min_compaction_lag_ms MdbKafkaCluster#min_compaction_lag_ms}.'''
        result = self._values.get("min_compaction_lag_ms")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def min_insync_replicas(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#min_insync_replicas MdbKafkaCluster#min_insync_replicas}.'''
        result = self._values.get("min_insync_replicas")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def preallocate(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#preallocate MdbKafkaCluster#preallocate}.'''
        result = self._values.get("preallocate")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def retention_bytes(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#retention_bytes MdbKafkaCluster#retention_bytes}.'''
        result = self._values.get("retention_bytes")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def retention_ms(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#retention_ms MdbKafkaCluster#retention_ms}.'''
        result = self._values.get("retention_ms")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def segment_bytes(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#segment_bytes MdbKafkaCluster#segment_bytes}.'''
        result = self._values.get("segment_bytes")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbKafkaClusterTopicTopicConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbKafkaClusterTopicTopicConfigOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbKafkaClusterTopicTopicConfigOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCleanupPolicy")
    def reset_cleanup_policy(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCleanupPolicy", []))

    @jsii.member(jsii_name="resetCompressionType")
    def reset_compression_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCompressionType", []))

    @jsii.member(jsii_name="resetDeleteRetentionMs")
    def reset_delete_retention_ms(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDeleteRetentionMs", []))

    @jsii.member(jsii_name="resetFileDeleteDelayMs")
    def reset_file_delete_delay_ms(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFileDeleteDelayMs", []))

    @jsii.member(jsii_name="resetFlushMessages")
    def reset_flush_messages(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFlushMessages", []))

    @jsii.member(jsii_name="resetFlushMs")
    def reset_flush_ms(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFlushMs", []))

    @jsii.member(jsii_name="resetMaxMessageBytes")
    def reset_max_message_bytes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxMessageBytes", []))

    @jsii.member(jsii_name="resetMinCompactionLagMs")
    def reset_min_compaction_lag_ms(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMinCompactionLagMs", []))

    @jsii.member(jsii_name="resetMinInsyncReplicas")
    def reset_min_insync_replicas(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMinInsyncReplicas", []))

    @jsii.member(jsii_name="resetPreallocate")
    def reset_preallocate(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPreallocate", []))

    @jsii.member(jsii_name="resetRetentionBytes")
    def reset_retention_bytes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRetentionBytes", []))

    @jsii.member(jsii_name="resetRetentionMs")
    def reset_retention_ms(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRetentionMs", []))

    @jsii.member(jsii_name="resetSegmentBytes")
    def reset_segment_bytes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSegmentBytes", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cleanupPolicyInput")
    def cleanup_policy_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "cleanupPolicyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="compressionTypeInput")
    def compression_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "compressionTypeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteRetentionMsInput")
    def delete_retention_ms_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteRetentionMsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fileDeleteDelayMsInput")
    def file_delete_delay_ms_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "fileDeleteDelayMsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="flushMessagesInput")
    def flush_messages_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "flushMessagesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="flushMsInput")
    def flush_ms_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "flushMsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxMessageBytesInput")
    def max_message_bytes_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "maxMessageBytesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minCompactionLagMsInput")
    def min_compaction_lag_ms_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "minCompactionLagMsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minInsyncReplicasInput")
    def min_insync_replicas_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "minInsyncReplicasInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="preallocateInput")
    def preallocate_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "preallocateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="retentionBytesInput")
    def retention_bytes_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "retentionBytesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="retentionMsInput")
    def retention_ms_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "retentionMsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="segmentBytesInput")
    def segment_bytes_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "segmentBytesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cleanupPolicy")
    def cleanup_policy(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "cleanupPolicy"))

    @cleanup_policy.setter
    def cleanup_policy(self, value: builtins.str) -> None:
        jsii.set(self, "cleanupPolicy", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="compressionType")
    def compression_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "compressionType"))

    @compression_type.setter
    def compression_type(self, value: builtins.str) -> None:
        jsii.set(self, "compressionType", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteRetentionMs")
    def delete_retention_ms(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "deleteRetentionMs"))

    @delete_retention_ms.setter
    def delete_retention_ms(self, value: builtins.str) -> None:
        jsii.set(self, "deleteRetentionMs", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fileDeleteDelayMs")
    def file_delete_delay_ms(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fileDeleteDelayMs"))

    @file_delete_delay_ms.setter
    def file_delete_delay_ms(self, value: builtins.str) -> None:
        jsii.set(self, "fileDeleteDelayMs", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="flushMessages")
    def flush_messages(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "flushMessages"))

    @flush_messages.setter
    def flush_messages(self, value: builtins.str) -> None:
        jsii.set(self, "flushMessages", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="flushMs")
    def flush_ms(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "flushMs"))

    @flush_ms.setter
    def flush_ms(self, value: builtins.str) -> None:
        jsii.set(self, "flushMs", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxMessageBytes")
    def max_message_bytes(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "maxMessageBytes"))

    @max_message_bytes.setter
    def max_message_bytes(self, value: builtins.str) -> None:
        jsii.set(self, "maxMessageBytes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minCompactionLagMs")
    def min_compaction_lag_ms(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "minCompactionLagMs"))

    @min_compaction_lag_ms.setter
    def min_compaction_lag_ms(self, value: builtins.str) -> None:
        jsii.set(self, "minCompactionLagMs", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minInsyncReplicas")
    def min_insync_replicas(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "minInsyncReplicas"))

    @min_insync_replicas.setter
    def min_insync_replicas(self, value: builtins.str) -> None:
        jsii.set(self, "minInsyncReplicas", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="preallocate")
    def preallocate(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "preallocate"))

    @preallocate.setter
    def preallocate(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "preallocate", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="retentionBytes")
    def retention_bytes(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "retentionBytes"))

    @retention_bytes.setter
    def retention_bytes(self, value: builtins.str) -> None:
        jsii.set(self, "retentionBytes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="retentionMs")
    def retention_ms(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "retentionMs"))

    @retention_ms.setter
    def retention_ms(self, value: builtins.str) -> None:
        jsii.set(self, "retentionMs", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="segmentBytes")
    def segment_bytes(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "segmentBytes"))

    @segment_bytes.setter
    def segment_bytes(self, value: builtins.str) -> None:
        jsii.set(self, "segmentBytes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbKafkaClusterTopicTopicConfig]:
        return typing.cast(typing.Optional[MdbKafkaClusterTopicTopicConfig], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbKafkaClusterTopicTopicConfig],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbKafkaClusterUser",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "password": "password", "permission": "permission"},
)
class MdbKafkaClusterUser:
    def __init__(
        self,
        *,
        name: builtins.str,
        password: builtins.str,
        permission: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbKafkaClusterUserPermission"]]] = None,
    ) -> None:
        '''
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#name MdbKafkaCluster#name}.
        :param password: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#password MdbKafkaCluster#password}.
        :param permission: permission block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#permission MdbKafkaCluster#permission}
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "password": password,
        }
        if permission is not None:
            self._values["permission"] = permission

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#name MdbKafkaCluster#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def password(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#password MdbKafkaCluster#password}.'''
        result = self._values.get("password")
        assert result is not None, "Required property 'password' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def permission(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbKafkaClusterUserPermission"]]]:
        '''permission block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#permission MdbKafkaCluster#permission}
        '''
        result = self._values.get("permission")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbKafkaClusterUserPermission"]]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbKafkaClusterUser(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbKafkaClusterUserList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbKafkaClusterUserList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "MdbKafkaClusterUserOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbKafkaClusterUserOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbKafkaClusterUser]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbKafkaClusterUser]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbKafkaClusterUser]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbKafkaClusterUserOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbKafkaClusterUserOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putPermission")
    def put_permission(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["MdbKafkaClusterUserPermission"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putPermission", [value]))

    @jsii.member(jsii_name="resetPermission")
    def reset_permission(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPermission", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="permission")
    def permission(self) -> "MdbKafkaClusterUserPermissionList":
        return typing.cast("MdbKafkaClusterUserPermissionList", jsii.get(self, "permission"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="passwordInput")
    def password_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "passwordInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="permissionInput")
    def permission_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbKafkaClusterUserPermission"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbKafkaClusterUserPermission"]]], jsii.get(self, "permissionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="password")
    def password(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "password"))

    @password.setter
    def password(self, value: builtins.str) -> None:
        jsii.set(self, "password", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbKafkaClusterUser]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbKafkaClusterUser]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbKafkaClusterUser]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbKafkaClusterUserPermission",
    jsii_struct_bases=[],
    name_mapping={"role": "role", "topic_name": "topicName"},
)
class MdbKafkaClusterUserPermission:
    def __init__(self, *, role: builtins.str, topic_name: builtins.str) -> None:
        '''
        :param role: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#role MdbKafkaCluster#role}.
        :param topic_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#topic_name MdbKafkaCluster#topic_name}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "role": role,
            "topic_name": topic_name,
        }

    @builtins.property
    def role(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#role MdbKafkaCluster#role}.'''
        result = self._values.get("role")
        assert result is not None, "Required property 'role' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def topic_name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_cluster#topic_name MdbKafkaCluster#topic_name}.'''
        result = self._values.get("topic_name")
        assert result is not None, "Required property 'topic_name' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbKafkaClusterUserPermission(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbKafkaClusterUserPermissionList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbKafkaClusterUserPermissionList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "MdbKafkaClusterUserPermissionOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbKafkaClusterUserPermissionOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbKafkaClusterUserPermission]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbKafkaClusterUserPermission]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbKafkaClusterUserPermission]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbKafkaClusterUserPermissionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbKafkaClusterUserPermissionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="roleInput")
    def role_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "roleInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="topicNameInput")
    def topic_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "topicNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="role")
    def role(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "role"))

    @role.setter
    def role(self, value: builtins.str) -> None:
        jsii.set(self, "role", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="topicName")
    def topic_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "topicName"))

    @topic_name.setter
    def topic_name(self, value: builtins.str) -> None:
        jsii.set(self, "topicName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbKafkaClusterUserPermission]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbKafkaClusterUserPermission]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbKafkaClusterUserPermission]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbKafkaConnector(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbKafkaConnector",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector yandex_mdb_kafka_connector}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        cluster_id: builtins.str,
        name: builtins.str,
        connector_config_mirrormaker: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbKafkaConnectorConnectorConfigMirrormaker"]]] = None,
        id: typing.Optional[builtins.str] = None,
        properties: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        tasks_max: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector yandex_mdb_kafka_connector} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#cluster_id MdbKafkaConnector#cluster_id}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#name MdbKafkaConnector#name}.
        :param connector_config_mirrormaker: connector_config_mirrormaker block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#connector_config_mirrormaker MdbKafkaConnector#connector_config_mirrormaker}
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#id MdbKafkaConnector#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param properties: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#properties MdbKafkaConnector#properties}.
        :param tasks_max: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#tasks_max MdbKafkaConnector#tasks_max}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = MdbKafkaConnectorConfig(
            cluster_id=cluster_id,
            name=name,
            connector_config_mirrormaker=connector_config_mirrormaker,
            id=id,
            properties=properties,
            tasks_max=tasks_max,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putConnectorConfigMirrormaker")
    def put_connector_config_mirrormaker(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["MdbKafkaConnectorConnectorConfigMirrormaker"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putConnectorConfigMirrormaker", [value]))

    @jsii.member(jsii_name="resetConnectorConfigMirrormaker")
    def reset_connector_config_mirrormaker(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetConnectorConfigMirrormaker", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetProperties")
    def reset_properties(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetProperties", []))

    @jsii.member(jsii_name="resetTasksMax")
    def reset_tasks_max(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTasksMax", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="connectorConfigMirrormaker")
    def connector_config_mirrormaker(
        self,
    ) -> "MdbKafkaConnectorConnectorConfigMirrormakerList":
        return typing.cast("MdbKafkaConnectorConnectorConfigMirrormakerList", jsii.get(self, "connectorConfigMirrormaker"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterIdInput")
    def cluster_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "clusterIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="connectorConfigMirrormakerInput")
    def connector_config_mirrormaker_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbKafkaConnectorConnectorConfigMirrormaker"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbKafkaConnectorConnectorConfigMirrormaker"]]], jsii.get(self, "connectorConfigMirrormakerInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="propertiesInput")
    def properties_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "propertiesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tasksMaxInput")
    def tasks_max_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "tasksMaxInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterId")
    def cluster_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "clusterId"))

    @cluster_id.setter
    def cluster_id(self, value: builtins.str) -> None:
        jsii.set(self, "clusterId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="properties")
    def properties(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "properties"))

    @properties.setter
    def properties(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "properties", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tasksMax")
    def tasks_max(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "tasksMax"))

    @tasks_max.setter
    def tasks_max(self, value: jsii.Number) -> None:
        jsii.set(self, "tasksMax", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbKafkaConnectorConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_id": "clusterId",
        "name": "name",
        "connector_config_mirrormaker": "connectorConfigMirrormaker",
        "id": "id",
        "properties": "properties",
        "tasks_max": "tasksMax",
    },
)
class MdbKafkaConnectorConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_id: builtins.str,
        name: builtins.str,
        connector_config_mirrormaker: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbKafkaConnectorConnectorConfigMirrormaker"]]] = None,
        id: typing.Optional[builtins.str] = None,
        properties: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        tasks_max: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#cluster_id MdbKafkaConnector#cluster_id}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#name MdbKafkaConnector#name}.
        :param connector_config_mirrormaker: connector_config_mirrormaker block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#connector_config_mirrormaker MdbKafkaConnector#connector_config_mirrormaker}
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#id MdbKafkaConnector#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param properties: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#properties MdbKafkaConnector#properties}.
        :param tasks_max: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#tasks_max MdbKafkaConnector#tasks_max}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {
            "cluster_id": cluster_id,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if connector_config_mirrormaker is not None:
            self._values["connector_config_mirrormaker"] = connector_config_mirrormaker
        if id is not None:
            self._values["id"] = id
        if properties is not None:
            self._values["properties"] = properties
        if tasks_max is not None:
            self._values["tasks_max"] = tasks_max

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def cluster_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#cluster_id MdbKafkaConnector#cluster_id}.'''
        result = self._values.get("cluster_id")
        assert result is not None, "Required property 'cluster_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#name MdbKafkaConnector#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def connector_config_mirrormaker(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbKafkaConnectorConnectorConfigMirrormaker"]]]:
        '''connector_config_mirrormaker block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#connector_config_mirrormaker MdbKafkaConnector#connector_config_mirrormaker}
        '''
        result = self._values.get("connector_config_mirrormaker")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbKafkaConnectorConnectorConfigMirrormaker"]]], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#id MdbKafkaConnector#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def properties(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#properties MdbKafkaConnector#properties}.'''
        result = self._values.get("properties")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def tasks_max(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#tasks_max MdbKafkaConnector#tasks_max}.'''
        result = self._values.get("tasks_max")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbKafkaConnectorConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbKafkaConnectorConnectorConfigMirrormaker",
    jsii_struct_bases=[],
    name_mapping={
        "replication_factor": "replicationFactor",
        "source_cluster": "sourceCluster",
        "target_cluster": "targetCluster",
        "topics": "topics",
    },
)
class MdbKafkaConnectorConnectorConfigMirrormaker:
    def __init__(
        self,
        *,
        replication_factor: jsii.Number,
        source_cluster: "MdbKafkaConnectorConnectorConfigMirrormakerSourceCluster",
        target_cluster: "MdbKafkaConnectorConnectorConfigMirrormakerTargetCluster",
        topics: builtins.str,
    ) -> None:
        '''
        :param replication_factor: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#replication_factor MdbKafkaConnector#replication_factor}.
        :param source_cluster: source_cluster block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#source_cluster MdbKafkaConnector#source_cluster}
        :param target_cluster: target_cluster block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#target_cluster MdbKafkaConnector#target_cluster}
        :param topics: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#topics MdbKafkaConnector#topics}.
        '''
        if isinstance(source_cluster, dict):
            source_cluster = MdbKafkaConnectorConnectorConfigMirrormakerSourceCluster(**source_cluster)
        if isinstance(target_cluster, dict):
            target_cluster = MdbKafkaConnectorConnectorConfigMirrormakerTargetCluster(**target_cluster)
        self._values: typing.Dict[str, typing.Any] = {
            "replication_factor": replication_factor,
            "source_cluster": source_cluster,
            "target_cluster": target_cluster,
            "topics": topics,
        }

    @builtins.property
    def replication_factor(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#replication_factor MdbKafkaConnector#replication_factor}.'''
        result = self._values.get("replication_factor")
        assert result is not None, "Required property 'replication_factor' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def source_cluster(
        self,
    ) -> "MdbKafkaConnectorConnectorConfigMirrormakerSourceCluster":
        '''source_cluster block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#source_cluster MdbKafkaConnector#source_cluster}
        '''
        result = self._values.get("source_cluster")
        assert result is not None, "Required property 'source_cluster' is missing"
        return typing.cast("MdbKafkaConnectorConnectorConfigMirrormakerSourceCluster", result)

    @builtins.property
    def target_cluster(
        self,
    ) -> "MdbKafkaConnectorConnectorConfigMirrormakerTargetCluster":
        '''target_cluster block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#target_cluster MdbKafkaConnector#target_cluster}
        '''
        result = self._values.get("target_cluster")
        assert result is not None, "Required property 'target_cluster' is missing"
        return typing.cast("MdbKafkaConnectorConnectorConfigMirrormakerTargetCluster", result)

    @builtins.property
    def topics(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#topics MdbKafkaConnector#topics}.'''
        result = self._values.get("topics")
        assert result is not None, "Required property 'topics' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbKafkaConnectorConnectorConfigMirrormaker(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbKafkaConnectorConnectorConfigMirrormakerList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbKafkaConnectorConnectorConfigMirrormakerList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "MdbKafkaConnectorConnectorConfigMirrormakerOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbKafkaConnectorConnectorConfigMirrormakerOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbKafkaConnectorConnectorConfigMirrormaker]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbKafkaConnectorConnectorConfigMirrormaker]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbKafkaConnectorConnectorConfigMirrormaker]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbKafkaConnectorConnectorConfigMirrormakerOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbKafkaConnectorConnectorConfigMirrormakerOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putSourceCluster")
    def put_source_cluster(
        self,
        *,
        alias: typing.Optional[builtins.str] = None,
        external_cluster: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalCluster"]]] = None,
        this_cluster: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisCluster"]]] = None,
    ) -> None:
        '''
        :param alias: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#alias MdbKafkaConnector#alias}.
        :param external_cluster: external_cluster block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#external_cluster MdbKafkaConnector#external_cluster}
        :param this_cluster: this_cluster block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#this_cluster MdbKafkaConnector#this_cluster}
        '''
        value = MdbKafkaConnectorConnectorConfigMirrormakerSourceCluster(
            alias=alias, external_cluster=external_cluster, this_cluster=this_cluster
        )

        return typing.cast(None, jsii.invoke(self, "putSourceCluster", [value]))

    @jsii.member(jsii_name="putTargetCluster")
    def put_target_cluster(
        self,
        *,
        alias: typing.Optional[builtins.str] = None,
        external_cluster: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalCluster"]]] = None,
        this_cluster: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisCluster"]]] = None,
    ) -> None:
        '''
        :param alias: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#alias MdbKafkaConnector#alias}.
        :param external_cluster: external_cluster block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#external_cluster MdbKafkaConnector#external_cluster}
        :param this_cluster: this_cluster block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#this_cluster MdbKafkaConnector#this_cluster}
        '''
        value = MdbKafkaConnectorConnectorConfigMirrormakerTargetCluster(
            alias=alias, external_cluster=external_cluster, this_cluster=this_cluster
        )

        return typing.cast(None, jsii.invoke(self, "putTargetCluster", [value]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sourceCluster")
    def source_cluster(
        self,
    ) -> "MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterOutputReference":
        return typing.cast("MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterOutputReference", jsii.get(self, "sourceCluster"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetCluster")
    def target_cluster(
        self,
    ) -> "MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterOutputReference":
        return typing.cast("MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterOutputReference", jsii.get(self, "targetCluster"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replicationFactorInput")
    def replication_factor_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "replicationFactorInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sourceClusterInput")
    def source_cluster_input(
        self,
    ) -> typing.Optional["MdbKafkaConnectorConnectorConfigMirrormakerSourceCluster"]:
        return typing.cast(typing.Optional["MdbKafkaConnectorConnectorConfigMirrormakerSourceCluster"], jsii.get(self, "sourceClusterInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetClusterInput")
    def target_cluster_input(
        self,
    ) -> typing.Optional["MdbKafkaConnectorConnectorConfigMirrormakerTargetCluster"]:
        return typing.cast(typing.Optional["MdbKafkaConnectorConnectorConfigMirrormakerTargetCluster"], jsii.get(self, "targetClusterInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="topicsInput")
    def topics_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "topicsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replicationFactor")
    def replication_factor(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "replicationFactor"))

    @replication_factor.setter
    def replication_factor(self, value: jsii.Number) -> None:
        jsii.set(self, "replicationFactor", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="topics")
    def topics(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "topics"))

    @topics.setter
    def topics(self, value: builtins.str) -> None:
        jsii.set(self, "topics", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbKafkaConnectorConnectorConfigMirrormaker]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbKafkaConnectorConnectorConfigMirrormaker]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbKafkaConnectorConnectorConfigMirrormaker]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbKafkaConnectorConnectorConfigMirrormakerSourceCluster",
    jsii_struct_bases=[],
    name_mapping={
        "alias": "alias",
        "external_cluster": "externalCluster",
        "this_cluster": "thisCluster",
    },
)
class MdbKafkaConnectorConnectorConfigMirrormakerSourceCluster:
    def __init__(
        self,
        *,
        alias: typing.Optional[builtins.str] = None,
        external_cluster: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalCluster"]]] = None,
        this_cluster: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisCluster"]]] = None,
    ) -> None:
        '''
        :param alias: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#alias MdbKafkaConnector#alias}.
        :param external_cluster: external_cluster block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#external_cluster MdbKafkaConnector#external_cluster}
        :param this_cluster: this_cluster block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#this_cluster MdbKafkaConnector#this_cluster}
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if alias is not None:
            self._values["alias"] = alias
        if external_cluster is not None:
            self._values["external_cluster"] = external_cluster
        if this_cluster is not None:
            self._values["this_cluster"] = this_cluster

    @builtins.property
    def alias(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#alias MdbKafkaConnector#alias}.'''
        result = self._values.get("alias")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def external_cluster(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalCluster"]]]:
        '''external_cluster block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#external_cluster MdbKafkaConnector#external_cluster}
        '''
        result = self._values.get("external_cluster")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalCluster"]]], result)

    @builtins.property
    def this_cluster(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisCluster"]]]:
        '''this_cluster block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#this_cluster MdbKafkaConnector#this_cluster}
        '''
        result = self._values.get("this_cluster")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisCluster"]]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbKafkaConnectorConnectorConfigMirrormakerSourceCluster(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalCluster",
    jsii_struct_bases=[],
    name_mapping={
        "bootstrap_servers": "bootstrapServers",
        "sasl_mechanism": "saslMechanism",
        "sasl_password": "saslPassword",
        "sasl_username": "saslUsername",
        "security_protocol": "securityProtocol",
    },
)
class MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalCluster:
    def __init__(
        self,
        *,
        bootstrap_servers: builtins.str,
        sasl_mechanism: typing.Optional[builtins.str] = None,
        sasl_password: typing.Optional[builtins.str] = None,
        sasl_username: typing.Optional[builtins.str] = None,
        security_protocol: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param bootstrap_servers: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#bootstrap_servers MdbKafkaConnector#bootstrap_servers}.
        :param sasl_mechanism: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#sasl_mechanism MdbKafkaConnector#sasl_mechanism}.
        :param sasl_password: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#sasl_password MdbKafkaConnector#sasl_password}.
        :param sasl_username: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#sasl_username MdbKafkaConnector#sasl_username}.
        :param security_protocol: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#security_protocol MdbKafkaConnector#security_protocol}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "bootstrap_servers": bootstrap_servers,
        }
        if sasl_mechanism is not None:
            self._values["sasl_mechanism"] = sasl_mechanism
        if sasl_password is not None:
            self._values["sasl_password"] = sasl_password
        if sasl_username is not None:
            self._values["sasl_username"] = sasl_username
        if security_protocol is not None:
            self._values["security_protocol"] = security_protocol

    @builtins.property
    def bootstrap_servers(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#bootstrap_servers MdbKafkaConnector#bootstrap_servers}.'''
        result = self._values.get("bootstrap_servers")
        assert result is not None, "Required property 'bootstrap_servers' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def sasl_mechanism(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#sasl_mechanism MdbKafkaConnector#sasl_mechanism}.'''
        result = self._values.get("sasl_mechanism")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def sasl_password(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#sasl_password MdbKafkaConnector#sasl_password}.'''
        result = self._values.get("sasl_password")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def sasl_username(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#sasl_username MdbKafkaConnector#sasl_username}.'''
        result = self._values.get("sasl_username")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def security_protocol(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#security_protocol MdbKafkaConnector#security_protocol}.'''
        result = self._values.get("security_protocol")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalCluster(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalClusterList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalClusterList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalClusterOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalClusterOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalCluster]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalCluster]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalCluster]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalClusterOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalClusterOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetSaslMechanism")
    def reset_sasl_mechanism(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSaslMechanism", []))

    @jsii.member(jsii_name="resetSaslPassword")
    def reset_sasl_password(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSaslPassword", []))

    @jsii.member(jsii_name="resetSaslUsername")
    def reset_sasl_username(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSaslUsername", []))

    @jsii.member(jsii_name="resetSecurityProtocol")
    def reset_security_protocol(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityProtocol", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bootstrapServersInput")
    def bootstrap_servers_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "bootstrapServersInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslMechanismInput")
    def sasl_mechanism_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "saslMechanismInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslPasswordInput")
    def sasl_password_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "saslPasswordInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslUsernameInput")
    def sasl_username_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "saslUsernameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityProtocolInput")
    def security_protocol_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "securityProtocolInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bootstrapServers")
    def bootstrap_servers(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "bootstrapServers"))

    @bootstrap_servers.setter
    def bootstrap_servers(self, value: builtins.str) -> None:
        jsii.set(self, "bootstrapServers", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslMechanism")
    def sasl_mechanism(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "saslMechanism"))

    @sasl_mechanism.setter
    def sasl_mechanism(self, value: builtins.str) -> None:
        jsii.set(self, "saslMechanism", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslPassword")
    def sasl_password(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "saslPassword"))

    @sasl_password.setter
    def sasl_password(self, value: builtins.str) -> None:
        jsii.set(self, "saslPassword", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslUsername")
    def sasl_username(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "saslUsername"))

    @sasl_username.setter
    def sasl_username(self, value: builtins.str) -> None:
        jsii.set(self, "saslUsername", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityProtocol")
    def security_protocol(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "securityProtocol"))

    @security_protocol.setter
    def security_protocol(self, value: builtins.str) -> None:
        jsii.set(self, "securityProtocol", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalCluster]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalCluster]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalCluster]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putExternalCluster")
    def put_external_cluster(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence[MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalCluster]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putExternalCluster", [value]))

    @jsii.member(jsii_name="putThisCluster")
    def put_this_cluster(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisCluster"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putThisCluster", [value]))

    @jsii.member(jsii_name="resetAlias")
    def reset_alias(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAlias", []))

    @jsii.member(jsii_name="resetExternalCluster")
    def reset_external_cluster(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetExternalCluster", []))

    @jsii.member(jsii_name="resetThisCluster")
    def reset_this_cluster(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetThisCluster", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="externalCluster")
    def external_cluster(
        self,
    ) -> MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalClusterList:
        return typing.cast(MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalClusterList, jsii.get(self, "externalCluster"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="thisCluster")
    def this_cluster(
        self,
    ) -> "MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisClusterList":
        return typing.cast("MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisClusterList", jsii.get(self, "thisCluster"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="aliasInput")
    def alias_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aliasInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="externalClusterInput")
    def external_cluster_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalCluster]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalCluster]]], jsii.get(self, "externalClusterInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="thisClusterInput")
    def this_cluster_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisCluster"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisCluster"]]], jsii.get(self, "thisClusterInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="alias")
    def alias(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "alias"))

    @alias.setter
    def alias(self, value: builtins.str) -> None:
        jsii.set(self, "alias", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[MdbKafkaConnectorConnectorConfigMirrormakerSourceCluster]:
        return typing.cast(typing.Optional[MdbKafkaConnectorConnectorConfigMirrormakerSourceCluster], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbKafkaConnectorConnectorConfigMirrormakerSourceCluster],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisCluster",
    jsii_struct_bases=[],
    name_mapping={},
)
class MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisCluster:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisCluster(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisClusterList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisClusterList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisClusterOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisClusterOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisCluster]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisCluster]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisCluster]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisClusterOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisClusterOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisCluster]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisCluster]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisCluster]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbKafkaConnectorConnectorConfigMirrormakerTargetCluster",
    jsii_struct_bases=[],
    name_mapping={
        "alias": "alias",
        "external_cluster": "externalCluster",
        "this_cluster": "thisCluster",
    },
)
class MdbKafkaConnectorConnectorConfigMirrormakerTargetCluster:
    def __init__(
        self,
        *,
        alias: typing.Optional[builtins.str] = None,
        external_cluster: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalCluster"]]] = None,
        this_cluster: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisCluster"]]] = None,
    ) -> None:
        '''
        :param alias: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#alias MdbKafkaConnector#alias}.
        :param external_cluster: external_cluster block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#external_cluster MdbKafkaConnector#external_cluster}
        :param this_cluster: this_cluster block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#this_cluster MdbKafkaConnector#this_cluster}
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if alias is not None:
            self._values["alias"] = alias
        if external_cluster is not None:
            self._values["external_cluster"] = external_cluster
        if this_cluster is not None:
            self._values["this_cluster"] = this_cluster

    @builtins.property
    def alias(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#alias MdbKafkaConnector#alias}.'''
        result = self._values.get("alias")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def external_cluster(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalCluster"]]]:
        '''external_cluster block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#external_cluster MdbKafkaConnector#external_cluster}
        '''
        result = self._values.get("external_cluster")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalCluster"]]], result)

    @builtins.property
    def this_cluster(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisCluster"]]]:
        '''this_cluster block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#this_cluster MdbKafkaConnector#this_cluster}
        '''
        result = self._values.get("this_cluster")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisCluster"]]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbKafkaConnectorConnectorConfigMirrormakerTargetCluster(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalCluster",
    jsii_struct_bases=[],
    name_mapping={
        "bootstrap_servers": "bootstrapServers",
        "sasl_mechanism": "saslMechanism",
        "sasl_password": "saslPassword",
        "sasl_username": "saslUsername",
        "security_protocol": "securityProtocol",
    },
)
class MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalCluster:
    def __init__(
        self,
        *,
        bootstrap_servers: builtins.str,
        sasl_mechanism: typing.Optional[builtins.str] = None,
        sasl_password: typing.Optional[builtins.str] = None,
        sasl_username: typing.Optional[builtins.str] = None,
        security_protocol: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param bootstrap_servers: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#bootstrap_servers MdbKafkaConnector#bootstrap_servers}.
        :param sasl_mechanism: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#sasl_mechanism MdbKafkaConnector#sasl_mechanism}.
        :param sasl_password: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#sasl_password MdbKafkaConnector#sasl_password}.
        :param sasl_username: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#sasl_username MdbKafkaConnector#sasl_username}.
        :param security_protocol: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#security_protocol MdbKafkaConnector#security_protocol}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "bootstrap_servers": bootstrap_servers,
        }
        if sasl_mechanism is not None:
            self._values["sasl_mechanism"] = sasl_mechanism
        if sasl_password is not None:
            self._values["sasl_password"] = sasl_password
        if sasl_username is not None:
            self._values["sasl_username"] = sasl_username
        if security_protocol is not None:
            self._values["security_protocol"] = security_protocol

    @builtins.property
    def bootstrap_servers(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#bootstrap_servers MdbKafkaConnector#bootstrap_servers}.'''
        result = self._values.get("bootstrap_servers")
        assert result is not None, "Required property 'bootstrap_servers' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def sasl_mechanism(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#sasl_mechanism MdbKafkaConnector#sasl_mechanism}.'''
        result = self._values.get("sasl_mechanism")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def sasl_password(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#sasl_password MdbKafkaConnector#sasl_password}.'''
        result = self._values.get("sasl_password")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def sasl_username(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#sasl_username MdbKafkaConnector#sasl_username}.'''
        result = self._values.get("sasl_username")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def security_protocol(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_connector#security_protocol MdbKafkaConnector#security_protocol}.'''
        result = self._values.get("security_protocol")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalCluster(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalClusterList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalClusterList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalClusterOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalClusterOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalCluster]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalCluster]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalCluster]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalClusterOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalClusterOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetSaslMechanism")
    def reset_sasl_mechanism(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSaslMechanism", []))

    @jsii.member(jsii_name="resetSaslPassword")
    def reset_sasl_password(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSaslPassword", []))

    @jsii.member(jsii_name="resetSaslUsername")
    def reset_sasl_username(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSaslUsername", []))

    @jsii.member(jsii_name="resetSecurityProtocol")
    def reset_security_protocol(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityProtocol", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bootstrapServersInput")
    def bootstrap_servers_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "bootstrapServersInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslMechanismInput")
    def sasl_mechanism_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "saslMechanismInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslPasswordInput")
    def sasl_password_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "saslPasswordInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslUsernameInput")
    def sasl_username_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "saslUsernameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityProtocolInput")
    def security_protocol_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "securityProtocolInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bootstrapServers")
    def bootstrap_servers(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "bootstrapServers"))

    @bootstrap_servers.setter
    def bootstrap_servers(self, value: builtins.str) -> None:
        jsii.set(self, "bootstrapServers", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslMechanism")
    def sasl_mechanism(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "saslMechanism"))

    @sasl_mechanism.setter
    def sasl_mechanism(self, value: builtins.str) -> None:
        jsii.set(self, "saslMechanism", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslPassword")
    def sasl_password(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "saslPassword"))

    @sasl_password.setter
    def sasl_password(self, value: builtins.str) -> None:
        jsii.set(self, "saslPassword", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="saslUsername")
    def sasl_username(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "saslUsername"))

    @sasl_username.setter
    def sasl_username(self, value: builtins.str) -> None:
        jsii.set(self, "saslUsername", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityProtocol")
    def security_protocol(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "securityProtocol"))

    @security_protocol.setter
    def security_protocol(self, value: builtins.str) -> None:
        jsii.set(self, "securityProtocol", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalCluster]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalCluster]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalCluster]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putExternalCluster")
    def put_external_cluster(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence[MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalCluster]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putExternalCluster", [value]))

    @jsii.member(jsii_name="putThisCluster")
    def put_this_cluster(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisCluster"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putThisCluster", [value]))

    @jsii.member(jsii_name="resetAlias")
    def reset_alias(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAlias", []))

    @jsii.member(jsii_name="resetExternalCluster")
    def reset_external_cluster(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetExternalCluster", []))

    @jsii.member(jsii_name="resetThisCluster")
    def reset_this_cluster(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetThisCluster", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="externalCluster")
    def external_cluster(
        self,
    ) -> MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalClusterList:
        return typing.cast(MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalClusterList, jsii.get(self, "externalCluster"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="thisCluster")
    def this_cluster(
        self,
    ) -> "MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisClusterList":
        return typing.cast("MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisClusterList", jsii.get(self, "thisCluster"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="aliasInput")
    def alias_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aliasInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="externalClusterInput")
    def external_cluster_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalCluster]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalCluster]]], jsii.get(self, "externalClusterInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="thisClusterInput")
    def this_cluster_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisCluster"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisCluster"]]], jsii.get(self, "thisClusterInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="alias")
    def alias(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "alias"))

    @alias.setter
    def alias(self, value: builtins.str) -> None:
        jsii.set(self, "alias", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[MdbKafkaConnectorConnectorConfigMirrormakerTargetCluster]:
        return typing.cast(typing.Optional[MdbKafkaConnectorConnectorConfigMirrormakerTargetCluster], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbKafkaConnectorConnectorConfigMirrormakerTargetCluster],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisCluster",
    jsii_struct_bases=[],
    name_mapping={},
)
class MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisCluster:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisCluster(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisClusterList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisClusterList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisClusterOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisClusterOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisCluster]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisCluster]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisCluster]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisClusterOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisClusterOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisCluster]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisCluster]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisCluster]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbKafkaTopic(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbKafkaTopic",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic yandex_mdb_kafka_topic}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        cluster_id: builtins.str,
        name: builtins.str,
        partitions: jsii.Number,
        replication_factor: jsii.Number,
        id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["MdbKafkaTopicTimeouts"] = None,
        topic_config: typing.Optional["MdbKafkaTopicTopicConfig"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic yandex_mdb_kafka_topic} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#cluster_id MdbKafkaTopic#cluster_id}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#name MdbKafkaTopic#name}.
        :param partitions: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#partitions MdbKafkaTopic#partitions}.
        :param replication_factor: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#replication_factor MdbKafkaTopic#replication_factor}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#id MdbKafkaTopic#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#timeouts MdbKafkaTopic#timeouts}
        :param topic_config: topic_config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#topic_config MdbKafkaTopic#topic_config}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = MdbKafkaTopicConfig(
            cluster_id=cluster_id,
            name=name,
            partitions=partitions,
            replication_factor=replication_factor,
            id=id,
            timeouts=timeouts,
            topic_config=topic_config,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#create MdbKafkaTopic#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#delete MdbKafkaTopic#delete}.
        :param read: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#read MdbKafkaTopic#read}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#update MdbKafkaTopic#update}.
        '''
        value = MdbKafkaTopicTimeouts(
            create=create, delete=delete, read=read, update=update
        )

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="putTopicConfig")
    def put_topic_config(
        self,
        *,
        cleanup_policy: typing.Optional[builtins.str] = None,
        compression_type: typing.Optional[builtins.str] = None,
        delete_retention_ms: typing.Optional[builtins.str] = None,
        file_delete_delay_ms: typing.Optional[builtins.str] = None,
        flush_messages: typing.Optional[builtins.str] = None,
        flush_ms: typing.Optional[builtins.str] = None,
        max_message_bytes: typing.Optional[builtins.str] = None,
        min_compaction_lag_ms: typing.Optional[builtins.str] = None,
        min_insync_replicas: typing.Optional[builtins.str] = None,
        preallocate: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        retention_bytes: typing.Optional[builtins.str] = None,
        retention_ms: typing.Optional[builtins.str] = None,
        segment_bytes: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param cleanup_policy: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#cleanup_policy MdbKafkaTopic#cleanup_policy}.
        :param compression_type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#compression_type MdbKafkaTopic#compression_type}.
        :param delete_retention_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#delete_retention_ms MdbKafkaTopic#delete_retention_ms}.
        :param file_delete_delay_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#file_delete_delay_ms MdbKafkaTopic#file_delete_delay_ms}.
        :param flush_messages: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#flush_messages MdbKafkaTopic#flush_messages}.
        :param flush_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#flush_ms MdbKafkaTopic#flush_ms}.
        :param max_message_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#max_message_bytes MdbKafkaTopic#max_message_bytes}.
        :param min_compaction_lag_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#min_compaction_lag_ms MdbKafkaTopic#min_compaction_lag_ms}.
        :param min_insync_replicas: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#min_insync_replicas MdbKafkaTopic#min_insync_replicas}.
        :param preallocate: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#preallocate MdbKafkaTopic#preallocate}.
        :param retention_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#retention_bytes MdbKafkaTopic#retention_bytes}.
        :param retention_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#retention_ms MdbKafkaTopic#retention_ms}.
        :param segment_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#segment_bytes MdbKafkaTopic#segment_bytes}.
        '''
        value = MdbKafkaTopicTopicConfig(
            cleanup_policy=cleanup_policy,
            compression_type=compression_type,
            delete_retention_ms=delete_retention_ms,
            file_delete_delay_ms=file_delete_delay_ms,
            flush_messages=flush_messages,
            flush_ms=flush_ms,
            max_message_bytes=max_message_bytes,
            min_compaction_lag_ms=min_compaction_lag_ms,
            min_insync_replicas=min_insync_replicas,
            preallocate=preallocate,
            retention_bytes=retention_bytes,
            retention_ms=retention_ms,
            segment_bytes=segment_bytes,
        )

        return typing.cast(None, jsii.invoke(self, "putTopicConfig", [value]))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="resetTopicConfig")
    def reset_topic_config(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTopicConfig", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "MdbKafkaTopicTimeoutsOutputReference":
        return typing.cast("MdbKafkaTopicTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="topicConfig")
    def topic_config(self) -> "MdbKafkaTopicTopicConfigOutputReference":
        return typing.cast("MdbKafkaTopicTopicConfigOutputReference", jsii.get(self, "topicConfig"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterIdInput")
    def cluster_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "clusterIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="partitionsInput")
    def partitions_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "partitionsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replicationFactorInput")
    def replication_factor_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "replicationFactorInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "MdbKafkaTopicTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "MdbKafkaTopicTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="topicConfigInput")
    def topic_config_input(self) -> typing.Optional["MdbKafkaTopicTopicConfig"]:
        return typing.cast(typing.Optional["MdbKafkaTopicTopicConfig"], jsii.get(self, "topicConfigInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterId")
    def cluster_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "clusterId"))

    @cluster_id.setter
    def cluster_id(self, value: builtins.str) -> None:
        jsii.set(self, "clusterId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="partitions")
    def partitions(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "partitions"))

    @partitions.setter
    def partitions(self, value: jsii.Number) -> None:
        jsii.set(self, "partitions", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replicationFactor")
    def replication_factor(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "replicationFactor"))

    @replication_factor.setter
    def replication_factor(self, value: jsii.Number) -> None:
        jsii.set(self, "replicationFactor", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbKafkaTopicConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_id": "clusterId",
        "name": "name",
        "partitions": "partitions",
        "replication_factor": "replicationFactor",
        "id": "id",
        "timeouts": "timeouts",
        "topic_config": "topicConfig",
    },
)
class MdbKafkaTopicConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_id: builtins.str,
        name: builtins.str,
        partitions: jsii.Number,
        replication_factor: jsii.Number,
        id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["MdbKafkaTopicTimeouts"] = None,
        topic_config: typing.Optional["MdbKafkaTopicTopicConfig"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#cluster_id MdbKafkaTopic#cluster_id}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#name MdbKafkaTopic#name}.
        :param partitions: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#partitions MdbKafkaTopic#partitions}.
        :param replication_factor: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#replication_factor MdbKafkaTopic#replication_factor}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#id MdbKafkaTopic#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#timeouts MdbKafkaTopic#timeouts}
        :param topic_config: topic_config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#topic_config MdbKafkaTopic#topic_config}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = MdbKafkaTopicTimeouts(**timeouts)
        if isinstance(topic_config, dict):
            topic_config = MdbKafkaTopicTopicConfig(**topic_config)
        self._values: typing.Dict[str, typing.Any] = {
            "cluster_id": cluster_id,
            "name": name,
            "partitions": partitions,
            "replication_factor": replication_factor,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if id is not None:
            self._values["id"] = id
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if topic_config is not None:
            self._values["topic_config"] = topic_config

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def cluster_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#cluster_id MdbKafkaTopic#cluster_id}.'''
        result = self._values.get("cluster_id")
        assert result is not None, "Required property 'cluster_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#name MdbKafkaTopic#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def partitions(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#partitions MdbKafkaTopic#partitions}.'''
        result = self._values.get("partitions")
        assert result is not None, "Required property 'partitions' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def replication_factor(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#replication_factor MdbKafkaTopic#replication_factor}.'''
        result = self._values.get("replication_factor")
        assert result is not None, "Required property 'replication_factor' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#id MdbKafkaTopic#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["MdbKafkaTopicTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#timeouts MdbKafkaTopic#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["MdbKafkaTopicTimeouts"], result)

    @builtins.property
    def topic_config(self) -> typing.Optional["MdbKafkaTopicTopicConfig"]:
        '''topic_config block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#topic_config MdbKafkaTopic#topic_config}
        '''
        result = self._values.get("topic_config")
        return typing.cast(typing.Optional["MdbKafkaTopicTopicConfig"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbKafkaTopicConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbKafkaTopicTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class MdbKafkaTopicTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#create MdbKafkaTopic#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#delete MdbKafkaTopic#delete}.
        :param read: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#read MdbKafkaTopic#read}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#update MdbKafkaTopic#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#create MdbKafkaTopic#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#delete MdbKafkaTopic#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#read MdbKafkaTopic#read}.'''
        result = self._values.get("read")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#update MdbKafkaTopic#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbKafkaTopicTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbKafkaTopicTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbKafkaTopicTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetRead")
    def reset_read(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRead", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="readInput")
    def read_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "readInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="read")
    def read(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "read"))

    @read.setter
    def read(self, value: builtins.str) -> None:
        jsii.set(self, "read", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbKafkaTopicTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbKafkaTopicTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbKafkaTopicTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbKafkaTopicTopicConfig",
    jsii_struct_bases=[],
    name_mapping={
        "cleanup_policy": "cleanupPolicy",
        "compression_type": "compressionType",
        "delete_retention_ms": "deleteRetentionMs",
        "file_delete_delay_ms": "fileDeleteDelayMs",
        "flush_messages": "flushMessages",
        "flush_ms": "flushMs",
        "max_message_bytes": "maxMessageBytes",
        "min_compaction_lag_ms": "minCompactionLagMs",
        "min_insync_replicas": "minInsyncReplicas",
        "preallocate": "preallocate",
        "retention_bytes": "retentionBytes",
        "retention_ms": "retentionMs",
        "segment_bytes": "segmentBytes",
    },
)
class MdbKafkaTopicTopicConfig:
    def __init__(
        self,
        *,
        cleanup_policy: typing.Optional[builtins.str] = None,
        compression_type: typing.Optional[builtins.str] = None,
        delete_retention_ms: typing.Optional[builtins.str] = None,
        file_delete_delay_ms: typing.Optional[builtins.str] = None,
        flush_messages: typing.Optional[builtins.str] = None,
        flush_ms: typing.Optional[builtins.str] = None,
        max_message_bytes: typing.Optional[builtins.str] = None,
        min_compaction_lag_ms: typing.Optional[builtins.str] = None,
        min_insync_replicas: typing.Optional[builtins.str] = None,
        preallocate: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        retention_bytes: typing.Optional[builtins.str] = None,
        retention_ms: typing.Optional[builtins.str] = None,
        segment_bytes: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param cleanup_policy: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#cleanup_policy MdbKafkaTopic#cleanup_policy}.
        :param compression_type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#compression_type MdbKafkaTopic#compression_type}.
        :param delete_retention_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#delete_retention_ms MdbKafkaTopic#delete_retention_ms}.
        :param file_delete_delay_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#file_delete_delay_ms MdbKafkaTopic#file_delete_delay_ms}.
        :param flush_messages: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#flush_messages MdbKafkaTopic#flush_messages}.
        :param flush_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#flush_ms MdbKafkaTopic#flush_ms}.
        :param max_message_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#max_message_bytes MdbKafkaTopic#max_message_bytes}.
        :param min_compaction_lag_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#min_compaction_lag_ms MdbKafkaTopic#min_compaction_lag_ms}.
        :param min_insync_replicas: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#min_insync_replicas MdbKafkaTopic#min_insync_replicas}.
        :param preallocate: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#preallocate MdbKafkaTopic#preallocate}.
        :param retention_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#retention_bytes MdbKafkaTopic#retention_bytes}.
        :param retention_ms: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#retention_ms MdbKafkaTopic#retention_ms}.
        :param segment_bytes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#segment_bytes MdbKafkaTopic#segment_bytes}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if cleanup_policy is not None:
            self._values["cleanup_policy"] = cleanup_policy
        if compression_type is not None:
            self._values["compression_type"] = compression_type
        if delete_retention_ms is not None:
            self._values["delete_retention_ms"] = delete_retention_ms
        if file_delete_delay_ms is not None:
            self._values["file_delete_delay_ms"] = file_delete_delay_ms
        if flush_messages is not None:
            self._values["flush_messages"] = flush_messages
        if flush_ms is not None:
            self._values["flush_ms"] = flush_ms
        if max_message_bytes is not None:
            self._values["max_message_bytes"] = max_message_bytes
        if min_compaction_lag_ms is not None:
            self._values["min_compaction_lag_ms"] = min_compaction_lag_ms
        if min_insync_replicas is not None:
            self._values["min_insync_replicas"] = min_insync_replicas
        if preallocate is not None:
            self._values["preallocate"] = preallocate
        if retention_bytes is not None:
            self._values["retention_bytes"] = retention_bytes
        if retention_ms is not None:
            self._values["retention_ms"] = retention_ms
        if segment_bytes is not None:
            self._values["segment_bytes"] = segment_bytes

    @builtins.property
    def cleanup_policy(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#cleanup_policy MdbKafkaTopic#cleanup_policy}.'''
        result = self._values.get("cleanup_policy")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def compression_type(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#compression_type MdbKafkaTopic#compression_type}.'''
        result = self._values.get("compression_type")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete_retention_ms(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#delete_retention_ms MdbKafkaTopic#delete_retention_ms}.'''
        result = self._values.get("delete_retention_ms")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def file_delete_delay_ms(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#file_delete_delay_ms MdbKafkaTopic#file_delete_delay_ms}.'''
        result = self._values.get("file_delete_delay_ms")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def flush_messages(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#flush_messages MdbKafkaTopic#flush_messages}.'''
        result = self._values.get("flush_messages")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def flush_ms(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#flush_ms MdbKafkaTopic#flush_ms}.'''
        result = self._values.get("flush_ms")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def max_message_bytes(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#max_message_bytes MdbKafkaTopic#max_message_bytes}.'''
        result = self._values.get("max_message_bytes")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def min_compaction_lag_ms(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#min_compaction_lag_ms MdbKafkaTopic#min_compaction_lag_ms}.'''
        result = self._values.get("min_compaction_lag_ms")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def min_insync_replicas(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#min_insync_replicas MdbKafkaTopic#min_insync_replicas}.'''
        result = self._values.get("min_insync_replicas")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def preallocate(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#preallocate MdbKafkaTopic#preallocate}.'''
        result = self._values.get("preallocate")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def retention_bytes(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#retention_bytes MdbKafkaTopic#retention_bytes}.'''
        result = self._values.get("retention_bytes")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def retention_ms(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#retention_ms MdbKafkaTopic#retention_ms}.'''
        result = self._values.get("retention_ms")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def segment_bytes(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_kafka_topic#segment_bytes MdbKafkaTopic#segment_bytes}.'''
        result = self._values.get("segment_bytes")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbKafkaTopicTopicConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbKafkaTopicTopicConfigOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbKafkaTopicTopicConfigOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCleanupPolicy")
    def reset_cleanup_policy(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCleanupPolicy", []))

    @jsii.member(jsii_name="resetCompressionType")
    def reset_compression_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCompressionType", []))

    @jsii.member(jsii_name="resetDeleteRetentionMs")
    def reset_delete_retention_ms(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDeleteRetentionMs", []))

    @jsii.member(jsii_name="resetFileDeleteDelayMs")
    def reset_file_delete_delay_ms(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFileDeleteDelayMs", []))

    @jsii.member(jsii_name="resetFlushMessages")
    def reset_flush_messages(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFlushMessages", []))

    @jsii.member(jsii_name="resetFlushMs")
    def reset_flush_ms(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFlushMs", []))

    @jsii.member(jsii_name="resetMaxMessageBytes")
    def reset_max_message_bytes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxMessageBytes", []))

    @jsii.member(jsii_name="resetMinCompactionLagMs")
    def reset_min_compaction_lag_ms(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMinCompactionLagMs", []))

    @jsii.member(jsii_name="resetMinInsyncReplicas")
    def reset_min_insync_replicas(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMinInsyncReplicas", []))

    @jsii.member(jsii_name="resetPreallocate")
    def reset_preallocate(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPreallocate", []))

    @jsii.member(jsii_name="resetRetentionBytes")
    def reset_retention_bytes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRetentionBytes", []))

    @jsii.member(jsii_name="resetRetentionMs")
    def reset_retention_ms(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRetentionMs", []))

    @jsii.member(jsii_name="resetSegmentBytes")
    def reset_segment_bytes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSegmentBytes", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cleanupPolicyInput")
    def cleanup_policy_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "cleanupPolicyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="compressionTypeInput")
    def compression_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "compressionTypeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteRetentionMsInput")
    def delete_retention_ms_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteRetentionMsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fileDeleteDelayMsInput")
    def file_delete_delay_ms_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "fileDeleteDelayMsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="flushMessagesInput")
    def flush_messages_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "flushMessagesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="flushMsInput")
    def flush_ms_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "flushMsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxMessageBytesInput")
    def max_message_bytes_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "maxMessageBytesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minCompactionLagMsInput")
    def min_compaction_lag_ms_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "minCompactionLagMsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minInsyncReplicasInput")
    def min_insync_replicas_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "minInsyncReplicasInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="preallocateInput")
    def preallocate_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "preallocateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="retentionBytesInput")
    def retention_bytes_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "retentionBytesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="retentionMsInput")
    def retention_ms_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "retentionMsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="segmentBytesInput")
    def segment_bytes_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "segmentBytesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cleanupPolicy")
    def cleanup_policy(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "cleanupPolicy"))

    @cleanup_policy.setter
    def cleanup_policy(self, value: builtins.str) -> None:
        jsii.set(self, "cleanupPolicy", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="compressionType")
    def compression_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "compressionType"))

    @compression_type.setter
    def compression_type(self, value: builtins.str) -> None:
        jsii.set(self, "compressionType", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteRetentionMs")
    def delete_retention_ms(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "deleteRetentionMs"))

    @delete_retention_ms.setter
    def delete_retention_ms(self, value: builtins.str) -> None:
        jsii.set(self, "deleteRetentionMs", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fileDeleteDelayMs")
    def file_delete_delay_ms(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fileDeleteDelayMs"))

    @file_delete_delay_ms.setter
    def file_delete_delay_ms(self, value: builtins.str) -> None:
        jsii.set(self, "fileDeleteDelayMs", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="flushMessages")
    def flush_messages(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "flushMessages"))

    @flush_messages.setter
    def flush_messages(self, value: builtins.str) -> None:
        jsii.set(self, "flushMessages", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="flushMs")
    def flush_ms(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "flushMs"))

    @flush_ms.setter
    def flush_ms(self, value: builtins.str) -> None:
        jsii.set(self, "flushMs", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxMessageBytes")
    def max_message_bytes(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "maxMessageBytes"))

    @max_message_bytes.setter
    def max_message_bytes(self, value: builtins.str) -> None:
        jsii.set(self, "maxMessageBytes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minCompactionLagMs")
    def min_compaction_lag_ms(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "minCompactionLagMs"))

    @min_compaction_lag_ms.setter
    def min_compaction_lag_ms(self, value: builtins.str) -> None:
        jsii.set(self, "minCompactionLagMs", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minInsyncReplicas")
    def min_insync_replicas(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "minInsyncReplicas"))

    @min_insync_replicas.setter
    def min_insync_replicas(self, value: builtins.str) -> None:
        jsii.set(self, "minInsyncReplicas", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="preallocate")
    def preallocate(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "preallocate"))

    @preallocate.setter
    def preallocate(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "preallocate", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="retentionBytes")
    def retention_bytes(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "retentionBytes"))

    @retention_bytes.setter
    def retention_bytes(self, value: builtins.str) -> None:
        jsii.set(self, "retentionBytes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="retentionMs")
    def retention_ms(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "retentionMs"))

    @retention_ms.setter
    def retention_ms(self, value: builtins.str) -> None:
        jsii.set(self, "retentionMs", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="segmentBytes")
    def segment_bytes(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "segmentBytes"))

    @segment_bytes.setter
    def segment_bytes(self, value: builtins.str) -> None:
        jsii.set(self, "segmentBytes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbKafkaTopicTopicConfig]:
        return typing.cast(typing.Optional[MdbKafkaTopicTopicConfig], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(self, value: typing.Optional[MdbKafkaTopicTopicConfig]) -> None:
        jsii.set(self, "internalValue", value)


class MdbMongodbCluster(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbMongodbCluster",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster yandex_mdb_mongodb_cluster}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        cluster_config: "MdbMongodbClusterClusterConfig",
        database: typing.Union[cdktf.IResolvable, typing.Sequence["MdbMongodbClusterDatabase"]],
        environment: builtins.str,
        host: typing.Union[cdktf.IResolvable, typing.Sequence["MdbMongodbClusterHost"]],
        name: builtins.str,
        network_id: builtins.str,
        resources: "MdbMongodbClusterResources",
        user: typing.Union[cdktf.IResolvable, typing.Sequence["MdbMongodbClusterUser"]],
        cluster_id: typing.Optional[builtins.str] = None,
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        maintenance_window: typing.Optional["MdbMongodbClusterMaintenanceWindow"] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        timeouts: typing.Optional["MdbMongodbClusterTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster yandex_mdb_mongodb_cluster} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param cluster_config: cluster_config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#cluster_config MdbMongodbCluster#cluster_config}
        :param database: database block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#database MdbMongodbCluster#database}
        :param environment: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#environment MdbMongodbCluster#environment}.
        :param host: host block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#host MdbMongodbCluster#host}
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#name MdbMongodbCluster#name}.
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#network_id MdbMongodbCluster#network_id}.
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#resources MdbMongodbCluster#resources}
        :param user: user block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#user MdbMongodbCluster#user}
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#cluster_id MdbMongodbCluster#cluster_id}.
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#deletion_protection MdbMongodbCluster#deletion_protection}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#description MdbMongodbCluster#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#folder_id MdbMongodbCluster#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#id MdbMongodbCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#labels MdbMongodbCluster#labels}.
        :param maintenance_window: maintenance_window block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#maintenance_window MdbMongodbCluster#maintenance_window}
        :param security_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#security_group_ids MdbMongodbCluster#security_group_ids}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#timeouts MdbMongodbCluster#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = MdbMongodbClusterConfig(
            cluster_config=cluster_config,
            database=database,
            environment=environment,
            host=host,
            name=name,
            network_id=network_id,
            resources=resources,
            user=user,
            cluster_id=cluster_id,
            deletion_protection=deletion_protection,
            description=description,
            folder_id=folder_id,
            id=id,
            labels=labels,
            maintenance_window=maintenance_window,
            security_group_ids=security_group_ids,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putClusterConfig")
    def put_cluster_config(
        self,
        *,
        version: builtins.str,
        access: typing.Optional["MdbMongodbClusterClusterConfigAccess"] = None,
        backup_window_start: typing.Optional["MdbMongodbClusterClusterConfigBackupWindowStart"] = None,
        feature_compatibility_version: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param version: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#version MdbMongodbCluster#version}.
        :param access: access block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#access MdbMongodbCluster#access}
        :param backup_window_start: backup_window_start block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#backup_window_start MdbMongodbCluster#backup_window_start}
        :param feature_compatibility_version: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#feature_compatibility_version MdbMongodbCluster#feature_compatibility_version}.
        '''
        value = MdbMongodbClusterClusterConfig(
            version=version,
            access=access,
            backup_window_start=backup_window_start,
            feature_compatibility_version=feature_compatibility_version,
        )

        return typing.cast(None, jsii.invoke(self, "putClusterConfig", [value]))

    @jsii.member(jsii_name="putDatabase")
    def put_database(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["MdbMongodbClusterDatabase"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putDatabase", [value]))

    @jsii.member(jsii_name="putHost")
    def put_host(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["MdbMongodbClusterHost"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putHost", [value]))

    @jsii.member(jsii_name="putMaintenanceWindow")
    def put_maintenance_window(
        self,
        *,
        type: builtins.str,
        day: typing.Optional[builtins.str] = None,
        hour: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#type MdbMongodbCluster#type}.
        :param day: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#day MdbMongodbCluster#day}.
        :param hour: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#hour MdbMongodbCluster#hour}.
        '''
        value = MdbMongodbClusterMaintenanceWindow(type=type, day=day, hour=hour)

        return typing.cast(None, jsii.invoke(self, "putMaintenanceWindow", [value]))

    @jsii.member(jsii_name="putResources")
    def put_resources(
        self,
        *,
        disk_size: jsii.Number,
        disk_type_id: builtins.str,
        resource_preset_id: builtins.str,
    ) -> None:
        '''
        :param disk_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#disk_size MdbMongodbCluster#disk_size}.
        :param disk_type_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#disk_type_id MdbMongodbCluster#disk_type_id}.
        :param resource_preset_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#resource_preset_id MdbMongodbCluster#resource_preset_id}.
        '''
        value = MdbMongodbClusterResources(
            disk_size=disk_size,
            disk_type_id=disk_type_id,
            resource_preset_id=resource_preset_id,
        )

        return typing.cast(None, jsii.invoke(self, "putResources", [value]))

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#create MdbMongodbCluster#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#delete MdbMongodbCluster#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#update MdbMongodbCluster#update}.
        '''
        value = MdbMongodbClusterTimeouts(create=create, delete=delete, update=update)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="putUser")
    def put_user(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["MdbMongodbClusterUser"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putUser", [value]))

    @jsii.member(jsii_name="resetClusterId")
    def reset_cluster_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetClusterId", []))

    @jsii.member(jsii_name="resetDeletionProtection")
    def reset_deletion_protection(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDeletionProtection", []))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetMaintenanceWindow")
    def reset_maintenance_window(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaintenanceWindow", []))

    @jsii.member(jsii_name="resetSecurityGroupIds")
    def reset_security_group_ids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityGroupIds", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterConfig")
    def cluster_config(self) -> "MdbMongodbClusterClusterConfigOutputReference":
        return typing.cast("MdbMongodbClusterClusterConfigOutputReference", jsii.get(self, "clusterConfig"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="database")
    def database(self) -> "MdbMongodbClusterDatabaseList":
        return typing.cast("MdbMongodbClusterDatabaseList", jsii.get(self, "database"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="health")
    def health(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "health"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="host")
    def host(self) -> "MdbMongodbClusterHostList":
        return typing.cast("MdbMongodbClusterHostList", jsii.get(self, "host"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maintenanceWindow")
    def maintenance_window(self) -> "MdbMongodbClusterMaintenanceWindowOutputReference":
        return typing.cast("MdbMongodbClusterMaintenanceWindowOutputReference", jsii.get(self, "maintenanceWindow"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resources")
    def resources(self) -> "MdbMongodbClusterResourcesOutputReference":
        return typing.cast("MdbMongodbClusterResourcesOutputReference", jsii.get(self, "resources"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sharded")
    def sharded(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "sharded"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "MdbMongodbClusterTimeoutsOutputReference":
        return typing.cast("MdbMongodbClusterTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="user")
    def user(self) -> "MdbMongodbClusterUserList":
        return typing.cast("MdbMongodbClusterUserList", jsii.get(self, "user"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterConfigInput")
    def cluster_config_input(self) -> typing.Optional["MdbMongodbClusterClusterConfig"]:
        return typing.cast(typing.Optional["MdbMongodbClusterClusterConfig"], jsii.get(self, "clusterConfigInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterIdInput")
    def cluster_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "clusterIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databaseInput")
    def database_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbMongodbClusterDatabase"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbMongodbClusterDatabase"]]], jsii.get(self, "databaseInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtectionInput")
    def deletion_protection_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "deletionProtectionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="environmentInput")
    def environment_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "environmentInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostInput")
    def host_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbMongodbClusterHost"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbMongodbClusterHost"]]], jsii.get(self, "hostInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maintenanceWindowInput")
    def maintenance_window_input(
        self,
    ) -> typing.Optional["MdbMongodbClusterMaintenanceWindow"]:
        return typing.cast(typing.Optional["MdbMongodbClusterMaintenanceWindow"], jsii.get(self, "maintenanceWindowInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkIdInput")
    def network_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "networkIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcesInput")
    def resources_input(self) -> typing.Optional["MdbMongodbClusterResources"]:
        return typing.cast(typing.Optional["MdbMongodbClusterResources"], jsii.get(self, "resourcesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIdsInput")
    def security_group_ids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "securityGroupIdsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "MdbMongodbClusterTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "MdbMongodbClusterTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="userInput")
    def user_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbMongodbClusterUser"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbMongodbClusterUser"]]], jsii.get(self, "userInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterId")
    def cluster_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "clusterId"))

    @cluster_id.setter
    def cluster_id(self, value: builtins.str) -> None:
        jsii.set(self, "clusterId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtection")
    def deletion_protection(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "deletionProtection"))

    @deletion_protection.setter
    def deletion_protection(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "deletionProtection", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="environment")
    def environment(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "environment"))

    @environment.setter
    def environment(self, value: builtins.str) -> None:
        jsii.set(self, "environment", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @network_id.setter
    def network_id(self, value: builtins.str) -> None:
        jsii.set(self, "networkId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "securityGroupIds"))

    @security_group_ids.setter
    def security_group_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "securityGroupIds", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbMongodbClusterClusterConfig",
    jsii_struct_bases=[],
    name_mapping={
        "version": "version",
        "access": "access",
        "backup_window_start": "backupWindowStart",
        "feature_compatibility_version": "featureCompatibilityVersion",
    },
)
class MdbMongodbClusterClusterConfig:
    def __init__(
        self,
        *,
        version: builtins.str,
        access: typing.Optional["MdbMongodbClusterClusterConfigAccess"] = None,
        backup_window_start: typing.Optional["MdbMongodbClusterClusterConfigBackupWindowStart"] = None,
        feature_compatibility_version: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param version: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#version MdbMongodbCluster#version}.
        :param access: access block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#access MdbMongodbCluster#access}
        :param backup_window_start: backup_window_start block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#backup_window_start MdbMongodbCluster#backup_window_start}
        :param feature_compatibility_version: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#feature_compatibility_version MdbMongodbCluster#feature_compatibility_version}.
        '''
        if isinstance(access, dict):
            access = MdbMongodbClusterClusterConfigAccess(**access)
        if isinstance(backup_window_start, dict):
            backup_window_start = MdbMongodbClusterClusterConfigBackupWindowStart(**backup_window_start)
        self._values: typing.Dict[str, typing.Any] = {
            "version": version,
        }
        if access is not None:
            self._values["access"] = access
        if backup_window_start is not None:
            self._values["backup_window_start"] = backup_window_start
        if feature_compatibility_version is not None:
            self._values["feature_compatibility_version"] = feature_compatibility_version

    @builtins.property
    def version(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#version MdbMongodbCluster#version}.'''
        result = self._values.get("version")
        assert result is not None, "Required property 'version' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def access(self) -> typing.Optional["MdbMongodbClusterClusterConfigAccess"]:
        '''access block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#access MdbMongodbCluster#access}
        '''
        result = self._values.get("access")
        return typing.cast(typing.Optional["MdbMongodbClusterClusterConfigAccess"], result)

    @builtins.property
    def backup_window_start(
        self,
    ) -> typing.Optional["MdbMongodbClusterClusterConfigBackupWindowStart"]:
        '''backup_window_start block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#backup_window_start MdbMongodbCluster#backup_window_start}
        '''
        result = self._values.get("backup_window_start")
        return typing.cast(typing.Optional["MdbMongodbClusterClusterConfigBackupWindowStart"], result)

    @builtins.property
    def feature_compatibility_version(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#feature_compatibility_version MdbMongodbCluster#feature_compatibility_version}.'''
        result = self._values.get("feature_compatibility_version")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbMongodbClusterClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbMongodbClusterClusterConfigAccess",
    jsii_struct_bases=[],
    name_mapping={},
)
class MdbMongodbClusterClusterConfigAccess:
    def __init__(self) -> None:
        self._values: typing.Dict[str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbMongodbClusterClusterConfigAccess(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbMongodbClusterClusterConfigAccessOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbMongodbClusterClusterConfigAccessOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dataLens")
    def data_lens(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "dataLens"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbMongodbClusterClusterConfigAccess]:
        return typing.cast(typing.Optional[MdbMongodbClusterClusterConfigAccess], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbMongodbClusterClusterConfigAccess],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbMongodbClusterClusterConfigBackupWindowStart",
    jsii_struct_bases=[],
    name_mapping={"hours": "hours", "minutes": "minutes"},
)
class MdbMongodbClusterClusterConfigBackupWindowStart:
    def __init__(
        self,
        *,
        hours: typing.Optional[jsii.Number] = None,
        minutes: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param hours: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#hours MdbMongodbCluster#hours}.
        :param minutes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#minutes MdbMongodbCluster#minutes}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if hours is not None:
            self._values["hours"] = hours
        if minutes is not None:
            self._values["minutes"] = minutes

    @builtins.property
    def hours(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#hours MdbMongodbCluster#hours}.'''
        result = self._values.get("hours")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def minutes(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#minutes MdbMongodbCluster#minutes}.'''
        result = self._values.get("minutes")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbMongodbClusterClusterConfigBackupWindowStart(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbMongodbClusterClusterConfigBackupWindowStartOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbMongodbClusterClusterConfigBackupWindowStartOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetHours")
    def reset_hours(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHours", []))

    @jsii.member(jsii_name="resetMinutes")
    def reset_minutes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMinutes", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hoursInput")
    def hours_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "hoursInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minutesInput")
    def minutes_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "minutesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hours")
    def hours(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "hours"))

    @hours.setter
    def hours(self, value: jsii.Number) -> None:
        jsii.set(self, "hours", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minutes")
    def minutes(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minutes"))

    @minutes.setter
    def minutes(self, value: jsii.Number) -> None:
        jsii.set(self, "minutes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[MdbMongodbClusterClusterConfigBackupWindowStart]:
        return typing.cast(typing.Optional[MdbMongodbClusterClusterConfigBackupWindowStart], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbMongodbClusterClusterConfigBackupWindowStart],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbMongodbClusterClusterConfigOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbMongodbClusterClusterConfigOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putAccess")
    def put_access(self) -> None:
        value = MdbMongodbClusterClusterConfigAccess()

        return typing.cast(None, jsii.invoke(self, "putAccess", [value]))

    @jsii.member(jsii_name="putBackupWindowStart")
    def put_backup_window_start(
        self,
        *,
        hours: typing.Optional[jsii.Number] = None,
        minutes: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param hours: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#hours MdbMongodbCluster#hours}.
        :param minutes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#minutes MdbMongodbCluster#minutes}.
        '''
        value = MdbMongodbClusterClusterConfigBackupWindowStart(
            hours=hours, minutes=minutes
        )

        return typing.cast(None, jsii.invoke(self, "putBackupWindowStart", [value]))

    @jsii.member(jsii_name="resetAccess")
    def reset_access(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAccess", []))

    @jsii.member(jsii_name="resetBackupWindowStart")
    def reset_backup_window_start(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetBackupWindowStart", []))

    @jsii.member(jsii_name="resetFeatureCompatibilityVersion")
    def reset_feature_compatibility_version(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFeatureCompatibilityVersion", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="access")
    def access(self) -> MdbMongodbClusterClusterConfigAccessOutputReference:
        return typing.cast(MdbMongodbClusterClusterConfigAccessOutputReference, jsii.get(self, "access"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backupWindowStart")
    def backup_window_start(
        self,
    ) -> MdbMongodbClusterClusterConfigBackupWindowStartOutputReference:
        return typing.cast(MdbMongodbClusterClusterConfigBackupWindowStartOutputReference, jsii.get(self, "backupWindowStart"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="accessInput")
    def access_input(self) -> typing.Optional[MdbMongodbClusterClusterConfigAccess]:
        return typing.cast(typing.Optional[MdbMongodbClusterClusterConfigAccess], jsii.get(self, "accessInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backupWindowStartInput")
    def backup_window_start_input(
        self,
    ) -> typing.Optional[MdbMongodbClusterClusterConfigBackupWindowStart]:
        return typing.cast(typing.Optional[MdbMongodbClusterClusterConfigBackupWindowStart], jsii.get(self, "backupWindowStartInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="featureCompatibilityVersionInput")
    def feature_compatibility_version_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "featureCompatibilityVersionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="versionInput")
    def version_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "versionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="featureCompatibilityVersion")
    def feature_compatibility_version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "featureCompatibilityVersion"))

    @feature_compatibility_version.setter
    def feature_compatibility_version(self, value: builtins.str) -> None:
        jsii.set(self, "featureCompatibilityVersion", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "version"))

    @version.setter
    def version(self, value: builtins.str) -> None:
        jsii.set(self, "version", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbMongodbClusterClusterConfig]:
        return typing.cast(typing.Optional[MdbMongodbClusterClusterConfig], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbMongodbClusterClusterConfig],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbMongodbClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_config": "clusterConfig",
        "database": "database",
        "environment": "environment",
        "host": "host",
        "name": "name",
        "network_id": "networkId",
        "resources": "resources",
        "user": "user",
        "cluster_id": "clusterId",
        "deletion_protection": "deletionProtection",
        "description": "description",
        "folder_id": "folderId",
        "id": "id",
        "labels": "labels",
        "maintenance_window": "maintenanceWindow",
        "security_group_ids": "securityGroupIds",
        "timeouts": "timeouts",
    },
)
class MdbMongodbClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_config: MdbMongodbClusterClusterConfig,
        database: typing.Union[cdktf.IResolvable, typing.Sequence["MdbMongodbClusterDatabase"]],
        environment: builtins.str,
        host: typing.Union[cdktf.IResolvable, typing.Sequence["MdbMongodbClusterHost"]],
        name: builtins.str,
        network_id: builtins.str,
        resources: "MdbMongodbClusterResources",
        user: typing.Union[cdktf.IResolvable, typing.Sequence["MdbMongodbClusterUser"]],
        cluster_id: typing.Optional[builtins.str] = None,
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        maintenance_window: typing.Optional["MdbMongodbClusterMaintenanceWindow"] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        timeouts: typing.Optional["MdbMongodbClusterTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_config: cluster_config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#cluster_config MdbMongodbCluster#cluster_config}
        :param database: database block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#database MdbMongodbCluster#database}
        :param environment: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#environment MdbMongodbCluster#environment}.
        :param host: host block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#host MdbMongodbCluster#host}
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#name MdbMongodbCluster#name}.
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#network_id MdbMongodbCluster#network_id}.
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#resources MdbMongodbCluster#resources}
        :param user: user block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#user MdbMongodbCluster#user}
        :param cluster_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#cluster_id MdbMongodbCluster#cluster_id}.
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#deletion_protection MdbMongodbCluster#deletion_protection}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#description MdbMongodbCluster#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#folder_id MdbMongodbCluster#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#id MdbMongodbCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#labels MdbMongodbCluster#labels}.
        :param maintenance_window: maintenance_window block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#maintenance_window MdbMongodbCluster#maintenance_window}
        :param security_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#security_group_ids MdbMongodbCluster#security_group_ids}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#timeouts MdbMongodbCluster#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(cluster_config, dict):
            cluster_config = MdbMongodbClusterClusterConfig(**cluster_config)
        if isinstance(resources, dict):
            resources = MdbMongodbClusterResources(**resources)
        if isinstance(maintenance_window, dict):
            maintenance_window = MdbMongodbClusterMaintenanceWindow(**maintenance_window)
        if isinstance(timeouts, dict):
            timeouts = MdbMongodbClusterTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "cluster_config": cluster_config,
            "database": database,
            "environment": environment,
            "host": host,
            "name": name,
            "network_id": network_id,
            "resources": resources,
            "user": user,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if cluster_id is not None:
            self._values["cluster_id"] = cluster_id
        if deletion_protection is not None:
            self._values["deletion_protection"] = deletion_protection
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if maintenance_window is not None:
            self._values["maintenance_window"] = maintenance_window
        if security_group_ids is not None:
            self._values["security_group_ids"] = security_group_ids
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def cluster_config(self) -> MdbMongodbClusterClusterConfig:
        '''cluster_config block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#cluster_config MdbMongodbCluster#cluster_config}
        '''
        result = self._values.get("cluster_config")
        assert result is not None, "Required property 'cluster_config' is missing"
        return typing.cast(MdbMongodbClusterClusterConfig, result)

    @builtins.property
    def database(
        self,
    ) -> typing.Union[cdktf.IResolvable, typing.List["MdbMongodbClusterDatabase"]]:
        '''database block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#database MdbMongodbCluster#database}
        '''
        result = self._values.get("database")
        assert result is not None, "Required property 'database' is missing"
        return typing.cast(typing.Union[cdktf.IResolvable, typing.List["MdbMongodbClusterDatabase"]], result)

    @builtins.property
    def environment(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#environment MdbMongodbCluster#environment}.'''
        result = self._values.get("environment")
        assert result is not None, "Required property 'environment' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def host(
        self,
    ) -> typing.Union[cdktf.IResolvable, typing.List["MdbMongodbClusterHost"]]:
        '''host block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#host MdbMongodbCluster#host}
        '''
        result = self._values.get("host")
        assert result is not None, "Required property 'host' is missing"
        return typing.cast(typing.Union[cdktf.IResolvable, typing.List["MdbMongodbClusterHost"]], result)

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#name MdbMongodbCluster#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def network_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#network_id MdbMongodbCluster#network_id}.'''
        result = self._values.get("network_id")
        assert result is not None, "Required property 'network_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def resources(self) -> "MdbMongodbClusterResources":
        '''resources block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#resources MdbMongodbCluster#resources}
        '''
        result = self._values.get("resources")
        assert result is not None, "Required property 'resources' is missing"
        return typing.cast("MdbMongodbClusterResources", result)

    @builtins.property
    def user(
        self,
    ) -> typing.Union[cdktf.IResolvable, typing.List["MdbMongodbClusterUser"]]:
        '''user block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#user MdbMongodbCluster#user}
        '''
        result = self._values.get("user")
        assert result is not None, "Required property 'user' is missing"
        return typing.cast(typing.Union[cdktf.IResolvable, typing.List["MdbMongodbClusterUser"]], result)

    @builtins.property
    def cluster_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#cluster_id MdbMongodbCluster#cluster_id}.'''
        result = self._values.get("cluster_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def deletion_protection(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#deletion_protection MdbMongodbCluster#deletion_protection}.'''
        result = self._values.get("deletion_protection")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#description MdbMongodbCluster#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#folder_id MdbMongodbCluster#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#id MdbMongodbCluster#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#labels MdbMongodbCluster#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def maintenance_window(
        self,
    ) -> typing.Optional["MdbMongodbClusterMaintenanceWindow"]:
        '''maintenance_window block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#maintenance_window MdbMongodbCluster#maintenance_window}
        '''
        result = self._values.get("maintenance_window")
        return typing.cast(typing.Optional["MdbMongodbClusterMaintenanceWindow"], result)

    @builtins.property
    def security_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#security_group_ids MdbMongodbCluster#security_group_ids}.'''
        result = self._values.get("security_group_ids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["MdbMongodbClusterTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#timeouts MdbMongodbCluster#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["MdbMongodbClusterTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbMongodbClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbMongodbClusterDatabase",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class MdbMongodbClusterDatabase:
    def __init__(self, *, name: builtins.str) -> None:
        '''
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#name MdbMongodbCluster#name}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#name MdbMongodbCluster#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbMongodbClusterDatabase(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbMongodbClusterDatabaseList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbMongodbClusterDatabaseList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "MdbMongodbClusterDatabaseOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbMongodbClusterDatabaseOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbMongodbClusterDatabase]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbMongodbClusterDatabase]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbMongodbClusterDatabase]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbMongodbClusterDatabaseOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbMongodbClusterDatabaseOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbMongodbClusterDatabase]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbMongodbClusterDatabase]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbMongodbClusterDatabase]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbMongodbClusterHost",
    jsii_struct_bases=[],
    name_mapping={
        "subnet_id": "subnetId",
        "zone_id": "zoneId",
        "assign_public_ip": "assignPublicIp",
        "role": "role",
        "shard_name": "shardName",
        "type": "type",
    },
)
class MdbMongodbClusterHost:
    def __init__(
        self,
        *,
        subnet_id: builtins.str,
        zone_id: builtins.str,
        assign_public_ip: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        role: typing.Optional[builtins.str] = None,
        shard_name: typing.Optional[builtins.str] = None,
        type: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param subnet_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#subnet_id MdbMongodbCluster#subnet_id}.
        :param zone_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#zone_id MdbMongodbCluster#zone_id}.
        :param assign_public_ip: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#assign_public_ip MdbMongodbCluster#assign_public_ip}.
        :param role: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#role MdbMongodbCluster#role}.
        :param shard_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#shard_name MdbMongodbCluster#shard_name}.
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#type MdbMongodbCluster#type}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "subnet_id": subnet_id,
            "zone_id": zone_id,
        }
        if assign_public_ip is not None:
            self._values["assign_public_ip"] = assign_public_ip
        if role is not None:
            self._values["role"] = role
        if shard_name is not None:
            self._values["shard_name"] = shard_name
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def subnet_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#subnet_id MdbMongodbCluster#subnet_id}.'''
        result = self._values.get("subnet_id")
        assert result is not None, "Required property 'subnet_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def zone_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#zone_id MdbMongodbCluster#zone_id}.'''
        result = self._values.get("zone_id")
        assert result is not None, "Required property 'zone_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def assign_public_ip(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#assign_public_ip MdbMongodbCluster#assign_public_ip}.'''
        result = self._values.get("assign_public_ip")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def role(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#role MdbMongodbCluster#role}.'''
        result = self._values.get("role")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def shard_name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#shard_name MdbMongodbCluster#shard_name}.'''
        result = self._values.get("shard_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def type(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#type MdbMongodbCluster#type}.'''
        result = self._values.get("type")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbMongodbClusterHost(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbMongodbClusterHostList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbMongodbClusterHostList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "MdbMongodbClusterHostOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbMongodbClusterHostOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbMongodbClusterHost]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbMongodbClusterHost]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbMongodbClusterHost]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbMongodbClusterHostOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbMongodbClusterHostOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetAssignPublicIp")
    def reset_assign_public_ip(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAssignPublicIp", []))

    @jsii.member(jsii_name="resetRole")
    def reset_role(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRole", []))

    @jsii.member(jsii_name="resetShardName")
    def reset_shard_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetShardName", []))

    @jsii.member(jsii_name="resetType")
    def reset_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetType", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="health")
    def health(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "health"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIpInput")
    def assign_public_ip_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "assignPublicIpInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="roleInput")
    def role_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "roleInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="shardNameInput")
    def shard_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "shardNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIdInput")
    def subnet_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "subnetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="typeInput")
    def type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "typeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneIdInput")
    def zone_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "zoneIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIp")
    def assign_public_ip(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "assignPublicIp"))

    @assign_public_ip.setter
    def assign_public_ip(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "assignPublicIp", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="role")
    def role(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "role"))

    @role.setter
    def role(self, value: builtins.str) -> None:
        jsii.set(self, "role", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="shardName")
    def shard_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "shardName"))

    @shard_name.setter
    def shard_name(self, value: builtins.str) -> None:
        jsii.set(self, "shardName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @subnet_id.setter
    def subnet_id(self, value: builtins.str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @type.setter
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneId")
    def zone_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zoneId"))

    @zone_id.setter
    def zone_id(self, value: builtins.str) -> None:
        jsii.set(self, "zoneId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbMongodbClusterHost]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbMongodbClusterHost]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbMongodbClusterHost]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbMongodbClusterMaintenanceWindow",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "day": "day", "hour": "hour"},
)
class MdbMongodbClusterMaintenanceWindow:
    def __init__(
        self,
        *,
        type: builtins.str,
        day: typing.Optional[builtins.str] = None,
        hour: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#type MdbMongodbCluster#type}.
        :param day: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#day MdbMongodbCluster#day}.
        :param hour: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#hour MdbMongodbCluster#hour}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }
        if day is not None:
            self._values["day"] = day
        if hour is not None:
            self._values["hour"] = hour

    @builtins.property
    def type(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#type MdbMongodbCluster#type}.'''
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def day(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#day MdbMongodbCluster#day}.'''
        result = self._values.get("day")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def hour(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#hour MdbMongodbCluster#hour}.'''
        result = self._values.get("hour")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbMongodbClusterMaintenanceWindow(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbMongodbClusterMaintenanceWindowOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbMongodbClusterMaintenanceWindowOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetDay")
    def reset_day(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDay", []))

    @jsii.member(jsii_name="resetHour")
    def reset_hour(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHour", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dayInput")
    def day_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dayInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hourInput")
    def hour_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "hourInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="typeInput")
    def type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "typeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="day")
    def day(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "day"))

    @day.setter
    def day(self, value: builtins.str) -> None:
        jsii.set(self, "day", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hour")
    def hour(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "hour"))

    @hour.setter
    def hour(self, value: jsii.Number) -> None:
        jsii.set(self, "hour", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @type.setter
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbMongodbClusterMaintenanceWindow]:
        return typing.cast(typing.Optional[MdbMongodbClusterMaintenanceWindow], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbMongodbClusterMaintenanceWindow],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbMongodbClusterResources",
    jsii_struct_bases=[],
    name_mapping={
        "disk_size": "diskSize",
        "disk_type_id": "diskTypeId",
        "resource_preset_id": "resourcePresetId",
    },
)
class MdbMongodbClusterResources:
    def __init__(
        self,
        *,
        disk_size: jsii.Number,
        disk_type_id: builtins.str,
        resource_preset_id: builtins.str,
    ) -> None:
        '''
        :param disk_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#disk_size MdbMongodbCluster#disk_size}.
        :param disk_type_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#disk_type_id MdbMongodbCluster#disk_type_id}.
        :param resource_preset_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#resource_preset_id MdbMongodbCluster#resource_preset_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "disk_size": disk_size,
            "disk_type_id": disk_type_id,
            "resource_preset_id": resource_preset_id,
        }

    @builtins.property
    def disk_size(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#disk_size MdbMongodbCluster#disk_size}.'''
        result = self._values.get("disk_size")
        assert result is not None, "Required property 'disk_size' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def disk_type_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#disk_type_id MdbMongodbCluster#disk_type_id}.'''
        result = self._values.get("disk_type_id")
        assert result is not None, "Required property 'disk_type_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def resource_preset_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#resource_preset_id MdbMongodbCluster#resource_preset_id}.'''
        result = self._values.get("resource_preset_id")
        assert result is not None, "Required property 'resource_preset_id' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbMongodbClusterResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbMongodbClusterResourcesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbMongodbClusterResourcesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSizeInput")
    def disk_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "diskSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeIdInput")
    def disk_type_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "diskTypeIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetIdInput")
    def resource_preset_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourcePresetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSize")
    def disk_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "diskSize"))

    @disk_size.setter
    def disk_size(self, value: jsii.Number) -> None:
        jsii.set(self, "diskSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeId")
    def disk_type_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskTypeId"))

    @disk_type_id.setter
    def disk_type_id(self, value: builtins.str) -> None:
        jsii.set(self, "diskTypeId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetId")
    def resource_preset_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourcePresetId"))

    @resource_preset_id.setter
    def resource_preset_id(self, value: builtins.str) -> None:
        jsii.set(self, "resourcePresetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbMongodbClusterResources]:
        return typing.cast(typing.Optional[MdbMongodbClusterResources], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbMongodbClusterResources],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbMongodbClusterTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class MdbMongodbClusterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#create MdbMongodbCluster#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#delete MdbMongodbCluster#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#update MdbMongodbCluster#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#create MdbMongodbCluster#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#delete MdbMongodbCluster#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#update MdbMongodbCluster#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbMongodbClusterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbMongodbClusterTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbMongodbClusterTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbMongodbClusterTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbMongodbClusterTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbMongodbClusterTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbMongodbClusterUser",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "password": "password", "permission": "permission"},
)
class MdbMongodbClusterUser:
    def __init__(
        self,
        *,
        name: builtins.str,
        password: builtins.str,
        permission: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbMongodbClusterUserPermission"]]] = None,
    ) -> None:
        '''
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#name MdbMongodbCluster#name}.
        :param password: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#password MdbMongodbCluster#password}.
        :param permission: permission block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#permission MdbMongodbCluster#permission}
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "password": password,
        }
        if permission is not None:
            self._values["permission"] = permission

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#name MdbMongodbCluster#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def password(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#password MdbMongodbCluster#password}.'''
        result = self._values.get("password")
        assert result is not None, "Required property 'password' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def permission(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbMongodbClusterUserPermission"]]]:
        '''permission block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#permission MdbMongodbCluster#permission}
        '''
        result = self._values.get("permission")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbMongodbClusterUserPermission"]]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbMongodbClusterUser(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbMongodbClusterUserList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbMongodbClusterUserList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "MdbMongodbClusterUserOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbMongodbClusterUserOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbMongodbClusterUser]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbMongodbClusterUser]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbMongodbClusterUser]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbMongodbClusterUserOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbMongodbClusterUserOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putPermission")
    def put_permission(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["MdbMongodbClusterUserPermission"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putPermission", [value]))

    @jsii.member(jsii_name="resetPermission")
    def reset_permission(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPermission", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="permission")
    def permission(self) -> "MdbMongodbClusterUserPermissionList":
        return typing.cast("MdbMongodbClusterUserPermissionList", jsii.get(self, "permission"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="passwordInput")
    def password_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "passwordInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="permissionInput")
    def permission_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbMongodbClusterUserPermission"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbMongodbClusterUserPermission"]]], jsii.get(self, "permissionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="password")
    def password(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "password"))

    @password.setter
    def password(self, value: builtins.str) -> None:
        jsii.set(self, "password", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbMongodbClusterUser]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbMongodbClusterUser]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbMongodbClusterUser]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbMongodbClusterUserPermission",
    jsii_struct_bases=[],
    name_mapping={"database_name": "databaseName", "roles": "roles"},
)
class MdbMongodbClusterUserPermission:
    def __init__(
        self,
        *,
        database_name: builtins.str,
        roles: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param database_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#database_name MdbMongodbCluster#database_name}.
        :param roles: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#roles MdbMongodbCluster#roles}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "database_name": database_name,
        }
        if roles is not None:
            self._values["roles"] = roles

    @builtins.property
    def database_name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#database_name MdbMongodbCluster#database_name}.'''
        result = self._values.get("database_name")
        assert result is not None, "Required property 'database_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def roles(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mongodb_cluster#roles MdbMongodbCluster#roles}.'''
        result = self._values.get("roles")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbMongodbClusterUserPermission(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbMongodbClusterUserPermissionList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbMongodbClusterUserPermissionList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "MdbMongodbClusterUserPermissionOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbMongodbClusterUserPermissionOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbMongodbClusterUserPermission]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbMongodbClusterUserPermission]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbMongodbClusterUserPermission]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbMongodbClusterUserPermissionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbMongodbClusterUserPermissionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetRoles")
    def reset_roles(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRoles", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databaseNameInput")
    def database_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "databaseNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="rolesInput")
    def roles_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "rolesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databaseName")
    def database_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "databaseName"))

    @database_name.setter
    def database_name(self, value: builtins.str) -> None:
        jsii.set(self, "databaseName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="roles")
    def roles(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "roles"))

    @roles.setter
    def roles(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "roles", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbMongodbClusterUserPermission]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbMongodbClusterUserPermission]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbMongodbClusterUserPermission]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbMysqlCluster(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbMysqlCluster",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster yandex_mdb_mysql_cluster}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        database: typing.Union[cdktf.IResolvable, typing.Sequence["MdbMysqlClusterDatabase"]],
        environment: builtins.str,
        host: typing.Union[cdktf.IResolvable, typing.Sequence["MdbMysqlClusterHost"]],
        name: builtins.str,
        network_id: builtins.str,
        resources: "MdbMysqlClusterResources",
        user: typing.Union[cdktf.IResolvable, typing.Sequence["MdbMysqlClusterUser"]],
        version: builtins.str,
        access: typing.Optional["MdbMysqlClusterAccess"] = None,
        allow_regeneration_host: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        backup_window_start: typing.Optional["MdbMysqlClusterBackupWindowStart"] = None,
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        maintenance_window: typing.Optional["MdbMysqlClusterMaintenanceWindow"] = None,
        mysql_config: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        restore: typing.Optional["MdbMysqlClusterRestore"] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        timeouts: typing.Optional["MdbMysqlClusterTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster yandex_mdb_mysql_cluster} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param database: database block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#database MdbMysqlCluster#database}
        :param environment: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#environment MdbMysqlCluster#environment}.
        :param host: host block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#host MdbMysqlCluster#host}
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#name MdbMysqlCluster#name}.
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#network_id MdbMysqlCluster#network_id}.
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#resources MdbMysqlCluster#resources}
        :param user: user block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#user MdbMysqlCluster#user}
        :param version: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#version MdbMysqlCluster#version}.
        :param access: access block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#access MdbMysqlCluster#access}
        :param allow_regeneration_host: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#allow_regeneration_host MdbMysqlCluster#allow_regeneration_host}.
        :param backup_window_start: backup_window_start block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#backup_window_start MdbMysqlCluster#backup_window_start}
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#deletion_protection MdbMysqlCluster#deletion_protection}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#description MdbMysqlCluster#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#folder_id MdbMysqlCluster#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#id MdbMysqlCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#labels MdbMysqlCluster#labels}.
        :param maintenance_window: maintenance_window block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#maintenance_window MdbMysqlCluster#maintenance_window}
        :param mysql_config: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#mysql_config MdbMysqlCluster#mysql_config}.
        :param restore: restore block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#restore MdbMysqlCluster#restore}
        :param security_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#security_group_ids MdbMysqlCluster#security_group_ids}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#timeouts MdbMysqlCluster#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = MdbMysqlClusterConfig(
            database=database,
            environment=environment,
            host=host,
            name=name,
            network_id=network_id,
            resources=resources,
            user=user,
            version=version,
            access=access,
            allow_regeneration_host=allow_regeneration_host,
            backup_window_start=backup_window_start,
            deletion_protection=deletion_protection,
            description=description,
            folder_id=folder_id,
            id=id,
            labels=labels,
            maintenance_window=maintenance_window,
            mysql_config=mysql_config,
            restore=restore,
            security_group_ids=security_group_ids,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putAccess")
    def put_access(
        self,
        *,
        data_lens: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        web_sql: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param data_lens: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#data_lens MdbMysqlCluster#data_lens}.
        :param web_sql: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#web_sql MdbMysqlCluster#web_sql}.
        '''
        value = MdbMysqlClusterAccess(data_lens=data_lens, web_sql=web_sql)

        return typing.cast(None, jsii.invoke(self, "putAccess", [value]))

    @jsii.member(jsii_name="putBackupWindowStart")
    def put_backup_window_start(
        self,
        *,
        hours: typing.Optional[jsii.Number] = None,
        minutes: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param hours: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#hours MdbMysqlCluster#hours}.
        :param minutes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#minutes MdbMysqlCluster#minutes}.
        '''
        value = MdbMysqlClusterBackupWindowStart(hours=hours, minutes=minutes)

        return typing.cast(None, jsii.invoke(self, "putBackupWindowStart", [value]))

    @jsii.member(jsii_name="putDatabase")
    def put_database(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["MdbMysqlClusterDatabase"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putDatabase", [value]))

    @jsii.member(jsii_name="putHost")
    def put_host(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["MdbMysqlClusterHost"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putHost", [value]))

    @jsii.member(jsii_name="putMaintenanceWindow")
    def put_maintenance_window(
        self,
        *,
        type: builtins.str,
        day: typing.Optional[builtins.str] = None,
        hour: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#type MdbMysqlCluster#type}.
        :param day: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#day MdbMysqlCluster#day}.
        :param hour: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#hour MdbMysqlCluster#hour}.
        '''
        value = MdbMysqlClusterMaintenanceWindow(type=type, day=day, hour=hour)

        return typing.cast(None, jsii.invoke(self, "putMaintenanceWindow", [value]))

    @jsii.member(jsii_name="putResources")
    def put_resources(
        self,
        *,
        disk_size: jsii.Number,
        disk_type_id: builtins.str,
        resource_preset_id: builtins.str,
    ) -> None:
        '''
        :param disk_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#disk_size MdbMysqlCluster#disk_size}.
        :param disk_type_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#disk_type_id MdbMysqlCluster#disk_type_id}.
        :param resource_preset_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#resource_preset_id MdbMysqlCluster#resource_preset_id}.
        '''
        value = MdbMysqlClusterResources(
            disk_size=disk_size,
            disk_type_id=disk_type_id,
            resource_preset_id=resource_preset_id,
        )

        return typing.cast(None, jsii.invoke(self, "putResources", [value]))

    @jsii.member(jsii_name="putRestore")
    def put_restore(
        self,
        *,
        backup_id: builtins.str,
        time: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param backup_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#backup_id MdbMysqlCluster#backup_id}.
        :param time: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#time MdbMysqlCluster#time}.
        '''
        value = MdbMysqlClusterRestore(backup_id=backup_id, time=time)

        return typing.cast(None, jsii.invoke(self, "putRestore", [value]))

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#create MdbMysqlCluster#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#delete MdbMysqlCluster#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#update MdbMysqlCluster#update}.
        '''
        value = MdbMysqlClusterTimeouts(create=create, delete=delete, update=update)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="putUser")
    def put_user(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["MdbMysqlClusterUser"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putUser", [value]))

    @jsii.member(jsii_name="resetAccess")
    def reset_access(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAccess", []))

    @jsii.member(jsii_name="resetAllowRegenerationHost")
    def reset_allow_regeneration_host(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAllowRegenerationHost", []))

    @jsii.member(jsii_name="resetBackupWindowStart")
    def reset_backup_window_start(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetBackupWindowStart", []))

    @jsii.member(jsii_name="resetDeletionProtection")
    def reset_deletion_protection(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDeletionProtection", []))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetMaintenanceWindow")
    def reset_maintenance_window(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaintenanceWindow", []))

    @jsii.member(jsii_name="resetMysqlConfig")
    def reset_mysql_config(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMysqlConfig", []))

    @jsii.member(jsii_name="resetRestore")
    def reset_restore(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRestore", []))

    @jsii.member(jsii_name="resetSecurityGroupIds")
    def reset_security_group_ids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityGroupIds", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="access")
    def access(self) -> "MdbMysqlClusterAccessOutputReference":
        return typing.cast("MdbMysqlClusterAccessOutputReference", jsii.get(self, "access"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backupWindowStart")
    def backup_window_start(self) -> "MdbMysqlClusterBackupWindowStartOutputReference":
        return typing.cast("MdbMysqlClusterBackupWindowStartOutputReference", jsii.get(self, "backupWindowStart"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="database")
    def database(self) -> "MdbMysqlClusterDatabaseList":
        return typing.cast("MdbMysqlClusterDatabaseList", jsii.get(self, "database"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="health")
    def health(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "health"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="host")
    def host(self) -> "MdbMysqlClusterHostList":
        return typing.cast("MdbMysqlClusterHostList", jsii.get(self, "host"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maintenanceWindow")
    def maintenance_window(self) -> "MdbMysqlClusterMaintenanceWindowOutputReference":
        return typing.cast("MdbMysqlClusterMaintenanceWindowOutputReference", jsii.get(self, "maintenanceWindow"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resources")
    def resources(self) -> "MdbMysqlClusterResourcesOutputReference":
        return typing.cast("MdbMysqlClusterResourcesOutputReference", jsii.get(self, "resources"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="restore")
    def restore(self) -> "MdbMysqlClusterRestoreOutputReference":
        return typing.cast("MdbMysqlClusterRestoreOutputReference", jsii.get(self, "restore"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "MdbMysqlClusterTimeoutsOutputReference":
        return typing.cast("MdbMysqlClusterTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="user")
    def user(self) -> "MdbMysqlClusterUserList":
        return typing.cast("MdbMysqlClusterUserList", jsii.get(self, "user"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="accessInput")
    def access_input(self) -> typing.Optional["MdbMysqlClusterAccess"]:
        return typing.cast(typing.Optional["MdbMysqlClusterAccess"], jsii.get(self, "accessInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allowRegenerationHostInput")
    def allow_regeneration_host_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "allowRegenerationHostInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backupWindowStartInput")
    def backup_window_start_input(
        self,
    ) -> typing.Optional["MdbMysqlClusterBackupWindowStart"]:
        return typing.cast(typing.Optional["MdbMysqlClusterBackupWindowStart"], jsii.get(self, "backupWindowStartInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databaseInput")
    def database_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbMysqlClusterDatabase"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbMysqlClusterDatabase"]]], jsii.get(self, "databaseInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtectionInput")
    def deletion_protection_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "deletionProtectionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="environmentInput")
    def environment_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "environmentInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostInput")
    def host_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbMysqlClusterHost"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbMysqlClusterHost"]]], jsii.get(self, "hostInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maintenanceWindowInput")
    def maintenance_window_input(
        self,
    ) -> typing.Optional["MdbMysqlClusterMaintenanceWindow"]:
        return typing.cast(typing.Optional["MdbMysqlClusterMaintenanceWindow"], jsii.get(self, "maintenanceWindowInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mysqlConfigInput")
    def mysql_config_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "mysqlConfigInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkIdInput")
    def network_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "networkIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcesInput")
    def resources_input(self) -> typing.Optional["MdbMysqlClusterResources"]:
        return typing.cast(typing.Optional["MdbMysqlClusterResources"], jsii.get(self, "resourcesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="restoreInput")
    def restore_input(self) -> typing.Optional["MdbMysqlClusterRestore"]:
        return typing.cast(typing.Optional["MdbMysqlClusterRestore"], jsii.get(self, "restoreInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIdsInput")
    def security_group_ids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "securityGroupIdsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "MdbMysqlClusterTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "MdbMysqlClusterTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="userInput")
    def user_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbMysqlClusterUser"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbMysqlClusterUser"]]], jsii.get(self, "userInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="versionInput")
    def version_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "versionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allowRegenerationHost")
    def allow_regeneration_host(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "allowRegenerationHost"))

    @allow_regeneration_host.setter
    def allow_regeneration_host(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "allowRegenerationHost", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtection")
    def deletion_protection(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "deletionProtection"))

    @deletion_protection.setter
    def deletion_protection(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "deletionProtection", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="environment")
    def environment(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "environment"))

    @environment.setter
    def environment(self, value: builtins.str) -> None:
        jsii.set(self, "environment", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mysqlConfig")
    def mysql_config(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "mysqlConfig"))

    @mysql_config.setter
    def mysql_config(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "mysqlConfig", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @network_id.setter
    def network_id(self, value: builtins.str) -> None:
        jsii.set(self, "networkId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "securityGroupIds"))

    @security_group_ids.setter
    def security_group_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "securityGroupIds", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "version"))

    @version.setter
    def version(self, value: builtins.str) -> None:
        jsii.set(self, "version", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbMysqlClusterAccess",
    jsii_struct_bases=[],
    name_mapping={"data_lens": "dataLens", "web_sql": "webSql"},
)
class MdbMysqlClusterAccess:
    def __init__(
        self,
        *,
        data_lens: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        web_sql: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param data_lens: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#data_lens MdbMysqlCluster#data_lens}.
        :param web_sql: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#web_sql MdbMysqlCluster#web_sql}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if data_lens is not None:
            self._values["data_lens"] = data_lens
        if web_sql is not None:
            self._values["web_sql"] = web_sql

    @builtins.property
    def data_lens(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#data_lens MdbMysqlCluster#data_lens}.'''
        result = self._values.get("data_lens")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def web_sql(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#web_sql MdbMysqlCluster#web_sql}.'''
        result = self._values.get("web_sql")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbMysqlClusterAccess(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbMysqlClusterAccessOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbMysqlClusterAccessOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetDataLens")
    def reset_data_lens(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDataLens", []))

    @jsii.member(jsii_name="resetWebSql")
    def reset_web_sql(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetWebSql", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dataLensInput")
    def data_lens_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "dataLensInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="webSqlInput")
    def web_sql_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "webSqlInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dataLens")
    def data_lens(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "dataLens"))

    @data_lens.setter
    def data_lens(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "dataLens", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="webSql")
    def web_sql(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "webSql"))

    @web_sql.setter
    def web_sql(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "webSql", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbMysqlClusterAccess]:
        return typing.cast(typing.Optional[MdbMysqlClusterAccess], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(self, value: typing.Optional[MdbMysqlClusterAccess]) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbMysqlClusterBackupWindowStart",
    jsii_struct_bases=[],
    name_mapping={"hours": "hours", "minutes": "minutes"},
)
class MdbMysqlClusterBackupWindowStart:
    def __init__(
        self,
        *,
        hours: typing.Optional[jsii.Number] = None,
        minutes: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param hours: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#hours MdbMysqlCluster#hours}.
        :param minutes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#minutes MdbMysqlCluster#minutes}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if hours is not None:
            self._values["hours"] = hours
        if minutes is not None:
            self._values["minutes"] = minutes

    @builtins.property
    def hours(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#hours MdbMysqlCluster#hours}.'''
        result = self._values.get("hours")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def minutes(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#minutes MdbMysqlCluster#minutes}.'''
        result = self._values.get("minutes")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbMysqlClusterBackupWindowStart(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbMysqlClusterBackupWindowStartOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbMysqlClusterBackupWindowStartOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetHours")
    def reset_hours(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHours", []))

    @jsii.member(jsii_name="resetMinutes")
    def reset_minutes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMinutes", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hoursInput")
    def hours_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "hoursInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minutesInput")
    def minutes_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "minutesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hours")
    def hours(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "hours"))

    @hours.setter
    def hours(self, value: jsii.Number) -> None:
        jsii.set(self, "hours", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minutes")
    def minutes(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minutes"))

    @minutes.setter
    def minutes(self, value: jsii.Number) -> None:
        jsii.set(self, "minutes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbMysqlClusterBackupWindowStart]:
        return typing.cast(typing.Optional[MdbMysqlClusterBackupWindowStart], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbMysqlClusterBackupWindowStart],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbMysqlClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "database": "database",
        "environment": "environment",
        "host": "host",
        "name": "name",
        "network_id": "networkId",
        "resources": "resources",
        "user": "user",
        "version": "version",
        "access": "access",
        "allow_regeneration_host": "allowRegenerationHost",
        "backup_window_start": "backupWindowStart",
        "deletion_protection": "deletionProtection",
        "description": "description",
        "folder_id": "folderId",
        "id": "id",
        "labels": "labels",
        "maintenance_window": "maintenanceWindow",
        "mysql_config": "mysqlConfig",
        "restore": "restore",
        "security_group_ids": "securityGroupIds",
        "timeouts": "timeouts",
    },
)
class MdbMysqlClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        database: typing.Union[cdktf.IResolvable, typing.Sequence["MdbMysqlClusterDatabase"]],
        environment: builtins.str,
        host: typing.Union[cdktf.IResolvable, typing.Sequence["MdbMysqlClusterHost"]],
        name: builtins.str,
        network_id: builtins.str,
        resources: "MdbMysqlClusterResources",
        user: typing.Union[cdktf.IResolvable, typing.Sequence["MdbMysqlClusterUser"]],
        version: builtins.str,
        access: typing.Optional[MdbMysqlClusterAccess] = None,
        allow_regeneration_host: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        backup_window_start: typing.Optional[MdbMysqlClusterBackupWindowStart] = None,
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        maintenance_window: typing.Optional["MdbMysqlClusterMaintenanceWindow"] = None,
        mysql_config: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        restore: typing.Optional["MdbMysqlClusterRestore"] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        timeouts: typing.Optional["MdbMysqlClusterTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param database: database block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#database MdbMysqlCluster#database}
        :param environment: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#environment MdbMysqlCluster#environment}.
        :param host: host block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#host MdbMysqlCluster#host}
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#name MdbMysqlCluster#name}.
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#network_id MdbMysqlCluster#network_id}.
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#resources MdbMysqlCluster#resources}
        :param user: user block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#user MdbMysqlCluster#user}
        :param version: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#version MdbMysqlCluster#version}.
        :param access: access block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#access MdbMysqlCluster#access}
        :param allow_regeneration_host: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#allow_regeneration_host MdbMysqlCluster#allow_regeneration_host}.
        :param backup_window_start: backup_window_start block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#backup_window_start MdbMysqlCluster#backup_window_start}
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#deletion_protection MdbMysqlCluster#deletion_protection}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#description MdbMysqlCluster#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#folder_id MdbMysqlCluster#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#id MdbMysqlCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#labels MdbMysqlCluster#labels}.
        :param maintenance_window: maintenance_window block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#maintenance_window MdbMysqlCluster#maintenance_window}
        :param mysql_config: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#mysql_config MdbMysqlCluster#mysql_config}.
        :param restore: restore block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#restore MdbMysqlCluster#restore}
        :param security_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#security_group_ids MdbMysqlCluster#security_group_ids}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#timeouts MdbMysqlCluster#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(resources, dict):
            resources = MdbMysqlClusterResources(**resources)
        if isinstance(access, dict):
            access = MdbMysqlClusterAccess(**access)
        if isinstance(backup_window_start, dict):
            backup_window_start = MdbMysqlClusterBackupWindowStart(**backup_window_start)
        if isinstance(maintenance_window, dict):
            maintenance_window = MdbMysqlClusterMaintenanceWindow(**maintenance_window)
        if isinstance(restore, dict):
            restore = MdbMysqlClusterRestore(**restore)
        if isinstance(timeouts, dict):
            timeouts = MdbMysqlClusterTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "database": database,
            "environment": environment,
            "host": host,
            "name": name,
            "network_id": network_id,
            "resources": resources,
            "user": user,
            "version": version,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if access is not None:
            self._values["access"] = access
        if allow_regeneration_host is not None:
            self._values["allow_regeneration_host"] = allow_regeneration_host
        if backup_window_start is not None:
            self._values["backup_window_start"] = backup_window_start
        if deletion_protection is not None:
            self._values["deletion_protection"] = deletion_protection
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if maintenance_window is not None:
            self._values["maintenance_window"] = maintenance_window
        if mysql_config is not None:
            self._values["mysql_config"] = mysql_config
        if restore is not None:
            self._values["restore"] = restore
        if security_group_ids is not None:
            self._values["security_group_ids"] = security_group_ids
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def database(
        self,
    ) -> typing.Union[cdktf.IResolvable, typing.List["MdbMysqlClusterDatabase"]]:
        '''database block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#database MdbMysqlCluster#database}
        '''
        result = self._values.get("database")
        assert result is not None, "Required property 'database' is missing"
        return typing.cast(typing.Union[cdktf.IResolvable, typing.List["MdbMysqlClusterDatabase"]], result)

    @builtins.property
    def environment(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#environment MdbMysqlCluster#environment}.'''
        result = self._values.get("environment")
        assert result is not None, "Required property 'environment' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def host(
        self,
    ) -> typing.Union[cdktf.IResolvable, typing.List["MdbMysqlClusterHost"]]:
        '''host block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#host MdbMysqlCluster#host}
        '''
        result = self._values.get("host")
        assert result is not None, "Required property 'host' is missing"
        return typing.cast(typing.Union[cdktf.IResolvable, typing.List["MdbMysqlClusterHost"]], result)

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#name MdbMysqlCluster#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def network_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#network_id MdbMysqlCluster#network_id}.'''
        result = self._values.get("network_id")
        assert result is not None, "Required property 'network_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def resources(self) -> "MdbMysqlClusterResources":
        '''resources block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#resources MdbMysqlCluster#resources}
        '''
        result = self._values.get("resources")
        assert result is not None, "Required property 'resources' is missing"
        return typing.cast("MdbMysqlClusterResources", result)

    @builtins.property
    def user(
        self,
    ) -> typing.Union[cdktf.IResolvable, typing.List["MdbMysqlClusterUser"]]:
        '''user block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#user MdbMysqlCluster#user}
        '''
        result = self._values.get("user")
        assert result is not None, "Required property 'user' is missing"
        return typing.cast(typing.Union[cdktf.IResolvable, typing.List["MdbMysqlClusterUser"]], result)

    @builtins.property
    def version(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#version MdbMysqlCluster#version}.'''
        result = self._values.get("version")
        assert result is not None, "Required property 'version' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def access(self) -> typing.Optional[MdbMysqlClusterAccess]:
        '''access block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#access MdbMysqlCluster#access}
        '''
        result = self._values.get("access")
        return typing.cast(typing.Optional[MdbMysqlClusterAccess], result)

    @builtins.property
    def allow_regeneration_host(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#allow_regeneration_host MdbMysqlCluster#allow_regeneration_host}.'''
        result = self._values.get("allow_regeneration_host")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def backup_window_start(self) -> typing.Optional[MdbMysqlClusterBackupWindowStart]:
        '''backup_window_start block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#backup_window_start MdbMysqlCluster#backup_window_start}
        '''
        result = self._values.get("backup_window_start")
        return typing.cast(typing.Optional[MdbMysqlClusterBackupWindowStart], result)

    @builtins.property
    def deletion_protection(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#deletion_protection MdbMysqlCluster#deletion_protection}.'''
        result = self._values.get("deletion_protection")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#description MdbMysqlCluster#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#folder_id MdbMysqlCluster#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#id MdbMysqlCluster#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#labels MdbMysqlCluster#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def maintenance_window(self) -> typing.Optional["MdbMysqlClusterMaintenanceWindow"]:
        '''maintenance_window block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#maintenance_window MdbMysqlCluster#maintenance_window}
        '''
        result = self._values.get("maintenance_window")
        return typing.cast(typing.Optional["MdbMysqlClusterMaintenanceWindow"], result)

    @builtins.property
    def mysql_config(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#mysql_config MdbMysqlCluster#mysql_config}.'''
        result = self._values.get("mysql_config")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def restore(self) -> typing.Optional["MdbMysqlClusterRestore"]:
        '''restore block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#restore MdbMysqlCluster#restore}
        '''
        result = self._values.get("restore")
        return typing.cast(typing.Optional["MdbMysqlClusterRestore"], result)

    @builtins.property
    def security_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#security_group_ids MdbMysqlCluster#security_group_ids}.'''
        result = self._values.get("security_group_ids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["MdbMysqlClusterTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#timeouts MdbMysqlCluster#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["MdbMysqlClusterTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbMysqlClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbMysqlClusterDatabase",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class MdbMysqlClusterDatabase:
    def __init__(self, *, name: builtins.str) -> None:
        '''
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#name MdbMysqlCluster#name}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#name MdbMysqlCluster#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbMysqlClusterDatabase(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbMysqlClusterDatabaseList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbMysqlClusterDatabaseList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "MdbMysqlClusterDatabaseOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbMysqlClusterDatabaseOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbMysqlClusterDatabase]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbMysqlClusterDatabase]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbMysqlClusterDatabase]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbMysqlClusterDatabaseOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbMysqlClusterDatabaseOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbMysqlClusterDatabase]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbMysqlClusterDatabase]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbMysqlClusterDatabase]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbMysqlClusterHost",
    jsii_struct_bases=[],
    name_mapping={
        "zone": "zone",
        "assign_public_ip": "assignPublicIp",
        "backup_priority": "backupPriority",
        "name": "name",
        "priority": "priority",
        "replication_source_name": "replicationSourceName",
        "subnet_id": "subnetId",
    },
)
class MdbMysqlClusterHost:
    def __init__(
        self,
        *,
        zone: builtins.str,
        assign_public_ip: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        backup_priority: typing.Optional[jsii.Number] = None,
        name: typing.Optional[builtins.str] = None,
        priority: typing.Optional[jsii.Number] = None,
        replication_source_name: typing.Optional[builtins.str] = None,
        subnet_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param zone: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#zone MdbMysqlCluster#zone}.
        :param assign_public_ip: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#assign_public_ip MdbMysqlCluster#assign_public_ip}.
        :param backup_priority: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#backup_priority MdbMysqlCluster#backup_priority}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#name MdbMysqlCluster#name}.
        :param priority: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#priority MdbMysqlCluster#priority}.
        :param replication_source_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#replication_source_name MdbMysqlCluster#replication_source_name}.
        :param subnet_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#subnet_id MdbMysqlCluster#subnet_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "zone": zone,
        }
        if assign_public_ip is not None:
            self._values["assign_public_ip"] = assign_public_ip
        if backup_priority is not None:
            self._values["backup_priority"] = backup_priority
        if name is not None:
            self._values["name"] = name
        if priority is not None:
            self._values["priority"] = priority
        if replication_source_name is not None:
            self._values["replication_source_name"] = replication_source_name
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id

    @builtins.property
    def zone(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#zone MdbMysqlCluster#zone}.'''
        result = self._values.get("zone")
        assert result is not None, "Required property 'zone' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def assign_public_ip(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#assign_public_ip MdbMysqlCluster#assign_public_ip}.'''
        result = self._values.get("assign_public_ip")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def backup_priority(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#backup_priority MdbMysqlCluster#backup_priority}.'''
        result = self._values.get("backup_priority")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#name MdbMysqlCluster#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def priority(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#priority MdbMysqlCluster#priority}.'''
        result = self._values.get("priority")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def replication_source_name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#replication_source_name MdbMysqlCluster#replication_source_name}.'''
        result = self._values.get("replication_source_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#subnet_id MdbMysqlCluster#subnet_id}.'''
        result = self._values.get("subnet_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbMysqlClusterHost(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbMysqlClusterHostList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbMysqlClusterHostList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "MdbMysqlClusterHostOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbMysqlClusterHostOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbMysqlClusterHost]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbMysqlClusterHost]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbMysqlClusterHost]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbMysqlClusterHostOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbMysqlClusterHostOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetAssignPublicIp")
    def reset_assign_public_ip(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAssignPublicIp", []))

    @jsii.member(jsii_name="resetBackupPriority")
    def reset_backup_priority(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetBackupPriority", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetPriority")
    def reset_priority(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPriority", []))

    @jsii.member(jsii_name="resetReplicationSourceName")
    def reset_replication_source_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetReplicationSourceName", []))

    @jsii.member(jsii_name="resetSubnetId")
    def reset_subnet_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSubnetId", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fqdn"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replicationSource")
    def replication_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "replicationSource"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIpInput")
    def assign_public_ip_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "assignPublicIpInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backupPriorityInput")
    def backup_priority_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "backupPriorityInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="priorityInput")
    def priority_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "priorityInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replicationSourceNameInput")
    def replication_source_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "replicationSourceNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIdInput")
    def subnet_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "subnetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneInput")
    def zone_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "zoneInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIp")
    def assign_public_ip(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "assignPublicIp"))

    @assign_public_ip.setter
    def assign_public_ip(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "assignPublicIp", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backupPriority")
    def backup_priority(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "backupPriority"))

    @backup_priority.setter
    def backup_priority(self, value: jsii.Number) -> None:
        jsii.set(self, "backupPriority", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="priority")
    def priority(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "priority"))

    @priority.setter
    def priority(self, value: jsii.Number) -> None:
        jsii.set(self, "priority", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replicationSourceName")
    def replication_source_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "replicationSourceName"))

    @replication_source_name.setter
    def replication_source_name(self, value: builtins.str) -> None:
        jsii.set(self, "replicationSourceName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @subnet_id.setter
    def subnet_id(self, value: builtins.str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zone")
    def zone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zone"))

    @zone.setter
    def zone(self, value: builtins.str) -> None:
        jsii.set(self, "zone", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbMysqlClusterHost]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbMysqlClusterHost]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbMysqlClusterHost]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbMysqlClusterMaintenanceWindow",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "day": "day", "hour": "hour"},
)
class MdbMysqlClusterMaintenanceWindow:
    def __init__(
        self,
        *,
        type: builtins.str,
        day: typing.Optional[builtins.str] = None,
        hour: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#type MdbMysqlCluster#type}.
        :param day: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#day MdbMysqlCluster#day}.
        :param hour: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#hour MdbMysqlCluster#hour}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }
        if day is not None:
            self._values["day"] = day
        if hour is not None:
            self._values["hour"] = hour

    @builtins.property
    def type(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#type MdbMysqlCluster#type}.'''
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def day(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#day MdbMysqlCluster#day}.'''
        result = self._values.get("day")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def hour(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#hour MdbMysqlCluster#hour}.'''
        result = self._values.get("hour")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbMysqlClusterMaintenanceWindow(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbMysqlClusterMaintenanceWindowOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbMysqlClusterMaintenanceWindowOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetDay")
    def reset_day(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDay", []))

    @jsii.member(jsii_name="resetHour")
    def reset_hour(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHour", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dayInput")
    def day_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dayInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hourInput")
    def hour_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "hourInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="typeInput")
    def type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "typeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="day")
    def day(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "day"))

    @day.setter
    def day(self, value: builtins.str) -> None:
        jsii.set(self, "day", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hour")
    def hour(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "hour"))

    @hour.setter
    def hour(self, value: jsii.Number) -> None:
        jsii.set(self, "hour", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @type.setter
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbMysqlClusterMaintenanceWindow]:
        return typing.cast(typing.Optional[MdbMysqlClusterMaintenanceWindow], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbMysqlClusterMaintenanceWindow],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbMysqlClusterResources",
    jsii_struct_bases=[],
    name_mapping={
        "disk_size": "diskSize",
        "disk_type_id": "diskTypeId",
        "resource_preset_id": "resourcePresetId",
    },
)
class MdbMysqlClusterResources:
    def __init__(
        self,
        *,
        disk_size: jsii.Number,
        disk_type_id: builtins.str,
        resource_preset_id: builtins.str,
    ) -> None:
        '''
        :param disk_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#disk_size MdbMysqlCluster#disk_size}.
        :param disk_type_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#disk_type_id MdbMysqlCluster#disk_type_id}.
        :param resource_preset_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#resource_preset_id MdbMysqlCluster#resource_preset_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "disk_size": disk_size,
            "disk_type_id": disk_type_id,
            "resource_preset_id": resource_preset_id,
        }

    @builtins.property
    def disk_size(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#disk_size MdbMysqlCluster#disk_size}.'''
        result = self._values.get("disk_size")
        assert result is not None, "Required property 'disk_size' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def disk_type_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#disk_type_id MdbMysqlCluster#disk_type_id}.'''
        result = self._values.get("disk_type_id")
        assert result is not None, "Required property 'disk_type_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def resource_preset_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#resource_preset_id MdbMysqlCluster#resource_preset_id}.'''
        result = self._values.get("resource_preset_id")
        assert result is not None, "Required property 'resource_preset_id' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbMysqlClusterResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbMysqlClusterResourcesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbMysqlClusterResourcesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSizeInput")
    def disk_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "diskSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeIdInput")
    def disk_type_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "diskTypeIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetIdInput")
    def resource_preset_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourcePresetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSize")
    def disk_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "diskSize"))

    @disk_size.setter
    def disk_size(self, value: jsii.Number) -> None:
        jsii.set(self, "diskSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeId")
    def disk_type_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskTypeId"))

    @disk_type_id.setter
    def disk_type_id(self, value: builtins.str) -> None:
        jsii.set(self, "diskTypeId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetId")
    def resource_preset_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourcePresetId"))

    @resource_preset_id.setter
    def resource_preset_id(self, value: builtins.str) -> None:
        jsii.set(self, "resourcePresetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbMysqlClusterResources]:
        return typing.cast(typing.Optional[MdbMysqlClusterResources], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(self, value: typing.Optional[MdbMysqlClusterResources]) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbMysqlClusterRestore",
    jsii_struct_bases=[],
    name_mapping={"backup_id": "backupId", "time": "time"},
)
class MdbMysqlClusterRestore:
    def __init__(
        self,
        *,
        backup_id: builtins.str,
        time: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param backup_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#backup_id MdbMysqlCluster#backup_id}.
        :param time: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#time MdbMysqlCluster#time}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "backup_id": backup_id,
        }
        if time is not None:
            self._values["time"] = time

    @builtins.property
    def backup_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#backup_id MdbMysqlCluster#backup_id}.'''
        result = self._values.get("backup_id")
        assert result is not None, "Required property 'backup_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def time(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#time MdbMysqlCluster#time}.'''
        result = self._values.get("time")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbMysqlClusterRestore(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbMysqlClusterRestoreOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbMysqlClusterRestoreOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetTime")
    def reset_time(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTime", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backupIdInput")
    def backup_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "backupIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeInput")
    def time_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "timeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backupId")
    def backup_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "backupId"))

    @backup_id.setter
    def backup_id(self, value: builtins.str) -> None:
        jsii.set(self, "backupId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="time")
    def time(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "time"))

    @time.setter
    def time(self, value: builtins.str) -> None:
        jsii.set(self, "time", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbMysqlClusterRestore]:
        return typing.cast(typing.Optional[MdbMysqlClusterRestore], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(self, value: typing.Optional[MdbMysqlClusterRestore]) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbMysqlClusterTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class MdbMysqlClusterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#create MdbMysqlCluster#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#delete MdbMysqlCluster#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#update MdbMysqlCluster#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#create MdbMysqlCluster#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#delete MdbMysqlCluster#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#update MdbMysqlCluster#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbMysqlClusterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbMysqlClusterTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbMysqlClusterTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbMysqlClusterTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbMysqlClusterTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbMysqlClusterTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbMysqlClusterUser",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "password": "password",
        "authentication_plugin": "authenticationPlugin",
        "connection_limits": "connectionLimits",
        "global_permissions": "globalPermissions",
        "permission": "permission",
    },
)
class MdbMysqlClusterUser:
    def __init__(
        self,
        *,
        name: builtins.str,
        password: builtins.str,
        authentication_plugin: typing.Optional[builtins.str] = None,
        connection_limits: typing.Optional["MdbMysqlClusterUserConnectionLimits"] = None,
        global_permissions: typing.Optional[typing.Sequence[builtins.str]] = None,
        permission: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbMysqlClusterUserPermission"]]] = None,
    ) -> None:
        '''
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#name MdbMysqlCluster#name}.
        :param password: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#password MdbMysqlCluster#password}.
        :param authentication_plugin: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#authentication_plugin MdbMysqlCluster#authentication_plugin}.
        :param connection_limits: connection_limits block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#connection_limits MdbMysqlCluster#connection_limits}
        :param global_permissions: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#global_permissions MdbMysqlCluster#global_permissions}.
        :param permission: permission block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#permission MdbMysqlCluster#permission}
        '''
        if isinstance(connection_limits, dict):
            connection_limits = MdbMysqlClusterUserConnectionLimits(**connection_limits)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "password": password,
        }
        if authentication_plugin is not None:
            self._values["authentication_plugin"] = authentication_plugin
        if connection_limits is not None:
            self._values["connection_limits"] = connection_limits
        if global_permissions is not None:
            self._values["global_permissions"] = global_permissions
        if permission is not None:
            self._values["permission"] = permission

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#name MdbMysqlCluster#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def password(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#password MdbMysqlCluster#password}.'''
        result = self._values.get("password")
        assert result is not None, "Required property 'password' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def authentication_plugin(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#authentication_plugin MdbMysqlCluster#authentication_plugin}.'''
        result = self._values.get("authentication_plugin")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def connection_limits(
        self,
    ) -> typing.Optional["MdbMysqlClusterUserConnectionLimits"]:
        '''connection_limits block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#connection_limits MdbMysqlCluster#connection_limits}
        '''
        result = self._values.get("connection_limits")
        return typing.cast(typing.Optional["MdbMysqlClusterUserConnectionLimits"], result)

    @builtins.property
    def global_permissions(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#global_permissions MdbMysqlCluster#global_permissions}.'''
        result = self._values.get("global_permissions")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def permission(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbMysqlClusterUserPermission"]]]:
        '''permission block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#permission MdbMysqlCluster#permission}
        '''
        result = self._values.get("permission")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbMysqlClusterUserPermission"]]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbMysqlClusterUser(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbMysqlClusterUserConnectionLimits",
    jsii_struct_bases=[],
    name_mapping={
        "max_connections_per_hour": "maxConnectionsPerHour",
        "max_questions_per_hour": "maxQuestionsPerHour",
        "max_updates_per_hour": "maxUpdatesPerHour",
        "max_user_connections": "maxUserConnections",
    },
)
class MdbMysqlClusterUserConnectionLimits:
    def __init__(
        self,
        *,
        max_connections_per_hour: typing.Optional[jsii.Number] = None,
        max_questions_per_hour: typing.Optional[jsii.Number] = None,
        max_updates_per_hour: typing.Optional[jsii.Number] = None,
        max_user_connections: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param max_connections_per_hour: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#max_connections_per_hour MdbMysqlCluster#max_connections_per_hour}.
        :param max_questions_per_hour: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#max_questions_per_hour MdbMysqlCluster#max_questions_per_hour}.
        :param max_updates_per_hour: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#max_updates_per_hour MdbMysqlCluster#max_updates_per_hour}.
        :param max_user_connections: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#max_user_connections MdbMysqlCluster#max_user_connections}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if max_connections_per_hour is not None:
            self._values["max_connections_per_hour"] = max_connections_per_hour
        if max_questions_per_hour is not None:
            self._values["max_questions_per_hour"] = max_questions_per_hour
        if max_updates_per_hour is not None:
            self._values["max_updates_per_hour"] = max_updates_per_hour
        if max_user_connections is not None:
            self._values["max_user_connections"] = max_user_connections

    @builtins.property
    def max_connections_per_hour(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#max_connections_per_hour MdbMysqlCluster#max_connections_per_hour}.'''
        result = self._values.get("max_connections_per_hour")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_questions_per_hour(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#max_questions_per_hour MdbMysqlCluster#max_questions_per_hour}.'''
        result = self._values.get("max_questions_per_hour")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_updates_per_hour(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#max_updates_per_hour MdbMysqlCluster#max_updates_per_hour}.'''
        result = self._values.get("max_updates_per_hour")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def max_user_connections(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#max_user_connections MdbMysqlCluster#max_user_connections}.'''
        result = self._values.get("max_user_connections")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbMysqlClusterUserConnectionLimits(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbMysqlClusterUserConnectionLimitsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbMysqlClusterUserConnectionLimitsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetMaxConnectionsPerHour")
    def reset_max_connections_per_hour(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxConnectionsPerHour", []))

    @jsii.member(jsii_name="resetMaxQuestionsPerHour")
    def reset_max_questions_per_hour(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxQuestionsPerHour", []))

    @jsii.member(jsii_name="resetMaxUpdatesPerHour")
    def reset_max_updates_per_hour(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxUpdatesPerHour", []))

    @jsii.member(jsii_name="resetMaxUserConnections")
    def reset_max_user_connections(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxUserConnections", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxConnectionsPerHourInput")
    def max_connections_per_hour_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxConnectionsPerHourInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxQuestionsPerHourInput")
    def max_questions_per_hour_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxQuestionsPerHourInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxUpdatesPerHourInput")
    def max_updates_per_hour_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxUpdatesPerHourInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxUserConnectionsInput")
    def max_user_connections_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxUserConnectionsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxConnectionsPerHour")
    def max_connections_per_hour(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxConnectionsPerHour"))

    @max_connections_per_hour.setter
    def max_connections_per_hour(self, value: jsii.Number) -> None:
        jsii.set(self, "maxConnectionsPerHour", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxQuestionsPerHour")
    def max_questions_per_hour(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxQuestionsPerHour"))

    @max_questions_per_hour.setter
    def max_questions_per_hour(self, value: jsii.Number) -> None:
        jsii.set(self, "maxQuestionsPerHour", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxUpdatesPerHour")
    def max_updates_per_hour(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxUpdatesPerHour"))

    @max_updates_per_hour.setter
    def max_updates_per_hour(self, value: jsii.Number) -> None:
        jsii.set(self, "maxUpdatesPerHour", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxUserConnections")
    def max_user_connections(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxUserConnections"))

    @max_user_connections.setter
    def max_user_connections(self, value: jsii.Number) -> None:
        jsii.set(self, "maxUserConnections", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbMysqlClusterUserConnectionLimits]:
        return typing.cast(typing.Optional[MdbMysqlClusterUserConnectionLimits], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbMysqlClusterUserConnectionLimits],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbMysqlClusterUserList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbMysqlClusterUserList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "MdbMysqlClusterUserOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbMysqlClusterUserOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbMysqlClusterUser]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbMysqlClusterUser]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbMysqlClusterUser]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbMysqlClusterUserOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbMysqlClusterUserOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putConnectionLimits")
    def put_connection_limits(
        self,
        *,
        max_connections_per_hour: typing.Optional[jsii.Number] = None,
        max_questions_per_hour: typing.Optional[jsii.Number] = None,
        max_updates_per_hour: typing.Optional[jsii.Number] = None,
        max_user_connections: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param max_connections_per_hour: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#max_connections_per_hour MdbMysqlCluster#max_connections_per_hour}.
        :param max_questions_per_hour: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#max_questions_per_hour MdbMysqlCluster#max_questions_per_hour}.
        :param max_updates_per_hour: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#max_updates_per_hour MdbMysqlCluster#max_updates_per_hour}.
        :param max_user_connections: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#max_user_connections MdbMysqlCluster#max_user_connections}.
        '''
        value = MdbMysqlClusterUserConnectionLimits(
            max_connections_per_hour=max_connections_per_hour,
            max_questions_per_hour=max_questions_per_hour,
            max_updates_per_hour=max_updates_per_hour,
            max_user_connections=max_user_connections,
        )

        return typing.cast(None, jsii.invoke(self, "putConnectionLimits", [value]))

    @jsii.member(jsii_name="putPermission")
    def put_permission(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["MdbMysqlClusterUserPermission"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putPermission", [value]))

    @jsii.member(jsii_name="resetAuthenticationPlugin")
    def reset_authentication_plugin(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAuthenticationPlugin", []))

    @jsii.member(jsii_name="resetConnectionLimits")
    def reset_connection_limits(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetConnectionLimits", []))

    @jsii.member(jsii_name="resetGlobalPermissions")
    def reset_global_permissions(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGlobalPermissions", []))

    @jsii.member(jsii_name="resetPermission")
    def reset_permission(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPermission", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="connectionLimits")
    def connection_limits(self) -> MdbMysqlClusterUserConnectionLimitsOutputReference:
        return typing.cast(MdbMysqlClusterUserConnectionLimitsOutputReference, jsii.get(self, "connectionLimits"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="permission")
    def permission(self) -> "MdbMysqlClusterUserPermissionList":
        return typing.cast("MdbMysqlClusterUserPermissionList", jsii.get(self, "permission"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="authenticationPluginInput")
    def authentication_plugin_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "authenticationPluginInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="connectionLimitsInput")
    def connection_limits_input(
        self,
    ) -> typing.Optional[MdbMysqlClusterUserConnectionLimits]:
        return typing.cast(typing.Optional[MdbMysqlClusterUserConnectionLimits], jsii.get(self, "connectionLimitsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="globalPermissionsInput")
    def global_permissions_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "globalPermissionsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="passwordInput")
    def password_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "passwordInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="permissionInput")
    def permission_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbMysqlClusterUserPermission"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbMysqlClusterUserPermission"]]], jsii.get(self, "permissionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="authenticationPlugin")
    def authentication_plugin(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "authenticationPlugin"))

    @authentication_plugin.setter
    def authentication_plugin(self, value: builtins.str) -> None:
        jsii.set(self, "authenticationPlugin", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="globalPermissions")
    def global_permissions(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "globalPermissions"))

    @global_permissions.setter
    def global_permissions(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "globalPermissions", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="password")
    def password(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "password"))

    @password.setter
    def password(self, value: builtins.str) -> None:
        jsii.set(self, "password", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbMysqlClusterUser]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbMysqlClusterUser]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbMysqlClusterUser]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbMysqlClusterUserPermission",
    jsii_struct_bases=[],
    name_mapping={"database_name": "databaseName", "roles": "roles"},
)
class MdbMysqlClusterUserPermission:
    def __init__(
        self,
        *,
        database_name: builtins.str,
        roles: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param database_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#database_name MdbMysqlCluster#database_name}.
        :param roles: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#roles MdbMysqlCluster#roles}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "database_name": database_name,
        }
        if roles is not None:
            self._values["roles"] = roles

    @builtins.property
    def database_name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#database_name MdbMysqlCluster#database_name}.'''
        result = self._values.get("database_name")
        assert result is not None, "Required property 'database_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def roles(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_mysql_cluster#roles MdbMysqlCluster#roles}.'''
        result = self._values.get("roles")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbMysqlClusterUserPermission(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbMysqlClusterUserPermissionList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbMysqlClusterUserPermissionList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "MdbMysqlClusterUserPermissionOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbMysqlClusterUserPermissionOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbMysqlClusterUserPermission]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbMysqlClusterUserPermission]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbMysqlClusterUserPermission]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbMysqlClusterUserPermissionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbMysqlClusterUserPermissionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetRoles")
    def reset_roles(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRoles", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databaseNameInput")
    def database_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "databaseNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="rolesInput")
    def roles_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "rolesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databaseName")
    def database_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "databaseName"))

    @database_name.setter
    def database_name(self, value: builtins.str) -> None:
        jsii.set(self, "databaseName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="roles")
    def roles(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "roles"))

    @roles.setter
    def roles(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "roles", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbMysqlClusterUserPermission]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbMysqlClusterUserPermission]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbMysqlClusterUserPermission]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbPostgresqlCluster(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlCluster",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster yandex_mdb_postgresql_cluster}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        config: "MdbPostgresqlClusterConfigA",
        database: typing.Union[cdktf.IResolvable, typing.Sequence["MdbPostgresqlClusterDatabase"]],
        environment: builtins.str,
        host: typing.Union[cdktf.IResolvable, typing.Sequence["MdbPostgresqlClusterHost"]],
        name: builtins.str,
        network_id: builtins.str,
        user: typing.Union[cdktf.IResolvable, typing.Sequence["MdbPostgresqlClusterUser"]],
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        host_master_name: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        maintenance_window: typing.Optional["MdbPostgresqlClusterMaintenanceWindow"] = None,
        restore: typing.Optional["MdbPostgresqlClusterRestore"] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        timeouts: typing.Optional["MdbPostgresqlClusterTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster yandex_mdb_postgresql_cluster} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param config: config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#config MdbPostgresqlCluster#config}
        :param database: database block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#database MdbPostgresqlCluster#database}
        :param environment: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#environment MdbPostgresqlCluster#environment}.
        :param host: host block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#host MdbPostgresqlCluster#host}
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#name MdbPostgresqlCluster#name}.
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#network_id MdbPostgresqlCluster#network_id}.
        :param user: user block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#user MdbPostgresqlCluster#user}
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#deletion_protection MdbPostgresqlCluster#deletion_protection}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#description MdbPostgresqlCluster#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#folder_id MdbPostgresqlCluster#folder_id}.
        :param host_master_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#host_master_name MdbPostgresqlCluster#host_master_name}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#id MdbPostgresqlCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#labels MdbPostgresqlCluster#labels}.
        :param maintenance_window: maintenance_window block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#maintenance_window MdbPostgresqlCluster#maintenance_window}
        :param restore: restore block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#restore MdbPostgresqlCluster#restore}
        :param security_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#security_group_ids MdbPostgresqlCluster#security_group_ids}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#timeouts MdbPostgresqlCluster#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config_ = MdbPostgresqlClusterConfig(
            config=config,
            database=database,
            environment=environment,
            host=host,
            name=name,
            network_id=network_id,
            user=user,
            deletion_protection=deletion_protection,
            description=description,
            folder_id=folder_id,
            host_master_name=host_master_name,
            id=id,
            labels=labels,
            maintenance_window=maintenance_window,
            restore=restore,
            security_group_ids=security_group_ids,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config_])

    @jsii.member(jsii_name="putConfig")
    def put_config(
        self,
        *,
        resources: "MdbPostgresqlClusterConfigResources",
        version: builtins.str,
        access: typing.Optional["MdbPostgresqlClusterConfigAccess"] = None,
        autofailover: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        backup_retain_period_days: typing.Optional[jsii.Number] = None,
        backup_window_start: typing.Optional["MdbPostgresqlClusterConfigBackupWindowStart"] = None,
        performance_diagnostics: typing.Optional["MdbPostgresqlClusterConfigPerformanceDiagnostics"] = None,
        pooler_config: typing.Optional["MdbPostgresqlClusterConfigPoolerConfig"] = None,
        postgresql_config: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
    ) -> None:
        '''
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#resources MdbPostgresqlCluster#resources}
        :param version: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#version MdbPostgresqlCluster#version}.
        :param access: access block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#access MdbPostgresqlCluster#access}
        :param autofailover: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#autofailover MdbPostgresqlCluster#autofailover}.
        :param backup_retain_period_days: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#backup_retain_period_days MdbPostgresqlCluster#backup_retain_period_days}.
        :param backup_window_start: backup_window_start block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#backup_window_start MdbPostgresqlCluster#backup_window_start}
        :param performance_diagnostics: performance_diagnostics block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#performance_diagnostics MdbPostgresqlCluster#performance_diagnostics}
        :param pooler_config: pooler_config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#pooler_config MdbPostgresqlCluster#pooler_config}
        :param postgresql_config: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#postgresql_config MdbPostgresqlCluster#postgresql_config}.
        '''
        value = MdbPostgresqlClusterConfigA(
            resources=resources,
            version=version,
            access=access,
            autofailover=autofailover,
            backup_retain_period_days=backup_retain_period_days,
            backup_window_start=backup_window_start,
            performance_diagnostics=performance_diagnostics,
            pooler_config=pooler_config,
            postgresql_config=postgresql_config,
        )

        return typing.cast(None, jsii.invoke(self, "putConfig", [value]))

    @jsii.member(jsii_name="putDatabase")
    def put_database(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["MdbPostgresqlClusterDatabase"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putDatabase", [value]))

    @jsii.member(jsii_name="putHost")
    def put_host(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["MdbPostgresqlClusterHost"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putHost", [value]))

    @jsii.member(jsii_name="putMaintenanceWindow")
    def put_maintenance_window(
        self,
        *,
        type: builtins.str,
        day: typing.Optional[builtins.str] = None,
        hour: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#type MdbPostgresqlCluster#type}.
        :param day: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#day MdbPostgresqlCluster#day}.
        :param hour: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#hour MdbPostgresqlCluster#hour}.
        '''
        value = MdbPostgresqlClusterMaintenanceWindow(type=type, day=day, hour=hour)

        return typing.cast(None, jsii.invoke(self, "putMaintenanceWindow", [value]))

    @jsii.member(jsii_name="putRestore")
    def put_restore(
        self,
        *,
        backup_id: builtins.str,
        time: typing.Optional[builtins.str] = None,
        time_inclusive: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param backup_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#backup_id MdbPostgresqlCluster#backup_id}.
        :param time: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#time MdbPostgresqlCluster#time}.
        :param time_inclusive: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#time_inclusive MdbPostgresqlCluster#time_inclusive}.
        '''
        value = MdbPostgresqlClusterRestore(
            backup_id=backup_id, time=time, time_inclusive=time_inclusive
        )

        return typing.cast(None, jsii.invoke(self, "putRestore", [value]))

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#create MdbPostgresqlCluster#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#delete MdbPostgresqlCluster#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#update MdbPostgresqlCluster#update}.
        '''
        value = MdbPostgresqlClusterTimeouts(
            create=create, delete=delete, update=update
        )

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="putUser")
    def put_user(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["MdbPostgresqlClusterUser"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putUser", [value]))

    @jsii.member(jsii_name="resetDeletionProtection")
    def reset_deletion_protection(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDeletionProtection", []))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetHostMasterName")
    def reset_host_master_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHostMasterName", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetMaintenanceWindow")
    def reset_maintenance_window(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaintenanceWindow", []))

    @jsii.member(jsii_name="resetRestore")
    def reset_restore(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRestore", []))

    @jsii.member(jsii_name="resetSecurityGroupIds")
    def reset_security_group_ids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityGroupIds", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="config")
    def config(self) -> "MdbPostgresqlClusterConfigAOutputReference":
        return typing.cast("MdbPostgresqlClusterConfigAOutputReference", jsii.get(self, "config"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="database")
    def database(self) -> "MdbPostgresqlClusterDatabaseList":
        return typing.cast("MdbPostgresqlClusterDatabaseList", jsii.get(self, "database"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="health")
    def health(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "health"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="host")
    def host(self) -> "MdbPostgresqlClusterHostList":
        return typing.cast("MdbPostgresqlClusterHostList", jsii.get(self, "host"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maintenanceWindow")
    def maintenance_window(
        self,
    ) -> "MdbPostgresqlClusterMaintenanceWindowOutputReference":
        return typing.cast("MdbPostgresqlClusterMaintenanceWindowOutputReference", jsii.get(self, "maintenanceWindow"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="restore")
    def restore(self) -> "MdbPostgresqlClusterRestoreOutputReference":
        return typing.cast("MdbPostgresqlClusterRestoreOutputReference", jsii.get(self, "restore"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "MdbPostgresqlClusterTimeoutsOutputReference":
        return typing.cast("MdbPostgresqlClusterTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="user")
    def user(self) -> "MdbPostgresqlClusterUserList":
        return typing.cast("MdbPostgresqlClusterUserList", jsii.get(self, "user"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="configInput")
    def config_input(self) -> typing.Optional["MdbPostgresqlClusterConfigA"]:
        return typing.cast(typing.Optional["MdbPostgresqlClusterConfigA"], jsii.get(self, "configInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databaseInput")
    def database_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbPostgresqlClusterDatabase"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbPostgresqlClusterDatabase"]]], jsii.get(self, "databaseInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtectionInput")
    def deletion_protection_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "deletionProtectionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="environmentInput")
    def environment_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "environmentInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostInput")
    def host_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbPostgresqlClusterHost"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbPostgresqlClusterHost"]]], jsii.get(self, "hostInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostMasterNameInput")
    def host_master_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "hostMasterNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maintenanceWindowInput")
    def maintenance_window_input(
        self,
    ) -> typing.Optional["MdbPostgresqlClusterMaintenanceWindow"]:
        return typing.cast(typing.Optional["MdbPostgresqlClusterMaintenanceWindow"], jsii.get(self, "maintenanceWindowInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkIdInput")
    def network_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "networkIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="restoreInput")
    def restore_input(self) -> typing.Optional["MdbPostgresqlClusterRestore"]:
        return typing.cast(typing.Optional["MdbPostgresqlClusterRestore"], jsii.get(self, "restoreInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIdsInput")
    def security_group_ids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "securityGroupIdsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "MdbPostgresqlClusterTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "MdbPostgresqlClusterTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="userInput")
    def user_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbPostgresqlClusterUser"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbPostgresqlClusterUser"]]], jsii.get(self, "userInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtection")
    def deletion_protection(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "deletionProtection"))

    @deletion_protection.setter
    def deletion_protection(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "deletionProtection", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="environment")
    def environment(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "environment"))

    @environment.setter
    def environment(self, value: builtins.str) -> None:
        jsii.set(self, "environment", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostMasterName")
    def host_master_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "hostMasterName"))

    @host_master_name.setter
    def host_master_name(self, value: builtins.str) -> None:
        jsii.set(self, "hostMasterName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @network_id.setter
    def network_id(self, value: builtins.str) -> None:
        jsii.set(self, "networkId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "securityGroupIds"))

    @security_group_ids.setter
    def security_group_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "securityGroupIds", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "config": "config",
        "database": "database",
        "environment": "environment",
        "host": "host",
        "name": "name",
        "network_id": "networkId",
        "user": "user",
        "deletion_protection": "deletionProtection",
        "description": "description",
        "folder_id": "folderId",
        "host_master_name": "hostMasterName",
        "id": "id",
        "labels": "labels",
        "maintenance_window": "maintenanceWindow",
        "restore": "restore",
        "security_group_ids": "securityGroupIds",
        "timeouts": "timeouts",
    },
)
class MdbPostgresqlClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        config: "MdbPostgresqlClusterConfigA",
        database: typing.Union[cdktf.IResolvable, typing.Sequence["MdbPostgresqlClusterDatabase"]],
        environment: builtins.str,
        host: typing.Union[cdktf.IResolvable, typing.Sequence["MdbPostgresqlClusterHost"]],
        name: builtins.str,
        network_id: builtins.str,
        user: typing.Union[cdktf.IResolvable, typing.Sequence["MdbPostgresqlClusterUser"]],
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        host_master_name: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        maintenance_window: typing.Optional["MdbPostgresqlClusterMaintenanceWindow"] = None,
        restore: typing.Optional["MdbPostgresqlClusterRestore"] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        timeouts: typing.Optional["MdbPostgresqlClusterTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param config: config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#config MdbPostgresqlCluster#config}
        :param database: database block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#database MdbPostgresqlCluster#database}
        :param environment: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#environment MdbPostgresqlCluster#environment}.
        :param host: host block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#host MdbPostgresqlCluster#host}
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#name MdbPostgresqlCluster#name}.
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#network_id MdbPostgresqlCluster#network_id}.
        :param user: user block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#user MdbPostgresqlCluster#user}
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#deletion_protection MdbPostgresqlCluster#deletion_protection}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#description MdbPostgresqlCluster#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#folder_id MdbPostgresqlCluster#folder_id}.
        :param host_master_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#host_master_name MdbPostgresqlCluster#host_master_name}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#id MdbPostgresqlCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#labels MdbPostgresqlCluster#labels}.
        :param maintenance_window: maintenance_window block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#maintenance_window MdbPostgresqlCluster#maintenance_window}
        :param restore: restore block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#restore MdbPostgresqlCluster#restore}
        :param security_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#security_group_ids MdbPostgresqlCluster#security_group_ids}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#timeouts MdbPostgresqlCluster#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(config, dict):
            config = MdbPostgresqlClusterConfigA(**config)
        if isinstance(maintenance_window, dict):
            maintenance_window = MdbPostgresqlClusterMaintenanceWindow(**maintenance_window)
        if isinstance(restore, dict):
            restore = MdbPostgresqlClusterRestore(**restore)
        if isinstance(timeouts, dict):
            timeouts = MdbPostgresqlClusterTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "config": config,
            "database": database,
            "environment": environment,
            "host": host,
            "name": name,
            "network_id": network_id,
            "user": user,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if deletion_protection is not None:
            self._values["deletion_protection"] = deletion_protection
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if host_master_name is not None:
            self._values["host_master_name"] = host_master_name
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if maintenance_window is not None:
            self._values["maintenance_window"] = maintenance_window
        if restore is not None:
            self._values["restore"] = restore
        if security_group_ids is not None:
            self._values["security_group_ids"] = security_group_ids
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def config(self) -> "MdbPostgresqlClusterConfigA":
        '''config block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#config MdbPostgresqlCluster#config}
        '''
        result = self._values.get("config")
        assert result is not None, "Required property 'config' is missing"
        return typing.cast("MdbPostgresqlClusterConfigA", result)

    @builtins.property
    def database(
        self,
    ) -> typing.Union[cdktf.IResolvable, typing.List["MdbPostgresqlClusterDatabase"]]:
        '''database block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#database MdbPostgresqlCluster#database}
        '''
        result = self._values.get("database")
        assert result is not None, "Required property 'database' is missing"
        return typing.cast(typing.Union[cdktf.IResolvable, typing.List["MdbPostgresqlClusterDatabase"]], result)

    @builtins.property
    def environment(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#environment MdbPostgresqlCluster#environment}.'''
        result = self._values.get("environment")
        assert result is not None, "Required property 'environment' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def host(
        self,
    ) -> typing.Union[cdktf.IResolvable, typing.List["MdbPostgresqlClusterHost"]]:
        '''host block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#host MdbPostgresqlCluster#host}
        '''
        result = self._values.get("host")
        assert result is not None, "Required property 'host' is missing"
        return typing.cast(typing.Union[cdktf.IResolvable, typing.List["MdbPostgresqlClusterHost"]], result)

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#name MdbPostgresqlCluster#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def network_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#network_id MdbPostgresqlCluster#network_id}.'''
        result = self._values.get("network_id")
        assert result is not None, "Required property 'network_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def user(
        self,
    ) -> typing.Union[cdktf.IResolvable, typing.List["MdbPostgresqlClusterUser"]]:
        '''user block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#user MdbPostgresqlCluster#user}
        '''
        result = self._values.get("user")
        assert result is not None, "Required property 'user' is missing"
        return typing.cast(typing.Union[cdktf.IResolvable, typing.List["MdbPostgresqlClusterUser"]], result)

    @builtins.property
    def deletion_protection(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#deletion_protection MdbPostgresqlCluster#deletion_protection}.'''
        result = self._values.get("deletion_protection")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#description MdbPostgresqlCluster#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#folder_id MdbPostgresqlCluster#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def host_master_name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#host_master_name MdbPostgresqlCluster#host_master_name}.'''
        result = self._values.get("host_master_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#id MdbPostgresqlCluster#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#labels MdbPostgresqlCluster#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def maintenance_window(
        self,
    ) -> typing.Optional["MdbPostgresqlClusterMaintenanceWindow"]:
        '''maintenance_window block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#maintenance_window MdbPostgresqlCluster#maintenance_window}
        '''
        result = self._values.get("maintenance_window")
        return typing.cast(typing.Optional["MdbPostgresqlClusterMaintenanceWindow"], result)

    @builtins.property
    def restore(self) -> typing.Optional["MdbPostgresqlClusterRestore"]:
        '''restore block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#restore MdbPostgresqlCluster#restore}
        '''
        result = self._values.get("restore")
        return typing.cast(typing.Optional["MdbPostgresqlClusterRestore"], result)

    @builtins.property
    def security_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#security_group_ids MdbPostgresqlCluster#security_group_ids}.'''
        result = self._values.get("security_group_ids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["MdbPostgresqlClusterTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#timeouts MdbPostgresqlCluster#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["MdbPostgresqlClusterTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbPostgresqlClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlClusterConfigA",
    jsii_struct_bases=[],
    name_mapping={
        "resources": "resources",
        "version": "version",
        "access": "access",
        "autofailover": "autofailover",
        "backup_retain_period_days": "backupRetainPeriodDays",
        "backup_window_start": "backupWindowStart",
        "performance_diagnostics": "performanceDiagnostics",
        "pooler_config": "poolerConfig",
        "postgresql_config": "postgresqlConfig",
    },
)
class MdbPostgresqlClusterConfigA:
    def __init__(
        self,
        *,
        resources: "MdbPostgresqlClusterConfigResources",
        version: builtins.str,
        access: typing.Optional["MdbPostgresqlClusterConfigAccess"] = None,
        autofailover: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        backup_retain_period_days: typing.Optional[jsii.Number] = None,
        backup_window_start: typing.Optional["MdbPostgresqlClusterConfigBackupWindowStart"] = None,
        performance_diagnostics: typing.Optional["MdbPostgresqlClusterConfigPerformanceDiagnostics"] = None,
        pooler_config: typing.Optional["MdbPostgresqlClusterConfigPoolerConfig"] = None,
        postgresql_config: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
    ) -> None:
        '''
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#resources MdbPostgresqlCluster#resources}
        :param version: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#version MdbPostgresqlCluster#version}.
        :param access: access block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#access MdbPostgresqlCluster#access}
        :param autofailover: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#autofailover MdbPostgresqlCluster#autofailover}.
        :param backup_retain_period_days: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#backup_retain_period_days MdbPostgresqlCluster#backup_retain_period_days}.
        :param backup_window_start: backup_window_start block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#backup_window_start MdbPostgresqlCluster#backup_window_start}
        :param performance_diagnostics: performance_diagnostics block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#performance_diagnostics MdbPostgresqlCluster#performance_diagnostics}
        :param pooler_config: pooler_config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#pooler_config MdbPostgresqlCluster#pooler_config}
        :param postgresql_config: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#postgresql_config MdbPostgresqlCluster#postgresql_config}.
        '''
        if isinstance(resources, dict):
            resources = MdbPostgresqlClusterConfigResources(**resources)
        if isinstance(access, dict):
            access = MdbPostgresqlClusterConfigAccess(**access)
        if isinstance(backup_window_start, dict):
            backup_window_start = MdbPostgresqlClusterConfigBackupWindowStart(**backup_window_start)
        if isinstance(performance_diagnostics, dict):
            performance_diagnostics = MdbPostgresqlClusterConfigPerformanceDiagnostics(**performance_diagnostics)
        if isinstance(pooler_config, dict):
            pooler_config = MdbPostgresqlClusterConfigPoolerConfig(**pooler_config)
        self._values: typing.Dict[str, typing.Any] = {
            "resources": resources,
            "version": version,
        }
        if access is not None:
            self._values["access"] = access
        if autofailover is not None:
            self._values["autofailover"] = autofailover
        if backup_retain_period_days is not None:
            self._values["backup_retain_period_days"] = backup_retain_period_days
        if backup_window_start is not None:
            self._values["backup_window_start"] = backup_window_start
        if performance_diagnostics is not None:
            self._values["performance_diagnostics"] = performance_diagnostics
        if pooler_config is not None:
            self._values["pooler_config"] = pooler_config
        if postgresql_config is not None:
            self._values["postgresql_config"] = postgresql_config

    @builtins.property
    def resources(self) -> "MdbPostgresqlClusterConfigResources":
        '''resources block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#resources MdbPostgresqlCluster#resources}
        '''
        result = self._values.get("resources")
        assert result is not None, "Required property 'resources' is missing"
        return typing.cast("MdbPostgresqlClusterConfigResources", result)

    @builtins.property
    def version(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#version MdbPostgresqlCluster#version}.'''
        result = self._values.get("version")
        assert result is not None, "Required property 'version' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def access(self) -> typing.Optional["MdbPostgresqlClusterConfigAccess"]:
        '''access block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#access MdbPostgresqlCluster#access}
        '''
        result = self._values.get("access")
        return typing.cast(typing.Optional["MdbPostgresqlClusterConfigAccess"], result)

    @builtins.property
    def autofailover(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#autofailover MdbPostgresqlCluster#autofailover}.'''
        result = self._values.get("autofailover")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def backup_retain_period_days(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#backup_retain_period_days MdbPostgresqlCluster#backup_retain_period_days}.'''
        result = self._values.get("backup_retain_period_days")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def backup_window_start(
        self,
    ) -> typing.Optional["MdbPostgresqlClusterConfigBackupWindowStart"]:
        '''backup_window_start block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#backup_window_start MdbPostgresqlCluster#backup_window_start}
        '''
        result = self._values.get("backup_window_start")
        return typing.cast(typing.Optional["MdbPostgresqlClusterConfigBackupWindowStart"], result)

    @builtins.property
    def performance_diagnostics(
        self,
    ) -> typing.Optional["MdbPostgresqlClusterConfigPerformanceDiagnostics"]:
        '''performance_diagnostics block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#performance_diagnostics MdbPostgresqlCluster#performance_diagnostics}
        '''
        result = self._values.get("performance_diagnostics")
        return typing.cast(typing.Optional["MdbPostgresqlClusterConfigPerformanceDiagnostics"], result)

    @builtins.property
    def pooler_config(
        self,
    ) -> typing.Optional["MdbPostgresqlClusterConfigPoolerConfig"]:
        '''pooler_config block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#pooler_config MdbPostgresqlCluster#pooler_config}
        '''
        result = self._values.get("pooler_config")
        return typing.cast(typing.Optional["MdbPostgresqlClusterConfigPoolerConfig"], result)

    @builtins.property
    def postgresql_config(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#postgresql_config MdbPostgresqlCluster#postgresql_config}.'''
        result = self._values.get("postgresql_config")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbPostgresqlClusterConfigA(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbPostgresqlClusterConfigAOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlClusterConfigAOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putAccess")
    def put_access(
        self,
        *,
        data_lens: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        serverless: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        web_sql: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param data_lens: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#data_lens MdbPostgresqlCluster#data_lens}.
        :param serverless: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#serverless MdbPostgresqlCluster#serverless}.
        :param web_sql: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#web_sql MdbPostgresqlCluster#web_sql}.
        '''
        value = MdbPostgresqlClusterConfigAccess(
            data_lens=data_lens, serverless=serverless, web_sql=web_sql
        )

        return typing.cast(None, jsii.invoke(self, "putAccess", [value]))

    @jsii.member(jsii_name="putBackupWindowStart")
    def put_backup_window_start(
        self,
        *,
        hours: typing.Optional[jsii.Number] = None,
        minutes: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param hours: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#hours MdbPostgresqlCluster#hours}.
        :param minutes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#minutes MdbPostgresqlCluster#minutes}.
        '''
        value = MdbPostgresqlClusterConfigBackupWindowStart(
            hours=hours, minutes=minutes
        )

        return typing.cast(None, jsii.invoke(self, "putBackupWindowStart", [value]))

    @jsii.member(jsii_name="putPerformanceDiagnostics")
    def put_performance_diagnostics(
        self,
        *,
        sessions_sampling_interval: jsii.Number,
        statements_sampling_interval: jsii.Number,
        enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param sessions_sampling_interval: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#sessions_sampling_interval MdbPostgresqlCluster#sessions_sampling_interval}.
        :param statements_sampling_interval: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#statements_sampling_interval MdbPostgresqlCluster#statements_sampling_interval}.
        :param enabled: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#enabled MdbPostgresqlCluster#enabled}.
        '''
        value = MdbPostgresqlClusterConfigPerformanceDiagnostics(
            sessions_sampling_interval=sessions_sampling_interval,
            statements_sampling_interval=statements_sampling_interval,
            enabled=enabled,
        )

        return typing.cast(None, jsii.invoke(self, "putPerformanceDiagnostics", [value]))

    @jsii.member(jsii_name="putPoolerConfig")
    def put_pooler_config(
        self,
        *,
        pool_discard: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        pooling_mode: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param pool_discard: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#pool_discard MdbPostgresqlCluster#pool_discard}.
        :param pooling_mode: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#pooling_mode MdbPostgresqlCluster#pooling_mode}.
        '''
        value = MdbPostgresqlClusterConfigPoolerConfig(
            pool_discard=pool_discard, pooling_mode=pooling_mode
        )

        return typing.cast(None, jsii.invoke(self, "putPoolerConfig", [value]))

    @jsii.member(jsii_name="putResources")
    def put_resources(
        self,
        *,
        disk_size: jsii.Number,
        resource_preset_id: builtins.str,
        disk_type_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param disk_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#disk_size MdbPostgresqlCluster#disk_size}.
        :param resource_preset_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#resource_preset_id MdbPostgresqlCluster#resource_preset_id}.
        :param disk_type_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#disk_type_id MdbPostgresqlCluster#disk_type_id}.
        '''
        value = MdbPostgresqlClusterConfigResources(
            disk_size=disk_size,
            resource_preset_id=resource_preset_id,
            disk_type_id=disk_type_id,
        )

        return typing.cast(None, jsii.invoke(self, "putResources", [value]))

    @jsii.member(jsii_name="resetAccess")
    def reset_access(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAccess", []))

    @jsii.member(jsii_name="resetAutofailover")
    def reset_autofailover(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAutofailover", []))

    @jsii.member(jsii_name="resetBackupRetainPeriodDays")
    def reset_backup_retain_period_days(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetBackupRetainPeriodDays", []))

    @jsii.member(jsii_name="resetBackupWindowStart")
    def reset_backup_window_start(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetBackupWindowStart", []))

    @jsii.member(jsii_name="resetPerformanceDiagnostics")
    def reset_performance_diagnostics(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPerformanceDiagnostics", []))

    @jsii.member(jsii_name="resetPoolerConfig")
    def reset_pooler_config(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPoolerConfig", []))

    @jsii.member(jsii_name="resetPostgresqlConfig")
    def reset_postgresql_config(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPostgresqlConfig", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="access")
    def access(self) -> "MdbPostgresqlClusterConfigAccessOutputReference":
        return typing.cast("MdbPostgresqlClusterConfigAccessOutputReference", jsii.get(self, "access"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backupWindowStart")
    def backup_window_start(
        self,
    ) -> "MdbPostgresqlClusterConfigBackupWindowStartOutputReference":
        return typing.cast("MdbPostgresqlClusterConfigBackupWindowStartOutputReference", jsii.get(self, "backupWindowStart"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="performanceDiagnostics")
    def performance_diagnostics(
        self,
    ) -> "MdbPostgresqlClusterConfigPerformanceDiagnosticsOutputReference":
        return typing.cast("MdbPostgresqlClusterConfigPerformanceDiagnosticsOutputReference", jsii.get(self, "performanceDiagnostics"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="poolerConfig")
    def pooler_config(self) -> "MdbPostgresqlClusterConfigPoolerConfigOutputReference":
        return typing.cast("MdbPostgresqlClusterConfigPoolerConfigOutputReference", jsii.get(self, "poolerConfig"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resources")
    def resources(self) -> "MdbPostgresqlClusterConfigResourcesOutputReference":
        return typing.cast("MdbPostgresqlClusterConfigResourcesOutputReference", jsii.get(self, "resources"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="accessInput")
    def access_input(self) -> typing.Optional["MdbPostgresqlClusterConfigAccess"]:
        return typing.cast(typing.Optional["MdbPostgresqlClusterConfigAccess"], jsii.get(self, "accessInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autofailoverInput")
    def autofailover_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "autofailoverInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backupRetainPeriodDaysInput")
    def backup_retain_period_days_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "backupRetainPeriodDaysInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backupWindowStartInput")
    def backup_window_start_input(
        self,
    ) -> typing.Optional["MdbPostgresqlClusterConfigBackupWindowStart"]:
        return typing.cast(typing.Optional["MdbPostgresqlClusterConfigBackupWindowStart"], jsii.get(self, "backupWindowStartInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="performanceDiagnosticsInput")
    def performance_diagnostics_input(
        self,
    ) -> typing.Optional["MdbPostgresqlClusterConfigPerformanceDiagnostics"]:
        return typing.cast(typing.Optional["MdbPostgresqlClusterConfigPerformanceDiagnostics"], jsii.get(self, "performanceDiagnosticsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="poolerConfigInput")
    def pooler_config_input(
        self,
    ) -> typing.Optional["MdbPostgresqlClusterConfigPoolerConfig"]:
        return typing.cast(typing.Optional["MdbPostgresqlClusterConfigPoolerConfig"], jsii.get(self, "poolerConfigInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="postgresqlConfigInput")
    def postgresql_config_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "postgresqlConfigInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcesInput")
    def resources_input(self) -> typing.Optional["MdbPostgresqlClusterConfigResources"]:
        return typing.cast(typing.Optional["MdbPostgresqlClusterConfigResources"], jsii.get(self, "resourcesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="versionInput")
    def version_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "versionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autofailover")
    def autofailover(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "autofailover"))

    @autofailover.setter
    def autofailover(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "autofailover", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backupRetainPeriodDays")
    def backup_retain_period_days(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "backupRetainPeriodDays"))

    @backup_retain_period_days.setter
    def backup_retain_period_days(self, value: jsii.Number) -> None:
        jsii.set(self, "backupRetainPeriodDays", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="postgresqlConfig")
    def postgresql_config(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "postgresqlConfig"))

    @postgresql_config.setter
    def postgresql_config(
        self,
        value: typing.Mapping[builtins.str, builtins.str],
    ) -> None:
        jsii.set(self, "postgresqlConfig", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "version"))

    @version.setter
    def version(self, value: builtins.str) -> None:
        jsii.set(self, "version", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbPostgresqlClusterConfigA]:
        return typing.cast(typing.Optional[MdbPostgresqlClusterConfigA], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbPostgresqlClusterConfigA],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlClusterConfigAccess",
    jsii_struct_bases=[],
    name_mapping={
        "data_lens": "dataLens",
        "serverless": "serverless",
        "web_sql": "webSql",
    },
)
class MdbPostgresqlClusterConfigAccess:
    def __init__(
        self,
        *,
        data_lens: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        serverless: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        web_sql: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param data_lens: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#data_lens MdbPostgresqlCluster#data_lens}.
        :param serverless: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#serverless MdbPostgresqlCluster#serverless}.
        :param web_sql: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#web_sql MdbPostgresqlCluster#web_sql}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if data_lens is not None:
            self._values["data_lens"] = data_lens
        if serverless is not None:
            self._values["serverless"] = serverless
        if web_sql is not None:
            self._values["web_sql"] = web_sql

    @builtins.property
    def data_lens(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#data_lens MdbPostgresqlCluster#data_lens}.'''
        result = self._values.get("data_lens")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def serverless(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#serverless MdbPostgresqlCluster#serverless}.'''
        result = self._values.get("serverless")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def web_sql(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#web_sql MdbPostgresqlCluster#web_sql}.'''
        result = self._values.get("web_sql")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbPostgresqlClusterConfigAccess(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbPostgresqlClusterConfigAccessOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlClusterConfigAccessOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetDataLens")
    def reset_data_lens(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDataLens", []))

    @jsii.member(jsii_name="resetServerless")
    def reset_serverless(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetServerless", []))

    @jsii.member(jsii_name="resetWebSql")
    def reset_web_sql(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetWebSql", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dataLensInput")
    def data_lens_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "dataLensInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serverlessInput")
    def serverless_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "serverlessInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="webSqlInput")
    def web_sql_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "webSqlInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dataLens")
    def data_lens(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "dataLens"))

    @data_lens.setter
    def data_lens(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "dataLens", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serverless")
    def serverless(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "serverless"))

    @serverless.setter
    def serverless(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "serverless", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="webSql")
    def web_sql(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "webSql"))

    @web_sql.setter
    def web_sql(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "webSql", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbPostgresqlClusterConfigAccess]:
        return typing.cast(typing.Optional[MdbPostgresqlClusterConfigAccess], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbPostgresqlClusterConfigAccess],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlClusterConfigBackupWindowStart",
    jsii_struct_bases=[],
    name_mapping={"hours": "hours", "minutes": "minutes"},
)
class MdbPostgresqlClusterConfigBackupWindowStart:
    def __init__(
        self,
        *,
        hours: typing.Optional[jsii.Number] = None,
        minutes: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param hours: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#hours MdbPostgresqlCluster#hours}.
        :param minutes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#minutes MdbPostgresqlCluster#minutes}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if hours is not None:
            self._values["hours"] = hours
        if minutes is not None:
            self._values["minutes"] = minutes

    @builtins.property
    def hours(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#hours MdbPostgresqlCluster#hours}.'''
        result = self._values.get("hours")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def minutes(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#minutes MdbPostgresqlCluster#minutes}.'''
        result = self._values.get("minutes")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbPostgresqlClusterConfigBackupWindowStart(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbPostgresqlClusterConfigBackupWindowStartOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlClusterConfigBackupWindowStartOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetHours")
    def reset_hours(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHours", []))

    @jsii.member(jsii_name="resetMinutes")
    def reset_minutes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMinutes", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hoursInput")
    def hours_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "hoursInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minutesInput")
    def minutes_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "minutesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hours")
    def hours(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "hours"))

    @hours.setter
    def hours(self, value: jsii.Number) -> None:
        jsii.set(self, "hours", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minutes")
    def minutes(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minutes"))

    @minutes.setter
    def minutes(self, value: jsii.Number) -> None:
        jsii.set(self, "minutes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[MdbPostgresqlClusterConfigBackupWindowStart]:
        return typing.cast(typing.Optional[MdbPostgresqlClusterConfigBackupWindowStart], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbPostgresqlClusterConfigBackupWindowStart],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlClusterConfigPerformanceDiagnostics",
    jsii_struct_bases=[],
    name_mapping={
        "sessions_sampling_interval": "sessionsSamplingInterval",
        "statements_sampling_interval": "statementsSamplingInterval",
        "enabled": "enabled",
    },
)
class MdbPostgresqlClusterConfigPerformanceDiagnostics:
    def __init__(
        self,
        *,
        sessions_sampling_interval: jsii.Number,
        statements_sampling_interval: jsii.Number,
        enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param sessions_sampling_interval: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#sessions_sampling_interval MdbPostgresqlCluster#sessions_sampling_interval}.
        :param statements_sampling_interval: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#statements_sampling_interval MdbPostgresqlCluster#statements_sampling_interval}.
        :param enabled: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#enabled MdbPostgresqlCluster#enabled}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "sessions_sampling_interval": sessions_sampling_interval,
            "statements_sampling_interval": statements_sampling_interval,
        }
        if enabled is not None:
            self._values["enabled"] = enabled

    @builtins.property
    def sessions_sampling_interval(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#sessions_sampling_interval MdbPostgresqlCluster#sessions_sampling_interval}.'''
        result = self._values.get("sessions_sampling_interval")
        assert result is not None, "Required property 'sessions_sampling_interval' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def statements_sampling_interval(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#statements_sampling_interval MdbPostgresqlCluster#statements_sampling_interval}.'''
        result = self._values.get("statements_sampling_interval")
        assert result is not None, "Required property 'statements_sampling_interval' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def enabled(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#enabled MdbPostgresqlCluster#enabled}.'''
        result = self._values.get("enabled")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbPostgresqlClusterConfigPerformanceDiagnostics(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbPostgresqlClusterConfigPerformanceDiagnosticsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlClusterConfigPerformanceDiagnosticsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetEnabled")
    def reset_enabled(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEnabled", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="enabledInput")
    def enabled_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "enabledInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sessionsSamplingIntervalInput")
    def sessions_sampling_interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "sessionsSamplingIntervalInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="statementsSamplingIntervalInput")
    def statements_sampling_interval_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "statementsSamplingIntervalInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "enabled"))

    @enabled.setter
    def enabled(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sessionsSamplingInterval")
    def sessions_sampling_interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "sessionsSamplingInterval"))

    @sessions_sampling_interval.setter
    def sessions_sampling_interval(self, value: jsii.Number) -> None:
        jsii.set(self, "sessionsSamplingInterval", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="statementsSamplingInterval")
    def statements_sampling_interval(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "statementsSamplingInterval"))

    @statements_sampling_interval.setter
    def statements_sampling_interval(self, value: jsii.Number) -> None:
        jsii.set(self, "statementsSamplingInterval", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[MdbPostgresqlClusterConfigPerformanceDiagnostics]:
        return typing.cast(typing.Optional[MdbPostgresqlClusterConfigPerformanceDiagnostics], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbPostgresqlClusterConfigPerformanceDiagnostics],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlClusterConfigPoolerConfig",
    jsii_struct_bases=[],
    name_mapping={"pool_discard": "poolDiscard", "pooling_mode": "poolingMode"},
)
class MdbPostgresqlClusterConfigPoolerConfig:
    def __init__(
        self,
        *,
        pool_discard: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        pooling_mode: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param pool_discard: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#pool_discard MdbPostgresqlCluster#pool_discard}.
        :param pooling_mode: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#pooling_mode MdbPostgresqlCluster#pooling_mode}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if pool_discard is not None:
            self._values["pool_discard"] = pool_discard
        if pooling_mode is not None:
            self._values["pooling_mode"] = pooling_mode

    @builtins.property
    def pool_discard(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#pool_discard MdbPostgresqlCluster#pool_discard}.'''
        result = self._values.get("pool_discard")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def pooling_mode(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#pooling_mode MdbPostgresqlCluster#pooling_mode}.'''
        result = self._values.get("pooling_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbPostgresqlClusterConfigPoolerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbPostgresqlClusterConfigPoolerConfigOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlClusterConfigPoolerConfigOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetPoolDiscard")
    def reset_pool_discard(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPoolDiscard", []))

    @jsii.member(jsii_name="resetPoolingMode")
    def reset_pooling_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPoolingMode", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="poolDiscardInput")
    def pool_discard_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "poolDiscardInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="poolingModeInput")
    def pooling_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "poolingModeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="poolDiscard")
    def pool_discard(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "poolDiscard"))

    @pool_discard.setter
    def pool_discard(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "poolDiscard", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="poolingMode")
    def pooling_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "poolingMode"))

    @pooling_mode.setter
    def pooling_mode(self, value: builtins.str) -> None:
        jsii.set(self, "poolingMode", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbPostgresqlClusterConfigPoolerConfig]:
        return typing.cast(typing.Optional[MdbPostgresqlClusterConfigPoolerConfig], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbPostgresqlClusterConfigPoolerConfig],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlClusterConfigResources",
    jsii_struct_bases=[],
    name_mapping={
        "disk_size": "diskSize",
        "resource_preset_id": "resourcePresetId",
        "disk_type_id": "diskTypeId",
    },
)
class MdbPostgresqlClusterConfigResources:
    def __init__(
        self,
        *,
        disk_size: jsii.Number,
        resource_preset_id: builtins.str,
        disk_type_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param disk_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#disk_size MdbPostgresqlCluster#disk_size}.
        :param resource_preset_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#resource_preset_id MdbPostgresqlCluster#resource_preset_id}.
        :param disk_type_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#disk_type_id MdbPostgresqlCluster#disk_type_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "disk_size": disk_size,
            "resource_preset_id": resource_preset_id,
        }
        if disk_type_id is not None:
            self._values["disk_type_id"] = disk_type_id

    @builtins.property
    def disk_size(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#disk_size MdbPostgresqlCluster#disk_size}.'''
        result = self._values.get("disk_size")
        assert result is not None, "Required property 'disk_size' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def resource_preset_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#resource_preset_id MdbPostgresqlCluster#resource_preset_id}.'''
        result = self._values.get("resource_preset_id")
        assert result is not None, "Required property 'resource_preset_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def disk_type_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#disk_type_id MdbPostgresqlCluster#disk_type_id}.'''
        result = self._values.get("disk_type_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbPostgresqlClusterConfigResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbPostgresqlClusterConfigResourcesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlClusterConfigResourcesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetDiskTypeId")
    def reset_disk_type_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDiskTypeId", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSizeInput")
    def disk_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "diskSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeIdInput")
    def disk_type_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "diskTypeIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetIdInput")
    def resource_preset_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourcePresetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSize")
    def disk_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "diskSize"))

    @disk_size.setter
    def disk_size(self, value: jsii.Number) -> None:
        jsii.set(self, "diskSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeId")
    def disk_type_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskTypeId"))

    @disk_type_id.setter
    def disk_type_id(self, value: builtins.str) -> None:
        jsii.set(self, "diskTypeId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetId")
    def resource_preset_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourcePresetId"))

    @resource_preset_id.setter
    def resource_preset_id(self, value: builtins.str) -> None:
        jsii.set(self, "resourcePresetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbPostgresqlClusterConfigResources]:
        return typing.cast(typing.Optional[MdbPostgresqlClusterConfigResources], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbPostgresqlClusterConfigResources],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlClusterDatabase",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "owner": "owner",
        "extension": "extension",
        "lc_collate": "lcCollate",
        "lc_type": "lcType",
    },
)
class MdbPostgresqlClusterDatabase:
    def __init__(
        self,
        *,
        name: builtins.str,
        owner: builtins.str,
        extension: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbPostgresqlClusterDatabaseExtension"]]] = None,
        lc_collate: typing.Optional[builtins.str] = None,
        lc_type: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#name MdbPostgresqlCluster#name}.
        :param owner: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#owner MdbPostgresqlCluster#owner}.
        :param extension: extension block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#extension MdbPostgresqlCluster#extension}
        :param lc_collate: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#lc_collate MdbPostgresqlCluster#lc_collate}.
        :param lc_type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#lc_type MdbPostgresqlCluster#lc_type}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "owner": owner,
        }
        if extension is not None:
            self._values["extension"] = extension
        if lc_collate is not None:
            self._values["lc_collate"] = lc_collate
        if lc_type is not None:
            self._values["lc_type"] = lc_type

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#name MdbPostgresqlCluster#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def owner(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#owner MdbPostgresqlCluster#owner}.'''
        result = self._values.get("owner")
        assert result is not None, "Required property 'owner' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def extension(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbPostgresqlClusterDatabaseExtension"]]]:
        '''extension block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#extension MdbPostgresqlCluster#extension}
        '''
        result = self._values.get("extension")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbPostgresqlClusterDatabaseExtension"]]], result)

    @builtins.property
    def lc_collate(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#lc_collate MdbPostgresqlCluster#lc_collate}.'''
        result = self._values.get("lc_collate")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def lc_type(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#lc_type MdbPostgresqlCluster#lc_type}.'''
        result = self._values.get("lc_type")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbPostgresqlClusterDatabase(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlClusterDatabaseExtension",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "version": "version"},
)
class MdbPostgresqlClusterDatabaseExtension:
    def __init__(
        self,
        *,
        name: builtins.str,
        version: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#name MdbPostgresqlCluster#name}.
        :param version: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#version MdbPostgresqlCluster#version}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }
        if version is not None:
            self._values["version"] = version

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#name MdbPostgresqlCluster#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def version(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#version MdbPostgresqlCluster#version}.'''
        result = self._values.get("version")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbPostgresqlClusterDatabaseExtension(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbPostgresqlClusterDatabaseExtensionList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlClusterDatabaseExtensionList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "MdbPostgresqlClusterDatabaseExtensionOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbPostgresqlClusterDatabaseExtensionOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbPostgresqlClusterDatabaseExtension]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbPostgresqlClusterDatabaseExtension]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbPostgresqlClusterDatabaseExtension]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbPostgresqlClusterDatabaseExtensionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlClusterDatabaseExtensionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetVersion")
    def reset_version(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetVersion", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="versionInput")
    def version_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "versionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "version"))

    @version.setter
    def version(self, value: builtins.str) -> None:
        jsii.set(self, "version", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbPostgresqlClusterDatabaseExtension]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbPostgresqlClusterDatabaseExtension]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbPostgresqlClusterDatabaseExtension]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbPostgresqlClusterDatabaseList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlClusterDatabaseList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "MdbPostgresqlClusterDatabaseOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbPostgresqlClusterDatabaseOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbPostgresqlClusterDatabase]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbPostgresqlClusterDatabase]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbPostgresqlClusterDatabase]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbPostgresqlClusterDatabaseOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlClusterDatabaseOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putExtension")
    def put_extension(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence[MdbPostgresqlClusterDatabaseExtension]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putExtension", [value]))

    @jsii.member(jsii_name="resetExtension")
    def reset_extension(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetExtension", []))

    @jsii.member(jsii_name="resetLcCollate")
    def reset_lc_collate(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLcCollate", []))

    @jsii.member(jsii_name="resetLcType")
    def reset_lc_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLcType", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="extension")
    def extension(self) -> MdbPostgresqlClusterDatabaseExtensionList:
        return typing.cast(MdbPostgresqlClusterDatabaseExtensionList, jsii.get(self, "extension"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="extensionInput")
    def extension_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbPostgresqlClusterDatabaseExtension]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbPostgresqlClusterDatabaseExtension]]], jsii.get(self, "extensionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="lcCollateInput")
    def lc_collate_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "lcCollateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="lcTypeInput")
    def lc_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "lcTypeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ownerInput")
    def owner_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "ownerInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="lcCollate")
    def lc_collate(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "lcCollate"))

    @lc_collate.setter
    def lc_collate(self, value: builtins.str) -> None:
        jsii.set(self, "lcCollate", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="lcType")
    def lc_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "lcType"))

    @lc_type.setter
    def lc_type(self, value: builtins.str) -> None:
        jsii.set(self, "lcType", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="owner")
    def owner(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "owner"))

    @owner.setter
    def owner(self, value: builtins.str) -> None:
        jsii.set(self, "owner", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbPostgresqlClusterDatabase]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbPostgresqlClusterDatabase]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbPostgresqlClusterDatabase]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlClusterHost",
    jsii_struct_bases=[],
    name_mapping={
        "zone": "zone",
        "assign_public_ip": "assignPublicIp",
        "name": "name",
        "priority": "priority",
        "replication_source_name": "replicationSourceName",
        "subnet_id": "subnetId",
    },
)
class MdbPostgresqlClusterHost:
    def __init__(
        self,
        *,
        zone: builtins.str,
        assign_public_ip: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        name: typing.Optional[builtins.str] = None,
        priority: typing.Optional[jsii.Number] = None,
        replication_source_name: typing.Optional[builtins.str] = None,
        subnet_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param zone: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#zone MdbPostgresqlCluster#zone}.
        :param assign_public_ip: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#assign_public_ip MdbPostgresqlCluster#assign_public_ip}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#name MdbPostgresqlCluster#name}.
        :param priority: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#priority MdbPostgresqlCluster#priority}.
        :param replication_source_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#replication_source_name MdbPostgresqlCluster#replication_source_name}.
        :param subnet_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#subnet_id MdbPostgresqlCluster#subnet_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "zone": zone,
        }
        if assign_public_ip is not None:
            self._values["assign_public_ip"] = assign_public_ip
        if name is not None:
            self._values["name"] = name
        if priority is not None:
            self._values["priority"] = priority
        if replication_source_name is not None:
            self._values["replication_source_name"] = replication_source_name
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id

    @builtins.property
    def zone(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#zone MdbPostgresqlCluster#zone}.'''
        result = self._values.get("zone")
        assert result is not None, "Required property 'zone' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def assign_public_ip(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#assign_public_ip MdbPostgresqlCluster#assign_public_ip}.'''
        result = self._values.get("assign_public_ip")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#name MdbPostgresqlCluster#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def priority(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#priority MdbPostgresqlCluster#priority}.'''
        result = self._values.get("priority")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def replication_source_name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#replication_source_name MdbPostgresqlCluster#replication_source_name}.'''
        result = self._values.get("replication_source_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#subnet_id MdbPostgresqlCluster#subnet_id}.'''
        result = self._values.get("subnet_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbPostgresqlClusterHost(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbPostgresqlClusterHostList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlClusterHostList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "MdbPostgresqlClusterHostOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbPostgresqlClusterHostOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbPostgresqlClusterHost]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbPostgresqlClusterHost]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbPostgresqlClusterHost]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbPostgresqlClusterHostOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlClusterHostOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetAssignPublicIp")
    def reset_assign_public_ip(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAssignPublicIp", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetPriority")
    def reset_priority(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPriority", []))

    @jsii.member(jsii_name="resetReplicationSourceName")
    def reset_replication_source_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetReplicationSourceName", []))

    @jsii.member(jsii_name="resetSubnetId")
    def reset_subnet_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSubnetId", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fqdn"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replicationSource")
    def replication_source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "replicationSource"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="role")
    def role(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "role"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIpInput")
    def assign_public_ip_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "assignPublicIpInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="priorityInput")
    def priority_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "priorityInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replicationSourceNameInput")
    def replication_source_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "replicationSourceNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIdInput")
    def subnet_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "subnetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneInput")
    def zone_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "zoneInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIp")
    def assign_public_ip(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "assignPublicIp"))

    @assign_public_ip.setter
    def assign_public_ip(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "assignPublicIp", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="priority")
    def priority(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "priority"))

    @priority.setter
    def priority(self, value: jsii.Number) -> None:
        jsii.set(self, "priority", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="replicationSourceName")
    def replication_source_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "replicationSourceName"))

    @replication_source_name.setter
    def replication_source_name(self, value: builtins.str) -> None:
        jsii.set(self, "replicationSourceName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @subnet_id.setter
    def subnet_id(self, value: builtins.str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zone")
    def zone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zone"))

    @zone.setter
    def zone(self, value: builtins.str) -> None:
        jsii.set(self, "zone", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbPostgresqlClusterHost]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbPostgresqlClusterHost]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbPostgresqlClusterHost]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlClusterMaintenanceWindow",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "day": "day", "hour": "hour"},
)
class MdbPostgresqlClusterMaintenanceWindow:
    def __init__(
        self,
        *,
        type: builtins.str,
        day: typing.Optional[builtins.str] = None,
        hour: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#type MdbPostgresqlCluster#type}.
        :param day: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#day MdbPostgresqlCluster#day}.
        :param hour: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#hour MdbPostgresqlCluster#hour}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }
        if day is not None:
            self._values["day"] = day
        if hour is not None:
            self._values["hour"] = hour

    @builtins.property
    def type(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#type MdbPostgresqlCluster#type}.'''
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def day(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#day MdbPostgresqlCluster#day}.'''
        result = self._values.get("day")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def hour(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#hour MdbPostgresqlCluster#hour}.'''
        result = self._values.get("hour")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbPostgresqlClusterMaintenanceWindow(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbPostgresqlClusterMaintenanceWindowOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlClusterMaintenanceWindowOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetDay")
    def reset_day(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDay", []))

    @jsii.member(jsii_name="resetHour")
    def reset_hour(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHour", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dayInput")
    def day_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dayInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hourInput")
    def hour_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "hourInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="typeInput")
    def type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "typeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="day")
    def day(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "day"))

    @day.setter
    def day(self, value: builtins.str) -> None:
        jsii.set(self, "day", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hour")
    def hour(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "hour"))

    @hour.setter
    def hour(self, value: jsii.Number) -> None:
        jsii.set(self, "hour", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @type.setter
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbPostgresqlClusterMaintenanceWindow]:
        return typing.cast(typing.Optional[MdbPostgresqlClusterMaintenanceWindow], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbPostgresqlClusterMaintenanceWindow],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlClusterRestore",
    jsii_struct_bases=[],
    name_mapping={
        "backup_id": "backupId",
        "time": "time",
        "time_inclusive": "timeInclusive",
    },
)
class MdbPostgresqlClusterRestore:
    def __init__(
        self,
        *,
        backup_id: builtins.str,
        time: typing.Optional[builtins.str] = None,
        time_inclusive: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param backup_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#backup_id MdbPostgresqlCluster#backup_id}.
        :param time: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#time MdbPostgresqlCluster#time}.
        :param time_inclusive: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#time_inclusive MdbPostgresqlCluster#time_inclusive}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "backup_id": backup_id,
        }
        if time is not None:
            self._values["time"] = time
        if time_inclusive is not None:
            self._values["time_inclusive"] = time_inclusive

    @builtins.property
    def backup_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#backup_id MdbPostgresqlCluster#backup_id}.'''
        result = self._values.get("backup_id")
        assert result is not None, "Required property 'backup_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def time(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#time MdbPostgresqlCluster#time}.'''
        result = self._values.get("time")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def time_inclusive(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#time_inclusive MdbPostgresqlCluster#time_inclusive}.'''
        result = self._values.get("time_inclusive")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbPostgresqlClusterRestore(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbPostgresqlClusterRestoreOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlClusterRestoreOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetTime")
    def reset_time(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTime", []))

    @jsii.member(jsii_name="resetTimeInclusive")
    def reset_time_inclusive(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeInclusive", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backupIdInput")
    def backup_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "backupIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeInclusiveInput")
    def time_inclusive_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "timeInclusiveInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeInput")
    def time_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "timeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backupId")
    def backup_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "backupId"))

    @backup_id.setter
    def backup_id(self, value: builtins.str) -> None:
        jsii.set(self, "backupId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="time")
    def time(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "time"))

    @time.setter
    def time(self, value: builtins.str) -> None:
        jsii.set(self, "time", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeInclusive")
    def time_inclusive(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "timeInclusive"))

    @time_inclusive.setter
    def time_inclusive(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "timeInclusive", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbPostgresqlClusterRestore]:
        return typing.cast(typing.Optional[MdbPostgresqlClusterRestore], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbPostgresqlClusterRestore],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlClusterTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class MdbPostgresqlClusterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#create MdbPostgresqlCluster#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#delete MdbPostgresqlCluster#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#update MdbPostgresqlCluster#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#create MdbPostgresqlCluster#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#delete MdbPostgresqlCluster#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#update MdbPostgresqlCluster#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbPostgresqlClusterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbPostgresqlClusterTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlClusterTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbPostgresqlClusterTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbPostgresqlClusterTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbPostgresqlClusterTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlClusterUser",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "password": "password",
        "conn_limit": "connLimit",
        "grants": "grants",
        "login": "login",
        "permission": "permission",
        "settings": "settings",
    },
)
class MdbPostgresqlClusterUser:
    def __init__(
        self,
        *,
        name: builtins.str,
        password: builtins.str,
        conn_limit: typing.Optional[jsii.Number] = None,
        grants: typing.Optional[typing.Sequence[builtins.str]] = None,
        login: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        permission: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbPostgresqlClusterUserPermission"]]] = None,
        settings: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
    ) -> None:
        '''
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#name MdbPostgresqlCluster#name}.
        :param password: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#password MdbPostgresqlCluster#password}.
        :param conn_limit: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#conn_limit MdbPostgresqlCluster#conn_limit}.
        :param grants: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#grants MdbPostgresqlCluster#grants}.
        :param login: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#login MdbPostgresqlCluster#login}.
        :param permission: permission block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#permission MdbPostgresqlCluster#permission}
        :param settings: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#settings MdbPostgresqlCluster#settings}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "password": password,
        }
        if conn_limit is not None:
            self._values["conn_limit"] = conn_limit
        if grants is not None:
            self._values["grants"] = grants
        if login is not None:
            self._values["login"] = login
        if permission is not None:
            self._values["permission"] = permission
        if settings is not None:
            self._values["settings"] = settings

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#name MdbPostgresqlCluster#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def password(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#password MdbPostgresqlCluster#password}.'''
        result = self._values.get("password")
        assert result is not None, "Required property 'password' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def conn_limit(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#conn_limit MdbPostgresqlCluster#conn_limit}.'''
        result = self._values.get("conn_limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def grants(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#grants MdbPostgresqlCluster#grants}.'''
        result = self._values.get("grants")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def login(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#login MdbPostgresqlCluster#login}.'''
        result = self._values.get("login")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def permission(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbPostgresqlClusterUserPermission"]]]:
        '''permission block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#permission MdbPostgresqlCluster#permission}
        '''
        result = self._values.get("permission")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbPostgresqlClusterUserPermission"]]], result)

    @builtins.property
    def settings(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#settings MdbPostgresqlCluster#settings}.'''
        result = self._values.get("settings")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbPostgresqlClusterUser(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbPostgresqlClusterUserList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlClusterUserList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "MdbPostgresqlClusterUserOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbPostgresqlClusterUserOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbPostgresqlClusterUser]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbPostgresqlClusterUser]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbPostgresqlClusterUser]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbPostgresqlClusterUserOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlClusterUserOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putPermission")
    def put_permission(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["MdbPostgresqlClusterUserPermission"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putPermission", [value]))

    @jsii.member(jsii_name="resetConnLimit")
    def reset_conn_limit(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetConnLimit", []))

    @jsii.member(jsii_name="resetGrants")
    def reset_grants(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGrants", []))

    @jsii.member(jsii_name="resetLogin")
    def reset_login(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogin", []))

    @jsii.member(jsii_name="resetPermission")
    def reset_permission(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPermission", []))

    @jsii.member(jsii_name="resetSettings")
    def reset_settings(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSettings", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="permission")
    def permission(self) -> "MdbPostgresqlClusterUserPermissionList":
        return typing.cast("MdbPostgresqlClusterUserPermissionList", jsii.get(self, "permission"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="connLimitInput")
    def conn_limit_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "connLimitInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="grantsInput")
    def grants_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "grantsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="loginInput")
    def login_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "loginInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="passwordInput")
    def password_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "passwordInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="permissionInput")
    def permission_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbPostgresqlClusterUserPermission"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbPostgresqlClusterUserPermission"]]], jsii.get(self, "permissionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="settingsInput")
    def settings_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "settingsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="connLimit")
    def conn_limit(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "connLimit"))

    @conn_limit.setter
    def conn_limit(self, value: jsii.Number) -> None:
        jsii.set(self, "connLimit", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="grants")
    def grants(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "grants"))

    @grants.setter
    def grants(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "grants", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="login")
    def login(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "login"))

    @login.setter
    def login(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "login", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="password")
    def password(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "password"))

    @password.setter
    def password(self, value: builtins.str) -> None:
        jsii.set(self, "password", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="settings")
    def settings(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "settings"))

    @settings.setter
    def settings(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "settings", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbPostgresqlClusterUser]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbPostgresqlClusterUser]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbPostgresqlClusterUser]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlClusterUserPermission",
    jsii_struct_bases=[],
    name_mapping={"database_name": "databaseName"},
)
class MdbPostgresqlClusterUserPermission:
    def __init__(self, *, database_name: builtins.str) -> None:
        '''
        :param database_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#database_name MdbPostgresqlCluster#database_name}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "database_name": database_name,
        }

    @builtins.property
    def database_name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_postgresql_cluster#database_name MdbPostgresqlCluster#database_name}.'''
        result = self._values.get("database_name")
        assert result is not None, "Required property 'database_name' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbPostgresqlClusterUserPermission(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbPostgresqlClusterUserPermissionList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlClusterUserPermissionList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "MdbPostgresqlClusterUserPermissionOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbPostgresqlClusterUserPermissionOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbPostgresqlClusterUserPermission]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbPostgresqlClusterUserPermission]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbPostgresqlClusterUserPermission]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbPostgresqlClusterUserPermissionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbPostgresqlClusterUserPermissionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databaseNameInput")
    def database_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "databaseNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databaseName")
    def database_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "databaseName"))

    @database_name.setter
    def database_name(self, value: builtins.str) -> None:
        jsii.set(self, "databaseName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbPostgresqlClusterUserPermission]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbPostgresqlClusterUserPermission]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbPostgresqlClusterUserPermission]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbRedisCluster(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbRedisCluster",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster yandex_mdb_redis_cluster}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        config: "MdbRedisClusterConfigA",
        environment: builtins.str,
        host: typing.Union[cdktf.IResolvable, typing.Sequence["MdbRedisClusterHost"]],
        name: builtins.str,
        network_id: builtins.str,
        resources: "MdbRedisClusterResources",
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        maintenance_window: typing.Optional["MdbRedisClusterMaintenanceWindow"] = None,
        persistence_mode: typing.Optional[builtins.str] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        sharded: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        timeouts: typing.Optional["MdbRedisClusterTimeouts"] = None,
        tls_enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster yandex_mdb_redis_cluster} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param config: config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#config MdbRedisCluster#config}
        :param environment: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#environment MdbRedisCluster#environment}.
        :param host: host block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#host MdbRedisCluster#host}
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#name MdbRedisCluster#name}.
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#network_id MdbRedisCluster#network_id}.
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#resources MdbRedisCluster#resources}
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#deletion_protection MdbRedisCluster#deletion_protection}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#description MdbRedisCluster#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#folder_id MdbRedisCluster#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#id MdbRedisCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#labels MdbRedisCluster#labels}.
        :param maintenance_window: maintenance_window block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#maintenance_window MdbRedisCluster#maintenance_window}
        :param persistence_mode: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#persistence_mode MdbRedisCluster#persistence_mode}.
        :param security_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#security_group_ids MdbRedisCluster#security_group_ids}.
        :param sharded: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#sharded MdbRedisCluster#sharded}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#timeouts MdbRedisCluster#timeouts}
        :param tls_enabled: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#tls_enabled MdbRedisCluster#tls_enabled}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config_ = MdbRedisClusterConfig(
            config=config,
            environment=environment,
            host=host,
            name=name,
            network_id=network_id,
            resources=resources,
            deletion_protection=deletion_protection,
            description=description,
            folder_id=folder_id,
            id=id,
            labels=labels,
            maintenance_window=maintenance_window,
            persistence_mode=persistence_mode,
            security_group_ids=security_group_ids,
            sharded=sharded,
            timeouts=timeouts,
            tls_enabled=tls_enabled,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config_])

    @jsii.member(jsii_name="putConfig")
    def put_config(
        self,
        *,
        password: builtins.str,
        version: builtins.str,
        databases: typing.Optional[jsii.Number] = None,
        maxmemory_policy: typing.Optional[builtins.str] = None,
        notify_keyspace_events: typing.Optional[builtins.str] = None,
        slowlog_log_slower_than: typing.Optional[jsii.Number] = None,
        slowlog_max_len: typing.Optional[jsii.Number] = None,
        timeout: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param password: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#password MdbRedisCluster#password}.
        :param version: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#version MdbRedisCluster#version}.
        :param databases: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#databases MdbRedisCluster#databases}.
        :param maxmemory_policy: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#maxmemory_policy MdbRedisCluster#maxmemory_policy}.
        :param notify_keyspace_events: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#notify_keyspace_events MdbRedisCluster#notify_keyspace_events}.
        :param slowlog_log_slower_than: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#slowlog_log_slower_than MdbRedisCluster#slowlog_log_slower_than}.
        :param slowlog_max_len: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#slowlog_max_len MdbRedisCluster#slowlog_max_len}.
        :param timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#timeout MdbRedisCluster#timeout}.
        '''
        value = MdbRedisClusterConfigA(
            password=password,
            version=version,
            databases=databases,
            maxmemory_policy=maxmemory_policy,
            notify_keyspace_events=notify_keyspace_events,
            slowlog_log_slower_than=slowlog_log_slower_than,
            slowlog_max_len=slowlog_max_len,
            timeout=timeout,
        )

        return typing.cast(None, jsii.invoke(self, "putConfig", [value]))

    @jsii.member(jsii_name="putHost")
    def put_host(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["MdbRedisClusterHost"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putHost", [value]))

    @jsii.member(jsii_name="putMaintenanceWindow")
    def put_maintenance_window(
        self,
        *,
        type: builtins.str,
        day: typing.Optional[builtins.str] = None,
        hour: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#type MdbRedisCluster#type}.
        :param day: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#day MdbRedisCluster#day}.
        :param hour: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#hour MdbRedisCluster#hour}.
        '''
        value = MdbRedisClusterMaintenanceWindow(type=type, day=day, hour=hour)

        return typing.cast(None, jsii.invoke(self, "putMaintenanceWindow", [value]))

    @jsii.member(jsii_name="putResources")
    def put_resources(
        self,
        *,
        disk_size: jsii.Number,
        resource_preset_id: builtins.str,
        disk_type_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param disk_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#disk_size MdbRedisCluster#disk_size}.
        :param resource_preset_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#resource_preset_id MdbRedisCluster#resource_preset_id}.
        :param disk_type_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#disk_type_id MdbRedisCluster#disk_type_id}.
        '''
        value = MdbRedisClusterResources(
            disk_size=disk_size,
            resource_preset_id=resource_preset_id,
            disk_type_id=disk_type_id,
        )

        return typing.cast(None, jsii.invoke(self, "putResources", [value]))

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#create MdbRedisCluster#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#delete MdbRedisCluster#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#update MdbRedisCluster#update}.
        '''
        value = MdbRedisClusterTimeouts(create=create, delete=delete, update=update)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetDeletionProtection")
    def reset_deletion_protection(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDeletionProtection", []))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetMaintenanceWindow")
    def reset_maintenance_window(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaintenanceWindow", []))

    @jsii.member(jsii_name="resetPersistenceMode")
    def reset_persistence_mode(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPersistenceMode", []))

    @jsii.member(jsii_name="resetSecurityGroupIds")
    def reset_security_group_ids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityGroupIds", []))

    @jsii.member(jsii_name="resetSharded")
    def reset_sharded(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSharded", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="resetTlsEnabled")
    def reset_tls_enabled(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTlsEnabled", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="config")
    def config(self) -> "MdbRedisClusterConfigAOutputReference":
        return typing.cast("MdbRedisClusterConfigAOutputReference", jsii.get(self, "config"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="health")
    def health(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "health"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="host")
    def host(self) -> "MdbRedisClusterHostList":
        return typing.cast("MdbRedisClusterHostList", jsii.get(self, "host"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maintenanceWindow")
    def maintenance_window(self) -> "MdbRedisClusterMaintenanceWindowOutputReference":
        return typing.cast("MdbRedisClusterMaintenanceWindowOutputReference", jsii.get(self, "maintenanceWindow"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resources")
    def resources(self) -> "MdbRedisClusterResourcesOutputReference":
        return typing.cast("MdbRedisClusterResourcesOutputReference", jsii.get(self, "resources"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "MdbRedisClusterTimeoutsOutputReference":
        return typing.cast("MdbRedisClusterTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="configInput")
    def config_input(self) -> typing.Optional["MdbRedisClusterConfigA"]:
        return typing.cast(typing.Optional["MdbRedisClusterConfigA"], jsii.get(self, "configInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtectionInput")
    def deletion_protection_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "deletionProtectionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="environmentInput")
    def environment_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "environmentInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostInput")
    def host_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbRedisClusterHost"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbRedisClusterHost"]]], jsii.get(self, "hostInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maintenanceWindowInput")
    def maintenance_window_input(
        self,
    ) -> typing.Optional["MdbRedisClusterMaintenanceWindow"]:
        return typing.cast(typing.Optional["MdbRedisClusterMaintenanceWindow"], jsii.get(self, "maintenanceWindowInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkIdInput")
    def network_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "networkIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="persistenceModeInput")
    def persistence_mode_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "persistenceModeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcesInput")
    def resources_input(self) -> typing.Optional["MdbRedisClusterResources"]:
        return typing.cast(typing.Optional["MdbRedisClusterResources"], jsii.get(self, "resourcesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIdsInput")
    def security_group_ids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "securityGroupIdsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="shardedInput")
    def sharded_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "shardedInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "MdbRedisClusterTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "MdbRedisClusterTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tlsEnabledInput")
    def tls_enabled_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "tlsEnabledInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtection")
    def deletion_protection(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "deletionProtection"))

    @deletion_protection.setter
    def deletion_protection(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "deletionProtection", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="environment")
    def environment(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "environment"))

    @environment.setter
    def environment(self, value: builtins.str) -> None:
        jsii.set(self, "environment", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @network_id.setter
    def network_id(self, value: builtins.str) -> None:
        jsii.set(self, "networkId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="persistenceMode")
    def persistence_mode(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "persistenceMode"))

    @persistence_mode.setter
    def persistence_mode(self, value: builtins.str) -> None:
        jsii.set(self, "persistenceMode", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "securityGroupIds"))

    @security_group_ids.setter
    def security_group_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "securityGroupIds", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sharded")
    def sharded(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "sharded"))

    @sharded.setter
    def sharded(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "sharded", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tlsEnabled")
    def tls_enabled(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "tlsEnabled"))

    @tls_enabled.setter
    def tls_enabled(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "tlsEnabled", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbRedisClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "config": "config",
        "environment": "environment",
        "host": "host",
        "name": "name",
        "network_id": "networkId",
        "resources": "resources",
        "deletion_protection": "deletionProtection",
        "description": "description",
        "folder_id": "folderId",
        "id": "id",
        "labels": "labels",
        "maintenance_window": "maintenanceWindow",
        "persistence_mode": "persistenceMode",
        "security_group_ids": "securityGroupIds",
        "sharded": "sharded",
        "timeouts": "timeouts",
        "tls_enabled": "tlsEnabled",
    },
)
class MdbRedisClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        config: "MdbRedisClusterConfigA",
        environment: builtins.str,
        host: typing.Union[cdktf.IResolvable, typing.Sequence["MdbRedisClusterHost"]],
        name: builtins.str,
        network_id: builtins.str,
        resources: "MdbRedisClusterResources",
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        maintenance_window: typing.Optional["MdbRedisClusterMaintenanceWindow"] = None,
        persistence_mode: typing.Optional[builtins.str] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        sharded: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        timeouts: typing.Optional["MdbRedisClusterTimeouts"] = None,
        tls_enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param config: config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#config MdbRedisCluster#config}
        :param environment: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#environment MdbRedisCluster#environment}.
        :param host: host block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#host MdbRedisCluster#host}
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#name MdbRedisCluster#name}.
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#network_id MdbRedisCluster#network_id}.
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#resources MdbRedisCluster#resources}
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#deletion_protection MdbRedisCluster#deletion_protection}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#description MdbRedisCluster#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#folder_id MdbRedisCluster#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#id MdbRedisCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#labels MdbRedisCluster#labels}.
        :param maintenance_window: maintenance_window block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#maintenance_window MdbRedisCluster#maintenance_window}
        :param persistence_mode: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#persistence_mode MdbRedisCluster#persistence_mode}.
        :param security_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#security_group_ids MdbRedisCluster#security_group_ids}.
        :param sharded: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#sharded MdbRedisCluster#sharded}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#timeouts MdbRedisCluster#timeouts}
        :param tls_enabled: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#tls_enabled MdbRedisCluster#tls_enabled}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(config, dict):
            config = MdbRedisClusterConfigA(**config)
        if isinstance(resources, dict):
            resources = MdbRedisClusterResources(**resources)
        if isinstance(maintenance_window, dict):
            maintenance_window = MdbRedisClusterMaintenanceWindow(**maintenance_window)
        if isinstance(timeouts, dict):
            timeouts = MdbRedisClusterTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "config": config,
            "environment": environment,
            "host": host,
            "name": name,
            "network_id": network_id,
            "resources": resources,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if deletion_protection is not None:
            self._values["deletion_protection"] = deletion_protection
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if maintenance_window is not None:
            self._values["maintenance_window"] = maintenance_window
        if persistence_mode is not None:
            self._values["persistence_mode"] = persistence_mode
        if security_group_ids is not None:
            self._values["security_group_ids"] = security_group_ids
        if sharded is not None:
            self._values["sharded"] = sharded
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if tls_enabled is not None:
            self._values["tls_enabled"] = tls_enabled

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def config(self) -> "MdbRedisClusterConfigA":
        '''config block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#config MdbRedisCluster#config}
        '''
        result = self._values.get("config")
        assert result is not None, "Required property 'config' is missing"
        return typing.cast("MdbRedisClusterConfigA", result)

    @builtins.property
    def environment(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#environment MdbRedisCluster#environment}.'''
        result = self._values.get("environment")
        assert result is not None, "Required property 'environment' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def host(
        self,
    ) -> typing.Union[cdktf.IResolvable, typing.List["MdbRedisClusterHost"]]:
        '''host block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#host MdbRedisCluster#host}
        '''
        result = self._values.get("host")
        assert result is not None, "Required property 'host' is missing"
        return typing.cast(typing.Union[cdktf.IResolvable, typing.List["MdbRedisClusterHost"]], result)

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#name MdbRedisCluster#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def network_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#network_id MdbRedisCluster#network_id}.'''
        result = self._values.get("network_id")
        assert result is not None, "Required property 'network_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def resources(self) -> "MdbRedisClusterResources":
        '''resources block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#resources MdbRedisCluster#resources}
        '''
        result = self._values.get("resources")
        assert result is not None, "Required property 'resources' is missing"
        return typing.cast("MdbRedisClusterResources", result)

    @builtins.property
    def deletion_protection(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#deletion_protection MdbRedisCluster#deletion_protection}.'''
        result = self._values.get("deletion_protection")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#description MdbRedisCluster#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#folder_id MdbRedisCluster#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#id MdbRedisCluster#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#labels MdbRedisCluster#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def maintenance_window(self) -> typing.Optional["MdbRedisClusterMaintenanceWindow"]:
        '''maintenance_window block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#maintenance_window MdbRedisCluster#maintenance_window}
        '''
        result = self._values.get("maintenance_window")
        return typing.cast(typing.Optional["MdbRedisClusterMaintenanceWindow"], result)

    @builtins.property
    def persistence_mode(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#persistence_mode MdbRedisCluster#persistence_mode}.'''
        result = self._values.get("persistence_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def security_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#security_group_ids MdbRedisCluster#security_group_ids}.'''
        result = self._values.get("security_group_ids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def sharded(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#sharded MdbRedisCluster#sharded}.'''
        result = self._values.get("sharded")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["MdbRedisClusterTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#timeouts MdbRedisCluster#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["MdbRedisClusterTimeouts"], result)

    @builtins.property
    def tls_enabled(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#tls_enabled MdbRedisCluster#tls_enabled}.'''
        result = self._values.get("tls_enabled")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbRedisClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbRedisClusterConfigA",
    jsii_struct_bases=[],
    name_mapping={
        "password": "password",
        "version": "version",
        "databases": "databases",
        "maxmemory_policy": "maxmemoryPolicy",
        "notify_keyspace_events": "notifyKeyspaceEvents",
        "slowlog_log_slower_than": "slowlogLogSlowerThan",
        "slowlog_max_len": "slowlogMaxLen",
        "timeout": "timeout",
    },
)
class MdbRedisClusterConfigA:
    def __init__(
        self,
        *,
        password: builtins.str,
        version: builtins.str,
        databases: typing.Optional[jsii.Number] = None,
        maxmemory_policy: typing.Optional[builtins.str] = None,
        notify_keyspace_events: typing.Optional[builtins.str] = None,
        slowlog_log_slower_than: typing.Optional[jsii.Number] = None,
        slowlog_max_len: typing.Optional[jsii.Number] = None,
        timeout: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param password: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#password MdbRedisCluster#password}.
        :param version: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#version MdbRedisCluster#version}.
        :param databases: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#databases MdbRedisCluster#databases}.
        :param maxmemory_policy: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#maxmemory_policy MdbRedisCluster#maxmemory_policy}.
        :param notify_keyspace_events: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#notify_keyspace_events MdbRedisCluster#notify_keyspace_events}.
        :param slowlog_log_slower_than: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#slowlog_log_slower_than MdbRedisCluster#slowlog_log_slower_than}.
        :param slowlog_max_len: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#slowlog_max_len MdbRedisCluster#slowlog_max_len}.
        :param timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#timeout MdbRedisCluster#timeout}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "password": password,
            "version": version,
        }
        if databases is not None:
            self._values["databases"] = databases
        if maxmemory_policy is not None:
            self._values["maxmemory_policy"] = maxmemory_policy
        if notify_keyspace_events is not None:
            self._values["notify_keyspace_events"] = notify_keyspace_events
        if slowlog_log_slower_than is not None:
            self._values["slowlog_log_slower_than"] = slowlog_log_slower_than
        if slowlog_max_len is not None:
            self._values["slowlog_max_len"] = slowlog_max_len
        if timeout is not None:
            self._values["timeout"] = timeout

    @builtins.property
    def password(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#password MdbRedisCluster#password}.'''
        result = self._values.get("password")
        assert result is not None, "Required property 'password' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def version(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#version MdbRedisCluster#version}.'''
        result = self._values.get("version")
        assert result is not None, "Required property 'version' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def databases(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#databases MdbRedisCluster#databases}.'''
        result = self._values.get("databases")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def maxmemory_policy(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#maxmemory_policy MdbRedisCluster#maxmemory_policy}.'''
        result = self._values.get("maxmemory_policy")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def notify_keyspace_events(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#notify_keyspace_events MdbRedisCluster#notify_keyspace_events}.'''
        result = self._values.get("notify_keyspace_events")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def slowlog_log_slower_than(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#slowlog_log_slower_than MdbRedisCluster#slowlog_log_slower_than}.'''
        result = self._values.get("slowlog_log_slower_than")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def slowlog_max_len(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#slowlog_max_len MdbRedisCluster#slowlog_max_len}.'''
        result = self._values.get("slowlog_max_len")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def timeout(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#timeout MdbRedisCluster#timeout}.'''
        result = self._values.get("timeout")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbRedisClusterConfigA(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbRedisClusterConfigAOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbRedisClusterConfigAOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetDatabases")
    def reset_databases(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDatabases", []))

    @jsii.member(jsii_name="resetMaxmemoryPolicy")
    def reset_maxmemory_policy(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxmemoryPolicy", []))

    @jsii.member(jsii_name="resetNotifyKeyspaceEvents")
    def reset_notify_keyspace_events(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNotifyKeyspaceEvents", []))

    @jsii.member(jsii_name="resetSlowlogLogSlowerThan")
    def reset_slowlog_log_slower_than(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSlowlogLogSlowerThan", []))

    @jsii.member(jsii_name="resetSlowlogMaxLen")
    def reset_slowlog_max_len(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSlowlogMaxLen", []))

    @jsii.member(jsii_name="resetTimeout")
    def reset_timeout(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeout", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databasesInput")
    def databases_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "databasesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxmemoryPolicyInput")
    def maxmemory_policy_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "maxmemoryPolicyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="notifyKeyspaceEventsInput")
    def notify_keyspace_events_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "notifyKeyspaceEventsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="passwordInput")
    def password_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "passwordInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="slowlogLogSlowerThanInput")
    def slowlog_log_slower_than_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "slowlogLogSlowerThanInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="slowlogMaxLenInput")
    def slowlog_max_len_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "slowlogMaxLenInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutInput")
    def timeout_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "timeoutInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="versionInput")
    def version_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "versionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databases")
    def databases(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "databases"))

    @databases.setter
    def databases(self, value: jsii.Number) -> None:
        jsii.set(self, "databases", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxmemoryPolicy")
    def maxmemory_policy(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "maxmemoryPolicy"))

    @maxmemory_policy.setter
    def maxmemory_policy(self, value: builtins.str) -> None:
        jsii.set(self, "maxmemoryPolicy", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="notifyKeyspaceEvents")
    def notify_keyspace_events(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "notifyKeyspaceEvents"))

    @notify_keyspace_events.setter
    def notify_keyspace_events(self, value: builtins.str) -> None:
        jsii.set(self, "notifyKeyspaceEvents", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="password")
    def password(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "password"))

    @password.setter
    def password(self, value: builtins.str) -> None:
        jsii.set(self, "password", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="slowlogLogSlowerThan")
    def slowlog_log_slower_than(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "slowlogLogSlowerThan"))

    @slowlog_log_slower_than.setter
    def slowlog_log_slower_than(self, value: jsii.Number) -> None:
        jsii.set(self, "slowlogLogSlowerThan", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="slowlogMaxLen")
    def slowlog_max_len(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "slowlogMaxLen"))

    @slowlog_max_len.setter
    def slowlog_max_len(self, value: jsii.Number) -> None:
        jsii.set(self, "slowlogMaxLen", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeout")
    def timeout(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "timeout"))

    @timeout.setter
    def timeout(self, value: jsii.Number) -> None:
        jsii.set(self, "timeout", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "version"))

    @version.setter
    def version(self, value: builtins.str) -> None:
        jsii.set(self, "version", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbRedisClusterConfigA]:
        return typing.cast(typing.Optional[MdbRedisClusterConfigA], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(self, value: typing.Optional[MdbRedisClusterConfigA]) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbRedisClusterHost",
    jsii_struct_bases=[],
    name_mapping={"zone": "zone", "shard_name": "shardName", "subnet_id": "subnetId"},
)
class MdbRedisClusterHost:
    def __init__(
        self,
        *,
        zone: builtins.str,
        shard_name: typing.Optional[builtins.str] = None,
        subnet_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param zone: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#zone MdbRedisCluster#zone}.
        :param shard_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#shard_name MdbRedisCluster#shard_name}.
        :param subnet_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#subnet_id MdbRedisCluster#subnet_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "zone": zone,
        }
        if shard_name is not None:
            self._values["shard_name"] = shard_name
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id

    @builtins.property
    def zone(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#zone MdbRedisCluster#zone}.'''
        result = self._values.get("zone")
        assert result is not None, "Required property 'zone' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def shard_name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#shard_name MdbRedisCluster#shard_name}.'''
        result = self._values.get("shard_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#subnet_id MdbRedisCluster#subnet_id}.'''
        result = self._values.get("subnet_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbRedisClusterHost(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbRedisClusterHostList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbRedisClusterHostList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "MdbRedisClusterHostOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbRedisClusterHostOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbRedisClusterHost]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbRedisClusterHost]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbRedisClusterHost]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbRedisClusterHostOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbRedisClusterHostOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetShardName")
    def reset_shard_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetShardName", []))

    @jsii.member(jsii_name="resetSubnetId")
    def reset_subnet_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSubnetId", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fqdn"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="shardNameInput")
    def shard_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "shardNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIdInput")
    def subnet_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "subnetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneInput")
    def zone_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "zoneInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="shardName")
    def shard_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "shardName"))

    @shard_name.setter
    def shard_name(self, value: builtins.str) -> None:
        jsii.set(self, "shardName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @subnet_id.setter
    def subnet_id(self, value: builtins.str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zone")
    def zone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zone"))

    @zone.setter
    def zone(self, value: builtins.str) -> None:
        jsii.set(self, "zone", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbRedisClusterHost]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbRedisClusterHost]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbRedisClusterHost]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbRedisClusterMaintenanceWindow",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "day": "day", "hour": "hour"},
)
class MdbRedisClusterMaintenanceWindow:
    def __init__(
        self,
        *,
        type: builtins.str,
        day: typing.Optional[builtins.str] = None,
        hour: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#type MdbRedisCluster#type}.
        :param day: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#day MdbRedisCluster#day}.
        :param hour: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#hour MdbRedisCluster#hour}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "type": type,
        }
        if day is not None:
            self._values["day"] = day
        if hour is not None:
            self._values["hour"] = hour

    @builtins.property
    def type(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#type MdbRedisCluster#type}.'''
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def day(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#day MdbRedisCluster#day}.'''
        result = self._values.get("day")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def hour(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#hour MdbRedisCluster#hour}.'''
        result = self._values.get("hour")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbRedisClusterMaintenanceWindow(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbRedisClusterMaintenanceWindowOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbRedisClusterMaintenanceWindowOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetDay")
    def reset_day(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDay", []))

    @jsii.member(jsii_name="resetHour")
    def reset_hour(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHour", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dayInput")
    def day_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dayInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hourInput")
    def hour_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "hourInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="typeInput")
    def type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "typeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="day")
    def day(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "day"))

    @day.setter
    def day(self, value: builtins.str) -> None:
        jsii.set(self, "day", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hour")
    def hour(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "hour"))

    @hour.setter
    def hour(self, value: jsii.Number) -> None:
        jsii.set(self, "hour", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @type.setter
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbRedisClusterMaintenanceWindow]:
        return typing.cast(typing.Optional[MdbRedisClusterMaintenanceWindow], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbRedisClusterMaintenanceWindow],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbRedisClusterResources",
    jsii_struct_bases=[],
    name_mapping={
        "disk_size": "diskSize",
        "resource_preset_id": "resourcePresetId",
        "disk_type_id": "diskTypeId",
    },
)
class MdbRedisClusterResources:
    def __init__(
        self,
        *,
        disk_size: jsii.Number,
        resource_preset_id: builtins.str,
        disk_type_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param disk_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#disk_size MdbRedisCluster#disk_size}.
        :param resource_preset_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#resource_preset_id MdbRedisCluster#resource_preset_id}.
        :param disk_type_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#disk_type_id MdbRedisCluster#disk_type_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "disk_size": disk_size,
            "resource_preset_id": resource_preset_id,
        }
        if disk_type_id is not None:
            self._values["disk_type_id"] = disk_type_id

    @builtins.property
    def disk_size(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#disk_size MdbRedisCluster#disk_size}.'''
        result = self._values.get("disk_size")
        assert result is not None, "Required property 'disk_size' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def resource_preset_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#resource_preset_id MdbRedisCluster#resource_preset_id}.'''
        result = self._values.get("resource_preset_id")
        assert result is not None, "Required property 'resource_preset_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def disk_type_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#disk_type_id MdbRedisCluster#disk_type_id}.'''
        result = self._values.get("disk_type_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbRedisClusterResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbRedisClusterResourcesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbRedisClusterResourcesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetDiskTypeId")
    def reset_disk_type_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDiskTypeId", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSizeInput")
    def disk_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "diskSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeIdInput")
    def disk_type_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "diskTypeIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetIdInput")
    def resource_preset_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourcePresetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSize")
    def disk_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "diskSize"))

    @disk_size.setter
    def disk_size(self, value: jsii.Number) -> None:
        jsii.set(self, "diskSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeId")
    def disk_type_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskTypeId"))

    @disk_type_id.setter
    def disk_type_id(self, value: builtins.str) -> None:
        jsii.set(self, "diskTypeId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetId")
    def resource_preset_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourcePresetId"))

    @resource_preset_id.setter
    def resource_preset_id(self, value: builtins.str) -> None:
        jsii.set(self, "resourcePresetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbRedisClusterResources]:
        return typing.cast(typing.Optional[MdbRedisClusterResources], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(self, value: typing.Optional[MdbRedisClusterResources]) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbRedisClusterTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class MdbRedisClusterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#create MdbRedisCluster#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#delete MdbRedisCluster#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#update MdbRedisCluster#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#create MdbRedisCluster#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#delete MdbRedisCluster#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_redis_cluster#update MdbRedisCluster#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbRedisClusterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbRedisClusterTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbRedisClusterTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbRedisClusterTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbRedisClusterTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbRedisClusterTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbSqlserverCluster(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbSqlserverCluster",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster yandex_mdb_sqlserver_cluster}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        database: typing.Union[cdktf.IResolvable, typing.Sequence["MdbSqlserverClusterDatabase"]],
        environment: builtins.str,
        host: typing.Union[cdktf.IResolvable, typing.Sequence["MdbSqlserverClusterHost"]],
        name: builtins.str,
        network_id: builtins.str,
        resources: "MdbSqlserverClusterResources",
        user: typing.Union[cdktf.IResolvable, typing.Sequence["MdbSqlserverClusterUser"]],
        version: builtins.str,
        backup_window_start: typing.Optional["MdbSqlserverClusterBackupWindowStart"] = None,
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        host_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        sqlserver_config: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["MdbSqlserverClusterTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster yandex_mdb_sqlserver_cluster} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param database: database block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#database MdbSqlserverCluster#database}
        :param environment: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#environment MdbSqlserverCluster#environment}.
        :param host: host block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#host MdbSqlserverCluster#host}
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#name MdbSqlserverCluster#name}.
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#network_id MdbSqlserverCluster#network_id}.
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#resources MdbSqlserverCluster#resources}
        :param user: user block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#user MdbSqlserverCluster#user}
        :param version: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#version MdbSqlserverCluster#version}.
        :param backup_window_start: backup_window_start block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#backup_window_start MdbSqlserverCluster#backup_window_start}
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#deletion_protection MdbSqlserverCluster#deletion_protection}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#description MdbSqlserverCluster#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#folder_id MdbSqlserverCluster#folder_id}.
        :param host_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#host_group_ids MdbSqlserverCluster#host_group_ids}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#id MdbSqlserverCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#labels MdbSqlserverCluster#labels}.
        :param security_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#security_group_ids MdbSqlserverCluster#security_group_ids}.
        :param sqlserver_config: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#sqlserver_config MdbSqlserverCluster#sqlserver_config}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#timeouts MdbSqlserverCluster#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = MdbSqlserverClusterConfig(
            database=database,
            environment=environment,
            host=host,
            name=name,
            network_id=network_id,
            resources=resources,
            user=user,
            version=version,
            backup_window_start=backup_window_start,
            deletion_protection=deletion_protection,
            description=description,
            folder_id=folder_id,
            host_group_ids=host_group_ids,
            id=id,
            labels=labels,
            security_group_ids=security_group_ids,
            sqlserver_config=sqlserver_config,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putBackupWindowStart")
    def put_backup_window_start(
        self,
        *,
        hours: typing.Optional[jsii.Number] = None,
        minutes: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param hours: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#hours MdbSqlserverCluster#hours}.
        :param minutes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#minutes MdbSqlserverCluster#minutes}.
        '''
        value = MdbSqlserverClusterBackupWindowStart(hours=hours, minutes=minutes)

        return typing.cast(None, jsii.invoke(self, "putBackupWindowStart", [value]))

    @jsii.member(jsii_name="putDatabase")
    def put_database(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["MdbSqlserverClusterDatabase"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putDatabase", [value]))

    @jsii.member(jsii_name="putHost")
    def put_host(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["MdbSqlserverClusterHost"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putHost", [value]))

    @jsii.member(jsii_name="putResources")
    def put_resources(
        self,
        *,
        disk_size: jsii.Number,
        disk_type_id: builtins.str,
        resource_preset_id: builtins.str,
    ) -> None:
        '''
        :param disk_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#disk_size MdbSqlserverCluster#disk_size}.
        :param disk_type_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#disk_type_id MdbSqlserverCluster#disk_type_id}.
        :param resource_preset_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#resource_preset_id MdbSqlserverCluster#resource_preset_id}.
        '''
        value = MdbSqlserverClusterResources(
            disk_size=disk_size,
            disk_type_id=disk_type_id,
            resource_preset_id=resource_preset_id,
        )

        return typing.cast(None, jsii.invoke(self, "putResources", [value]))

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#create MdbSqlserverCluster#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#delete MdbSqlserverCluster#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#update MdbSqlserverCluster#update}.
        '''
        value = MdbSqlserverClusterTimeouts(
            create=create, delete=delete, update=update
        )

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="putUser")
    def put_user(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["MdbSqlserverClusterUser"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putUser", [value]))

    @jsii.member(jsii_name="resetBackupWindowStart")
    def reset_backup_window_start(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetBackupWindowStart", []))

    @jsii.member(jsii_name="resetDeletionProtection")
    def reset_deletion_protection(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDeletionProtection", []))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetHostGroupIds")
    def reset_host_group_ids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHostGroupIds", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetSecurityGroupIds")
    def reset_security_group_ids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityGroupIds", []))

    @jsii.member(jsii_name="resetSqlserverConfig")
    def reset_sqlserver_config(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSqlserverConfig", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backupWindowStart")
    def backup_window_start(
        self,
    ) -> "MdbSqlserverClusterBackupWindowStartOutputReference":
        return typing.cast("MdbSqlserverClusterBackupWindowStartOutputReference", jsii.get(self, "backupWindowStart"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="database")
    def database(self) -> "MdbSqlserverClusterDatabaseList":
        return typing.cast("MdbSqlserverClusterDatabaseList", jsii.get(self, "database"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="health")
    def health(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "health"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="host")
    def host(self) -> "MdbSqlserverClusterHostList":
        return typing.cast("MdbSqlserverClusterHostList", jsii.get(self, "host"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resources")
    def resources(self) -> "MdbSqlserverClusterResourcesOutputReference":
        return typing.cast("MdbSqlserverClusterResourcesOutputReference", jsii.get(self, "resources"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "MdbSqlserverClusterTimeoutsOutputReference":
        return typing.cast("MdbSqlserverClusterTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="user")
    def user(self) -> "MdbSqlserverClusterUserList":
        return typing.cast("MdbSqlserverClusterUserList", jsii.get(self, "user"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="backupWindowStartInput")
    def backup_window_start_input(
        self,
    ) -> typing.Optional["MdbSqlserverClusterBackupWindowStart"]:
        return typing.cast(typing.Optional["MdbSqlserverClusterBackupWindowStart"], jsii.get(self, "backupWindowStartInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databaseInput")
    def database_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbSqlserverClusterDatabase"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbSqlserverClusterDatabase"]]], jsii.get(self, "databaseInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtectionInput")
    def deletion_protection_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "deletionProtectionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="environmentInput")
    def environment_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "environmentInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostGroupIdsInput")
    def host_group_ids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "hostGroupIdsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostInput")
    def host_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbSqlserverClusterHost"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbSqlserverClusterHost"]]], jsii.get(self, "hostInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkIdInput")
    def network_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "networkIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcesInput")
    def resources_input(self) -> typing.Optional["MdbSqlserverClusterResources"]:
        return typing.cast(typing.Optional["MdbSqlserverClusterResources"], jsii.get(self, "resourcesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIdsInput")
    def security_group_ids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "securityGroupIdsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sqlserverConfigInput")
    def sqlserver_config_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "sqlserverConfigInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "MdbSqlserverClusterTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "MdbSqlserverClusterTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="userInput")
    def user_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbSqlserverClusterUser"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbSqlserverClusterUser"]]], jsii.get(self, "userInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="versionInput")
    def version_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "versionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletionProtection")
    def deletion_protection(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "deletionProtection"))

    @deletion_protection.setter
    def deletion_protection(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "deletionProtection", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="environment")
    def environment(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "environment"))

    @environment.setter
    def environment(self, value: builtins.str) -> None:
        jsii.set(self, "environment", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hostGroupIds")
    def host_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "hostGroupIds"))

    @host_group_ids.setter
    def host_group_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "hostGroupIds", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @network_id.setter
    def network_id(self, value: builtins.str) -> None:
        jsii.set(self, "networkId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "securityGroupIds"))

    @security_group_ids.setter
    def security_group_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "securityGroupIds", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sqlserverConfig")
    def sqlserver_config(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "sqlserverConfig"))

    @sqlserver_config.setter
    def sqlserver_config(
        self,
        value: typing.Mapping[builtins.str, builtins.str],
    ) -> None:
        jsii.set(self, "sqlserverConfig", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "version"))

    @version.setter
    def version(self, value: builtins.str) -> None:
        jsii.set(self, "version", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbSqlserverClusterBackupWindowStart",
    jsii_struct_bases=[],
    name_mapping={"hours": "hours", "minutes": "minutes"},
)
class MdbSqlserverClusterBackupWindowStart:
    def __init__(
        self,
        *,
        hours: typing.Optional[jsii.Number] = None,
        minutes: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param hours: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#hours MdbSqlserverCluster#hours}.
        :param minutes: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#minutes MdbSqlserverCluster#minutes}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if hours is not None:
            self._values["hours"] = hours
        if minutes is not None:
            self._values["minutes"] = minutes

    @builtins.property
    def hours(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#hours MdbSqlserverCluster#hours}.'''
        result = self._values.get("hours")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def minutes(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#minutes MdbSqlserverCluster#minutes}.'''
        result = self._values.get("minutes")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbSqlserverClusterBackupWindowStart(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbSqlserverClusterBackupWindowStartOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbSqlserverClusterBackupWindowStartOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetHours")
    def reset_hours(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetHours", []))

    @jsii.member(jsii_name="resetMinutes")
    def reset_minutes(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMinutes", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hoursInput")
    def hours_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "hoursInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minutesInput")
    def minutes_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "minutesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="hours")
    def hours(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "hours"))

    @hours.setter
    def hours(self, value: jsii.Number) -> None:
        jsii.set(self, "hours", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="minutes")
    def minutes(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "minutes"))

    @minutes.setter
    def minutes(self, value: jsii.Number) -> None:
        jsii.set(self, "minutes", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbSqlserverClusterBackupWindowStart]:
        return typing.cast(typing.Optional[MdbSqlserverClusterBackupWindowStart], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbSqlserverClusterBackupWindowStart],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbSqlserverClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "database": "database",
        "environment": "environment",
        "host": "host",
        "name": "name",
        "network_id": "networkId",
        "resources": "resources",
        "user": "user",
        "version": "version",
        "backup_window_start": "backupWindowStart",
        "deletion_protection": "deletionProtection",
        "description": "description",
        "folder_id": "folderId",
        "host_group_ids": "hostGroupIds",
        "id": "id",
        "labels": "labels",
        "security_group_ids": "securityGroupIds",
        "sqlserver_config": "sqlserverConfig",
        "timeouts": "timeouts",
    },
)
class MdbSqlserverClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        database: typing.Union[cdktf.IResolvable, typing.Sequence["MdbSqlserverClusterDatabase"]],
        environment: builtins.str,
        host: typing.Union[cdktf.IResolvable, typing.Sequence["MdbSqlserverClusterHost"]],
        name: builtins.str,
        network_id: builtins.str,
        resources: "MdbSqlserverClusterResources",
        user: typing.Union[cdktf.IResolvable, typing.Sequence["MdbSqlserverClusterUser"]],
        version: builtins.str,
        backup_window_start: typing.Optional[MdbSqlserverClusterBackupWindowStart] = None,
        deletion_protection: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        host_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        sqlserver_config: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["MdbSqlserverClusterTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param database: database block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#database MdbSqlserverCluster#database}
        :param environment: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#environment MdbSqlserverCluster#environment}.
        :param host: host block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#host MdbSqlserverCluster#host}
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#name MdbSqlserverCluster#name}.
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#network_id MdbSqlserverCluster#network_id}.
        :param resources: resources block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#resources MdbSqlserverCluster#resources}
        :param user: user block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#user MdbSqlserverCluster#user}
        :param version: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#version MdbSqlserverCluster#version}.
        :param backup_window_start: backup_window_start block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#backup_window_start MdbSqlserverCluster#backup_window_start}
        :param deletion_protection: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#deletion_protection MdbSqlserverCluster#deletion_protection}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#description MdbSqlserverCluster#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#folder_id MdbSqlserverCluster#folder_id}.
        :param host_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#host_group_ids MdbSqlserverCluster#host_group_ids}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#id MdbSqlserverCluster#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#labels MdbSqlserverCluster#labels}.
        :param security_group_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#security_group_ids MdbSqlserverCluster#security_group_ids}.
        :param sqlserver_config: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#sqlserver_config MdbSqlserverCluster#sqlserver_config}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#timeouts MdbSqlserverCluster#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(resources, dict):
            resources = MdbSqlserverClusterResources(**resources)
        if isinstance(backup_window_start, dict):
            backup_window_start = MdbSqlserverClusterBackupWindowStart(**backup_window_start)
        if isinstance(timeouts, dict):
            timeouts = MdbSqlserverClusterTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "database": database,
            "environment": environment,
            "host": host,
            "name": name,
            "network_id": network_id,
            "resources": resources,
            "user": user,
            "version": version,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if backup_window_start is not None:
            self._values["backup_window_start"] = backup_window_start
        if deletion_protection is not None:
            self._values["deletion_protection"] = deletion_protection
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if host_group_ids is not None:
            self._values["host_group_ids"] = host_group_ids
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if security_group_ids is not None:
            self._values["security_group_ids"] = security_group_ids
        if sqlserver_config is not None:
            self._values["sqlserver_config"] = sqlserver_config
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def database(
        self,
    ) -> typing.Union[cdktf.IResolvable, typing.List["MdbSqlserverClusterDatabase"]]:
        '''database block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#database MdbSqlserverCluster#database}
        '''
        result = self._values.get("database")
        assert result is not None, "Required property 'database' is missing"
        return typing.cast(typing.Union[cdktf.IResolvable, typing.List["MdbSqlserverClusterDatabase"]], result)

    @builtins.property
    def environment(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#environment MdbSqlserverCluster#environment}.'''
        result = self._values.get("environment")
        assert result is not None, "Required property 'environment' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def host(
        self,
    ) -> typing.Union[cdktf.IResolvable, typing.List["MdbSqlserverClusterHost"]]:
        '''host block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#host MdbSqlserverCluster#host}
        '''
        result = self._values.get("host")
        assert result is not None, "Required property 'host' is missing"
        return typing.cast(typing.Union[cdktf.IResolvable, typing.List["MdbSqlserverClusterHost"]], result)

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#name MdbSqlserverCluster#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def network_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#network_id MdbSqlserverCluster#network_id}.'''
        result = self._values.get("network_id")
        assert result is not None, "Required property 'network_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def resources(self) -> "MdbSqlserverClusterResources":
        '''resources block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#resources MdbSqlserverCluster#resources}
        '''
        result = self._values.get("resources")
        assert result is not None, "Required property 'resources' is missing"
        return typing.cast("MdbSqlserverClusterResources", result)

    @builtins.property
    def user(
        self,
    ) -> typing.Union[cdktf.IResolvable, typing.List["MdbSqlserverClusterUser"]]:
        '''user block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#user MdbSqlserverCluster#user}
        '''
        result = self._values.get("user")
        assert result is not None, "Required property 'user' is missing"
        return typing.cast(typing.Union[cdktf.IResolvable, typing.List["MdbSqlserverClusterUser"]], result)

    @builtins.property
    def version(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#version MdbSqlserverCluster#version}.'''
        result = self._values.get("version")
        assert result is not None, "Required property 'version' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def backup_window_start(
        self,
    ) -> typing.Optional[MdbSqlserverClusterBackupWindowStart]:
        '''backup_window_start block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#backup_window_start MdbSqlserverCluster#backup_window_start}
        '''
        result = self._values.get("backup_window_start")
        return typing.cast(typing.Optional[MdbSqlserverClusterBackupWindowStart], result)

    @builtins.property
    def deletion_protection(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#deletion_protection MdbSqlserverCluster#deletion_protection}.'''
        result = self._values.get("deletion_protection")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#description MdbSqlserverCluster#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#folder_id MdbSqlserverCluster#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def host_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#host_group_ids MdbSqlserverCluster#host_group_ids}.'''
        result = self._values.get("host_group_ids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#id MdbSqlserverCluster#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#labels MdbSqlserverCluster#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def security_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#security_group_ids MdbSqlserverCluster#security_group_ids}.'''
        result = self._values.get("security_group_ids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def sqlserver_config(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#sqlserver_config MdbSqlserverCluster#sqlserver_config}.'''
        result = self._values.get("sqlserver_config")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["MdbSqlserverClusterTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#timeouts MdbSqlserverCluster#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["MdbSqlserverClusterTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbSqlserverClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbSqlserverClusterDatabase",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class MdbSqlserverClusterDatabase:
    def __init__(self, *, name: builtins.str) -> None:
        '''
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#name MdbSqlserverCluster#name}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#name MdbSqlserverCluster#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbSqlserverClusterDatabase(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbSqlserverClusterDatabaseList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbSqlserverClusterDatabaseList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "MdbSqlserverClusterDatabaseOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbSqlserverClusterDatabaseOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbSqlserverClusterDatabase]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbSqlserverClusterDatabase]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbSqlserverClusterDatabase]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbSqlserverClusterDatabaseOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbSqlserverClusterDatabaseOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbSqlserverClusterDatabase]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbSqlserverClusterDatabase]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbSqlserverClusterDatabase]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbSqlserverClusterHost",
    jsii_struct_bases=[],
    name_mapping={
        "zone": "zone",
        "assign_public_ip": "assignPublicIp",
        "subnet_id": "subnetId",
    },
)
class MdbSqlserverClusterHost:
    def __init__(
        self,
        *,
        zone: builtins.str,
        assign_public_ip: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        subnet_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param zone: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#zone MdbSqlserverCluster#zone}.
        :param assign_public_ip: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#assign_public_ip MdbSqlserverCluster#assign_public_ip}.
        :param subnet_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#subnet_id MdbSqlserverCluster#subnet_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "zone": zone,
        }
        if assign_public_ip is not None:
            self._values["assign_public_ip"] = assign_public_ip
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id

    @builtins.property
    def zone(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#zone MdbSqlserverCluster#zone}.'''
        result = self._values.get("zone")
        assert result is not None, "Required property 'zone' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def assign_public_ip(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#assign_public_ip MdbSqlserverCluster#assign_public_ip}.'''
        result = self._values.get("assign_public_ip")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def subnet_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#subnet_id MdbSqlserverCluster#subnet_id}.'''
        result = self._values.get("subnet_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbSqlserverClusterHost(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbSqlserverClusterHostList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbSqlserverClusterHostList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "MdbSqlserverClusterHostOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbSqlserverClusterHostOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbSqlserverClusterHost]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbSqlserverClusterHost]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbSqlserverClusterHost]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbSqlserverClusterHostOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbSqlserverClusterHostOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetAssignPublicIp")
    def reset_assign_public_ip(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAssignPublicIp", []))

    @jsii.member(jsii_name="resetSubnetId")
    def reset_subnet_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSubnetId", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "fqdn"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIpInput")
    def assign_public_ip_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "assignPublicIpInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIdInput")
    def subnet_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "subnetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneInput")
    def zone_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "zoneInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIp")
    def assign_public_ip(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "assignPublicIp"))

    @assign_public_ip.setter
    def assign_public_ip(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "assignPublicIp", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "subnetId"))

    @subnet_id.setter
    def subnet_id(self, value: builtins.str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zone")
    def zone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zone"))

    @zone.setter
    def zone(self, value: builtins.str) -> None:
        jsii.set(self, "zone", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbSqlserverClusterHost]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbSqlserverClusterHost]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbSqlserverClusterHost]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbSqlserverClusterResources",
    jsii_struct_bases=[],
    name_mapping={
        "disk_size": "diskSize",
        "disk_type_id": "diskTypeId",
        "resource_preset_id": "resourcePresetId",
    },
)
class MdbSqlserverClusterResources:
    def __init__(
        self,
        *,
        disk_size: jsii.Number,
        disk_type_id: builtins.str,
        resource_preset_id: builtins.str,
    ) -> None:
        '''
        :param disk_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#disk_size MdbSqlserverCluster#disk_size}.
        :param disk_type_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#disk_type_id MdbSqlserverCluster#disk_type_id}.
        :param resource_preset_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#resource_preset_id MdbSqlserverCluster#resource_preset_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "disk_size": disk_size,
            "disk_type_id": disk_type_id,
            "resource_preset_id": resource_preset_id,
        }

    @builtins.property
    def disk_size(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#disk_size MdbSqlserverCluster#disk_size}.'''
        result = self._values.get("disk_size")
        assert result is not None, "Required property 'disk_size' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def disk_type_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#disk_type_id MdbSqlserverCluster#disk_type_id}.'''
        result = self._values.get("disk_type_id")
        assert result is not None, "Required property 'disk_type_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def resource_preset_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#resource_preset_id MdbSqlserverCluster#resource_preset_id}.'''
        result = self._values.get("resource_preset_id")
        assert result is not None, "Required property 'resource_preset_id' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbSqlserverClusterResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbSqlserverClusterResourcesOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbSqlserverClusterResourcesOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSizeInput")
    def disk_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "diskSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeIdInput")
    def disk_type_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "diskTypeIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetIdInput")
    def resource_preset_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourcePresetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSize")
    def disk_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "diskSize"))

    @disk_size.setter
    def disk_size(self, value: jsii.Number) -> None:
        jsii.set(self, "diskSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskTypeId")
    def disk_type_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "diskTypeId"))

    @disk_type_id.setter
    def disk_type_id(self, value: builtins.str) -> None:
        jsii.set(self, "diskTypeId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetId")
    def resource_preset_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourcePresetId"))

    @resource_preset_id.setter
    def resource_preset_id(self, value: builtins.str) -> None:
        jsii.set(self, "resourcePresetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[MdbSqlserverClusterResources]:
        return typing.cast(typing.Optional[MdbSqlserverClusterResources], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[MdbSqlserverClusterResources],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbSqlserverClusterTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class MdbSqlserverClusterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#create MdbSqlserverCluster#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#delete MdbSqlserverCluster#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#update MdbSqlserverCluster#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#create MdbSqlserverCluster#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#delete MdbSqlserverCluster#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#update MdbSqlserverCluster#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbSqlserverClusterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbSqlserverClusterTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbSqlserverClusterTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbSqlserverClusterTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbSqlserverClusterTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbSqlserverClusterTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbSqlserverClusterUser",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "password": "password", "permission": "permission"},
)
class MdbSqlserverClusterUser:
    def __init__(
        self,
        *,
        name: builtins.str,
        password: builtins.str,
        permission: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["MdbSqlserverClusterUserPermission"]]] = None,
    ) -> None:
        '''
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#name MdbSqlserverCluster#name}.
        :param password: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#password MdbSqlserverCluster#password}.
        :param permission: permission block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#permission MdbSqlserverCluster#permission}
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "password": password,
        }
        if permission is not None:
            self._values["permission"] = permission

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#name MdbSqlserverCluster#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def password(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#password MdbSqlserverCluster#password}.'''
        result = self._values.get("password")
        assert result is not None, "Required property 'password' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def permission(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbSqlserverClusterUserPermission"]]]:
        '''permission block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#permission MdbSqlserverCluster#permission}
        '''
        result = self._values.get("permission")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbSqlserverClusterUserPermission"]]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbSqlserverClusterUser(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbSqlserverClusterUserList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbSqlserverClusterUserList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "MdbSqlserverClusterUserOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbSqlserverClusterUserOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbSqlserverClusterUser]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbSqlserverClusterUser]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbSqlserverClusterUser]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbSqlserverClusterUserOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbSqlserverClusterUserOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putPermission")
    def put_permission(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["MdbSqlserverClusterUserPermission"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putPermission", [value]))

    @jsii.member(jsii_name="resetPermission")
    def reset_permission(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPermission", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="permission")
    def permission(self) -> "MdbSqlserverClusterUserPermissionList":
        return typing.cast("MdbSqlserverClusterUserPermissionList", jsii.get(self, "permission"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="passwordInput")
    def password_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "passwordInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="permissionInput")
    def permission_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbSqlserverClusterUserPermission"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MdbSqlserverClusterUserPermission"]]], jsii.get(self, "permissionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="password")
    def password(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "password"))

    @password.setter
    def password(self, value: builtins.str) -> None:
        jsii.set(self, "password", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbSqlserverClusterUser]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbSqlserverClusterUser]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbSqlserverClusterUser]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MdbSqlserverClusterUserPermission",
    jsii_struct_bases=[],
    name_mapping={"database_name": "databaseName", "roles": "roles"},
)
class MdbSqlserverClusterUserPermission:
    def __init__(
        self,
        *,
        database_name: builtins.str,
        roles: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param database_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#database_name MdbSqlserverCluster#database_name}.
        :param roles: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#roles MdbSqlserverCluster#roles}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "database_name": database_name,
        }
        if roles is not None:
            self._values["roles"] = roles

    @builtins.property
    def database_name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#database_name MdbSqlserverCluster#database_name}.'''
        result = self._values.get("database_name")
        assert result is not None, "Required property 'database_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def roles(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/mdb_sqlserver_cluster#roles MdbSqlserverCluster#roles}.'''
        result = self._values.get("roles")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MdbSqlserverClusterUserPermission(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MdbSqlserverClusterUserPermissionList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbSqlserverClusterUserPermissionList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "MdbSqlserverClusterUserPermissionOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("MdbSqlserverClusterUserPermissionOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbSqlserverClusterUserPermission]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbSqlserverClusterUserPermission]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MdbSqlserverClusterUserPermission]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MdbSqlserverClusterUserPermissionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MdbSqlserverClusterUserPermissionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetRoles")
    def reset_roles(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRoles", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databaseNameInput")
    def database_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "databaseNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="rolesInput")
    def roles_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "rolesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databaseName")
    def database_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "databaseName"))

    @database_name.setter
    def database_name(self, value: builtins.str) -> None:
        jsii.set(self, "databaseName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="roles")
    def roles(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "roles"))

    @roles.setter
    def roles(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "roles", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, MdbSqlserverClusterUserPermission]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, MdbSqlserverClusterUserPermission]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, MdbSqlserverClusterUserPermission]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class MessageQueue(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.MessageQueue",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/message_queue yandex_message_queue}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        access_key: typing.Optional[builtins.str] = None,
        content_based_deduplication: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        delay_seconds: typing.Optional[jsii.Number] = None,
        fifo_queue: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        id: typing.Optional[builtins.str] = None,
        max_message_size: typing.Optional[jsii.Number] = None,
        message_retention_seconds: typing.Optional[jsii.Number] = None,
        name: typing.Optional[builtins.str] = None,
        name_prefix: typing.Optional[builtins.str] = None,
        receive_wait_time_seconds: typing.Optional[jsii.Number] = None,
        redrive_policy: typing.Optional[builtins.str] = None,
        secret_key: typing.Optional[builtins.str] = None,
        visibility_timeout_seconds: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/message_queue yandex_message_queue} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param access_key: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#access_key MessageQueue#access_key}.
        :param content_based_deduplication: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#content_based_deduplication MessageQueue#content_based_deduplication}.
        :param delay_seconds: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#delay_seconds MessageQueue#delay_seconds}.
        :param fifo_queue: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#fifo_queue MessageQueue#fifo_queue}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#id MessageQueue#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param max_message_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#max_message_size MessageQueue#max_message_size}.
        :param message_retention_seconds: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#message_retention_seconds MessageQueue#message_retention_seconds}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#name MessageQueue#name}.
        :param name_prefix: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#name_prefix MessageQueue#name_prefix}.
        :param receive_wait_time_seconds: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#receive_wait_time_seconds MessageQueue#receive_wait_time_seconds}.
        :param redrive_policy: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#redrive_policy MessageQueue#redrive_policy}.
        :param secret_key: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#secret_key MessageQueue#secret_key}.
        :param visibility_timeout_seconds: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#visibility_timeout_seconds MessageQueue#visibility_timeout_seconds}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = MessageQueueConfig(
            access_key=access_key,
            content_based_deduplication=content_based_deduplication,
            delay_seconds=delay_seconds,
            fifo_queue=fifo_queue,
            id=id,
            max_message_size=max_message_size,
            message_retention_seconds=message_retention_seconds,
            name=name,
            name_prefix=name_prefix,
            receive_wait_time_seconds=receive_wait_time_seconds,
            redrive_policy=redrive_policy,
            secret_key=secret_key,
            visibility_timeout_seconds=visibility_timeout_seconds,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetAccessKey")
    def reset_access_key(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAccessKey", []))

    @jsii.member(jsii_name="resetContentBasedDeduplication")
    def reset_content_based_deduplication(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetContentBasedDeduplication", []))

    @jsii.member(jsii_name="resetDelaySeconds")
    def reset_delay_seconds(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelaySeconds", []))

    @jsii.member(jsii_name="resetFifoQueue")
    def reset_fifo_queue(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFifoQueue", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetMaxMessageSize")
    def reset_max_message_size(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxMessageSize", []))

    @jsii.member(jsii_name="resetMessageRetentionSeconds")
    def reset_message_retention_seconds(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMessageRetentionSeconds", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetNamePrefix")
    def reset_name_prefix(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNamePrefix", []))

    @jsii.member(jsii_name="resetReceiveWaitTimeSeconds")
    def reset_receive_wait_time_seconds(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetReceiveWaitTimeSeconds", []))

    @jsii.member(jsii_name="resetRedrivePolicy")
    def reset_redrive_policy(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRedrivePolicy", []))

    @jsii.member(jsii_name="resetSecretKey")
    def reset_secret_key(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecretKey", []))

    @jsii.member(jsii_name="resetVisibilityTimeoutSeconds")
    def reset_visibility_timeout_seconds(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetVisibilityTimeoutSeconds", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="arn")
    def arn(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "arn"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="accessKeyInput")
    def access_key_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "accessKeyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="contentBasedDeduplicationInput")
    def content_based_deduplication_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "contentBasedDeduplicationInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delaySecondsInput")
    def delay_seconds_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "delaySecondsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fifoQueueInput")
    def fifo_queue_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "fifoQueueInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxMessageSizeInput")
    def max_message_size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxMessageSizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="messageRetentionSecondsInput")
    def message_retention_seconds_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "messageRetentionSecondsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="namePrefixInput")
    def name_prefix_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "namePrefixInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="receiveWaitTimeSecondsInput")
    def receive_wait_time_seconds_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "receiveWaitTimeSecondsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="redrivePolicyInput")
    def redrive_policy_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "redrivePolicyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="secretKeyInput")
    def secret_key_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "secretKeyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="visibilityTimeoutSecondsInput")
    def visibility_timeout_seconds_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "visibilityTimeoutSecondsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="accessKey")
    def access_key(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "accessKey"))

    @access_key.setter
    def access_key(self, value: builtins.str) -> None:
        jsii.set(self, "accessKey", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="contentBasedDeduplication")
    def content_based_deduplication(
        self,
    ) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "contentBasedDeduplication"))

    @content_based_deduplication.setter
    def content_based_deduplication(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "contentBasedDeduplication", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delaySeconds")
    def delay_seconds(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "delaySeconds"))

    @delay_seconds.setter
    def delay_seconds(self, value: jsii.Number) -> None:
        jsii.set(self, "delaySeconds", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fifoQueue")
    def fifo_queue(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "fifoQueue"))

    @fifo_queue.setter
    def fifo_queue(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "fifoQueue", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxMessageSize")
    def max_message_size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxMessageSize"))

    @max_message_size.setter
    def max_message_size(self, value: jsii.Number) -> None:
        jsii.set(self, "maxMessageSize", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="messageRetentionSeconds")
    def message_retention_seconds(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "messageRetentionSeconds"))

    @message_retention_seconds.setter
    def message_retention_seconds(self, value: jsii.Number) -> None:
        jsii.set(self, "messageRetentionSeconds", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "namePrefix"))

    @name_prefix.setter
    def name_prefix(self, value: builtins.str) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="receiveWaitTimeSeconds")
    def receive_wait_time_seconds(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "receiveWaitTimeSeconds"))

    @receive_wait_time_seconds.setter
    def receive_wait_time_seconds(self, value: jsii.Number) -> None:
        jsii.set(self, "receiveWaitTimeSeconds", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="redrivePolicy")
    def redrive_policy(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "redrivePolicy"))

    @redrive_policy.setter
    def redrive_policy(self, value: builtins.str) -> None:
        jsii.set(self, "redrivePolicy", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="secretKey")
    def secret_key(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "secretKey"))

    @secret_key.setter
    def secret_key(self, value: builtins.str) -> None:
        jsii.set(self, "secretKey", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="visibilityTimeoutSeconds")
    def visibility_timeout_seconds(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "visibilityTimeoutSeconds"))

    @visibility_timeout_seconds.setter
    def visibility_timeout_seconds(self, value: jsii.Number) -> None:
        jsii.set(self, "visibilityTimeoutSeconds", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.MessageQueueConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "access_key": "accessKey",
        "content_based_deduplication": "contentBasedDeduplication",
        "delay_seconds": "delaySeconds",
        "fifo_queue": "fifoQueue",
        "id": "id",
        "max_message_size": "maxMessageSize",
        "message_retention_seconds": "messageRetentionSeconds",
        "name": "name",
        "name_prefix": "namePrefix",
        "receive_wait_time_seconds": "receiveWaitTimeSeconds",
        "redrive_policy": "redrivePolicy",
        "secret_key": "secretKey",
        "visibility_timeout_seconds": "visibilityTimeoutSeconds",
    },
)
class MessageQueueConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        access_key: typing.Optional[builtins.str] = None,
        content_based_deduplication: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        delay_seconds: typing.Optional[jsii.Number] = None,
        fifo_queue: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        id: typing.Optional[builtins.str] = None,
        max_message_size: typing.Optional[jsii.Number] = None,
        message_retention_seconds: typing.Optional[jsii.Number] = None,
        name: typing.Optional[builtins.str] = None,
        name_prefix: typing.Optional[builtins.str] = None,
        receive_wait_time_seconds: typing.Optional[jsii.Number] = None,
        redrive_policy: typing.Optional[builtins.str] = None,
        secret_key: typing.Optional[builtins.str] = None,
        visibility_timeout_seconds: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param access_key: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#access_key MessageQueue#access_key}.
        :param content_based_deduplication: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#content_based_deduplication MessageQueue#content_based_deduplication}.
        :param delay_seconds: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#delay_seconds MessageQueue#delay_seconds}.
        :param fifo_queue: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#fifo_queue MessageQueue#fifo_queue}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#id MessageQueue#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param max_message_size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#max_message_size MessageQueue#max_message_size}.
        :param message_retention_seconds: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#message_retention_seconds MessageQueue#message_retention_seconds}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#name MessageQueue#name}.
        :param name_prefix: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#name_prefix MessageQueue#name_prefix}.
        :param receive_wait_time_seconds: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#receive_wait_time_seconds MessageQueue#receive_wait_time_seconds}.
        :param redrive_policy: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#redrive_policy MessageQueue#redrive_policy}.
        :param secret_key: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#secret_key MessageQueue#secret_key}.
        :param visibility_timeout_seconds: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#visibility_timeout_seconds MessageQueue#visibility_timeout_seconds}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if access_key is not None:
            self._values["access_key"] = access_key
        if content_based_deduplication is not None:
            self._values["content_based_deduplication"] = content_based_deduplication
        if delay_seconds is not None:
            self._values["delay_seconds"] = delay_seconds
        if fifo_queue is not None:
            self._values["fifo_queue"] = fifo_queue
        if id is not None:
            self._values["id"] = id
        if max_message_size is not None:
            self._values["max_message_size"] = max_message_size
        if message_retention_seconds is not None:
            self._values["message_retention_seconds"] = message_retention_seconds
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if receive_wait_time_seconds is not None:
            self._values["receive_wait_time_seconds"] = receive_wait_time_seconds
        if redrive_policy is not None:
            self._values["redrive_policy"] = redrive_policy
        if secret_key is not None:
            self._values["secret_key"] = secret_key
        if visibility_timeout_seconds is not None:
            self._values["visibility_timeout_seconds"] = visibility_timeout_seconds

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def access_key(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#access_key MessageQueue#access_key}.'''
        result = self._values.get("access_key")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def content_based_deduplication(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#content_based_deduplication MessageQueue#content_based_deduplication}.'''
        result = self._values.get("content_based_deduplication")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def delay_seconds(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#delay_seconds MessageQueue#delay_seconds}.'''
        result = self._values.get("delay_seconds")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fifo_queue(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#fifo_queue MessageQueue#fifo_queue}.'''
        result = self._values.get("fifo_queue")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#id MessageQueue#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def max_message_size(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#max_message_size MessageQueue#max_message_size}.'''
        result = self._values.get("max_message_size")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def message_retention_seconds(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#message_retention_seconds MessageQueue#message_retention_seconds}.'''
        result = self._values.get("message_retention_seconds")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#name MessageQueue#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name_prefix(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#name_prefix MessageQueue#name_prefix}.'''
        result = self._values.get("name_prefix")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def receive_wait_time_seconds(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#receive_wait_time_seconds MessageQueue#receive_wait_time_seconds}.'''
        result = self._values.get("receive_wait_time_seconds")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def redrive_policy(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#redrive_policy MessageQueue#redrive_policy}.'''
        result = self._values.get("redrive_policy")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def secret_key(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#secret_key MessageQueue#secret_key}.'''
        result = self._values.get("secret_key")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def visibility_timeout_seconds(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/message_queue#visibility_timeout_seconds MessageQueue#visibility_timeout_seconds}.'''
        result = self._values.get("visibility_timeout_seconds")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MessageQueueConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OrganizationmanagerOrganizationIamBinding(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.OrganizationmanagerOrganizationIamBinding",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_organization_iam_binding yandex_organizationmanager_organization_iam_binding}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        members: typing.Sequence[builtins.str],
        organization_id: builtins.str,
        role: builtins.str,
        id: typing.Optional[builtins.str] = None,
        sleep_after: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_organization_iam_binding yandex_organizationmanager_organization_iam_binding} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param members: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_organization_iam_binding#members OrganizationmanagerOrganizationIamBinding#members}.
        :param organization_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_organization_iam_binding#organization_id OrganizationmanagerOrganizationIamBinding#organization_id}.
        :param role: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_organization_iam_binding#role OrganizationmanagerOrganizationIamBinding#role}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_organization_iam_binding#id OrganizationmanagerOrganizationIamBinding#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param sleep_after: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_organization_iam_binding#sleep_after OrganizationmanagerOrganizationIamBinding#sleep_after}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = OrganizationmanagerOrganizationIamBindingConfig(
            members=members,
            organization_id=organization_id,
            role=role,
            id=id,
            sleep_after=sleep_after,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetSleepAfter")
    def reset_sleep_after(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSleepAfter", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="membersInput")
    def members_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "membersInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="organizationIdInput")
    def organization_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "organizationIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="roleInput")
    def role_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "roleInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sleepAfterInput")
    def sleep_after_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "sleepAfterInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="members")
    def members(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "members"))

    @members.setter
    def members(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "members", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="organizationId")
    def organization_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "organizationId"))

    @organization_id.setter
    def organization_id(self, value: builtins.str) -> None:
        jsii.set(self, "organizationId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="role")
    def role(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "role"))

    @role.setter
    def role(self, value: builtins.str) -> None:
        jsii.set(self, "role", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sleepAfter")
    def sleep_after(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "sleepAfter"))

    @sleep_after.setter
    def sleep_after(self, value: jsii.Number) -> None:
        jsii.set(self, "sleepAfter", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.OrganizationmanagerOrganizationIamBindingConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "members": "members",
        "organization_id": "organizationId",
        "role": "role",
        "id": "id",
        "sleep_after": "sleepAfter",
    },
)
class OrganizationmanagerOrganizationIamBindingConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        members: typing.Sequence[builtins.str],
        organization_id: builtins.str,
        role: builtins.str,
        id: typing.Optional[builtins.str] = None,
        sleep_after: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param members: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_organization_iam_binding#members OrganizationmanagerOrganizationIamBinding#members}.
        :param organization_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_organization_iam_binding#organization_id OrganizationmanagerOrganizationIamBinding#organization_id}.
        :param role: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_organization_iam_binding#role OrganizationmanagerOrganizationIamBinding#role}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_organization_iam_binding#id OrganizationmanagerOrganizationIamBinding#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param sleep_after: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_organization_iam_binding#sleep_after OrganizationmanagerOrganizationIamBinding#sleep_after}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {
            "members": members,
            "organization_id": organization_id,
            "role": role,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if id is not None:
            self._values["id"] = id
        if sleep_after is not None:
            self._values["sleep_after"] = sleep_after

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def members(self) -> typing.List[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_organization_iam_binding#members OrganizationmanagerOrganizationIamBinding#members}.'''
        result = self._values.get("members")
        assert result is not None, "Required property 'members' is missing"
        return typing.cast(typing.List[builtins.str], result)

    @builtins.property
    def organization_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_organization_iam_binding#organization_id OrganizationmanagerOrganizationIamBinding#organization_id}.'''
        result = self._values.get("organization_id")
        assert result is not None, "Required property 'organization_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def role(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_organization_iam_binding#role OrganizationmanagerOrganizationIamBinding#role}.'''
        result = self._values.get("role")
        assert result is not None, "Required property 'role' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_organization_iam_binding#id OrganizationmanagerOrganizationIamBinding#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def sleep_after(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_organization_iam_binding#sleep_after OrganizationmanagerOrganizationIamBinding#sleep_after}.'''
        result = self._values.get("sleep_after")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OrganizationmanagerOrganizationIamBindingConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OrganizationmanagerOrganizationIamMember(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.OrganizationmanagerOrganizationIamMember",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_organization_iam_member yandex_organizationmanager_organization_iam_member}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        member: builtins.str,
        organization_id: builtins.str,
        role: builtins.str,
        id: typing.Optional[builtins.str] = None,
        sleep_after: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_organization_iam_member yandex_organizationmanager_organization_iam_member} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param member: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_organization_iam_member#member OrganizationmanagerOrganizationIamMember#member}.
        :param organization_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_organization_iam_member#organization_id OrganizationmanagerOrganizationIamMember#organization_id}.
        :param role: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_organization_iam_member#role OrganizationmanagerOrganizationIamMember#role}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_organization_iam_member#id OrganizationmanagerOrganizationIamMember#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param sleep_after: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_organization_iam_member#sleep_after OrganizationmanagerOrganizationIamMember#sleep_after}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = OrganizationmanagerOrganizationIamMemberConfig(
            member=member,
            organization_id=organization_id,
            role=role,
            id=id,
            sleep_after=sleep_after,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetSleepAfter")
    def reset_sleep_after(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSleepAfter", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="memberInput")
    def member_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "memberInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="organizationIdInput")
    def organization_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "organizationIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="roleInput")
    def role_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "roleInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sleepAfterInput")
    def sleep_after_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "sleepAfterInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="member")
    def member(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "member"))

    @member.setter
    def member(self, value: builtins.str) -> None:
        jsii.set(self, "member", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="organizationId")
    def organization_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "organizationId"))

    @organization_id.setter
    def organization_id(self, value: builtins.str) -> None:
        jsii.set(self, "organizationId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="role")
    def role(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "role"))

    @role.setter
    def role(self, value: builtins.str) -> None:
        jsii.set(self, "role", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sleepAfter")
    def sleep_after(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "sleepAfter"))

    @sleep_after.setter
    def sleep_after(self, value: jsii.Number) -> None:
        jsii.set(self, "sleepAfter", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.OrganizationmanagerOrganizationIamMemberConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "member": "member",
        "organization_id": "organizationId",
        "role": "role",
        "id": "id",
        "sleep_after": "sleepAfter",
    },
)
class OrganizationmanagerOrganizationIamMemberConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        member: builtins.str,
        organization_id: builtins.str,
        role: builtins.str,
        id: typing.Optional[builtins.str] = None,
        sleep_after: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param member: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_organization_iam_member#member OrganizationmanagerOrganizationIamMember#member}.
        :param organization_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_organization_iam_member#organization_id OrganizationmanagerOrganizationIamMember#organization_id}.
        :param role: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_organization_iam_member#role OrganizationmanagerOrganizationIamMember#role}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_organization_iam_member#id OrganizationmanagerOrganizationIamMember#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param sleep_after: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_organization_iam_member#sleep_after OrganizationmanagerOrganizationIamMember#sleep_after}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {
            "member": member,
            "organization_id": organization_id,
            "role": role,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if id is not None:
            self._values["id"] = id
        if sleep_after is not None:
            self._values["sleep_after"] = sleep_after

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def member(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_organization_iam_member#member OrganizationmanagerOrganizationIamMember#member}.'''
        result = self._values.get("member")
        assert result is not None, "Required property 'member' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def organization_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_organization_iam_member#organization_id OrganizationmanagerOrganizationIamMember#organization_id}.'''
        result = self._values.get("organization_id")
        assert result is not None, "Required property 'organization_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def role(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_organization_iam_member#role OrganizationmanagerOrganizationIamMember#role}.'''
        result = self._values.get("role")
        assert result is not None, "Required property 'role' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_organization_iam_member#id OrganizationmanagerOrganizationIamMember#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def sleep_after(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_organization_iam_member#sleep_after OrganizationmanagerOrganizationIamMember#sleep_after}.'''
        result = self._values.get("sleep_after")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OrganizationmanagerOrganizationIamMemberConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OrganizationmanagerSamlFederation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.OrganizationmanagerSamlFederation",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation yandex_organizationmanager_saml_federation}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        issuer: builtins.str,
        name: builtins.str,
        organization_id: builtins.str,
        sso_binding: builtins.str,
        sso_url: builtins.str,
        auto_create_account_on_login: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        case_insensitive_name_ids: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        cookie_max_age: typing.Optional[builtins.str] = None,
        description: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        security_settings: typing.Optional["OrganizationmanagerSamlFederationSecuritySettings"] = None,
        timeouts: typing.Optional["OrganizationmanagerSamlFederationTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation yandex_organizationmanager_saml_federation} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param issuer: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#issuer OrganizationmanagerSamlFederation#issuer}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#name OrganizationmanagerSamlFederation#name}.
        :param organization_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#organization_id OrganizationmanagerSamlFederation#organization_id}.
        :param sso_binding: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#sso_binding OrganizationmanagerSamlFederation#sso_binding}.
        :param sso_url: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#sso_url OrganizationmanagerSamlFederation#sso_url}.
        :param auto_create_account_on_login: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#auto_create_account_on_login OrganizationmanagerSamlFederation#auto_create_account_on_login}.
        :param case_insensitive_name_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#case_insensitive_name_ids OrganizationmanagerSamlFederation#case_insensitive_name_ids}.
        :param cookie_max_age: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#cookie_max_age OrganizationmanagerSamlFederation#cookie_max_age}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#description OrganizationmanagerSamlFederation#description}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#id OrganizationmanagerSamlFederation#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#labels OrganizationmanagerSamlFederation#labels}.
        :param security_settings: security_settings block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#security_settings OrganizationmanagerSamlFederation#security_settings}
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#timeouts OrganizationmanagerSamlFederation#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = OrganizationmanagerSamlFederationConfig(
            issuer=issuer,
            name=name,
            organization_id=organization_id,
            sso_binding=sso_binding,
            sso_url=sso_url,
            auto_create_account_on_login=auto_create_account_on_login,
            case_insensitive_name_ids=case_insensitive_name_ids,
            cookie_max_age=cookie_max_age,
            description=description,
            id=id,
            labels=labels,
            security_settings=security_settings,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putSecuritySettings")
    def put_security_settings(
        self,
        *,
        encrypted_assertions: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        '''
        :param encrypted_assertions: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#encrypted_assertions OrganizationmanagerSamlFederation#encrypted_assertions}.
        '''
        value = OrganizationmanagerSamlFederationSecuritySettings(
            encrypted_assertions=encrypted_assertions
        )

        return typing.cast(None, jsii.invoke(self, "putSecuritySettings", [value]))

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#create OrganizationmanagerSamlFederation#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#delete OrganizationmanagerSamlFederation#delete}.
        :param read: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#read OrganizationmanagerSamlFederation#read}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#update OrganizationmanagerSamlFederation#update}.
        '''
        value = OrganizationmanagerSamlFederationTimeouts(
            create=create, delete=delete, read=read, update=update
        )

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetAutoCreateAccountOnLogin")
    def reset_auto_create_account_on_login(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAutoCreateAccountOnLogin", []))

    @jsii.member(jsii_name="resetCaseInsensitiveNameIds")
    def reset_case_insensitive_name_ids(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCaseInsensitiveNameIds", []))

    @jsii.member(jsii_name="resetCookieMaxAge")
    def reset_cookie_max_age(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCookieMaxAge", []))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetSecuritySettings")
    def reset_security_settings(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecuritySettings", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securitySettings")
    def security_settings(
        self,
    ) -> "OrganizationmanagerSamlFederationSecuritySettingsOutputReference":
        return typing.cast("OrganizationmanagerSamlFederationSecuritySettingsOutputReference", jsii.get(self, "securitySettings"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "OrganizationmanagerSamlFederationTimeoutsOutputReference":
        return typing.cast("OrganizationmanagerSamlFederationTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoCreateAccountOnLoginInput")
    def auto_create_account_on_login_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "autoCreateAccountOnLoginInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="caseInsensitiveNameIdsInput")
    def case_insensitive_name_ids_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "caseInsensitiveNameIdsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cookieMaxAgeInput")
    def cookie_max_age_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "cookieMaxAgeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="issuerInput")
    def issuer_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "issuerInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="organizationIdInput")
    def organization_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "organizationIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securitySettingsInput")
    def security_settings_input(
        self,
    ) -> typing.Optional["OrganizationmanagerSamlFederationSecuritySettings"]:
        return typing.cast(typing.Optional["OrganizationmanagerSamlFederationSecuritySettings"], jsii.get(self, "securitySettingsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ssoBindingInput")
    def sso_binding_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "ssoBindingInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ssoUrlInput")
    def sso_url_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "ssoUrlInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "OrganizationmanagerSamlFederationTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "OrganizationmanagerSamlFederationTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoCreateAccountOnLogin")
    def auto_create_account_on_login(
        self,
    ) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "autoCreateAccountOnLogin"))

    @auto_create_account_on_login.setter
    def auto_create_account_on_login(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "autoCreateAccountOnLogin", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="caseInsensitiveNameIds")
    def case_insensitive_name_ids(
        self,
    ) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "caseInsensitiveNameIds"))

    @case_insensitive_name_ids.setter
    def case_insensitive_name_ids(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "caseInsensitiveNameIds", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cookieMaxAge")
    def cookie_max_age(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "cookieMaxAge"))

    @cookie_max_age.setter
    def cookie_max_age(self, value: builtins.str) -> None:
        jsii.set(self, "cookieMaxAge", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="issuer")
    def issuer(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "issuer"))

    @issuer.setter
    def issuer(self, value: builtins.str) -> None:
        jsii.set(self, "issuer", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="organizationId")
    def organization_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "organizationId"))

    @organization_id.setter
    def organization_id(self, value: builtins.str) -> None:
        jsii.set(self, "organizationId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ssoBinding")
    def sso_binding(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ssoBinding"))

    @sso_binding.setter
    def sso_binding(self, value: builtins.str) -> None:
        jsii.set(self, "ssoBinding", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ssoUrl")
    def sso_url(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ssoUrl"))

    @sso_url.setter
    def sso_url(self, value: builtins.str) -> None:
        jsii.set(self, "ssoUrl", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.OrganizationmanagerSamlFederationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "issuer": "issuer",
        "name": "name",
        "organization_id": "organizationId",
        "sso_binding": "ssoBinding",
        "sso_url": "ssoUrl",
        "auto_create_account_on_login": "autoCreateAccountOnLogin",
        "case_insensitive_name_ids": "caseInsensitiveNameIds",
        "cookie_max_age": "cookieMaxAge",
        "description": "description",
        "id": "id",
        "labels": "labels",
        "security_settings": "securitySettings",
        "timeouts": "timeouts",
    },
)
class OrganizationmanagerSamlFederationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        issuer: builtins.str,
        name: builtins.str,
        organization_id: builtins.str,
        sso_binding: builtins.str,
        sso_url: builtins.str,
        auto_create_account_on_login: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        case_insensitive_name_ids: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        cookie_max_age: typing.Optional[builtins.str] = None,
        description: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        security_settings: typing.Optional["OrganizationmanagerSamlFederationSecuritySettings"] = None,
        timeouts: typing.Optional["OrganizationmanagerSamlFederationTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param issuer: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#issuer OrganizationmanagerSamlFederation#issuer}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#name OrganizationmanagerSamlFederation#name}.
        :param organization_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#organization_id OrganizationmanagerSamlFederation#organization_id}.
        :param sso_binding: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#sso_binding OrganizationmanagerSamlFederation#sso_binding}.
        :param sso_url: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#sso_url OrganizationmanagerSamlFederation#sso_url}.
        :param auto_create_account_on_login: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#auto_create_account_on_login OrganizationmanagerSamlFederation#auto_create_account_on_login}.
        :param case_insensitive_name_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#case_insensitive_name_ids OrganizationmanagerSamlFederation#case_insensitive_name_ids}.
        :param cookie_max_age: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#cookie_max_age OrganizationmanagerSamlFederation#cookie_max_age}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#description OrganizationmanagerSamlFederation#description}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#id OrganizationmanagerSamlFederation#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#labels OrganizationmanagerSamlFederation#labels}.
        :param security_settings: security_settings block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#security_settings OrganizationmanagerSamlFederation#security_settings}
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#timeouts OrganizationmanagerSamlFederation#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(security_settings, dict):
            security_settings = OrganizationmanagerSamlFederationSecuritySettings(**security_settings)
        if isinstance(timeouts, dict):
            timeouts = OrganizationmanagerSamlFederationTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "issuer": issuer,
            "name": name,
            "organization_id": organization_id,
            "sso_binding": sso_binding,
            "sso_url": sso_url,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if auto_create_account_on_login is not None:
            self._values["auto_create_account_on_login"] = auto_create_account_on_login
        if case_insensitive_name_ids is not None:
            self._values["case_insensitive_name_ids"] = case_insensitive_name_ids
        if cookie_max_age is not None:
            self._values["cookie_max_age"] = cookie_max_age
        if description is not None:
            self._values["description"] = description
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if security_settings is not None:
            self._values["security_settings"] = security_settings
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def issuer(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#issuer OrganizationmanagerSamlFederation#issuer}.'''
        result = self._values.get("issuer")
        assert result is not None, "Required property 'issuer' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#name OrganizationmanagerSamlFederation#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def organization_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#organization_id OrganizationmanagerSamlFederation#organization_id}.'''
        result = self._values.get("organization_id")
        assert result is not None, "Required property 'organization_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def sso_binding(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#sso_binding OrganizationmanagerSamlFederation#sso_binding}.'''
        result = self._values.get("sso_binding")
        assert result is not None, "Required property 'sso_binding' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def sso_url(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#sso_url OrganizationmanagerSamlFederation#sso_url}.'''
        result = self._values.get("sso_url")
        assert result is not None, "Required property 'sso_url' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def auto_create_account_on_login(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#auto_create_account_on_login OrganizationmanagerSamlFederation#auto_create_account_on_login}.'''
        result = self._values.get("auto_create_account_on_login")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def case_insensitive_name_ids(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#case_insensitive_name_ids OrganizationmanagerSamlFederation#case_insensitive_name_ids}.'''
        result = self._values.get("case_insensitive_name_ids")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def cookie_max_age(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#cookie_max_age OrganizationmanagerSamlFederation#cookie_max_age}.'''
        result = self._values.get("cookie_max_age")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#description OrganizationmanagerSamlFederation#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#id OrganizationmanagerSamlFederation#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#labels OrganizationmanagerSamlFederation#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def security_settings(
        self,
    ) -> typing.Optional["OrganizationmanagerSamlFederationSecuritySettings"]:
        '''security_settings block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#security_settings OrganizationmanagerSamlFederation#security_settings}
        '''
        result = self._values.get("security_settings")
        return typing.cast(typing.Optional["OrganizationmanagerSamlFederationSecuritySettings"], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["OrganizationmanagerSamlFederationTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#timeouts OrganizationmanagerSamlFederation#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["OrganizationmanagerSamlFederationTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OrganizationmanagerSamlFederationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.OrganizationmanagerSamlFederationSecuritySettings",
    jsii_struct_bases=[],
    name_mapping={"encrypted_assertions": "encryptedAssertions"},
)
class OrganizationmanagerSamlFederationSecuritySettings:
    def __init__(
        self,
        *,
        encrypted_assertions: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        '''
        :param encrypted_assertions: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#encrypted_assertions OrganizationmanagerSamlFederation#encrypted_assertions}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "encrypted_assertions": encrypted_assertions,
        }

    @builtins.property
    def encrypted_assertions(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#encrypted_assertions OrganizationmanagerSamlFederation#encrypted_assertions}.'''
        result = self._values.get("encrypted_assertions")
        assert result is not None, "Required property 'encrypted_assertions' is missing"
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OrganizationmanagerSamlFederationSecuritySettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OrganizationmanagerSamlFederationSecuritySettingsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.OrganizationmanagerSamlFederationSecuritySettingsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="encryptedAssertionsInput")
    def encrypted_assertions_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "encryptedAssertionsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="encryptedAssertions")
    def encrypted_assertions(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "encryptedAssertions"))

    @encrypted_assertions.setter
    def encrypted_assertions(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "encryptedAssertions", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[OrganizationmanagerSamlFederationSecuritySettings]:
        return typing.cast(typing.Optional[OrganizationmanagerSamlFederationSecuritySettings], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[OrganizationmanagerSamlFederationSecuritySettings],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.OrganizationmanagerSamlFederationTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class OrganizationmanagerSamlFederationTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#create OrganizationmanagerSamlFederation#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#delete OrganizationmanagerSamlFederation#delete}.
        :param read: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#read OrganizationmanagerSamlFederation#read}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#update OrganizationmanagerSamlFederation#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#create OrganizationmanagerSamlFederation#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#delete OrganizationmanagerSamlFederation#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#read OrganizationmanagerSamlFederation#read}.'''
        result = self._values.get("read")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/organizationmanager_saml_federation#update OrganizationmanagerSamlFederation#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OrganizationmanagerSamlFederationTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OrganizationmanagerSamlFederationTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.OrganizationmanagerSamlFederationTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetRead")
    def reset_read(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRead", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="readInput")
    def read_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "readInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="read")
    def read(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "read"))

    @read.setter
    def read(self, value: builtins.str) -> None:
        jsii.set(self, "read", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, OrganizationmanagerSamlFederationTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, OrganizationmanagerSamlFederationTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, OrganizationmanagerSamlFederationTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ResourcemanagerCloud(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ResourcemanagerCloud",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud yandex_resourcemanager_cloud}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        description: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        organization_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ResourcemanagerCloudTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud yandex_resourcemanager_cloud} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud#description ResourcemanagerCloud#description}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud#id ResourcemanagerCloud#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud#labels ResourcemanagerCloud#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud#name ResourcemanagerCloud#name}.
        :param organization_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud#organization_id ResourcemanagerCloud#organization_id}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud#timeouts ResourcemanagerCloud#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = ResourcemanagerCloudConfig(
            description=description,
            id=id,
            labels=labels,
            name=name,
            organization_id=organization_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud#create ResourcemanagerCloud#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud#delete ResourcemanagerCloud#delete}.
        :param read: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud#read ResourcemanagerCloud#read}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud#update ResourcemanagerCloud#update}.
        '''
        value = ResourcemanagerCloudTimeouts(
            create=create, delete=delete, read=read, update=update
        )

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetOrganizationId")
    def reset_organization_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOrganizationId", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "ResourcemanagerCloudTimeoutsOutputReference":
        return typing.cast("ResourcemanagerCloudTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="organizationIdInput")
    def organization_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "organizationIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "ResourcemanagerCloudTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "ResourcemanagerCloudTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="organizationId")
    def organization_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "organizationId"))

    @organization_id.setter
    def organization_id(self, value: builtins.str) -> None:
        jsii.set(self, "organizationId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ResourcemanagerCloudConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "description": "description",
        "id": "id",
        "labels": "labels",
        "name": "name",
        "organization_id": "organizationId",
        "timeouts": "timeouts",
    },
)
class ResourcemanagerCloudConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        description: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        organization_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ResourcemanagerCloudTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud#description ResourcemanagerCloud#description}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud#id ResourcemanagerCloud#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud#labels ResourcemanagerCloud#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud#name ResourcemanagerCloud#name}.
        :param organization_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud#organization_id ResourcemanagerCloud#organization_id}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud#timeouts ResourcemanagerCloud#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ResourcemanagerCloudTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if name is not None:
            self._values["name"] = name
        if organization_id is not None:
            self._values["organization_id"] = organization_id
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud#description ResourcemanagerCloud#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud#id ResourcemanagerCloud#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud#labels ResourcemanagerCloud#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud#name ResourcemanagerCloud#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def organization_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud#organization_id ResourcemanagerCloud#organization_id}.'''
        result = self._values.get("organization_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["ResourcemanagerCloudTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud#timeouts ResourcemanagerCloud#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["ResourcemanagerCloudTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ResourcemanagerCloudConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ResourcemanagerCloudIamBinding(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ResourcemanagerCloudIamBinding",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud_iam_binding yandex_resourcemanager_cloud_iam_binding}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        cloud_id: builtins.str,
        members: typing.Sequence[builtins.str],
        role: builtins.str,
        id: typing.Optional[builtins.str] = None,
        sleep_after: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud_iam_binding yandex_resourcemanager_cloud_iam_binding} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param cloud_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud_iam_binding#cloud_id ResourcemanagerCloudIamBinding#cloud_id}.
        :param members: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud_iam_binding#members ResourcemanagerCloudIamBinding#members}.
        :param role: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud_iam_binding#role ResourcemanagerCloudIamBinding#role}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud_iam_binding#id ResourcemanagerCloudIamBinding#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param sleep_after: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud_iam_binding#sleep_after ResourcemanagerCloudIamBinding#sleep_after}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = ResourcemanagerCloudIamBindingConfig(
            cloud_id=cloud_id,
            members=members,
            role=role,
            id=id,
            sleep_after=sleep_after,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetSleepAfter")
    def reset_sleep_after(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSleepAfter", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cloudIdInput")
    def cloud_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "cloudIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="membersInput")
    def members_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "membersInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="roleInput")
    def role_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "roleInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sleepAfterInput")
    def sleep_after_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "sleepAfterInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cloudId")
    def cloud_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "cloudId"))

    @cloud_id.setter
    def cloud_id(self, value: builtins.str) -> None:
        jsii.set(self, "cloudId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="members")
    def members(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "members"))

    @members.setter
    def members(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "members", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="role")
    def role(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "role"))

    @role.setter
    def role(self, value: builtins.str) -> None:
        jsii.set(self, "role", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sleepAfter")
    def sleep_after(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "sleepAfter"))

    @sleep_after.setter
    def sleep_after(self, value: jsii.Number) -> None:
        jsii.set(self, "sleepAfter", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ResourcemanagerCloudIamBindingConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cloud_id": "cloudId",
        "members": "members",
        "role": "role",
        "id": "id",
        "sleep_after": "sleepAfter",
    },
)
class ResourcemanagerCloudIamBindingConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cloud_id: builtins.str,
        members: typing.Sequence[builtins.str],
        role: builtins.str,
        id: typing.Optional[builtins.str] = None,
        sleep_after: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cloud_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud_iam_binding#cloud_id ResourcemanagerCloudIamBinding#cloud_id}.
        :param members: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud_iam_binding#members ResourcemanagerCloudIamBinding#members}.
        :param role: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud_iam_binding#role ResourcemanagerCloudIamBinding#role}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud_iam_binding#id ResourcemanagerCloudIamBinding#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param sleep_after: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud_iam_binding#sleep_after ResourcemanagerCloudIamBinding#sleep_after}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {
            "cloud_id": cloud_id,
            "members": members,
            "role": role,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if id is not None:
            self._values["id"] = id
        if sleep_after is not None:
            self._values["sleep_after"] = sleep_after

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def cloud_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud_iam_binding#cloud_id ResourcemanagerCloudIamBinding#cloud_id}.'''
        result = self._values.get("cloud_id")
        assert result is not None, "Required property 'cloud_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def members(self) -> typing.List[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud_iam_binding#members ResourcemanagerCloudIamBinding#members}.'''
        result = self._values.get("members")
        assert result is not None, "Required property 'members' is missing"
        return typing.cast(typing.List[builtins.str], result)

    @builtins.property
    def role(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud_iam_binding#role ResourcemanagerCloudIamBinding#role}.'''
        result = self._values.get("role")
        assert result is not None, "Required property 'role' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud_iam_binding#id ResourcemanagerCloudIamBinding#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def sleep_after(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud_iam_binding#sleep_after ResourcemanagerCloudIamBinding#sleep_after}.'''
        result = self._values.get("sleep_after")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ResourcemanagerCloudIamBindingConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ResourcemanagerCloudIamMember(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ResourcemanagerCloudIamMember",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud_iam_member yandex_resourcemanager_cloud_iam_member}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        cloud_id: builtins.str,
        member: builtins.str,
        role: builtins.str,
        id: typing.Optional[builtins.str] = None,
        sleep_after: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud_iam_member yandex_resourcemanager_cloud_iam_member} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param cloud_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud_iam_member#cloud_id ResourcemanagerCloudIamMember#cloud_id}.
        :param member: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud_iam_member#member ResourcemanagerCloudIamMember#member}.
        :param role: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud_iam_member#role ResourcemanagerCloudIamMember#role}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud_iam_member#id ResourcemanagerCloudIamMember#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param sleep_after: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud_iam_member#sleep_after ResourcemanagerCloudIamMember#sleep_after}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = ResourcemanagerCloudIamMemberConfig(
            cloud_id=cloud_id,
            member=member,
            role=role,
            id=id,
            sleep_after=sleep_after,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetSleepAfter")
    def reset_sleep_after(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSleepAfter", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cloudIdInput")
    def cloud_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "cloudIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="memberInput")
    def member_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "memberInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="roleInput")
    def role_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "roleInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sleepAfterInput")
    def sleep_after_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "sleepAfterInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cloudId")
    def cloud_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "cloudId"))

    @cloud_id.setter
    def cloud_id(self, value: builtins.str) -> None:
        jsii.set(self, "cloudId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="member")
    def member(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "member"))

    @member.setter
    def member(self, value: builtins.str) -> None:
        jsii.set(self, "member", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="role")
    def role(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "role"))

    @role.setter
    def role(self, value: builtins.str) -> None:
        jsii.set(self, "role", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sleepAfter")
    def sleep_after(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "sleepAfter"))

    @sleep_after.setter
    def sleep_after(self, value: jsii.Number) -> None:
        jsii.set(self, "sleepAfter", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ResourcemanagerCloudIamMemberConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cloud_id": "cloudId",
        "member": "member",
        "role": "role",
        "id": "id",
        "sleep_after": "sleepAfter",
    },
)
class ResourcemanagerCloudIamMemberConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cloud_id: builtins.str,
        member: builtins.str,
        role: builtins.str,
        id: typing.Optional[builtins.str] = None,
        sleep_after: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cloud_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud_iam_member#cloud_id ResourcemanagerCloudIamMember#cloud_id}.
        :param member: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud_iam_member#member ResourcemanagerCloudIamMember#member}.
        :param role: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud_iam_member#role ResourcemanagerCloudIamMember#role}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud_iam_member#id ResourcemanagerCloudIamMember#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param sleep_after: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud_iam_member#sleep_after ResourcemanagerCloudIamMember#sleep_after}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {
            "cloud_id": cloud_id,
            "member": member,
            "role": role,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if id is not None:
            self._values["id"] = id
        if sleep_after is not None:
            self._values["sleep_after"] = sleep_after

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def cloud_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud_iam_member#cloud_id ResourcemanagerCloudIamMember#cloud_id}.'''
        result = self._values.get("cloud_id")
        assert result is not None, "Required property 'cloud_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def member(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud_iam_member#member ResourcemanagerCloudIamMember#member}.'''
        result = self._values.get("member")
        assert result is not None, "Required property 'member' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def role(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud_iam_member#role ResourcemanagerCloudIamMember#role}.'''
        result = self._values.get("role")
        assert result is not None, "Required property 'role' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud_iam_member#id ResourcemanagerCloudIamMember#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def sleep_after(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud_iam_member#sleep_after ResourcemanagerCloudIamMember#sleep_after}.'''
        result = self._values.get("sleep_after")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ResourcemanagerCloudIamMemberConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ResourcemanagerCloudTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ResourcemanagerCloudTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud#create ResourcemanagerCloud#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud#delete ResourcemanagerCloud#delete}.
        :param read: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud#read ResourcemanagerCloud#read}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud#update ResourcemanagerCloud#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud#create ResourcemanagerCloud#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud#delete ResourcemanagerCloud#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud#read ResourcemanagerCloud#read}.'''
        result = self._values.get("read")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_cloud#update ResourcemanagerCloud#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ResourcemanagerCloudTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ResourcemanagerCloudTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ResourcemanagerCloudTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetRead")
    def reset_read(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRead", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="readInput")
    def read_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "readInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="read")
    def read(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "read"))

    @read.setter
    def read(self, value: builtins.str) -> None:
        jsii.set(self, "read", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, ResourcemanagerCloudTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, ResourcemanagerCloudTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, ResourcemanagerCloudTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ResourcemanagerFolder(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ResourcemanagerFolder",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder yandex_resourcemanager_folder}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        cloud_id: typing.Optional[builtins.str] = None,
        description: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ResourcemanagerFolderTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder yandex_resourcemanager_folder} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param cloud_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder#cloud_id ResourcemanagerFolder#cloud_id}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder#description ResourcemanagerFolder#description}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder#id ResourcemanagerFolder#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder#labels ResourcemanagerFolder#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder#name ResourcemanagerFolder#name}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder#timeouts ResourcemanagerFolder#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = ResourcemanagerFolderConfig(
            cloud_id=cloud_id,
            description=description,
            id=id,
            labels=labels,
            name=name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder#create ResourcemanagerFolder#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder#delete ResourcemanagerFolder#delete}.
        :param read: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder#read ResourcemanagerFolder#read}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder#update ResourcemanagerFolder#update}.
        '''
        value = ResourcemanagerFolderTimeouts(
            create=create, delete=delete, read=read, update=update
        )

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetCloudId")
    def reset_cloud_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCloudId", []))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "ResourcemanagerFolderTimeoutsOutputReference":
        return typing.cast("ResourcemanagerFolderTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cloudIdInput")
    def cloud_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "cloudIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "ResourcemanagerFolderTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "ResourcemanagerFolderTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cloudId")
    def cloud_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "cloudId"))

    @cloud_id.setter
    def cloud_id(self, value: builtins.str) -> None:
        jsii.set(self, "cloudId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ResourcemanagerFolderConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cloud_id": "cloudId",
        "description": "description",
        "id": "id",
        "labels": "labels",
        "name": "name",
        "timeouts": "timeouts",
    },
)
class ResourcemanagerFolderConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cloud_id: typing.Optional[builtins.str] = None,
        description: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ResourcemanagerFolderTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cloud_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder#cloud_id ResourcemanagerFolder#cloud_id}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder#description ResourcemanagerFolder#description}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder#id ResourcemanagerFolder#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder#labels ResourcemanagerFolder#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder#name ResourcemanagerFolder#name}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder#timeouts ResourcemanagerFolder#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ResourcemanagerFolderTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if cloud_id is not None:
            self._values["cloud_id"] = cloud_id
        if description is not None:
            self._values["description"] = description
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if name is not None:
            self._values["name"] = name
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def cloud_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder#cloud_id ResourcemanagerFolder#cloud_id}.'''
        result = self._values.get("cloud_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder#description ResourcemanagerFolder#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder#id ResourcemanagerFolder#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder#labels ResourcemanagerFolder#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder#name ResourcemanagerFolder#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["ResourcemanagerFolderTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder#timeouts ResourcemanagerFolder#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["ResourcemanagerFolderTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ResourcemanagerFolderConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ResourcemanagerFolderIamBinding(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ResourcemanagerFolderIamBinding",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_binding yandex_resourcemanager_folder_iam_binding}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        folder_id: builtins.str,
        members: typing.Sequence[builtins.str],
        role: builtins.str,
        id: typing.Optional[builtins.str] = None,
        sleep_after: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_binding yandex_resourcemanager_folder_iam_binding} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_binding#folder_id ResourcemanagerFolderIamBinding#folder_id}.
        :param members: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_binding#members ResourcemanagerFolderIamBinding#members}.
        :param role: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_binding#role ResourcemanagerFolderIamBinding#role}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_binding#id ResourcemanagerFolderIamBinding#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param sleep_after: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_binding#sleep_after ResourcemanagerFolderIamBinding#sleep_after}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = ResourcemanagerFolderIamBindingConfig(
            folder_id=folder_id,
            members=members,
            role=role,
            id=id,
            sleep_after=sleep_after,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetSleepAfter")
    def reset_sleep_after(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSleepAfter", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="membersInput")
    def members_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "membersInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="roleInput")
    def role_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "roleInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sleepAfterInput")
    def sleep_after_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "sleepAfterInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="members")
    def members(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "members"))

    @members.setter
    def members(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "members", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="role")
    def role(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "role"))

    @role.setter
    def role(self, value: builtins.str) -> None:
        jsii.set(self, "role", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sleepAfter")
    def sleep_after(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "sleepAfter"))

    @sleep_after.setter
    def sleep_after(self, value: jsii.Number) -> None:
        jsii.set(self, "sleepAfter", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ResourcemanagerFolderIamBindingConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "folder_id": "folderId",
        "members": "members",
        "role": "role",
        "id": "id",
        "sleep_after": "sleepAfter",
    },
)
class ResourcemanagerFolderIamBindingConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        folder_id: builtins.str,
        members: typing.Sequence[builtins.str],
        role: builtins.str,
        id: typing.Optional[builtins.str] = None,
        sleep_after: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_binding#folder_id ResourcemanagerFolderIamBinding#folder_id}.
        :param members: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_binding#members ResourcemanagerFolderIamBinding#members}.
        :param role: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_binding#role ResourcemanagerFolderIamBinding#role}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_binding#id ResourcemanagerFolderIamBinding#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param sleep_after: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_binding#sleep_after ResourcemanagerFolderIamBinding#sleep_after}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {
            "folder_id": folder_id,
            "members": members,
            "role": role,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if id is not None:
            self._values["id"] = id
        if sleep_after is not None:
            self._values["sleep_after"] = sleep_after

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def folder_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_binding#folder_id ResourcemanagerFolderIamBinding#folder_id}.'''
        result = self._values.get("folder_id")
        assert result is not None, "Required property 'folder_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def members(self) -> typing.List[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_binding#members ResourcemanagerFolderIamBinding#members}.'''
        result = self._values.get("members")
        assert result is not None, "Required property 'members' is missing"
        return typing.cast(typing.List[builtins.str], result)

    @builtins.property
    def role(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_binding#role ResourcemanagerFolderIamBinding#role}.'''
        result = self._values.get("role")
        assert result is not None, "Required property 'role' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_binding#id ResourcemanagerFolderIamBinding#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def sleep_after(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_binding#sleep_after ResourcemanagerFolderIamBinding#sleep_after}.'''
        result = self._values.get("sleep_after")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ResourcemanagerFolderIamBindingConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ResourcemanagerFolderIamMember(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ResourcemanagerFolderIamMember",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_member yandex_resourcemanager_folder_iam_member}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        folder_id: builtins.str,
        member: builtins.str,
        role: builtins.str,
        id: typing.Optional[builtins.str] = None,
        sleep_after: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_member yandex_resourcemanager_folder_iam_member} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_member#folder_id ResourcemanagerFolderIamMember#folder_id}.
        :param member: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_member#member ResourcemanagerFolderIamMember#member}.
        :param role: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_member#role ResourcemanagerFolderIamMember#role}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_member#id ResourcemanagerFolderIamMember#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param sleep_after: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_member#sleep_after ResourcemanagerFolderIamMember#sleep_after}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = ResourcemanagerFolderIamMemberConfig(
            folder_id=folder_id,
            member=member,
            role=role,
            id=id,
            sleep_after=sleep_after,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetSleepAfter")
    def reset_sleep_after(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSleepAfter", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="memberInput")
    def member_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "memberInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="roleInput")
    def role_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "roleInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sleepAfterInput")
    def sleep_after_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "sleepAfterInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="member")
    def member(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "member"))

    @member.setter
    def member(self, value: builtins.str) -> None:
        jsii.set(self, "member", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="role")
    def role(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "role"))

    @role.setter
    def role(self, value: builtins.str) -> None:
        jsii.set(self, "role", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sleepAfter")
    def sleep_after(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "sleepAfter"))

    @sleep_after.setter
    def sleep_after(self, value: jsii.Number) -> None:
        jsii.set(self, "sleepAfter", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ResourcemanagerFolderIamMemberConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "folder_id": "folderId",
        "member": "member",
        "role": "role",
        "id": "id",
        "sleep_after": "sleepAfter",
    },
)
class ResourcemanagerFolderIamMemberConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        folder_id: builtins.str,
        member: builtins.str,
        role: builtins.str,
        id: typing.Optional[builtins.str] = None,
        sleep_after: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_member#folder_id ResourcemanagerFolderIamMember#folder_id}.
        :param member: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_member#member ResourcemanagerFolderIamMember#member}.
        :param role: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_member#role ResourcemanagerFolderIamMember#role}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_member#id ResourcemanagerFolderIamMember#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param sleep_after: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_member#sleep_after ResourcemanagerFolderIamMember#sleep_after}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {
            "folder_id": folder_id,
            "member": member,
            "role": role,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if id is not None:
            self._values["id"] = id
        if sleep_after is not None:
            self._values["sleep_after"] = sleep_after

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def folder_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_member#folder_id ResourcemanagerFolderIamMember#folder_id}.'''
        result = self._values.get("folder_id")
        assert result is not None, "Required property 'folder_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def member(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_member#member ResourcemanagerFolderIamMember#member}.'''
        result = self._values.get("member")
        assert result is not None, "Required property 'member' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def role(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_member#role ResourcemanagerFolderIamMember#role}.'''
        result = self._values.get("role")
        assert result is not None, "Required property 'role' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_member#id ResourcemanagerFolderIamMember#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def sleep_after(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_member#sleep_after ResourcemanagerFolderIamMember#sleep_after}.'''
        result = self._values.get("sleep_after")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ResourcemanagerFolderIamMemberConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ResourcemanagerFolderIamPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ResourcemanagerFolderIamPolicy",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_policy yandex_resourcemanager_folder_iam_policy}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        folder_id: builtins.str,
        policy_data: builtins.str,
        id: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_policy yandex_resourcemanager_folder_iam_policy} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_policy#folder_id ResourcemanagerFolderIamPolicy#folder_id}.
        :param policy_data: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_policy#policy_data ResourcemanagerFolderIamPolicy#policy_data}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_policy#id ResourcemanagerFolderIamPolicy#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = ResourcemanagerFolderIamPolicyConfig(
            folder_id=folder_id,
            policy_data=policy_data,
            id=id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="policyDataInput")
    def policy_data_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "policyDataInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="policyData")
    def policy_data(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "policyData"))

    @policy_data.setter
    def policy_data(self, value: builtins.str) -> None:
        jsii.set(self, "policyData", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ResourcemanagerFolderIamPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "folder_id": "folderId",
        "policy_data": "policyData",
        "id": "id",
    },
)
class ResourcemanagerFolderIamPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        folder_id: builtins.str,
        policy_data: builtins.str,
        id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_policy#folder_id ResourcemanagerFolderIamPolicy#folder_id}.
        :param policy_data: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_policy#policy_data ResourcemanagerFolderIamPolicy#policy_data}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_policy#id ResourcemanagerFolderIamPolicy#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {
            "folder_id": folder_id,
            "policy_data": policy_data,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if id is not None:
            self._values["id"] = id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def folder_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_policy#folder_id ResourcemanagerFolderIamPolicy#folder_id}.'''
        result = self._values.get("folder_id")
        assert result is not None, "Required property 'folder_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def policy_data(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_policy#policy_data ResourcemanagerFolderIamPolicy#policy_data}.'''
        result = self._values.get("policy_data")
        assert result is not None, "Required property 'policy_data' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder_iam_policy#id ResourcemanagerFolderIamPolicy#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ResourcemanagerFolderIamPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ResourcemanagerFolderTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class ResourcemanagerFolderTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder#create ResourcemanagerFolder#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder#delete ResourcemanagerFolder#delete}.
        :param read: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder#read ResourcemanagerFolder#read}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder#update ResourcemanagerFolder#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder#create ResourcemanagerFolder#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder#delete ResourcemanagerFolder#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder#read ResourcemanagerFolder#read}.'''
        result = self._values.get("read")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/resourcemanager_folder#update ResourcemanagerFolder#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ResourcemanagerFolderTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ResourcemanagerFolderTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ResourcemanagerFolderTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetRead")
    def reset_read(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRead", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="readInput")
    def read_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "readInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="read")
    def read(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "read"))

    @read.setter
    def read(self, value: builtins.str) -> None:
        jsii.set(self, "read", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, ResourcemanagerFolderTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, ResourcemanagerFolderTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, ResourcemanagerFolderTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class ServerlessContainer(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ServerlessContainer",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container yandex_serverless_container}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        image: "ServerlessContainerImage",
        memory: jsii.Number,
        name: builtins.str,
        concurrency: typing.Optional[jsii.Number] = None,
        core_fraction: typing.Optional[jsii.Number] = None,
        cores: typing.Optional[jsii.Number] = None,
        description: typing.Optional[builtins.str] = None,
        execution_timeout: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        service_account_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ServerlessContainerTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container yandex_serverless_container} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param image: image block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#image ServerlessContainer#image}
        :param memory: Container memory in megabytes, should be aligned to 128. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#memory ServerlessContainer#memory}
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#name ServerlessContainer#name}.
        :param concurrency: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#concurrency ServerlessContainer#concurrency}.
        :param core_fraction: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#core_fraction ServerlessContainer#core_fraction}.
        :param cores: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#cores ServerlessContainer#cores}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#description ServerlessContainer#description}.
        :param execution_timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#execution_timeout ServerlessContainer#execution_timeout}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#folder_id ServerlessContainer#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#id ServerlessContainer#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#labels ServerlessContainer#labels}.
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#service_account_id ServerlessContainer#service_account_id}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#timeouts ServerlessContainer#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = ServerlessContainerConfig(
            image=image,
            memory=memory,
            name=name,
            concurrency=concurrency,
            core_fraction=core_fraction,
            cores=cores,
            description=description,
            execution_timeout=execution_timeout,
            folder_id=folder_id,
            id=id,
            labels=labels,
            service_account_id=service_account_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putImage")
    def put_image(
        self,
        *,
        url: builtins.str,
        args: typing.Optional[typing.Sequence[builtins.str]] = None,
        command: typing.Optional[typing.Sequence[builtins.str]] = None,
        digest: typing.Optional[builtins.str] = None,
        environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        work_dir: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param url: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#url ServerlessContainer#url}.
        :param args: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#args ServerlessContainer#args}.
        :param command: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#command ServerlessContainer#command}.
        :param digest: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#digest ServerlessContainer#digest}.
        :param environment: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#environment ServerlessContainer#environment}.
        :param work_dir: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#work_dir ServerlessContainer#work_dir}.
        '''
        value = ServerlessContainerImage(
            url=url,
            args=args,
            command=command,
            digest=digest,
            environment=environment,
            work_dir=work_dir,
        )

        return typing.cast(None, jsii.invoke(self, "putImage", [value]))

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#create ServerlessContainer#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#delete ServerlessContainer#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#update ServerlessContainer#update}.
        '''
        value = ServerlessContainerTimeouts(
            create=create, delete=delete, update=update
        )

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetConcurrency")
    def reset_concurrency(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetConcurrency", []))

    @jsii.member(jsii_name="resetCoreFraction")
    def reset_core_fraction(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCoreFraction", []))

    @jsii.member(jsii_name="resetCores")
    def reset_cores(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCores", []))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetExecutionTimeout")
    def reset_execution_timeout(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetExecutionTimeout", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetServiceAccountId")
    def reset_service_account_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetServiceAccountId", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="image")
    def image(self) -> "ServerlessContainerImageOutputReference":
        return typing.cast("ServerlessContainerImageOutputReference", jsii.get(self, "image"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="revisionId")
    def revision_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "revisionId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "ServerlessContainerTimeoutsOutputReference":
        return typing.cast("ServerlessContainerTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="url")
    def url(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "url"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="concurrencyInput")
    def concurrency_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "concurrencyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="coreFractionInput")
    def core_fraction_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "coreFractionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="coresInput")
    def cores_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "coresInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="executionTimeoutInput")
    def execution_timeout_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "executionTimeoutInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="imageInput")
    def image_input(self) -> typing.Optional["ServerlessContainerImage"]:
        return typing.cast(typing.Optional["ServerlessContainerImage"], jsii.get(self, "imageInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="memoryInput")
    def memory_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "memoryInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountIdInput")
    def service_account_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceAccountIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "ServerlessContainerTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "ServerlessContainerTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="concurrency")
    def concurrency(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "concurrency"))

    @concurrency.setter
    def concurrency(self, value: jsii.Number) -> None:
        jsii.set(self, "concurrency", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="coreFraction")
    def core_fraction(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "coreFraction"))

    @core_fraction.setter
    def core_fraction(self, value: jsii.Number) -> None:
        jsii.set(self, "coreFraction", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cores")
    def cores(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "cores"))

    @cores.setter
    def cores(self, value: jsii.Number) -> None:
        jsii.set(self, "cores", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="executionTimeout")
    def execution_timeout(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "executionTimeout"))

    @execution_timeout.setter
    def execution_timeout(self, value: builtins.str) -> None:
        jsii.set(self, "executionTimeout", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="memory")
    def memory(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "memory"))

    @memory.setter
    def memory(self, value: jsii.Number) -> None:
        jsii.set(self, "memory", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountId")
    def service_account_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "serviceAccountId"))

    @service_account_id.setter
    def service_account_id(self, value: builtins.str) -> None:
        jsii.set(self, "serviceAccountId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ServerlessContainerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "image": "image",
        "memory": "memory",
        "name": "name",
        "concurrency": "concurrency",
        "core_fraction": "coreFraction",
        "cores": "cores",
        "description": "description",
        "execution_timeout": "executionTimeout",
        "folder_id": "folderId",
        "id": "id",
        "labels": "labels",
        "service_account_id": "serviceAccountId",
        "timeouts": "timeouts",
    },
)
class ServerlessContainerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        image: "ServerlessContainerImage",
        memory: jsii.Number,
        name: builtins.str,
        concurrency: typing.Optional[jsii.Number] = None,
        core_fraction: typing.Optional[jsii.Number] = None,
        cores: typing.Optional[jsii.Number] = None,
        description: typing.Optional[builtins.str] = None,
        execution_timeout: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        service_account_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["ServerlessContainerTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param image: image block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#image ServerlessContainer#image}
        :param memory: Container memory in megabytes, should be aligned to 128. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#memory ServerlessContainer#memory}
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#name ServerlessContainer#name}.
        :param concurrency: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#concurrency ServerlessContainer#concurrency}.
        :param core_fraction: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#core_fraction ServerlessContainer#core_fraction}.
        :param cores: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#cores ServerlessContainer#cores}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#description ServerlessContainer#description}.
        :param execution_timeout: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#execution_timeout ServerlessContainer#execution_timeout}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#folder_id ServerlessContainer#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#id ServerlessContainer#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#labels ServerlessContainer#labels}.
        :param service_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#service_account_id ServerlessContainer#service_account_id}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#timeouts ServerlessContainer#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(image, dict):
            image = ServerlessContainerImage(**image)
        if isinstance(timeouts, dict):
            timeouts = ServerlessContainerTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "image": image,
            "memory": memory,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if concurrency is not None:
            self._values["concurrency"] = concurrency
        if core_fraction is not None:
            self._values["core_fraction"] = core_fraction
        if cores is not None:
            self._values["cores"] = cores
        if description is not None:
            self._values["description"] = description
        if execution_timeout is not None:
            self._values["execution_timeout"] = execution_timeout
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if service_account_id is not None:
            self._values["service_account_id"] = service_account_id
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def image(self) -> "ServerlessContainerImage":
        '''image block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#image ServerlessContainer#image}
        '''
        result = self._values.get("image")
        assert result is not None, "Required property 'image' is missing"
        return typing.cast("ServerlessContainerImage", result)

    @builtins.property
    def memory(self) -> jsii.Number:
        '''Container memory in megabytes, should be aligned to 128.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#memory ServerlessContainer#memory}
        '''
        result = self._values.get("memory")
        assert result is not None, "Required property 'memory' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#name ServerlessContainer#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def concurrency(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#concurrency ServerlessContainer#concurrency}.'''
        result = self._values.get("concurrency")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def core_fraction(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#core_fraction ServerlessContainer#core_fraction}.'''
        result = self._values.get("core_fraction")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def cores(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#cores ServerlessContainer#cores}.'''
        result = self._values.get("cores")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#description ServerlessContainer#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def execution_timeout(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#execution_timeout ServerlessContainer#execution_timeout}.'''
        result = self._values.get("execution_timeout")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#folder_id ServerlessContainer#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#id ServerlessContainer#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#labels ServerlessContainer#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def service_account_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#service_account_id ServerlessContainer#service_account_id}.'''
        result = self._values.get("service_account_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["ServerlessContainerTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#timeouts ServerlessContainer#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["ServerlessContainerTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServerlessContainerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ServerlessContainerImage",
    jsii_struct_bases=[],
    name_mapping={
        "url": "url",
        "args": "args",
        "command": "command",
        "digest": "digest",
        "environment": "environment",
        "work_dir": "workDir",
    },
)
class ServerlessContainerImage:
    def __init__(
        self,
        *,
        url: builtins.str,
        args: typing.Optional[typing.Sequence[builtins.str]] = None,
        command: typing.Optional[typing.Sequence[builtins.str]] = None,
        digest: typing.Optional[builtins.str] = None,
        environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        work_dir: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param url: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#url ServerlessContainer#url}.
        :param args: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#args ServerlessContainer#args}.
        :param command: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#command ServerlessContainer#command}.
        :param digest: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#digest ServerlessContainer#digest}.
        :param environment: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#environment ServerlessContainer#environment}.
        :param work_dir: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#work_dir ServerlessContainer#work_dir}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "url": url,
        }
        if args is not None:
            self._values["args"] = args
        if command is not None:
            self._values["command"] = command
        if digest is not None:
            self._values["digest"] = digest
        if environment is not None:
            self._values["environment"] = environment
        if work_dir is not None:
            self._values["work_dir"] = work_dir

    @builtins.property
    def url(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#url ServerlessContainer#url}.'''
        result = self._values.get("url")
        assert result is not None, "Required property 'url' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def args(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#args ServerlessContainer#args}.'''
        result = self._values.get("args")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def command(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#command ServerlessContainer#command}.'''
        result = self._values.get("command")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def digest(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#digest ServerlessContainer#digest}.'''
        result = self._values.get("digest")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def environment(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#environment ServerlessContainer#environment}.'''
        result = self._values.get("environment")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def work_dir(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#work_dir ServerlessContainer#work_dir}.'''
        result = self._values.get("work_dir")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServerlessContainerImage(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ServerlessContainerImageOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ServerlessContainerImageOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetArgs")
    def reset_args(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetArgs", []))

    @jsii.member(jsii_name="resetCommand")
    def reset_command(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCommand", []))

    @jsii.member(jsii_name="resetDigest")
    def reset_digest(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDigest", []))

    @jsii.member(jsii_name="resetEnvironment")
    def reset_environment(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEnvironment", []))

    @jsii.member(jsii_name="resetWorkDir")
    def reset_work_dir(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetWorkDir", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="argsInput")
    def args_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "argsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="commandInput")
    def command_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "commandInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="digestInput")
    def digest_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "digestInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="environmentInput")
    def environment_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "environmentInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="urlInput")
    def url_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "urlInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="workDirInput")
    def work_dir_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "workDirInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="args")
    def args(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "args"))

    @args.setter
    def args(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "args", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="command")
    def command(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "command"))

    @command.setter
    def command(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "command", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="digest")
    def digest(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "digest"))

    @digest.setter
    def digest(self, value: builtins.str) -> None:
        jsii.set(self, "digest", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="environment")
    def environment(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "environment"))

    @environment.setter
    def environment(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "environment", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="url")
    def url(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "url"))

    @url.setter
    def url(self, value: builtins.str) -> None:
        jsii.set(self, "url", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="workDir")
    def work_dir(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "workDir"))

    @work_dir.setter
    def work_dir(self, value: builtins.str) -> None:
        jsii.set(self, "workDir", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[ServerlessContainerImage]:
        return typing.cast(typing.Optional[ServerlessContainerImage], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(self, value: typing.Optional[ServerlessContainerImage]) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.ServerlessContainerTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class ServerlessContainerTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#create ServerlessContainer#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#delete ServerlessContainer#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#update ServerlessContainer#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#create ServerlessContainer#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#delete ServerlessContainer#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/serverless_container#update ServerlessContainer#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServerlessContainerTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ServerlessContainerTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.ServerlessContainerTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, ServerlessContainerTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, ServerlessContainerTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, ServerlessContainerTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class StorageBucket(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.StorageBucket",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket yandex_storage_bucket}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        access_key: typing.Optional[builtins.str] = None,
        acl: typing.Optional[builtins.str] = None,
        bucket: typing.Optional[builtins.str] = None,
        bucket_prefix: typing.Optional[builtins.str] = None,
        cors_rule: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["StorageBucketCorsRule"]]] = None,
        force_destroy: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        grant: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["StorageBucketGrant"]]] = None,
        id: typing.Optional[builtins.str] = None,
        lifecycle_rule: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["StorageBucketLifecycleRule"]]] = None,
        logging: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["StorageBucketLogging"]]] = None,
        policy: typing.Optional[builtins.str] = None,
        secret_key: typing.Optional[builtins.str] = None,
        server_side_encryption_configuration: typing.Optional["StorageBucketServerSideEncryptionConfiguration"] = None,
        versioning: typing.Optional["StorageBucketVersioning"] = None,
        website: typing.Optional["StorageBucketWebsite"] = None,
        website_domain: typing.Optional[builtins.str] = None,
        website_endpoint: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket yandex_storage_bucket} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param access_key: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#access_key StorageBucket#access_key}.
        :param acl: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#acl StorageBucket#acl}.
        :param bucket: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#bucket StorageBucket#bucket}.
        :param bucket_prefix: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#bucket_prefix StorageBucket#bucket_prefix}.
        :param cors_rule: cors_rule block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#cors_rule StorageBucket#cors_rule}
        :param force_destroy: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#force_destroy StorageBucket#force_destroy}.
        :param grant: grant block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#grant StorageBucket#grant}
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#id StorageBucket#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param lifecycle_rule: lifecycle_rule block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#lifecycle_rule StorageBucket#lifecycle_rule}
        :param logging: logging block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#logging StorageBucket#logging}
        :param policy: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#policy StorageBucket#policy}.
        :param secret_key: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#secret_key StorageBucket#secret_key}.
        :param server_side_encryption_configuration: server_side_encryption_configuration block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#server_side_encryption_configuration StorageBucket#server_side_encryption_configuration}
        :param versioning: versioning block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#versioning StorageBucket#versioning}
        :param website: website block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#website StorageBucket#website}
        :param website_domain: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#website_domain StorageBucket#website_domain}.
        :param website_endpoint: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#website_endpoint StorageBucket#website_endpoint}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = StorageBucketConfig(
            access_key=access_key,
            acl=acl,
            bucket=bucket,
            bucket_prefix=bucket_prefix,
            cors_rule=cors_rule,
            force_destroy=force_destroy,
            grant=grant,
            id=id,
            lifecycle_rule=lifecycle_rule,
            logging=logging,
            policy=policy,
            secret_key=secret_key,
            server_side_encryption_configuration=server_side_encryption_configuration,
            versioning=versioning,
            website=website,
            website_domain=website_domain,
            website_endpoint=website_endpoint,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putCorsRule")
    def put_cors_rule(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["StorageBucketCorsRule"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putCorsRule", [value]))

    @jsii.member(jsii_name="putGrant")
    def put_grant(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["StorageBucketGrant"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putGrant", [value]))

    @jsii.member(jsii_name="putLifecycleRule")
    def put_lifecycle_rule(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["StorageBucketLifecycleRule"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putLifecycleRule", [value]))

    @jsii.member(jsii_name="putLogging")
    def put_logging(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["StorageBucketLogging"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putLogging", [value]))

    @jsii.member(jsii_name="putServerSideEncryptionConfiguration")
    def put_server_side_encryption_configuration(
        self,
        *,
        rule: "StorageBucketServerSideEncryptionConfigurationRule",
    ) -> None:
        '''
        :param rule: rule block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#rule StorageBucket#rule}
        '''
        value = StorageBucketServerSideEncryptionConfiguration(rule=rule)

        return typing.cast(None, jsii.invoke(self, "putServerSideEncryptionConfiguration", [value]))

    @jsii.member(jsii_name="putVersioning")
    def put_versioning(
        self,
        *,
        enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param enabled: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#enabled StorageBucket#enabled}.
        '''
        value = StorageBucketVersioning(enabled=enabled)

        return typing.cast(None, jsii.invoke(self, "putVersioning", [value]))

    @jsii.member(jsii_name="putWebsite")
    def put_website(
        self,
        *,
        error_document: typing.Optional[builtins.str] = None,
        index_document: typing.Optional[builtins.str] = None,
        redirect_all_requests_to: typing.Optional[builtins.str] = None,
        routing_rules: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param error_document: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#error_document StorageBucket#error_document}.
        :param index_document: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#index_document StorageBucket#index_document}.
        :param redirect_all_requests_to: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#redirect_all_requests_to StorageBucket#redirect_all_requests_to}.
        :param routing_rules: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#routing_rules StorageBucket#routing_rules}.
        '''
        value = StorageBucketWebsite(
            error_document=error_document,
            index_document=index_document,
            redirect_all_requests_to=redirect_all_requests_to,
            routing_rules=routing_rules,
        )

        return typing.cast(None, jsii.invoke(self, "putWebsite", [value]))

    @jsii.member(jsii_name="resetAccessKey")
    def reset_access_key(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAccessKey", []))

    @jsii.member(jsii_name="resetAcl")
    def reset_acl(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAcl", []))

    @jsii.member(jsii_name="resetBucket")
    def reset_bucket(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetBucket", []))

    @jsii.member(jsii_name="resetBucketPrefix")
    def reset_bucket_prefix(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetBucketPrefix", []))

    @jsii.member(jsii_name="resetCorsRule")
    def reset_cors_rule(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCorsRule", []))

    @jsii.member(jsii_name="resetForceDestroy")
    def reset_force_destroy(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetForceDestroy", []))

    @jsii.member(jsii_name="resetGrant")
    def reset_grant(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetGrant", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLifecycleRule")
    def reset_lifecycle_rule(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLifecycleRule", []))

    @jsii.member(jsii_name="resetLogging")
    def reset_logging(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLogging", []))

    @jsii.member(jsii_name="resetPolicy")
    def reset_policy(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPolicy", []))

    @jsii.member(jsii_name="resetSecretKey")
    def reset_secret_key(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecretKey", []))

    @jsii.member(jsii_name="resetServerSideEncryptionConfiguration")
    def reset_server_side_encryption_configuration(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetServerSideEncryptionConfiguration", []))

    @jsii.member(jsii_name="resetVersioning")
    def reset_versioning(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetVersioning", []))

    @jsii.member(jsii_name="resetWebsite")
    def reset_website(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetWebsite", []))

    @jsii.member(jsii_name="resetWebsiteDomain")
    def reset_website_domain(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetWebsiteDomain", []))

    @jsii.member(jsii_name="resetWebsiteEndpoint")
    def reset_website_endpoint(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetWebsiteEndpoint", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bucketDomainName")
    def bucket_domain_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "bucketDomainName"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="corsRule")
    def cors_rule(self) -> "StorageBucketCorsRuleList":
        return typing.cast("StorageBucketCorsRuleList", jsii.get(self, "corsRule"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="grant")
    def grant(self) -> "StorageBucketGrantList":
        return typing.cast("StorageBucketGrantList", jsii.get(self, "grant"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="lifecycleRule")
    def lifecycle_rule(self) -> "StorageBucketLifecycleRuleList":
        return typing.cast("StorageBucketLifecycleRuleList", jsii.get(self, "lifecycleRule"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logging")
    def logging(self) -> "StorageBucketLoggingList":
        return typing.cast("StorageBucketLoggingList", jsii.get(self, "logging"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serverSideEncryptionConfiguration")
    def server_side_encryption_configuration(
        self,
    ) -> "StorageBucketServerSideEncryptionConfigurationOutputReference":
        return typing.cast("StorageBucketServerSideEncryptionConfigurationOutputReference", jsii.get(self, "serverSideEncryptionConfiguration"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="versioning")
    def versioning(self) -> "StorageBucketVersioningOutputReference":
        return typing.cast("StorageBucketVersioningOutputReference", jsii.get(self, "versioning"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="website")
    def website(self) -> "StorageBucketWebsiteOutputReference":
        return typing.cast("StorageBucketWebsiteOutputReference", jsii.get(self, "website"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="accessKeyInput")
    def access_key_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "accessKeyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="aclInput")
    def acl_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aclInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bucketInput")
    def bucket_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "bucketInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bucketPrefixInput")
    def bucket_prefix_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "bucketPrefixInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="corsRuleInput")
    def cors_rule_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["StorageBucketCorsRule"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["StorageBucketCorsRule"]]], jsii.get(self, "corsRuleInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="forceDestroyInput")
    def force_destroy_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "forceDestroyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="grantInput")
    def grant_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["StorageBucketGrant"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["StorageBucketGrant"]]], jsii.get(self, "grantInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="lifecycleRuleInput")
    def lifecycle_rule_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["StorageBucketLifecycleRule"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["StorageBucketLifecycleRule"]]], jsii.get(self, "lifecycleRuleInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="loggingInput")
    def logging_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["StorageBucketLogging"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["StorageBucketLogging"]]], jsii.get(self, "loggingInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="policyInput")
    def policy_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "policyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="secretKeyInput")
    def secret_key_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "secretKeyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serverSideEncryptionConfigurationInput")
    def server_side_encryption_configuration_input(
        self,
    ) -> typing.Optional["StorageBucketServerSideEncryptionConfiguration"]:
        return typing.cast(typing.Optional["StorageBucketServerSideEncryptionConfiguration"], jsii.get(self, "serverSideEncryptionConfigurationInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="versioningInput")
    def versioning_input(self) -> typing.Optional["StorageBucketVersioning"]:
        return typing.cast(typing.Optional["StorageBucketVersioning"], jsii.get(self, "versioningInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="websiteDomainInput")
    def website_domain_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "websiteDomainInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="websiteEndpointInput")
    def website_endpoint_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "websiteEndpointInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="websiteInput")
    def website_input(self) -> typing.Optional["StorageBucketWebsite"]:
        return typing.cast(typing.Optional["StorageBucketWebsite"], jsii.get(self, "websiteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="accessKey")
    def access_key(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "accessKey"))

    @access_key.setter
    def access_key(self, value: builtins.str) -> None:
        jsii.set(self, "accessKey", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="acl")
    def acl(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "acl"))

    @acl.setter
    def acl(self, value: builtins.str) -> None:
        jsii.set(self, "acl", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bucket")
    def bucket(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "bucket"))

    @bucket.setter
    def bucket(self, value: builtins.str) -> None:
        jsii.set(self, "bucket", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bucketPrefix")
    def bucket_prefix(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "bucketPrefix"))

    @bucket_prefix.setter
    def bucket_prefix(self, value: builtins.str) -> None:
        jsii.set(self, "bucketPrefix", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="forceDestroy")
    def force_destroy(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "forceDestroy"))

    @force_destroy.setter
    def force_destroy(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "forceDestroy", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="policy")
    def policy(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "policy"))

    @policy.setter
    def policy(self, value: builtins.str) -> None:
        jsii.set(self, "policy", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="secretKey")
    def secret_key(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "secretKey"))

    @secret_key.setter
    def secret_key(self, value: builtins.str) -> None:
        jsii.set(self, "secretKey", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="websiteDomain")
    def website_domain(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "websiteDomain"))

    @website_domain.setter
    def website_domain(self, value: builtins.str) -> None:
        jsii.set(self, "websiteDomain", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="websiteEndpoint")
    def website_endpoint(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "websiteEndpoint"))

    @website_endpoint.setter
    def website_endpoint(self, value: builtins.str) -> None:
        jsii.set(self, "websiteEndpoint", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.StorageBucketConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "access_key": "accessKey",
        "acl": "acl",
        "bucket": "bucket",
        "bucket_prefix": "bucketPrefix",
        "cors_rule": "corsRule",
        "force_destroy": "forceDestroy",
        "grant": "grant",
        "id": "id",
        "lifecycle_rule": "lifecycleRule",
        "logging": "logging",
        "policy": "policy",
        "secret_key": "secretKey",
        "server_side_encryption_configuration": "serverSideEncryptionConfiguration",
        "versioning": "versioning",
        "website": "website",
        "website_domain": "websiteDomain",
        "website_endpoint": "websiteEndpoint",
    },
)
class StorageBucketConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        access_key: typing.Optional[builtins.str] = None,
        acl: typing.Optional[builtins.str] = None,
        bucket: typing.Optional[builtins.str] = None,
        bucket_prefix: typing.Optional[builtins.str] = None,
        cors_rule: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["StorageBucketCorsRule"]]] = None,
        force_destroy: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        grant: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["StorageBucketGrant"]]] = None,
        id: typing.Optional[builtins.str] = None,
        lifecycle_rule: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["StorageBucketLifecycleRule"]]] = None,
        logging: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["StorageBucketLogging"]]] = None,
        policy: typing.Optional[builtins.str] = None,
        secret_key: typing.Optional[builtins.str] = None,
        server_side_encryption_configuration: typing.Optional["StorageBucketServerSideEncryptionConfiguration"] = None,
        versioning: typing.Optional["StorageBucketVersioning"] = None,
        website: typing.Optional["StorageBucketWebsite"] = None,
        website_domain: typing.Optional[builtins.str] = None,
        website_endpoint: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param access_key: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#access_key StorageBucket#access_key}.
        :param acl: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#acl StorageBucket#acl}.
        :param bucket: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#bucket StorageBucket#bucket}.
        :param bucket_prefix: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#bucket_prefix StorageBucket#bucket_prefix}.
        :param cors_rule: cors_rule block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#cors_rule StorageBucket#cors_rule}
        :param force_destroy: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#force_destroy StorageBucket#force_destroy}.
        :param grant: grant block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#grant StorageBucket#grant}
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#id StorageBucket#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param lifecycle_rule: lifecycle_rule block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#lifecycle_rule StorageBucket#lifecycle_rule}
        :param logging: logging block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#logging StorageBucket#logging}
        :param policy: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#policy StorageBucket#policy}.
        :param secret_key: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#secret_key StorageBucket#secret_key}.
        :param server_side_encryption_configuration: server_side_encryption_configuration block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#server_side_encryption_configuration StorageBucket#server_side_encryption_configuration}
        :param versioning: versioning block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#versioning StorageBucket#versioning}
        :param website: website block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#website StorageBucket#website}
        :param website_domain: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#website_domain StorageBucket#website_domain}.
        :param website_endpoint: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#website_endpoint StorageBucket#website_endpoint}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(server_side_encryption_configuration, dict):
            server_side_encryption_configuration = StorageBucketServerSideEncryptionConfiguration(**server_side_encryption_configuration)
        if isinstance(versioning, dict):
            versioning = StorageBucketVersioning(**versioning)
        if isinstance(website, dict):
            website = StorageBucketWebsite(**website)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if access_key is not None:
            self._values["access_key"] = access_key
        if acl is not None:
            self._values["acl"] = acl
        if bucket is not None:
            self._values["bucket"] = bucket
        if bucket_prefix is not None:
            self._values["bucket_prefix"] = bucket_prefix
        if cors_rule is not None:
            self._values["cors_rule"] = cors_rule
        if force_destroy is not None:
            self._values["force_destroy"] = force_destroy
        if grant is not None:
            self._values["grant"] = grant
        if id is not None:
            self._values["id"] = id
        if lifecycle_rule is not None:
            self._values["lifecycle_rule"] = lifecycle_rule
        if logging is not None:
            self._values["logging"] = logging
        if policy is not None:
            self._values["policy"] = policy
        if secret_key is not None:
            self._values["secret_key"] = secret_key
        if server_side_encryption_configuration is not None:
            self._values["server_side_encryption_configuration"] = server_side_encryption_configuration
        if versioning is not None:
            self._values["versioning"] = versioning
        if website is not None:
            self._values["website"] = website
        if website_domain is not None:
            self._values["website_domain"] = website_domain
        if website_endpoint is not None:
            self._values["website_endpoint"] = website_endpoint

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def access_key(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#access_key StorageBucket#access_key}.'''
        result = self._values.get("access_key")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def acl(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#acl StorageBucket#acl}.'''
        result = self._values.get("acl")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def bucket(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#bucket StorageBucket#bucket}.'''
        result = self._values.get("bucket")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def bucket_prefix(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#bucket_prefix StorageBucket#bucket_prefix}.'''
        result = self._values.get("bucket_prefix")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cors_rule(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["StorageBucketCorsRule"]]]:
        '''cors_rule block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#cors_rule StorageBucket#cors_rule}
        '''
        result = self._values.get("cors_rule")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["StorageBucketCorsRule"]]], result)

    @builtins.property
    def force_destroy(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#force_destroy StorageBucket#force_destroy}.'''
        result = self._values.get("force_destroy")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def grant(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["StorageBucketGrant"]]]:
        '''grant block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#grant StorageBucket#grant}
        '''
        result = self._values.get("grant")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["StorageBucketGrant"]]], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#id StorageBucket#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def lifecycle_rule(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["StorageBucketLifecycleRule"]]]:
        '''lifecycle_rule block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#lifecycle_rule StorageBucket#lifecycle_rule}
        '''
        result = self._values.get("lifecycle_rule")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["StorageBucketLifecycleRule"]]], result)

    @builtins.property
    def logging(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["StorageBucketLogging"]]]:
        '''logging block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#logging StorageBucket#logging}
        '''
        result = self._values.get("logging")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["StorageBucketLogging"]]], result)

    @builtins.property
    def policy(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#policy StorageBucket#policy}.'''
        result = self._values.get("policy")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def secret_key(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#secret_key StorageBucket#secret_key}.'''
        result = self._values.get("secret_key")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def server_side_encryption_configuration(
        self,
    ) -> typing.Optional["StorageBucketServerSideEncryptionConfiguration"]:
        '''server_side_encryption_configuration block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#server_side_encryption_configuration StorageBucket#server_side_encryption_configuration}
        '''
        result = self._values.get("server_side_encryption_configuration")
        return typing.cast(typing.Optional["StorageBucketServerSideEncryptionConfiguration"], result)

    @builtins.property
    def versioning(self) -> typing.Optional["StorageBucketVersioning"]:
        '''versioning block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#versioning StorageBucket#versioning}
        '''
        result = self._values.get("versioning")
        return typing.cast(typing.Optional["StorageBucketVersioning"], result)

    @builtins.property
    def website(self) -> typing.Optional["StorageBucketWebsite"]:
        '''website block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#website StorageBucket#website}
        '''
        result = self._values.get("website")
        return typing.cast(typing.Optional["StorageBucketWebsite"], result)

    @builtins.property
    def website_domain(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#website_domain StorageBucket#website_domain}.'''
        result = self._values.get("website_domain")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def website_endpoint(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#website_endpoint StorageBucket#website_endpoint}.'''
        result = self._values.get("website_endpoint")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageBucketConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.StorageBucketCorsRule",
    jsii_struct_bases=[],
    name_mapping={
        "allowed_methods": "allowedMethods",
        "allowed_origins": "allowedOrigins",
        "allowed_headers": "allowedHeaders",
        "expose_headers": "exposeHeaders",
        "max_age_seconds": "maxAgeSeconds",
    },
)
class StorageBucketCorsRule:
    def __init__(
        self,
        *,
        allowed_methods: typing.Sequence[builtins.str],
        allowed_origins: typing.Sequence[builtins.str],
        allowed_headers: typing.Optional[typing.Sequence[builtins.str]] = None,
        expose_headers: typing.Optional[typing.Sequence[builtins.str]] = None,
        max_age_seconds: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param allowed_methods: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#allowed_methods StorageBucket#allowed_methods}.
        :param allowed_origins: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#allowed_origins StorageBucket#allowed_origins}.
        :param allowed_headers: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#allowed_headers StorageBucket#allowed_headers}.
        :param expose_headers: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#expose_headers StorageBucket#expose_headers}.
        :param max_age_seconds: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#max_age_seconds StorageBucket#max_age_seconds}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "allowed_methods": allowed_methods,
            "allowed_origins": allowed_origins,
        }
        if allowed_headers is not None:
            self._values["allowed_headers"] = allowed_headers
        if expose_headers is not None:
            self._values["expose_headers"] = expose_headers
        if max_age_seconds is not None:
            self._values["max_age_seconds"] = max_age_seconds

    @builtins.property
    def allowed_methods(self) -> typing.List[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#allowed_methods StorageBucket#allowed_methods}.'''
        result = self._values.get("allowed_methods")
        assert result is not None, "Required property 'allowed_methods' is missing"
        return typing.cast(typing.List[builtins.str], result)

    @builtins.property
    def allowed_origins(self) -> typing.List[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#allowed_origins StorageBucket#allowed_origins}.'''
        result = self._values.get("allowed_origins")
        assert result is not None, "Required property 'allowed_origins' is missing"
        return typing.cast(typing.List[builtins.str], result)

    @builtins.property
    def allowed_headers(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#allowed_headers StorageBucket#allowed_headers}.'''
        result = self._values.get("allowed_headers")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def expose_headers(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#expose_headers StorageBucket#expose_headers}.'''
        result = self._values.get("expose_headers")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def max_age_seconds(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#max_age_seconds StorageBucket#max_age_seconds}.'''
        result = self._values.get("max_age_seconds")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageBucketCorsRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StorageBucketCorsRuleList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.StorageBucketCorsRuleList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "StorageBucketCorsRuleOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("StorageBucketCorsRuleOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[StorageBucketCorsRule]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[StorageBucketCorsRule]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[StorageBucketCorsRule]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class StorageBucketCorsRuleOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.StorageBucketCorsRuleOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetAllowedHeaders")
    def reset_allowed_headers(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAllowedHeaders", []))

    @jsii.member(jsii_name="resetExposeHeaders")
    def reset_expose_headers(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetExposeHeaders", []))

    @jsii.member(jsii_name="resetMaxAgeSeconds")
    def reset_max_age_seconds(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxAgeSeconds", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allowedHeadersInput")
    def allowed_headers_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "allowedHeadersInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allowedMethodsInput")
    def allowed_methods_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "allowedMethodsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allowedOriginsInput")
    def allowed_origins_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "allowedOriginsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="exposeHeadersInput")
    def expose_headers_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "exposeHeadersInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxAgeSecondsInput")
    def max_age_seconds_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxAgeSecondsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allowedHeaders")
    def allowed_headers(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "allowedHeaders"))

    @allowed_headers.setter
    def allowed_headers(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "allowedHeaders", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allowedMethods")
    def allowed_methods(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "allowedMethods"))

    @allowed_methods.setter
    def allowed_methods(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "allowedMethods", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="allowedOrigins")
    def allowed_origins(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "allowedOrigins"))

    @allowed_origins.setter
    def allowed_origins(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "allowedOrigins", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="exposeHeaders")
    def expose_headers(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "exposeHeaders"))

    @expose_headers.setter
    def expose_headers(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "exposeHeaders", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxAgeSeconds")
    def max_age_seconds(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "maxAgeSeconds"))

    @max_age_seconds.setter
    def max_age_seconds(self, value: jsii.Number) -> None:
        jsii.set(self, "maxAgeSeconds", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, StorageBucketCorsRule]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, StorageBucketCorsRule]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, StorageBucketCorsRule]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.StorageBucketGrant",
    jsii_struct_bases=[],
    name_mapping={
        "permissions": "permissions",
        "type": "type",
        "id": "id",
        "uri": "uri",
    },
)
class StorageBucketGrant:
    def __init__(
        self,
        *,
        permissions: typing.Sequence[builtins.str],
        type: builtins.str,
        id: typing.Optional[builtins.str] = None,
        uri: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param permissions: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#permissions StorageBucket#permissions}.
        :param type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#type StorageBucket#type}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#id StorageBucket#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param uri: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#uri StorageBucket#uri}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "permissions": permissions,
            "type": type,
        }
        if id is not None:
            self._values["id"] = id
        if uri is not None:
            self._values["uri"] = uri

    @builtins.property
    def permissions(self) -> typing.List[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#permissions StorageBucket#permissions}.'''
        result = self._values.get("permissions")
        assert result is not None, "Required property 'permissions' is missing"
        return typing.cast(typing.List[builtins.str], result)

    @builtins.property
    def type(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#type StorageBucket#type}.'''
        result = self._values.get("type")
        assert result is not None, "Required property 'type' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#id StorageBucket#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def uri(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#uri StorageBucket#uri}.'''
        result = self._values.get("uri")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageBucketGrant(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StorageBucketGrantList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.StorageBucketGrantList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "StorageBucketGrantOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("StorageBucketGrantOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[StorageBucketGrant]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[StorageBucketGrant]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[StorageBucketGrant]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class StorageBucketGrantOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.StorageBucketGrantOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetUri")
    def reset_uri(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUri", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="permissionsInput")
    def permissions_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "permissionsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="typeInput")
    def type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "typeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="uriInput")
    def uri_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "uriInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="permissions")
    def permissions(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "permissions"))

    @permissions.setter
    def permissions(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "permissions", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="type")
    def type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "type"))

    @type.setter
    def type(self, value: builtins.str) -> None:
        jsii.set(self, "type", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="uri")
    def uri(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "uri"))

    @uri.setter
    def uri(self, value: builtins.str) -> None:
        jsii.set(self, "uri", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, StorageBucketGrant]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, StorageBucketGrant]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, StorageBucketGrant]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.StorageBucketLifecycleRule",
    jsii_struct_bases=[],
    name_mapping={
        "enabled": "enabled",
        "abort_incomplete_multipart_upload_days": "abortIncompleteMultipartUploadDays",
        "expiration": "expiration",
        "id": "id",
        "noncurrent_version_expiration": "noncurrentVersionExpiration",
        "noncurrent_version_transition": "noncurrentVersionTransition",
        "prefix": "prefix",
        "transition": "transition",
    },
)
class StorageBucketLifecycleRule:
    def __init__(
        self,
        *,
        enabled: typing.Union[builtins.bool, cdktf.IResolvable],
        abort_incomplete_multipart_upload_days: typing.Optional[jsii.Number] = None,
        expiration: typing.Optional["StorageBucketLifecycleRuleExpiration"] = None,
        id: typing.Optional[builtins.str] = None,
        noncurrent_version_expiration: typing.Optional["StorageBucketLifecycleRuleNoncurrentVersionExpiration"] = None,
        noncurrent_version_transition: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["StorageBucketLifecycleRuleNoncurrentVersionTransition"]]] = None,
        prefix: typing.Optional[builtins.str] = None,
        transition: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["StorageBucketLifecycleRuleTransition"]]] = None,
    ) -> None:
        '''
        :param enabled: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#enabled StorageBucket#enabled}.
        :param abort_incomplete_multipart_upload_days: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#abort_incomplete_multipart_upload_days StorageBucket#abort_incomplete_multipart_upload_days}.
        :param expiration: expiration block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#expiration StorageBucket#expiration}
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#id StorageBucket#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param noncurrent_version_expiration: noncurrent_version_expiration block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#noncurrent_version_expiration StorageBucket#noncurrent_version_expiration}
        :param noncurrent_version_transition: noncurrent_version_transition block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#noncurrent_version_transition StorageBucket#noncurrent_version_transition}
        :param prefix: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#prefix StorageBucket#prefix}.
        :param transition: transition block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#transition StorageBucket#transition}
        '''
        if isinstance(expiration, dict):
            expiration = StorageBucketLifecycleRuleExpiration(**expiration)
        if isinstance(noncurrent_version_expiration, dict):
            noncurrent_version_expiration = StorageBucketLifecycleRuleNoncurrentVersionExpiration(**noncurrent_version_expiration)
        self._values: typing.Dict[str, typing.Any] = {
            "enabled": enabled,
        }
        if abort_incomplete_multipart_upload_days is not None:
            self._values["abort_incomplete_multipart_upload_days"] = abort_incomplete_multipart_upload_days
        if expiration is not None:
            self._values["expiration"] = expiration
        if id is not None:
            self._values["id"] = id
        if noncurrent_version_expiration is not None:
            self._values["noncurrent_version_expiration"] = noncurrent_version_expiration
        if noncurrent_version_transition is not None:
            self._values["noncurrent_version_transition"] = noncurrent_version_transition
        if prefix is not None:
            self._values["prefix"] = prefix
        if transition is not None:
            self._values["transition"] = transition

    @builtins.property
    def enabled(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#enabled StorageBucket#enabled}.'''
        result = self._values.get("enabled")
        assert result is not None, "Required property 'enabled' is missing"
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], result)

    @builtins.property
    def abort_incomplete_multipart_upload_days(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#abort_incomplete_multipart_upload_days StorageBucket#abort_incomplete_multipart_upload_days}.'''
        result = self._values.get("abort_incomplete_multipart_upload_days")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def expiration(self) -> typing.Optional["StorageBucketLifecycleRuleExpiration"]:
        '''expiration block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#expiration StorageBucket#expiration}
        '''
        result = self._values.get("expiration")
        return typing.cast(typing.Optional["StorageBucketLifecycleRuleExpiration"], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#id StorageBucket#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def noncurrent_version_expiration(
        self,
    ) -> typing.Optional["StorageBucketLifecycleRuleNoncurrentVersionExpiration"]:
        '''noncurrent_version_expiration block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#noncurrent_version_expiration StorageBucket#noncurrent_version_expiration}
        '''
        result = self._values.get("noncurrent_version_expiration")
        return typing.cast(typing.Optional["StorageBucketLifecycleRuleNoncurrentVersionExpiration"], result)

    @builtins.property
    def noncurrent_version_transition(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["StorageBucketLifecycleRuleNoncurrentVersionTransition"]]]:
        '''noncurrent_version_transition block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#noncurrent_version_transition StorageBucket#noncurrent_version_transition}
        '''
        result = self._values.get("noncurrent_version_transition")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["StorageBucketLifecycleRuleNoncurrentVersionTransition"]]], result)

    @builtins.property
    def prefix(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#prefix StorageBucket#prefix}.'''
        result = self._values.get("prefix")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def transition(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["StorageBucketLifecycleRuleTransition"]]]:
        '''transition block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#transition StorageBucket#transition}
        '''
        result = self._values.get("transition")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["StorageBucketLifecycleRuleTransition"]]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageBucketLifecycleRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.StorageBucketLifecycleRuleExpiration",
    jsii_struct_bases=[],
    name_mapping={
        "date": "date",
        "days": "days",
        "expired_object_delete_marker": "expiredObjectDeleteMarker",
    },
)
class StorageBucketLifecycleRuleExpiration:
    def __init__(
        self,
        *,
        date: typing.Optional[builtins.str] = None,
        days: typing.Optional[jsii.Number] = None,
        expired_object_delete_marker: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param date: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#date StorageBucket#date}.
        :param days: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#days StorageBucket#days}.
        :param expired_object_delete_marker: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#expired_object_delete_marker StorageBucket#expired_object_delete_marker}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if date is not None:
            self._values["date"] = date
        if days is not None:
            self._values["days"] = days
        if expired_object_delete_marker is not None:
            self._values["expired_object_delete_marker"] = expired_object_delete_marker

    @builtins.property
    def date(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#date StorageBucket#date}.'''
        result = self._values.get("date")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def days(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#days StorageBucket#days}.'''
        result = self._values.get("days")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def expired_object_delete_marker(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#expired_object_delete_marker StorageBucket#expired_object_delete_marker}.'''
        result = self._values.get("expired_object_delete_marker")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageBucketLifecycleRuleExpiration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StorageBucketLifecycleRuleExpirationOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.StorageBucketLifecycleRuleExpirationOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetDate")
    def reset_date(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDate", []))

    @jsii.member(jsii_name="resetDays")
    def reset_days(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDays", []))

    @jsii.member(jsii_name="resetExpiredObjectDeleteMarker")
    def reset_expired_object_delete_marker(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetExpiredObjectDeleteMarker", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dateInput")
    def date_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="daysInput")
    def days_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "daysInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="expiredObjectDeleteMarkerInput")
    def expired_object_delete_marker_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "expiredObjectDeleteMarkerInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="date")
    def date(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "date"))

    @date.setter
    def date(self, value: builtins.str) -> None:
        jsii.set(self, "date", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="days")
    def days(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "days"))

    @days.setter
    def days(self, value: jsii.Number) -> None:
        jsii.set(self, "days", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="expiredObjectDeleteMarker")
    def expired_object_delete_marker(
        self,
    ) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "expiredObjectDeleteMarker"))

    @expired_object_delete_marker.setter
    def expired_object_delete_marker(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "expiredObjectDeleteMarker", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[StorageBucketLifecycleRuleExpiration]:
        return typing.cast(typing.Optional[StorageBucketLifecycleRuleExpiration], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[StorageBucketLifecycleRuleExpiration],
    ) -> None:
        jsii.set(self, "internalValue", value)


class StorageBucketLifecycleRuleList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.StorageBucketLifecycleRuleList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "StorageBucketLifecycleRuleOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("StorageBucketLifecycleRuleOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[StorageBucketLifecycleRule]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[StorageBucketLifecycleRule]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[StorageBucketLifecycleRule]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.StorageBucketLifecycleRuleNoncurrentVersionExpiration",
    jsii_struct_bases=[],
    name_mapping={"days": "days"},
)
class StorageBucketLifecycleRuleNoncurrentVersionExpiration:
    def __init__(self, *, days: typing.Optional[jsii.Number] = None) -> None:
        '''
        :param days: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#days StorageBucket#days}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if days is not None:
            self._values["days"] = days

    @builtins.property
    def days(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#days StorageBucket#days}.'''
        result = self._values.get("days")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageBucketLifecycleRuleNoncurrentVersionExpiration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StorageBucketLifecycleRuleNoncurrentVersionExpirationOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.StorageBucketLifecycleRuleNoncurrentVersionExpirationOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetDays")
    def reset_days(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDays", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="daysInput")
    def days_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "daysInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="days")
    def days(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "days"))

    @days.setter
    def days(self, value: jsii.Number) -> None:
        jsii.set(self, "days", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[StorageBucketLifecycleRuleNoncurrentVersionExpiration]:
        return typing.cast(typing.Optional[StorageBucketLifecycleRuleNoncurrentVersionExpiration], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[StorageBucketLifecycleRuleNoncurrentVersionExpiration],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.StorageBucketLifecycleRuleNoncurrentVersionTransition",
    jsii_struct_bases=[],
    name_mapping={"storage_class": "storageClass", "days": "days"},
)
class StorageBucketLifecycleRuleNoncurrentVersionTransition:
    def __init__(
        self,
        *,
        storage_class: builtins.str,
        days: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param storage_class: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#storage_class StorageBucket#storage_class}.
        :param days: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#days StorageBucket#days}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "storage_class": storage_class,
        }
        if days is not None:
            self._values["days"] = days

    @builtins.property
    def storage_class(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#storage_class StorageBucket#storage_class}.'''
        result = self._values.get("storage_class")
        assert result is not None, "Required property 'storage_class' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def days(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#days StorageBucket#days}.'''
        result = self._values.get("days")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageBucketLifecycleRuleNoncurrentVersionTransition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StorageBucketLifecycleRuleNoncurrentVersionTransitionList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.StorageBucketLifecycleRuleNoncurrentVersionTransitionList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "StorageBucketLifecycleRuleNoncurrentVersionTransitionOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("StorageBucketLifecycleRuleNoncurrentVersionTransitionOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[StorageBucketLifecycleRuleNoncurrentVersionTransition]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[StorageBucketLifecycleRuleNoncurrentVersionTransition]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[StorageBucketLifecycleRuleNoncurrentVersionTransition]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class StorageBucketLifecycleRuleNoncurrentVersionTransitionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.StorageBucketLifecycleRuleNoncurrentVersionTransitionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetDays")
    def reset_days(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDays", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="daysInput")
    def days_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "daysInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="storageClassInput")
    def storage_class_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "storageClassInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="days")
    def days(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "days"))

    @days.setter
    def days(self, value: jsii.Number) -> None:
        jsii.set(self, "days", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="storageClass")
    def storage_class(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "storageClass"))

    @storage_class.setter
    def storage_class(self, value: builtins.str) -> None:
        jsii.set(self, "storageClass", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, StorageBucketLifecycleRuleNoncurrentVersionTransition]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, StorageBucketLifecycleRuleNoncurrentVersionTransition]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, StorageBucketLifecycleRuleNoncurrentVersionTransition]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class StorageBucketLifecycleRuleOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.StorageBucketLifecycleRuleOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="putExpiration")
    def put_expiration(
        self,
        *,
        date: typing.Optional[builtins.str] = None,
        days: typing.Optional[jsii.Number] = None,
        expired_object_delete_marker: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param date: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#date StorageBucket#date}.
        :param days: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#days StorageBucket#days}.
        :param expired_object_delete_marker: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#expired_object_delete_marker StorageBucket#expired_object_delete_marker}.
        '''
        value = StorageBucketLifecycleRuleExpiration(
            date=date,
            days=days,
            expired_object_delete_marker=expired_object_delete_marker,
        )

        return typing.cast(None, jsii.invoke(self, "putExpiration", [value]))

    @jsii.member(jsii_name="putNoncurrentVersionExpiration")
    def put_noncurrent_version_expiration(
        self,
        *,
        days: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param days: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#days StorageBucket#days}.
        '''
        value = StorageBucketLifecycleRuleNoncurrentVersionExpiration(days=days)

        return typing.cast(None, jsii.invoke(self, "putNoncurrentVersionExpiration", [value]))

    @jsii.member(jsii_name="putNoncurrentVersionTransition")
    def put_noncurrent_version_transition(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence[StorageBucketLifecycleRuleNoncurrentVersionTransition]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putNoncurrentVersionTransition", [value]))

    @jsii.member(jsii_name="putTransition")
    def put_transition(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["StorageBucketLifecycleRuleTransition"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putTransition", [value]))

    @jsii.member(jsii_name="resetAbortIncompleteMultipartUploadDays")
    def reset_abort_incomplete_multipart_upload_days(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAbortIncompleteMultipartUploadDays", []))

    @jsii.member(jsii_name="resetExpiration")
    def reset_expiration(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetExpiration", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetNoncurrentVersionExpiration")
    def reset_noncurrent_version_expiration(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNoncurrentVersionExpiration", []))

    @jsii.member(jsii_name="resetNoncurrentVersionTransition")
    def reset_noncurrent_version_transition(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNoncurrentVersionTransition", []))

    @jsii.member(jsii_name="resetPrefix")
    def reset_prefix(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPrefix", []))

    @jsii.member(jsii_name="resetTransition")
    def reset_transition(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTransition", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="expiration")
    def expiration(self) -> StorageBucketLifecycleRuleExpirationOutputReference:
        return typing.cast(StorageBucketLifecycleRuleExpirationOutputReference, jsii.get(self, "expiration"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="noncurrentVersionExpiration")
    def noncurrent_version_expiration(
        self,
    ) -> StorageBucketLifecycleRuleNoncurrentVersionExpirationOutputReference:
        return typing.cast(StorageBucketLifecycleRuleNoncurrentVersionExpirationOutputReference, jsii.get(self, "noncurrentVersionExpiration"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="noncurrentVersionTransition")
    def noncurrent_version_transition(
        self,
    ) -> StorageBucketLifecycleRuleNoncurrentVersionTransitionList:
        return typing.cast(StorageBucketLifecycleRuleNoncurrentVersionTransitionList, jsii.get(self, "noncurrentVersionTransition"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="transition")
    def transition(self) -> "StorageBucketLifecycleRuleTransitionList":
        return typing.cast("StorageBucketLifecycleRuleTransitionList", jsii.get(self, "transition"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="abortIncompleteMultipartUploadDaysInput")
    def abort_incomplete_multipart_upload_days_input(
        self,
    ) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "abortIncompleteMultipartUploadDaysInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="enabledInput")
    def enabled_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "enabledInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="expirationInput")
    def expiration_input(self) -> typing.Optional[StorageBucketLifecycleRuleExpiration]:
        return typing.cast(typing.Optional[StorageBucketLifecycleRuleExpiration], jsii.get(self, "expirationInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="noncurrentVersionExpirationInput")
    def noncurrent_version_expiration_input(
        self,
    ) -> typing.Optional[StorageBucketLifecycleRuleNoncurrentVersionExpiration]:
        return typing.cast(typing.Optional[StorageBucketLifecycleRuleNoncurrentVersionExpiration], jsii.get(self, "noncurrentVersionExpirationInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="noncurrentVersionTransitionInput")
    def noncurrent_version_transition_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[StorageBucketLifecycleRuleNoncurrentVersionTransition]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[StorageBucketLifecycleRuleNoncurrentVersionTransition]]], jsii.get(self, "noncurrentVersionTransitionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="prefixInput")
    def prefix_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "prefixInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="transitionInput")
    def transition_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["StorageBucketLifecycleRuleTransition"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["StorageBucketLifecycleRuleTransition"]]], jsii.get(self, "transitionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="abortIncompleteMultipartUploadDays")
    def abort_incomplete_multipart_upload_days(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "abortIncompleteMultipartUploadDays"))

    @abort_incomplete_multipart_upload_days.setter
    def abort_incomplete_multipart_upload_days(self, value: jsii.Number) -> None:
        jsii.set(self, "abortIncompleteMultipartUploadDays", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "enabled"))

    @enabled.setter
    def enabled(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="prefix")
    def prefix(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "prefix"))

    @prefix.setter
    def prefix(self, value: builtins.str) -> None:
        jsii.set(self, "prefix", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, StorageBucketLifecycleRule]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, StorageBucketLifecycleRule]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, StorageBucketLifecycleRule]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.StorageBucketLifecycleRuleTransition",
    jsii_struct_bases=[],
    name_mapping={"storage_class": "storageClass", "date": "date", "days": "days"},
)
class StorageBucketLifecycleRuleTransition:
    def __init__(
        self,
        *,
        storage_class: builtins.str,
        date: typing.Optional[builtins.str] = None,
        days: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param storage_class: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#storage_class StorageBucket#storage_class}.
        :param date: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#date StorageBucket#date}.
        :param days: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#days StorageBucket#days}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "storage_class": storage_class,
        }
        if date is not None:
            self._values["date"] = date
        if days is not None:
            self._values["days"] = days

    @builtins.property
    def storage_class(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#storage_class StorageBucket#storage_class}.'''
        result = self._values.get("storage_class")
        assert result is not None, "Required property 'storage_class' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def date(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#date StorageBucket#date}.'''
        result = self._values.get("date")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def days(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#days StorageBucket#days}.'''
        result = self._values.get("days")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageBucketLifecycleRuleTransition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StorageBucketLifecycleRuleTransitionList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.StorageBucketLifecycleRuleTransitionList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "StorageBucketLifecycleRuleTransitionOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("StorageBucketLifecycleRuleTransitionOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[StorageBucketLifecycleRuleTransition]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[StorageBucketLifecycleRuleTransition]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[StorageBucketLifecycleRuleTransition]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class StorageBucketLifecycleRuleTransitionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.StorageBucketLifecycleRuleTransitionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetDate")
    def reset_date(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDate", []))

    @jsii.member(jsii_name="resetDays")
    def reset_days(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDays", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dateInput")
    def date_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="daysInput")
    def days_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "daysInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="storageClassInput")
    def storage_class_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "storageClassInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="date")
    def date(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "date"))

    @date.setter
    def date(self, value: builtins.str) -> None:
        jsii.set(self, "date", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="days")
    def days(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "days"))

    @days.setter
    def days(self, value: jsii.Number) -> None:
        jsii.set(self, "days", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="storageClass")
    def storage_class(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "storageClass"))

    @storage_class.setter
    def storage_class(self, value: builtins.str) -> None:
        jsii.set(self, "storageClass", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, StorageBucketLifecycleRuleTransition]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, StorageBucketLifecycleRuleTransition]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, StorageBucketLifecycleRuleTransition]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.StorageBucketLogging",
    jsii_struct_bases=[],
    name_mapping={"target_bucket": "targetBucket", "target_prefix": "targetPrefix"},
)
class StorageBucketLogging:
    def __init__(
        self,
        *,
        target_bucket: builtins.str,
        target_prefix: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param target_bucket: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#target_bucket StorageBucket#target_bucket}.
        :param target_prefix: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#target_prefix StorageBucket#target_prefix}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "target_bucket": target_bucket,
        }
        if target_prefix is not None:
            self._values["target_prefix"] = target_prefix

    @builtins.property
    def target_bucket(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#target_bucket StorageBucket#target_bucket}.'''
        result = self._values.get("target_bucket")
        assert result is not None, "Required property 'target_bucket' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def target_prefix(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#target_prefix StorageBucket#target_prefix}.'''
        result = self._values.get("target_prefix")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageBucketLogging(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StorageBucketLoggingList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.StorageBucketLoggingList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "StorageBucketLoggingOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("StorageBucketLoggingOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[StorageBucketLogging]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[StorageBucketLogging]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[StorageBucketLogging]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class StorageBucketLoggingOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.StorageBucketLoggingOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetTargetPrefix")
    def reset_target_prefix(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTargetPrefix", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetBucketInput")
    def target_bucket_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "targetBucketInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetPrefixInput")
    def target_prefix_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "targetPrefixInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetBucket")
    def target_bucket(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "targetBucket"))

    @target_bucket.setter
    def target_bucket(self, value: builtins.str) -> None:
        jsii.set(self, "targetBucket", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="targetPrefix")
    def target_prefix(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "targetPrefix"))

    @target_prefix.setter
    def target_prefix(self, value: builtins.str) -> None:
        jsii.set(self, "targetPrefix", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, StorageBucketLogging]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, StorageBucketLogging]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, StorageBucketLogging]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.StorageBucketServerSideEncryptionConfiguration",
    jsii_struct_bases=[],
    name_mapping={"rule": "rule"},
)
class StorageBucketServerSideEncryptionConfiguration:
    def __init__(
        self,
        *,
        rule: "StorageBucketServerSideEncryptionConfigurationRule",
    ) -> None:
        '''
        :param rule: rule block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#rule StorageBucket#rule}
        '''
        if isinstance(rule, dict):
            rule = StorageBucketServerSideEncryptionConfigurationRule(**rule)
        self._values: typing.Dict[str, typing.Any] = {
            "rule": rule,
        }

    @builtins.property
    def rule(self) -> "StorageBucketServerSideEncryptionConfigurationRule":
        '''rule block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#rule StorageBucket#rule}
        '''
        result = self._values.get("rule")
        assert result is not None, "Required property 'rule' is missing"
        return typing.cast("StorageBucketServerSideEncryptionConfigurationRule", result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageBucketServerSideEncryptionConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StorageBucketServerSideEncryptionConfigurationOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.StorageBucketServerSideEncryptionConfigurationOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putRule")
    def put_rule(
        self,
        *,
        apply_server_side_encryption_by_default: "StorageBucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefault",
    ) -> None:
        '''
        :param apply_server_side_encryption_by_default: apply_server_side_encryption_by_default block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#apply_server_side_encryption_by_default StorageBucket#apply_server_side_encryption_by_default}
        '''
        value = StorageBucketServerSideEncryptionConfigurationRule(
            apply_server_side_encryption_by_default=apply_server_side_encryption_by_default,
        )

        return typing.cast(None, jsii.invoke(self, "putRule", [value]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="rule")
    def rule(
        self,
    ) -> "StorageBucketServerSideEncryptionConfigurationRuleOutputReference":
        return typing.cast("StorageBucketServerSideEncryptionConfigurationRuleOutputReference", jsii.get(self, "rule"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ruleInput")
    def rule_input(
        self,
    ) -> typing.Optional["StorageBucketServerSideEncryptionConfigurationRule"]:
        return typing.cast(typing.Optional["StorageBucketServerSideEncryptionConfigurationRule"], jsii.get(self, "ruleInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[StorageBucketServerSideEncryptionConfiguration]:
        return typing.cast(typing.Optional[StorageBucketServerSideEncryptionConfiguration], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[StorageBucketServerSideEncryptionConfiguration],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.StorageBucketServerSideEncryptionConfigurationRule",
    jsii_struct_bases=[],
    name_mapping={
        "apply_server_side_encryption_by_default": "applyServerSideEncryptionByDefault",
    },
)
class StorageBucketServerSideEncryptionConfigurationRule:
    def __init__(
        self,
        *,
        apply_server_side_encryption_by_default: "StorageBucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefault",
    ) -> None:
        '''
        :param apply_server_side_encryption_by_default: apply_server_side_encryption_by_default block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#apply_server_side_encryption_by_default StorageBucket#apply_server_side_encryption_by_default}
        '''
        if isinstance(apply_server_side_encryption_by_default, dict):
            apply_server_side_encryption_by_default = StorageBucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefault(**apply_server_side_encryption_by_default)
        self._values: typing.Dict[str, typing.Any] = {
            "apply_server_side_encryption_by_default": apply_server_side_encryption_by_default,
        }

    @builtins.property
    def apply_server_side_encryption_by_default(
        self,
    ) -> "StorageBucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefault":
        '''apply_server_side_encryption_by_default block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#apply_server_side_encryption_by_default StorageBucket#apply_server_side_encryption_by_default}
        '''
        result = self._values.get("apply_server_side_encryption_by_default")
        assert result is not None, "Required property 'apply_server_side_encryption_by_default' is missing"
        return typing.cast("StorageBucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefault", result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageBucketServerSideEncryptionConfigurationRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.StorageBucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefault",
    jsii_struct_bases=[],
    name_mapping={
        "kms_master_key_id": "kmsMasterKeyId",
        "sse_algorithm": "sseAlgorithm",
    },
)
class StorageBucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefault:
    def __init__(
        self,
        *,
        kms_master_key_id: builtins.str,
        sse_algorithm: builtins.str,
    ) -> None:
        '''
        :param kms_master_key_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#kms_master_key_id StorageBucket#kms_master_key_id}.
        :param sse_algorithm: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#sse_algorithm StorageBucket#sse_algorithm}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "kms_master_key_id": kms_master_key_id,
            "sse_algorithm": sse_algorithm,
        }

    @builtins.property
    def kms_master_key_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#kms_master_key_id StorageBucket#kms_master_key_id}.'''
        result = self._values.get("kms_master_key_id")
        assert result is not None, "Required property 'kms_master_key_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def sse_algorithm(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#sse_algorithm StorageBucket#sse_algorithm}.'''
        result = self._values.get("sse_algorithm")
        assert result is not None, "Required property 'sse_algorithm' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageBucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefault(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StorageBucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefaultOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.StorageBucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefaultOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="kmsMasterKeyIdInput")
    def kms_master_key_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "kmsMasterKeyIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sseAlgorithmInput")
    def sse_algorithm_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sseAlgorithmInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="kmsMasterKeyId")
    def kms_master_key_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "kmsMasterKeyId"))

    @kms_master_key_id.setter
    def kms_master_key_id(self, value: builtins.str) -> None:
        jsii.set(self, "kmsMasterKeyId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sseAlgorithm")
    def sse_algorithm(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "sseAlgorithm"))

    @sse_algorithm.setter
    def sse_algorithm(self, value: builtins.str) -> None:
        jsii.set(self, "sseAlgorithm", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[StorageBucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefault]:
        return typing.cast(typing.Optional[StorageBucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefault], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[StorageBucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefault],
    ) -> None:
        jsii.set(self, "internalValue", value)


class StorageBucketServerSideEncryptionConfigurationRuleOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.StorageBucketServerSideEncryptionConfigurationRuleOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putApplyServerSideEncryptionByDefault")
    def put_apply_server_side_encryption_by_default(
        self,
        *,
        kms_master_key_id: builtins.str,
        sse_algorithm: builtins.str,
    ) -> None:
        '''
        :param kms_master_key_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#kms_master_key_id StorageBucket#kms_master_key_id}.
        :param sse_algorithm: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#sse_algorithm StorageBucket#sse_algorithm}.
        '''
        value = StorageBucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefault(
            kms_master_key_id=kms_master_key_id, sse_algorithm=sse_algorithm
        )

        return typing.cast(None, jsii.invoke(self, "putApplyServerSideEncryptionByDefault", [value]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="applyServerSideEncryptionByDefault")
    def apply_server_side_encryption_by_default(
        self,
    ) -> StorageBucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefaultOutputReference:
        return typing.cast(StorageBucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefaultOutputReference, jsii.get(self, "applyServerSideEncryptionByDefault"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="applyServerSideEncryptionByDefaultInput")
    def apply_server_side_encryption_by_default_input(
        self,
    ) -> typing.Optional[StorageBucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefault]:
        return typing.cast(typing.Optional[StorageBucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefault], jsii.get(self, "applyServerSideEncryptionByDefaultInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[StorageBucketServerSideEncryptionConfigurationRule]:
        return typing.cast(typing.Optional[StorageBucketServerSideEncryptionConfigurationRule], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[StorageBucketServerSideEncryptionConfigurationRule],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.StorageBucketVersioning",
    jsii_struct_bases=[],
    name_mapping={"enabled": "enabled"},
)
class StorageBucketVersioning:
    def __init__(
        self,
        *,
        enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
    ) -> None:
        '''
        :param enabled: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#enabled StorageBucket#enabled}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if enabled is not None:
            self._values["enabled"] = enabled

    @builtins.property
    def enabled(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#enabled StorageBucket#enabled}.'''
        result = self._values.get("enabled")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageBucketVersioning(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StorageBucketVersioningOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.StorageBucketVersioningOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetEnabled")
    def reset_enabled(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEnabled", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="enabledInput")
    def enabled_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "enabledInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "enabled"))

    @enabled.setter
    def enabled(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[StorageBucketVersioning]:
        return typing.cast(typing.Optional[StorageBucketVersioning], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(self, value: typing.Optional[StorageBucketVersioning]) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.StorageBucketWebsite",
    jsii_struct_bases=[],
    name_mapping={
        "error_document": "errorDocument",
        "index_document": "indexDocument",
        "redirect_all_requests_to": "redirectAllRequestsTo",
        "routing_rules": "routingRules",
    },
)
class StorageBucketWebsite:
    def __init__(
        self,
        *,
        error_document: typing.Optional[builtins.str] = None,
        index_document: typing.Optional[builtins.str] = None,
        redirect_all_requests_to: typing.Optional[builtins.str] = None,
        routing_rules: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param error_document: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#error_document StorageBucket#error_document}.
        :param index_document: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#index_document StorageBucket#index_document}.
        :param redirect_all_requests_to: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#redirect_all_requests_to StorageBucket#redirect_all_requests_to}.
        :param routing_rules: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#routing_rules StorageBucket#routing_rules}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if error_document is not None:
            self._values["error_document"] = error_document
        if index_document is not None:
            self._values["index_document"] = index_document
        if redirect_all_requests_to is not None:
            self._values["redirect_all_requests_to"] = redirect_all_requests_to
        if routing_rules is not None:
            self._values["routing_rules"] = routing_rules

    @builtins.property
    def error_document(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#error_document StorageBucket#error_document}.'''
        result = self._values.get("error_document")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def index_document(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#index_document StorageBucket#index_document}.'''
        result = self._values.get("index_document")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def redirect_all_requests_to(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#redirect_all_requests_to StorageBucket#redirect_all_requests_to}.'''
        result = self._values.get("redirect_all_requests_to")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def routing_rules(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_bucket#routing_rules StorageBucket#routing_rules}.'''
        result = self._values.get("routing_rules")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageBucketWebsite(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StorageBucketWebsiteOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.StorageBucketWebsiteOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetErrorDocument")
    def reset_error_document(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetErrorDocument", []))

    @jsii.member(jsii_name="resetIndexDocument")
    def reset_index_document(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIndexDocument", []))

    @jsii.member(jsii_name="resetRedirectAllRequestsTo")
    def reset_redirect_all_requests_to(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRedirectAllRequestsTo", []))

    @jsii.member(jsii_name="resetRoutingRules")
    def reset_routing_rules(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRoutingRules", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errorDocumentInput")
    def error_document_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "errorDocumentInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="indexDocumentInput")
    def index_document_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "indexDocumentInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="redirectAllRequestsToInput")
    def redirect_all_requests_to_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "redirectAllRequestsToInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="routingRulesInput")
    def routing_rules_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "routingRulesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errorDocument")
    def error_document(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "errorDocument"))

    @error_document.setter
    def error_document(self, value: builtins.str) -> None:
        jsii.set(self, "errorDocument", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="indexDocument")
    def index_document(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "indexDocument"))

    @index_document.setter
    def index_document(self, value: builtins.str) -> None:
        jsii.set(self, "indexDocument", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="redirectAllRequestsTo")
    def redirect_all_requests_to(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "redirectAllRequestsTo"))

    @redirect_all_requests_to.setter
    def redirect_all_requests_to(self, value: builtins.str) -> None:
        jsii.set(self, "redirectAllRequestsTo", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="routingRules")
    def routing_rules(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "routingRules"))

    @routing_rules.setter
    def routing_rules(self, value: builtins.str) -> None:
        jsii.set(self, "routingRules", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[StorageBucketWebsite]:
        return typing.cast(typing.Optional[StorageBucketWebsite], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(self, value: typing.Optional[StorageBucketWebsite]) -> None:
        jsii.set(self, "internalValue", value)


class StorageObject(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.StorageObject",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/storage_object yandex_storage_object}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        bucket: builtins.str,
        key: builtins.str,
        access_key: typing.Optional[builtins.str] = None,
        acl: typing.Optional[builtins.str] = None,
        content: typing.Optional[builtins.str] = None,
        content_base64: typing.Optional[builtins.str] = None,
        content_type: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        secret_key: typing.Optional[builtins.str] = None,
        source: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/storage_object yandex_storage_object} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param bucket: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_object#bucket StorageObject#bucket}.
        :param key: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_object#key StorageObject#key}.
        :param access_key: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_object#access_key StorageObject#access_key}.
        :param acl: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_object#acl StorageObject#acl}.
        :param content: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_object#content StorageObject#content}.
        :param content_base64: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_object#content_base64 StorageObject#content_base64}.
        :param content_type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_object#content_type StorageObject#content_type}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_object#id StorageObject#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param secret_key: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_object#secret_key StorageObject#secret_key}.
        :param source: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_object#source StorageObject#source}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = StorageObjectConfig(
            bucket=bucket,
            key=key,
            access_key=access_key,
            acl=acl,
            content=content,
            content_base64=content_base64,
            content_type=content_type,
            id=id,
            secret_key=secret_key,
            source=source,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="resetAccessKey")
    def reset_access_key(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAccessKey", []))

    @jsii.member(jsii_name="resetAcl")
    def reset_acl(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAcl", []))

    @jsii.member(jsii_name="resetContent")
    def reset_content(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetContent", []))

    @jsii.member(jsii_name="resetContentBase64")
    def reset_content_base64(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetContentBase64", []))

    @jsii.member(jsii_name="resetContentType")
    def reset_content_type(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetContentType", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetSecretKey")
    def reset_secret_key(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecretKey", []))

    @jsii.member(jsii_name="resetSource")
    def reset_source(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSource", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="accessKeyInput")
    def access_key_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "accessKeyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="aclInput")
    def acl_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aclInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bucketInput")
    def bucket_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "bucketInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="contentBase64Input")
    def content_base64_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "contentBase64Input"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="contentInput")
    def content_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "contentInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="contentTypeInput")
    def content_type_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "contentTypeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="keyInput")
    def key_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "keyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="secretKeyInput")
    def secret_key_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "secretKeyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sourceInput")
    def source_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "sourceInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="accessKey")
    def access_key(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "accessKey"))

    @access_key.setter
    def access_key(self, value: builtins.str) -> None:
        jsii.set(self, "accessKey", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="acl")
    def acl(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "acl"))

    @acl.setter
    def acl(self, value: builtins.str) -> None:
        jsii.set(self, "acl", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bucket")
    def bucket(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "bucket"))

    @bucket.setter
    def bucket(self, value: builtins.str) -> None:
        jsii.set(self, "bucket", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="content")
    def content(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "content"))

    @content.setter
    def content(self, value: builtins.str) -> None:
        jsii.set(self, "content", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="contentBase64")
    def content_base64(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "contentBase64"))

    @content_base64.setter
    def content_base64(self, value: builtins.str) -> None:
        jsii.set(self, "contentBase64", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="contentType")
    def content_type(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "contentType"))

    @content_type.setter
    def content_type(self, value: builtins.str) -> None:
        jsii.set(self, "contentType", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="key")
    def key(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "key"))

    @key.setter
    def key(self, value: builtins.str) -> None:
        jsii.set(self, "key", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="secretKey")
    def secret_key(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "secretKey"))

    @secret_key.setter
    def secret_key(self, value: builtins.str) -> None:
        jsii.set(self, "secretKey", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="source")
    def source(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "source"))

    @source.setter
    def source(self, value: builtins.str) -> None:
        jsii.set(self, "source", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.StorageObjectConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "bucket": "bucket",
        "key": "key",
        "access_key": "accessKey",
        "acl": "acl",
        "content": "content",
        "content_base64": "contentBase64",
        "content_type": "contentType",
        "id": "id",
        "secret_key": "secretKey",
        "source": "source",
    },
)
class StorageObjectConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        bucket: builtins.str,
        key: builtins.str,
        access_key: typing.Optional[builtins.str] = None,
        acl: typing.Optional[builtins.str] = None,
        content: typing.Optional[builtins.str] = None,
        content_base64: typing.Optional[builtins.str] = None,
        content_type: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        secret_key: typing.Optional[builtins.str] = None,
        source: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param bucket: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_object#bucket StorageObject#bucket}.
        :param key: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_object#key StorageObject#key}.
        :param access_key: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_object#access_key StorageObject#access_key}.
        :param acl: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_object#acl StorageObject#acl}.
        :param content: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_object#content StorageObject#content}.
        :param content_base64: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_object#content_base64 StorageObject#content_base64}.
        :param content_type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_object#content_type StorageObject#content_type}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_object#id StorageObject#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param secret_key: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_object#secret_key StorageObject#secret_key}.
        :param source: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_object#source StorageObject#source}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values: typing.Dict[str, typing.Any] = {
            "bucket": bucket,
            "key": key,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if access_key is not None:
            self._values["access_key"] = access_key
        if acl is not None:
            self._values["acl"] = acl
        if content is not None:
            self._values["content"] = content
        if content_base64 is not None:
            self._values["content_base64"] = content_base64
        if content_type is not None:
            self._values["content_type"] = content_type
        if id is not None:
            self._values["id"] = id
        if secret_key is not None:
            self._values["secret_key"] = secret_key
        if source is not None:
            self._values["source"] = source

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def bucket(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_object#bucket StorageObject#bucket}.'''
        result = self._values.get("bucket")
        assert result is not None, "Required property 'bucket' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def key(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_object#key StorageObject#key}.'''
        result = self._values.get("key")
        assert result is not None, "Required property 'key' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def access_key(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_object#access_key StorageObject#access_key}.'''
        result = self._values.get("access_key")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def acl(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_object#acl StorageObject#acl}.'''
        result = self._values.get("acl")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def content(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_object#content StorageObject#content}.'''
        result = self._values.get("content")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def content_base64(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_object#content_base64 StorageObject#content_base64}.'''
        result = self._values.get("content_base64")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def content_type(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_object#content_type StorageObject#content_type}.'''
        result = self._values.get("content_type")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_object#id StorageObject#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def secret_key(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_object#secret_key StorageObject#secret_key}.'''
        result = self._values.get("secret_key")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def source(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/storage_object#source StorageObject#source}.'''
        result = self._values.get("source")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StorageObjectConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VpcAddress(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.VpcAddress",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address yandex_vpc_address}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        description: typing.Optional[builtins.str] = None,
        external_ipv4_address: typing.Optional["VpcAddressExternalIpv4Address"] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["VpcAddressTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address yandex_vpc_address} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#description VpcAddress#description}.
        :param external_ipv4_address: external_ipv4_address block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#external_ipv4_address VpcAddress#external_ipv4_address}
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#folder_id VpcAddress#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#id VpcAddress#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#labels VpcAddress#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#name VpcAddress#name}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#timeouts VpcAddress#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = VpcAddressConfig(
            description=description,
            external_ipv4_address=external_ipv4_address,
            folder_id=folder_id,
            id=id,
            labels=labels,
            name=name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putExternalIpv4Address")
    def put_external_ipv4_address(
        self,
        *,
        ddos_protection_provider: typing.Optional[builtins.str] = None,
        outgoing_smtp_capability: typing.Optional[builtins.str] = None,
        zone_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param ddos_protection_provider: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#ddos_protection_provider VpcAddress#ddos_protection_provider}.
        :param outgoing_smtp_capability: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#outgoing_smtp_capability VpcAddress#outgoing_smtp_capability}.
        :param zone_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#zone_id VpcAddress#zone_id}.
        '''
        value = VpcAddressExternalIpv4Address(
            ddos_protection_provider=ddos_protection_provider,
            outgoing_smtp_capability=outgoing_smtp_capability,
            zone_id=zone_id,
        )

        return typing.cast(None, jsii.invoke(self, "putExternalIpv4Address", [value]))

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#create VpcAddress#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#delete VpcAddress#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#update VpcAddress#update}.
        '''
        value = VpcAddressTimeouts(create=create, delete=delete, update=update)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetExternalIpv4Address")
    def reset_external_ipv4_address(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetExternalIpv4Address", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="externalIpv4Address")
    def external_ipv4_address(self) -> "VpcAddressExternalIpv4AddressOutputReference":
        return typing.cast("VpcAddressExternalIpv4AddressOutputReference", jsii.get(self, "externalIpv4Address"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="reserved")
    def reserved(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "reserved"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "VpcAddressTimeoutsOutputReference":
        return typing.cast("VpcAddressTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="used")
    def used(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "used"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="externalIpv4AddressInput")
    def external_ipv4_address_input(
        self,
    ) -> typing.Optional["VpcAddressExternalIpv4Address"]:
        return typing.cast(typing.Optional["VpcAddressExternalIpv4Address"], jsii.get(self, "externalIpv4AddressInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "VpcAddressTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "VpcAddressTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.VpcAddressConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "description": "description",
        "external_ipv4_address": "externalIpv4Address",
        "folder_id": "folderId",
        "id": "id",
        "labels": "labels",
        "name": "name",
        "timeouts": "timeouts",
    },
)
class VpcAddressConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        description: typing.Optional[builtins.str] = None,
        external_ipv4_address: typing.Optional["VpcAddressExternalIpv4Address"] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["VpcAddressTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#description VpcAddress#description}.
        :param external_ipv4_address: external_ipv4_address block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#external_ipv4_address VpcAddress#external_ipv4_address}
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#folder_id VpcAddress#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#id VpcAddress#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#labels VpcAddress#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#name VpcAddress#name}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#timeouts VpcAddress#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(external_ipv4_address, dict):
            external_ipv4_address = VpcAddressExternalIpv4Address(**external_ipv4_address)
        if isinstance(timeouts, dict):
            timeouts = VpcAddressTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if external_ipv4_address is not None:
            self._values["external_ipv4_address"] = external_ipv4_address
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if name is not None:
            self._values["name"] = name
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#description VpcAddress#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def external_ipv4_address(self) -> typing.Optional["VpcAddressExternalIpv4Address"]:
        '''external_ipv4_address block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#external_ipv4_address VpcAddress#external_ipv4_address}
        '''
        result = self._values.get("external_ipv4_address")
        return typing.cast(typing.Optional["VpcAddressExternalIpv4Address"], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#folder_id VpcAddress#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#id VpcAddress#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#labels VpcAddress#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#name VpcAddress#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["VpcAddressTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#timeouts VpcAddress#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["VpcAddressTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcAddressConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.VpcAddressExternalIpv4Address",
    jsii_struct_bases=[],
    name_mapping={
        "ddos_protection_provider": "ddosProtectionProvider",
        "outgoing_smtp_capability": "outgoingSmtpCapability",
        "zone_id": "zoneId",
    },
)
class VpcAddressExternalIpv4Address:
    def __init__(
        self,
        *,
        ddos_protection_provider: typing.Optional[builtins.str] = None,
        outgoing_smtp_capability: typing.Optional[builtins.str] = None,
        zone_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param ddos_protection_provider: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#ddos_protection_provider VpcAddress#ddos_protection_provider}.
        :param outgoing_smtp_capability: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#outgoing_smtp_capability VpcAddress#outgoing_smtp_capability}.
        :param zone_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#zone_id VpcAddress#zone_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if ddos_protection_provider is not None:
            self._values["ddos_protection_provider"] = ddos_protection_provider
        if outgoing_smtp_capability is not None:
            self._values["outgoing_smtp_capability"] = outgoing_smtp_capability
        if zone_id is not None:
            self._values["zone_id"] = zone_id

    @builtins.property
    def ddos_protection_provider(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#ddos_protection_provider VpcAddress#ddos_protection_provider}.'''
        result = self._values.get("ddos_protection_provider")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def outgoing_smtp_capability(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#outgoing_smtp_capability VpcAddress#outgoing_smtp_capability}.'''
        result = self._values.get("outgoing_smtp_capability")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def zone_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#zone_id VpcAddress#zone_id}.'''
        result = self._values.get("zone_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcAddressExternalIpv4Address(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VpcAddressExternalIpv4AddressOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.VpcAddressExternalIpv4AddressOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetDdosProtectionProvider")
    def reset_ddos_protection_provider(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDdosProtectionProvider", []))

    @jsii.member(jsii_name="resetOutgoingSmtpCapability")
    def reset_outgoing_smtp_capability(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOutgoingSmtpCapability", []))

    @jsii.member(jsii_name="resetZoneId")
    def reset_zone_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetZoneId", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="address")
    def address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "address"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ddosProtectionProviderInput")
    def ddos_protection_provider_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "ddosProtectionProviderInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="outgoingSmtpCapabilityInput")
    def outgoing_smtp_capability_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "outgoingSmtpCapabilityInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneIdInput")
    def zone_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "zoneIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ddosProtectionProvider")
    def ddos_protection_provider(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ddosProtectionProvider"))

    @ddos_protection_provider.setter
    def ddos_protection_provider(self, value: builtins.str) -> None:
        jsii.set(self, "ddosProtectionProvider", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="outgoingSmtpCapability")
    def outgoing_smtp_capability(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "outgoingSmtpCapability"))

    @outgoing_smtp_capability.setter
    def outgoing_smtp_capability(self, value: builtins.str) -> None:
        jsii.set(self, "outgoingSmtpCapability", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneId")
    def zone_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zoneId"))

    @zone_id.setter
    def zone_id(self, value: builtins.str) -> None:
        jsii.set(self, "zoneId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[VpcAddressExternalIpv4Address]:
        return typing.cast(typing.Optional[VpcAddressExternalIpv4Address], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[VpcAddressExternalIpv4Address],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.VpcAddressTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class VpcAddressTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#create VpcAddress#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#delete VpcAddress#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#update VpcAddress#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#create VpcAddress#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#delete VpcAddress#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_address#update VpcAddress#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcAddressTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VpcAddressTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.VpcAddressTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, VpcAddressTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, VpcAddressTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, VpcAddressTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class VpcDefaultSecurityGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.VpcDefaultSecurityGroup",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group yandex_vpc_default_security_group}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        network_id: builtins.str,
        description: typing.Optional[builtins.str] = None,
        egress: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["VpcDefaultSecurityGroupEgress"]]] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        ingress: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["VpcDefaultSecurityGroupIngress"]]] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["VpcDefaultSecurityGroupTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group yandex_vpc_default_security_group} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#network_id VpcDefaultSecurityGroup#network_id}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#description VpcDefaultSecurityGroup#description}.
        :param egress: egress block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#egress VpcDefaultSecurityGroup#egress}
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#folder_id VpcDefaultSecurityGroup#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#id VpcDefaultSecurityGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param ingress: ingress block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#ingress VpcDefaultSecurityGroup#ingress}
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#labels VpcDefaultSecurityGroup#labels}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#timeouts VpcDefaultSecurityGroup#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = VpcDefaultSecurityGroupConfig(
            network_id=network_id,
            description=description,
            egress=egress,
            folder_id=folder_id,
            id=id,
            ingress=ingress,
            labels=labels,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putEgress")
    def put_egress(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["VpcDefaultSecurityGroupEgress"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putEgress", [value]))

    @jsii.member(jsii_name="putIngress")
    def put_ingress(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["VpcDefaultSecurityGroupIngress"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putIngress", [value]))

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#create VpcDefaultSecurityGroup#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#delete VpcDefaultSecurityGroup#delete}.
        :param read: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#read VpcDefaultSecurityGroup#read}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#update VpcDefaultSecurityGroup#update}.
        '''
        value = VpcDefaultSecurityGroupTimeouts(
            create=create, delete=delete, read=read, update=update
        )

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetEgress")
    def reset_egress(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEgress", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetIngress")
    def reset_ingress(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIngress", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="egress")
    def egress(self) -> "VpcDefaultSecurityGroupEgressList":
        return typing.cast("VpcDefaultSecurityGroupEgressList", jsii.get(self, "egress"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ingress")
    def ingress(self) -> "VpcDefaultSecurityGroupIngressList":
        return typing.cast("VpcDefaultSecurityGroupIngressList", jsii.get(self, "ingress"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "VpcDefaultSecurityGroupTimeoutsOutputReference":
        return typing.cast("VpcDefaultSecurityGroupTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="egressInput")
    def egress_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["VpcDefaultSecurityGroupEgress"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["VpcDefaultSecurityGroupEgress"]]], jsii.get(self, "egressInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ingressInput")
    def ingress_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["VpcDefaultSecurityGroupIngress"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["VpcDefaultSecurityGroupIngress"]]], jsii.get(self, "ingressInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkIdInput")
    def network_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "networkIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "VpcDefaultSecurityGroupTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "VpcDefaultSecurityGroupTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @network_id.setter
    def network_id(self, value: builtins.str) -> None:
        jsii.set(self, "networkId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.VpcDefaultSecurityGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "network_id": "networkId",
        "description": "description",
        "egress": "egress",
        "folder_id": "folderId",
        "id": "id",
        "ingress": "ingress",
        "labels": "labels",
        "timeouts": "timeouts",
    },
)
class VpcDefaultSecurityGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        network_id: builtins.str,
        description: typing.Optional[builtins.str] = None,
        egress: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["VpcDefaultSecurityGroupEgress"]]] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        ingress: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["VpcDefaultSecurityGroupIngress"]]] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        timeouts: typing.Optional["VpcDefaultSecurityGroupTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#network_id VpcDefaultSecurityGroup#network_id}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#description VpcDefaultSecurityGroup#description}.
        :param egress: egress block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#egress VpcDefaultSecurityGroup#egress}
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#folder_id VpcDefaultSecurityGroup#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#id VpcDefaultSecurityGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param ingress: ingress block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#ingress VpcDefaultSecurityGroup#ingress}
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#labels VpcDefaultSecurityGroup#labels}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#timeouts VpcDefaultSecurityGroup#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = VpcDefaultSecurityGroupTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "network_id": network_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if egress is not None:
            self._values["egress"] = egress
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if ingress is not None:
            self._values["ingress"] = ingress
        if labels is not None:
            self._values["labels"] = labels
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def network_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#network_id VpcDefaultSecurityGroup#network_id}.'''
        result = self._values.get("network_id")
        assert result is not None, "Required property 'network_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#description VpcDefaultSecurityGroup#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def egress(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["VpcDefaultSecurityGroupEgress"]]]:
        '''egress block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#egress VpcDefaultSecurityGroup#egress}
        '''
        result = self._values.get("egress")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["VpcDefaultSecurityGroupEgress"]]], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#folder_id VpcDefaultSecurityGroup#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#id VpcDefaultSecurityGroup#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def ingress(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["VpcDefaultSecurityGroupIngress"]]]:
        '''ingress block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#ingress VpcDefaultSecurityGroup#ingress}
        '''
        result = self._values.get("ingress")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["VpcDefaultSecurityGroupIngress"]]], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#labels VpcDefaultSecurityGroup#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["VpcDefaultSecurityGroupTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#timeouts VpcDefaultSecurityGroup#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["VpcDefaultSecurityGroupTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcDefaultSecurityGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.VpcDefaultSecurityGroupEgress",
    jsii_struct_bases=[],
    name_mapping={
        "protocol": "protocol",
        "description": "description",
        "from_port": "fromPort",
        "labels": "labels",
        "port": "port",
        "predefined_target": "predefinedTarget",
        "security_group_id": "securityGroupId",
        "to_port": "toPort",
        "v4_cidr_blocks": "v4CidrBlocks",
        "v6_cidr_blocks": "v6CidrBlocks",
    },
)
class VpcDefaultSecurityGroupEgress:
    def __init__(
        self,
        *,
        protocol: builtins.str,
        description: typing.Optional[builtins.str] = None,
        from_port: typing.Optional[jsii.Number] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        port: typing.Optional[jsii.Number] = None,
        predefined_target: typing.Optional[builtins.str] = None,
        security_group_id: typing.Optional[builtins.str] = None,
        to_port: typing.Optional[jsii.Number] = None,
        v4_cidr_blocks: typing.Optional[typing.Sequence[builtins.str]] = None,
        v6_cidr_blocks: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param protocol: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#protocol VpcDefaultSecurityGroup#protocol}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#description VpcDefaultSecurityGroup#description}.
        :param from_port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#from_port VpcDefaultSecurityGroup#from_port}.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#labels VpcDefaultSecurityGroup#labels}.
        :param port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#port VpcDefaultSecurityGroup#port}.
        :param predefined_target: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#predefined_target VpcDefaultSecurityGroup#predefined_target}.
        :param security_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#security_group_id VpcDefaultSecurityGroup#security_group_id}.
        :param to_port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#to_port VpcDefaultSecurityGroup#to_port}.
        :param v4_cidr_blocks: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#v4_cidr_blocks VpcDefaultSecurityGroup#v4_cidr_blocks}.
        :param v6_cidr_blocks: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#v6_cidr_blocks VpcDefaultSecurityGroup#v6_cidr_blocks}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "protocol": protocol,
        }
        if description is not None:
            self._values["description"] = description
        if from_port is not None:
            self._values["from_port"] = from_port
        if labels is not None:
            self._values["labels"] = labels
        if port is not None:
            self._values["port"] = port
        if predefined_target is not None:
            self._values["predefined_target"] = predefined_target
        if security_group_id is not None:
            self._values["security_group_id"] = security_group_id
        if to_port is not None:
            self._values["to_port"] = to_port
        if v4_cidr_blocks is not None:
            self._values["v4_cidr_blocks"] = v4_cidr_blocks
        if v6_cidr_blocks is not None:
            self._values["v6_cidr_blocks"] = v6_cidr_blocks

    @builtins.property
    def protocol(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#protocol VpcDefaultSecurityGroup#protocol}.'''
        result = self._values.get("protocol")
        assert result is not None, "Required property 'protocol' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#description VpcDefaultSecurityGroup#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def from_port(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#from_port VpcDefaultSecurityGroup#from_port}.'''
        result = self._values.get("from_port")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#labels VpcDefaultSecurityGroup#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#port VpcDefaultSecurityGroup#port}.'''
        result = self._values.get("port")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def predefined_target(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#predefined_target VpcDefaultSecurityGroup#predefined_target}.'''
        result = self._values.get("predefined_target")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def security_group_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#security_group_id VpcDefaultSecurityGroup#security_group_id}.'''
        result = self._values.get("security_group_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def to_port(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#to_port VpcDefaultSecurityGroup#to_port}.'''
        result = self._values.get("to_port")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def v4_cidr_blocks(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#v4_cidr_blocks VpcDefaultSecurityGroup#v4_cidr_blocks}.'''
        result = self._values.get("v4_cidr_blocks")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def v6_cidr_blocks(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#v6_cidr_blocks VpcDefaultSecurityGroup#v6_cidr_blocks}.'''
        result = self._values.get("v6_cidr_blocks")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcDefaultSecurityGroupEgress(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VpcDefaultSecurityGroupEgressList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.VpcDefaultSecurityGroupEgressList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "VpcDefaultSecurityGroupEgressOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("VpcDefaultSecurityGroupEgressOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[VpcDefaultSecurityGroupEgress]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[VpcDefaultSecurityGroupEgress]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[VpcDefaultSecurityGroupEgress]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class VpcDefaultSecurityGroupEgressOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.VpcDefaultSecurityGroupEgressOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFromPort")
    def reset_from_port(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFromPort", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetPort")
    def reset_port(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPort", []))

    @jsii.member(jsii_name="resetPredefinedTarget")
    def reset_predefined_target(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPredefinedTarget", []))

    @jsii.member(jsii_name="resetSecurityGroupId")
    def reset_security_group_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityGroupId", []))

    @jsii.member(jsii_name="resetToPort")
    def reset_to_port(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetToPort", []))

    @jsii.member(jsii_name="resetV4CidrBlocks")
    def reset_v4_cidr_blocks(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetV4CidrBlocks", []))

    @jsii.member(jsii_name="resetV6CidrBlocks")
    def reset_v6_cidr_blocks(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetV6CidrBlocks", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fromPortInput")
    def from_port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "fromPortInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="portInput")
    def port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "portInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="predefinedTargetInput")
    def predefined_target_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "predefinedTargetInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="protocolInput")
    def protocol_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "protocolInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIdInput")
    def security_group_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "securityGroupIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="toPortInput")
    def to_port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "toPortInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="v4CidrBlocksInput")
    def v4_cidr_blocks_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "v4CidrBlocksInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="v6CidrBlocksInput")
    def v6_cidr_blocks_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "v6CidrBlocksInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fromPort")
    def from_port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "fromPort"))

    @from_port.setter
    def from_port(self, value: jsii.Number) -> None:
        jsii.set(self, "fromPort", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "port"))

    @port.setter
    def port(self, value: jsii.Number) -> None:
        jsii.set(self, "port", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="predefinedTarget")
    def predefined_target(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "predefinedTarget"))

    @predefined_target.setter
    def predefined_target(self, value: builtins.str) -> None:
        jsii.set(self, "predefinedTarget", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "protocol"))

    @protocol.setter
    def protocol(self, value: builtins.str) -> None:
        jsii.set(self, "protocol", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupId")
    def security_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "securityGroupId"))

    @security_group_id.setter
    def security_group_id(self, value: builtins.str) -> None:
        jsii.set(self, "securityGroupId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="toPort")
    def to_port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "toPort"))

    @to_port.setter
    def to_port(self, value: jsii.Number) -> None:
        jsii.set(self, "toPort", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="v4CidrBlocks")
    def v4_cidr_blocks(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "v4CidrBlocks"))

    @v4_cidr_blocks.setter
    def v4_cidr_blocks(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "v4CidrBlocks", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="v6CidrBlocks")
    def v6_cidr_blocks(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "v6CidrBlocks"))

    @v6_cidr_blocks.setter
    def v6_cidr_blocks(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "v6CidrBlocks", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, VpcDefaultSecurityGroupEgress]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, VpcDefaultSecurityGroupEgress]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, VpcDefaultSecurityGroupEgress]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.VpcDefaultSecurityGroupIngress",
    jsii_struct_bases=[],
    name_mapping={
        "protocol": "protocol",
        "description": "description",
        "from_port": "fromPort",
        "labels": "labels",
        "port": "port",
        "predefined_target": "predefinedTarget",
        "security_group_id": "securityGroupId",
        "to_port": "toPort",
        "v4_cidr_blocks": "v4CidrBlocks",
        "v6_cidr_blocks": "v6CidrBlocks",
    },
)
class VpcDefaultSecurityGroupIngress:
    def __init__(
        self,
        *,
        protocol: builtins.str,
        description: typing.Optional[builtins.str] = None,
        from_port: typing.Optional[jsii.Number] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        port: typing.Optional[jsii.Number] = None,
        predefined_target: typing.Optional[builtins.str] = None,
        security_group_id: typing.Optional[builtins.str] = None,
        to_port: typing.Optional[jsii.Number] = None,
        v4_cidr_blocks: typing.Optional[typing.Sequence[builtins.str]] = None,
        v6_cidr_blocks: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param protocol: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#protocol VpcDefaultSecurityGroup#protocol}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#description VpcDefaultSecurityGroup#description}.
        :param from_port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#from_port VpcDefaultSecurityGroup#from_port}.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#labels VpcDefaultSecurityGroup#labels}.
        :param port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#port VpcDefaultSecurityGroup#port}.
        :param predefined_target: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#predefined_target VpcDefaultSecurityGroup#predefined_target}.
        :param security_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#security_group_id VpcDefaultSecurityGroup#security_group_id}.
        :param to_port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#to_port VpcDefaultSecurityGroup#to_port}.
        :param v4_cidr_blocks: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#v4_cidr_blocks VpcDefaultSecurityGroup#v4_cidr_blocks}.
        :param v6_cidr_blocks: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#v6_cidr_blocks VpcDefaultSecurityGroup#v6_cidr_blocks}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "protocol": protocol,
        }
        if description is not None:
            self._values["description"] = description
        if from_port is not None:
            self._values["from_port"] = from_port
        if labels is not None:
            self._values["labels"] = labels
        if port is not None:
            self._values["port"] = port
        if predefined_target is not None:
            self._values["predefined_target"] = predefined_target
        if security_group_id is not None:
            self._values["security_group_id"] = security_group_id
        if to_port is not None:
            self._values["to_port"] = to_port
        if v4_cidr_blocks is not None:
            self._values["v4_cidr_blocks"] = v4_cidr_blocks
        if v6_cidr_blocks is not None:
            self._values["v6_cidr_blocks"] = v6_cidr_blocks

    @builtins.property
    def protocol(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#protocol VpcDefaultSecurityGroup#protocol}.'''
        result = self._values.get("protocol")
        assert result is not None, "Required property 'protocol' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#description VpcDefaultSecurityGroup#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def from_port(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#from_port VpcDefaultSecurityGroup#from_port}.'''
        result = self._values.get("from_port")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#labels VpcDefaultSecurityGroup#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#port VpcDefaultSecurityGroup#port}.'''
        result = self._values.get("port")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def predefined_target(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#predefined_target VpcDefaultSecurityGroup#predefined_target}.'''
        result = self._values.get("predefined_target")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def security_group_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#security_group_id VpcDefaultSecurityGroup#security_group_id}.'''
        result = self._values.get("security_group_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def to_port(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#to_port VpcDefaultSecurityGroup#to_port}.'''
        result = self._values.get("to_port")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def v4_cidr_blocks(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#v4_cidr_blocks VpcDefaultSecurityGroup#v4_cidr_blocks}.'''
        result = self._values.get("v4_cidr_blocks")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def v6_cidr_blocks(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#v6_cidr_blocks VpcDefaultSecurityGroup#v6_cidr_blocks}.'''
        result = self._values.get("v6_cidr_blocks")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcDefaultSecurityGroupIngress(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VpcDefaultSecurityGroupIngressList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.VpcDefaultSecurityGroupIngressList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(
        self,
        index: jsii.Number,
    ) -> "VpcDefaultSecurityGroupIngressOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("VpcDefaultSecurityGroupIngressOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[VpcDefaultSecurityGroupIngress]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[VpcDefaultSecurityGroupIngress]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[VpcDefaultSecurityGroupIngress]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class VpcDefaultSecurityGroupIngressOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.VpcDefaultSecurityGroupIngressOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFromPort")
    def reset_from_port(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFromPort", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetPort")
    def reset_port(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPort", []))

    @jsii.member(jsii_name="resetPredefinedTarget")
    def reset_predefined_target(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPredefinedTarget", []))

    @jsii.member(jsii_name="resetSecurityGroupId")
    def reset_security_group_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityGroupId", []))

    @jsii.member(jsii_name="resetToPort")
    def reset_to_port(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetToPort", []))

    @jsii.member(jsii_name="resetV4CidrBlocks")
    def reset_v4_cidr_blocks(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetV4CidrBlocks", []))

    @jsii.member(jsii_name="resetV6CidrBlocks")
    def reset_v6_cidr_blocks(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetV6CidrBlocks", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fromPortInput")
    def from_port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "fromPortInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="portInput")
    def port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "portInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="predefinedTargetInput")
    def predefined_target_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "predefinedTargetInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="protocolInput")
    def protocol_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "protocolInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIdInput")
    def security_group_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "securityGroupIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="toPortInput")
    def to_port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "toPortInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="v4CidrBlocksInput")
    def v4_cidr_blocks_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "v4CidrBlocksInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="v6CidrBlocksInput")
    def v6_cidr_blocks_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "v6CidrBlocksInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fromPort")
    def from_port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "fromPort"))

    @from_port.setter
    def from_port(self, value: jsii.Number) -> None:
        jsii.set(self, "fromPort", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "port"))

    @port.setter
    def port(self, value: jsii.Number) -> None:
        jsii.set(self, "port", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="predefinedTarget")
    def predefined_target(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "predefinedTarget"))

    @predefined_target.setter
    def predefined_target(self, value: builtins.str) -> None:
        jsii.set(self, "predefinedTarget", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "protocol"))

    @protocol.setter
    def protocol(self, value: builtins.str) -> None:
        jsii.set(self, "protocol", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupId")
    def security_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "securityGroupId"))

    @security_group_id.setter
    def security_group_id(self, value: builtins.str) -> None:
        jsii.set(self, "securityGroupId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="toPort")
    def to_port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "toPort"))

    @to_port.setter
    def to_port(self, value: jsii.Number) -> None:
        jsii.set(self, "toPort", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="v4CidrBlocks")
    def v4_cidr_blocks(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "v4CidrBlocks"))

    @v4_cidr_blocks.setter
    def v4_cidr_blocks(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "v4CidrBlocks", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="v6CidrBlocks")
    def v6_cidr_blocks(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "v6CidrBlocks"))

    @v6_cidr_blocks.setter
    def v6_cidr_blocks(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "v6CidrBlocks", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, VpcDefaultSecurityGroupIngress]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, VpcDefaultSecurityGroupIngress]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, VpcDefaultSecurityGroupIngress]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.VpcDefaultSecurityGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class VpcDefaultSecurityGroupTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#create VpcDefaultSecurityGroup#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#delete VpcDefaultSecurityGroup#delete}.
        :param read: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#read VpcDefaultSecurityGroup#read}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#update VpcDefaultSecurityGroup#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#create VpcDefaultSecurityGroup#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#delete VpcDefaultSecurityGroup#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#read VpcDefaultSecurityGroup#read}.'''
        result = self._values.get("read")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_default_security_group#update VpcDefaultSecurityGroup#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcDefaultSecurityGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VpcDefaultSecurityGroupTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.VpcDefaultSecurityGroupTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetRead")
    def reset_read(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRead", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="readInput")
    def read_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "readInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="read")
    def read(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "read"))

    @read.setter
    def read(self, value: builtins.str) -> None:
        jsii.set(self, "read", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, VpcDefaultSecurityGroupTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, VpcDefaultSecurityGroupTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, VpcDefaultSecurityGroupTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class VpcNetwork(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.VpcNetwork",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/vpc_network yandex_vpc_network}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["VpcNetworkTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/vpc_network yandex_vpc_network} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_network#description VpcNetwork#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_network#folder_id VpcNetwork#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_network#id VpcNetwork#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_network#labels VpcNetwork#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_network#name VpcNetwork#name}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_network#timeouts VpcNetwork#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = VpcNetworkConfig(
            description=description,
            folder_id=folder_id,
            id=id,
            labels=labels,
            name=name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_network#create VpcNetwork#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_network#delete VpcNetwork#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_network#update VpcNetwork#update}.
        '''
        value = VpcNetworkTimeouts(create=create, delete=delete, update=update)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="defaultSecurityGroupId")
    def default_security_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "defaultSecurityGroupId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "subnetIds"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "VpcNetworkTimeoutsOutputReference":
        return typing.cast("VpcNetworkTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "VpcNetworkTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "VpcNetworkTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.VpcNetworkConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "description": "description",
        "folder_id": "folderId",
        "id": "id",
        "labels": "labels",
        "name": "name",
        "timeouts": "timeouts",
    },
)
class VpcNetworkConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["VpcNetworkTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_network#description VpcNetwork#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_network#folder_id VpcNetwork#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_network#id VpcNetwork#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_network#labels VpcNetwork#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_network#name VpcNetwork#name}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_network#timeouts VpcNetwork#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = VpcNetworkTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if name is not None:
            self._values["name"] = name
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_network#description VpcNetwork#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_network#folder_id VpcNetwork#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_network#id VpcNetwork#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_network#labels VpcNetwork#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_network#name VpcNetwork#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["VpcNetworkTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_network#timeouts VpcNetwork#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["VpcNetworkTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcNetworkConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.VpcNetworkTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class VpcNetworkTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_network#create VpcNetwork#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_network#delete VpcNetwork#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_network#update VpcNetwork#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_network#create VpcNetwork#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_network#delete VpcNetwork#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_network#update VpcNetwork#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcNetworkTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VpcNetworkTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.VpcNetworkTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, VpcNetworkTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, VpcNetworkTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, VpcNetworkTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class VpcRouteTable(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.VpcRouteTable",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table yandex_vpc_route_table}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        network_id: builtins.str,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        static_route: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["VpcRouteTableStaticRoute"]]] = None,
        timeouts: typing.Optional["VpcRouteTableTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table yandex_vpc_route_table} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#network_id VpcRouteTable#network_id}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#description VpcRouteTable#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#folder_id VpcRouteTable#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#id VpcRouteTable#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#labels VpcRouteTable#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#name VpcRouteTable#name}.
        :param static_route: static_route block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#static_route VpcRouteTable#static_route}
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#timeouts VpcRouteTable#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = VpcRouteTableConfig(
            network_id=network_id,
            description=description,
            folder_id=folder_id,
            id=id,
            labels=labels,
            name=name,
            static_route=static_route,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putStaticRoute")
    def put_static_route(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["VpcRouteTableStaticRoute"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putStaticRoute", [value]))

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#create VpcRouteTable#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#delete VpcRouteTable#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#update VpcRouteTable#update}.
        '''
        value = VpcRouteTableTimeouts(create=create, delete=delete, update=update)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetStaticRoute")
    def reset_static_route(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStaticRoute", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="staticRoute")
    def static_route(self) -> "VpcRouteTableStaticRouteList":
        return typing.cast("VpcRouteTableStaticRouteList", jsii.get(self, "staticRoute"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "VpcRouteTableTimeoutsOutputReference":
        return typing.cast("VpcRouteTableTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkIdInput")
    def network_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "networkIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="staticRouteInput")
    def static_route_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["VpcRouteTableStaticRoute"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["VpcRouteTableStaticRoute"]]], jsii.get(self, "staticRouteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "VpcRouteTableTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "VpcRouteTableTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @network_id.setter
    def network_id(self, value: builtins.str) -> None:
        jsii.set(self, "networkId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.VpcRouteTableConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "network_id": "networkId",
        "description": "description",
        "folder_id": "folderId",
        "id": "id",
        "labels": "labels",
        "name": "name",
        "static_route": "staticRoute",
        "timeouts": "timeouts",
    },
)
class VpcRouteTableConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        network_id: builtins.str,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        static_route: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["VpcRouteTableStaticRoute"]]] = None,
        timeouts: typing.Optional["VpcRouteTableTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#network_id VpcRouteTable#network_id}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#description VpcRouteTable#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#folder_id VpcRouteTable#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#id VpcRouteTable#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#labels VpcRouteTable#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#name VpcRouteTable#name}.
        :param static_route: static_route block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#static_route VpcRouteTable#static_route}
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#timeouts VpcRouteTable#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = VpcRouteTableTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "network_id": network_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if name is not None:
            self._values["name"] = name
        if static_route is not None:
            self._values["static_route"] = static_route
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def network_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#network_id VpcRouteTable#network_id}.'''
        result = self._values.get("network_id")
        assert result is not None, "Required property 'network_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#description VpcRouteTable#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#folder_id VpcRouteTable#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#id VpcRouteTable#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#labels VpcRouteTable#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#name VpcRouteTable#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def static_route(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["VpcRouteTableStaticRoute"]]]:
        '''static_route block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#static_route VpcRouteTable#static_route}
        '''
        result = self._values.get("static_route")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["VpcRouteTableStaticRoute"]]], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["VpcRouteTableTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#timeouts VpcRouteTable#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["VpcRouteTableTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcRouteTableConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.VpcRouteTableStaticRoute",
    jsii_struct_bases=[],
    name_mapping={
        "destination_prefix": "destinationPrefix",
        "next_hop_address": "nextHopAddress",
    },
)
class VpcRouteTableStaticRoute:
    def __init__(
        self,
        *,
        destination_prefix: typing.Optional[builtins.str] = None,
        next_hop_address: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param destination_prefix: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#destination_prefix VpcRouteTable#destination_prefix}.
        :param next_hop_address: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#next_hop_address VpcRouteTable#next_hop_address}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if destination_prefix is not None:
            self._values["destination_prefix"] = destination_prefix
        if next_hop_address is not None:
            self._values["next_hop_address"] = next_hop_address

    @builtins.property
    def destination_prefix(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#destination_prefix VpcRouteTable#destination_prefix}.'''
        result = self._values.get("destination_prefix")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def next_hop_address(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#next_hop_address VpcRouteTable#next_hop_address}.'''
        result = self._values.get("next_hop_address")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcRouteTableStaticRoute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VpcRouteTableStaticRouteList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.VpcRouteTableStaticRouteList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "VpcRouteTableStaticRouteOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("VpcRouteTableStaticRouteOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[VpcRouteTableStaticRoute]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[VpcRouteTableStaticRoute]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[VpcRouteTableStaticRoute]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class VpcRouteTableStaticRouteOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.VpcRouteTableStaticRouteOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetDestinationPrefix")
    def reset_destination_prefix(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDestinationPrefix", []))

    @jsii.member(jsii_name="resetNextHopAddress")
    def reset_next_hop_address(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNextHopAddress", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="destinationPrefixInput")
    def destination_prefix_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "destinationPrefixInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nextHopAddressInput")
    def next_hop_address_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nextHopAddressInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="destinationPrefix")
    def destination_prefix(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "destinationPrefix"))

    @destination_prefix.setter
    def destination_prefix(self, value: builtins.str) -> None:
        jsii.set(self, "destinationPrefix", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nextHopAddress")
    def next_hop_address(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "nextHopAddress"))

    @next_hop_address.setter
    def next_hop_address(self, value: builtins.str) -> None:
        jsii.set(self, "nextHopAddress", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, VpcRouteTableStaticRoute]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, VpcRouteTableStaticRoute]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, VpcRouteTableStaticRoute]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.VpcRouteTableTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class VpcRouteTableTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#create VpcRouteTable#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#delete VpcRouteTable#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#update VpcRouteTable#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#create VpcRouteTable#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#delete VpcRouteTable#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_route_table#update VpcRouteTable#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcRouteTableTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VpcRouteTableTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.VpcRouteTableTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, VpcRouteTableTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, VpcRouteTableTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, VpcRouteTableTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class VpcSecurityGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.VpcSecurityGroup",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group yandex_vpc_security_group}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        network_id: builtins.str,
        description: typing.Optional[builtins.str] = None,
        egress: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["VpcSecurityGroupEgress"]]] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        ingress: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["VpcSecurityGroupIngress"]]] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["VpcSecurityGroupTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group yandex_vpc_security_group} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#network_id VpcSecurityGroup#network_id}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#description VpcSecurityGroup#description}.
        :param egress: egress block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#egress VpcSecurityGroup#egress}
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#folder_id VpcSecurityGroup#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#id VpcSecurityGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param ingress: ingress block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#ingress VpcSecurityGroup#ingress}
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#labels VpcSecurityGroup#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#name VpcSecurityGroup#name}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#timeouts VpcSecurityGroup#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = VpcSecurityGroupConfig(
            network_id=network_id,
            description=description,
            egress=egress,
            folder_id=folder_id,
            id=id,
            ingress=ingress,
            labels=labels,
            name=name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putEgress")
    def put_egress(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["VpcSecurityGroupEgress"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putEgress", [value]))

    @jsii.member(jsii_name="putIngress")
    def put_ingress(
        self,
        value: typing.Union[cdktf.IResolvable, typing.Sequence["VpcSecurityGroupIngress"]],
    ) -> None:
        '''
        :param value: -
        '''
        return typing.cast(None, jsii.invoke(self, "putIngress", [value]))

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#create VpcSecurityGroup#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#delete VpcSecurityGroup#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#update VpcSecurityGroup#update}.
        '''
        value = VpcSecurityGroupTimeouts(create=create, delete=delete, update=update)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetEgress")
    def reset_egress(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEgress", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetIngress")
    def reset_ingress(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetIngress", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="egress")
    def egress(self) -> "VpcSecurityGroupEgressList":
        return typing.cast("VpcSecurityGroupEgressList", jsii.get(self, "egress"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ingress")
    def ingress(self) -> "VpcSecurityGroupIngressList":
        return typing.cast("VpcSecurityGroupIngressList", jsii.get(self, "ingress"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "VpcSecurityGroupTimeoutsOutputReference":
        return typing.cast("VpcSecurityGroupTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="egressInput")
    def egress_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["VpcSecurityGroupEgress"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["VpcSecurityGroupEgress"]]], jsii.get(self, "egressInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ingressInput")
    def ingress_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["VpcSecurityGroupIngress"]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["VpcSecurityGroupIngress"]]], jsii.get(self, "ingressInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkIdInput")
    def network_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "networkIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "VpcSecurityGroupTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "VpcSecurityGroupTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @network_id.setter
    def network_id(self, value: builtins.str) -> None:
        jsii.set(self, "networkId", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.VpcSecurityGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "network_id": "networkId",
        "description": "description",
        "egress": "egress",
        "folder_id": "folderId",
        "id": "id",
        "ingress": "ingress",
        "labels": "labels",
        "name": "name",
        "timeouts": "timeouts",
    },
)
class VpcSecurityGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        network_id: builtins.str,
        description: typing.Optional[builtins.str] = None,
        egress: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["VpcSecurityGroupEgress"]]] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        ingress: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence["VpcSecurityGroupIngress"]]] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["VpcSecurityGroupTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#network_id VpcSecurityGroup#network_id}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#description VpcSecurityGroup#description}.
        :param egress: egress block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#egress VpcSecurityGroup#egress}
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#folder_id VpcSecurityGroup#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#id VpcSecurityGroup#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param ingress: ingress block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#ingress VpcSecurityGroup#ingress}
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#labels VpcSecurityGroup#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#name VpcSecurityGroup#name}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#timeouts VpcSecurityGroup#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = VpcSecurityGroupTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "network_id": network_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if egress is not None:
            self._values["egress"] = egress
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if ingress is not None:
            self._values["ingress"] = ingress
        if labels is not None:
            self._values["labels"] = labels
        if name is not None:
            self._values["name"] = name
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def network_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#network_id VpcSecurityGroup#network_id}.'''
        result = self._values.get("network_id")
        assert result is not None, "Required property 'network_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#description VpcSecurityGroup#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def egress(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["VpcSecurityGroupEgress"]]]:
        '''egress block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#egress VpcSecurityGroup#egress}
        '''
        result = self._values.get("egress")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["VpcSecurityGroupEgress"]]], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#folder_id VpcSecurityGroup#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#id VpcSecurityGroup#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def ingress(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["VpcSecurityGroupIngress"]]]:
        '''ingress block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#ingress VpcSecurityGroup#ingress}
        '''
        result = self._values.get("ingress")
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["VpcSecurityGroupIngress"]]], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#labels VpcSecurityGroup#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#name VpcSecurityGroup#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["VpcSecurityGroupTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#timeouts VpcSecurityGroup#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["VpcSecurityGroupTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcSecurityGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.VpcSecurityGroupEgress",
    jsii_struct_bases=[],
    name_mapping={
        "protocol": "protocol",
        "description": "description",
        "from_port": "fromPort",
        "labels": "labels",
        "port": "port",
        "predefined_target": "predefinedTarget",
        "security_group_id": "securityGroupId",
        "to_port": "toPort",
        "v4_cidr_blocks": "v4CidrBlocks",
        "v6_cidr_blocks": "v6CidrBlocks",
    },
)
class VpcSecurityGroupEgress:
    def __init__(
        self,
        *,
        protocol: builtins.str,
        description: typing.Optional[builtins.str] = None,
        from_port: typing.Optional[jsii.Number] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        port: typing.Optional[jsii.Number] = None,
        predefined_target: typing.Optional[builtins.str] = None,
        security_group_id: typing.Optional[builtins.str] = None,
        to_port: typing.Optional[jsii.Number] = None,
        v4_cidr_blocks: typing.Optional[typing.Sequence[builtins.str]] = None,
        v6_cidr_blocks: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param protocol: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#protocol VpcSecurityGroup#protocol}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#description VpcSecurityGroup#description}.
        :param from_port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#from_port VpcSecurityGroup#from_port}.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#labels VpcSecurityGroup#labels}.
        :param port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#port VpcSecurityGroup#port}.
        :param predefined_target: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#predefined_target VpcSecurityGroup#predefined_target}.
        :param security_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#security_group_id VpcSecurityGroup#security_group_id}.
        :param to_port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#to_port VpcSecurityGroup#to_port}.
        :param v4_cidr_blocks: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#v4_cidr_blocks VpcSecurityGroup#v4_cidr_blocks}.
        :param v6_cidr_blocks: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#v6_cidr_blocks VpcSecurityGroup#v6_cidr_blocks}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "protocol": protocol,
        }
        if description is not None:
            self._values["description"] = description
        if from_port is not None:
            self._values["from_port"] = from_port
        if labels is not None:
            self._values["labels"] = labels
        if port is not None:
            self._values["port"] = port
        if predefined_target is not None:
            self._values["predefined_target"] = predefined_target
        if security_group_id is not None:
            self._values["security_group_id"] = security_group_id
        if to_port is not None:
            self._values["to_port"] = to_port
        if v4_cidr_blocks is not None:
            self._values["v4_cidr_blocks"] = v4_cidr_blocks
        if v6_cidr_blocks is not None:
            self._values["v6_cidr_blocks"] = v6_cidr_blocks

    @builtins.property
    def protocol(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#protocol VpcSecurityGroup#protocol}.'''
        result = self._values.get("protocol")
        assert result is not None, "Required property 'protocol' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#description VpcSecurityGroup#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def from_port(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#from_port VpcSecurityGroup#from_port}.'''
        result = self._values.get("from_port")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#labels VpcSecurityGroup#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#port VpcSecurityGroup#port}.'''
        result = self._values.get("port")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def predefined_target(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#predefined_target VpcSecurityGroup#predefined_target}.'''
        result = self._values.get("predefined_target")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def security_group_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#security_group_id VpcSecurityGroup#security_group_id}.'''
        result = self._values.get("security_group_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def to_port(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#to_port VpcSecurityGroup#to_port}.'''
        result = self._values.get("to_port")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def v4_cidr_blocks(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#v4_cidr_blocks VpcSecurityGroup#v4_cidr_blocks}.'''
        result = self._values.get("v4_cidr_blocks")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def v6_cidr_blocks(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#v6_cidr_blocks VpcSecurityGroup#v6_cidr_blocks}.'''
        result = self._values.get("v6_cidr_blocks")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcSecurityGroupEgress(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VpcSecurityGroupEgressList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.VpcSecurityGroupEgressList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "VpcSecurityGroupEgressOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("VpcSecurityGroupEgressOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[VpcSecurityGroupEgress]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[VpcSecurityGroupEgress]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[VpcSecurityGroupEgress]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class VpcSecurityGroupEgressOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.VpcSecurityGroupEgressOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFromPort")
    def reset_from_port(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFromPort", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetPort")
    def reset_port(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPort", []))

    @jsii.member(jsii_name="resetPredefinedTarget")
    def reset_predefined_target(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPredefinedTarget", []))

    @jsii.member(jsii_name="resetSecurityGroupId")
    def reset_security_group_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityGroupId", []))

    @jsii.member(jsii_name="resetToPort")
    def reset_to_port(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetToPort", []))

    @jsii.member(jsii_name="resetV4CidrBlocks")
    def reset_v4_cidr_blocks(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetV4CidrBlocks", []))

    @jsii.member(jsii_name="resetV6CidrBlocks")
    def reset_v6_cidr_blocks(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetV6CidrBlocks", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fromPortInput")
    def from_port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "fromPortInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="portInput")
    def port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "portInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="predefinedTargetInput")
    def predefined_target_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "predefinedTargetInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="protocolInput")
    def protocol_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "protocolInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIdInput")
    def security_group_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "securityGroupIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="toPortInput")
    def to_port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "toPortInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="v4CidrBlocksInput")
    def v4_cidr_blocks_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "v4CidrBlocksInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="v6CidrBlocksInput")
    def v6_cidr_blocks_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "v6CidrBlocksInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fromPort")
    def from_port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "fromPort"))

    @from_port.setter
    def from_port(self, value: jsii.Number) -> None:
        jsii.set(self, "fromPort", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "port"))

    @port.setter
    def port(self, value: jsii.Number) -> None:
        jsii.set(self, "port", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="predefinedTarget")
    def predefined_target(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "predefinedTarget"))

    @predefined_target.setter
    def predefined_target(self, value: builtins.str) -> None:
        jsii.set(self, "predefinedTarget", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "protocol"))

    @protocol.setter
    def protocol(self, value: builtins.str) -> None:
        jsii.set(self, "protocol", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupId")
    def security_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "securityGroupId"))

    @security_group_id.setter
    def security_group_id(self, value: builtins.str) -> None:
        jsii.set(self, "securityGroupId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="toPort")
    def to_port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "toPort"))

    @to_port.setter
    def to_port(self, value: jsii.Number) -> None:
        jsii.set(self, "toPort", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="v4CidrBlocks")
    def v4_cidr_blocks(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "v4CidrBlocks"))

    @v4_cidr_blocks.setter
    def v4_cidr_blocks(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "v4CidrBlocks", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="v6CidrBlocks")
    def v6_cidr_blocks(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "v6CidrBlocks"))

    @v6_cidr_blocks.setter
    def v6_cidr_blocks(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "v6CidrBlocks", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, VpcSecurityGroupEgress]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, VpcSecurityGroupEgress]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, VpcSecurityGroupEgress]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.VpcSecurityGroupIngress",
    jsii_struct_bases=[],
    name_mapping={
        "protocol": "protocol",
        "description": "description",
        "from_port": "fromPort",
        "labels": "labels",
        "port": "port",
        "predefined_target": "predefinedTarget",
        "security_group_id": "securityGroupId",
        "to_port": "toPort",
        "v4_cidr_blocks": "v4CidrBlocks",
        "v6_cidr_blocks": "v6CidrBlocks",
    },
)
class VpcSecurityGroupIngress:
    def __init__(
        self,
        *,
        protocol: builtins.str,
        description: typing.Optional[builtins.str] = None,
        from_port: typing.Optional[jsii.Number] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        port: typing.Optional[jsii.Number] = None,
        predefined_target: typing.Optional[builtins.str] = None,
        security_group_id: typing.Optional[builtins.str] = None,
        to_port: typing.Optional[jsii.Number] = None,
        v4_cidr_blocks: typing.Optional[typing.Sequence[builtins.str]] = None,
        v6_cidr_blocks: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param protocol: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#protocol VpcSecurityGroup#protocol}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#description VpcSecurityGroup#description}.
        :param from_port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#from_port VpcSecurityGroup#from_port}.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#labels VpcSecurityGroup#labels}.
        :param port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#port VpcSecurityGroup#port}.
        :param predefined_target: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#predefined_target VpcSecurityGroup#predefined_target}.
        :param security_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#security_group_id VpcSecurityGroup#security_group_id}.
        :param to_port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#to_port VpcSecurityGroup#to_port}.
        :param v4_cidr_blocks: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#v4_cidr_blocks VpcSecurityGroup#v4_cidr_blocks}.
        :param v6_cidr_blocks: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#v6_cidr_blocks VpcSecurityGroup#v6_cidr_blocks}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "protocol": protocol,
        }
        if description is not None:
            self._values["description"] = description
        if from_port is not None:
            self._values["from_port"] = from_port
        if labels is not None:
            self._values["labels"] = labels
        if port is not None:
            self._values["port"] = port
        if predefined_target is not None:
            self._values["predefined_target"] = predefined_target
        if security_group_id is not None:
            self._values["security_group_id"] = security_group_id
        if to_port is not None:
            self._values["to_port"] = to_port
        if v4_cidr_blocks is not None:
            self._values["v4_cidr_blocks"] = v4_cidr_blocks
        if v6_cidr_blocks is not None:
            self._values["v6_cidr_blocks"] = v6_cidr_blocks

    @builtins.property
    def protocol(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#protocol VpcSecurityGroup#protocol}.'''
        result = self._values.get("protocol")
        assert result is not None, "Required property 'protocol' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#description VpcSecurityGroup#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def from_port(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#from_port VpcSecurityGroup#from_port}.'''
        result = self._values.get("from_port")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#labels VpcSecurityGroup#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#port VpcSecurityGroup#port}.'''
        result = self._values.get("port")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def predefined_target(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#predefined_target VpcSecurityGroup#predefined_target}.'''
        result = self._values.get("predefined_target")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def security_group_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#security_group_id VpcSecurityGroup#security_group_id}.'''
        result = self._values.get("security_group_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def to_port(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#to_port VpcSecurityGroup#to_port}.'''
        result = self._values.get("to_port")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def v4_cidr_blocks(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#v4_cidr_blocks VpcSecurityGroup#v4_cidr_blocks}.'''
        result = self._values.get("v4_cidr_blocks")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def v6_cidr_blocks(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#v6_cidr_blocks VpcSecurityGroup#v6_cidr_blocks}.'''
        result = self._values.get("v6_cidr_blocks")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcSecurityGroupIngress(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VpcSecurityGroupIngressList(
    cdktf.ComplexList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.VpcSecurityGroupIngressList",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        wraps_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, wraps_set])

    @jsii.member(jsii_name="get")
    def get(self, index: jsii.Number) -> "VpcSecurityGroupIngressOutputReference":
        '''
        :param index: the index of the item to return.
        '''
        return typing.cast("VpcSecurityGroupIngressOutputReference", jsii.invoke(self, "get", [index]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformAttribute")
    def _terraform_attribute(self) -> builtins.str:
        '''The attribute on the parent resource this class is referencing.'''
        return typing.cast(builtins.str, jsii.get(self, "terraformAttribute"))

    @_terraform_attribute.setter
    def _terraform_attribute(self, value: builtins.str) -> None:
        jsii.set(self, "terraformAttribute", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="terraformResource")
    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
        '''The parent resource.'''
        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))

    @_terraform_resource.setter
    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
        jsii.set(self, "terraformResource", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="wrapsSet")
    def _wraps_set(self) -> builtins.bool:
        '''whether the list is wrapping a set (will add tolist() to be able to access an item via an index).'''
        return typing.cast(builtins.bool, jsii.get(self, "wrapsSet"))

    @_wraps_set.setter
    def _wraps_set(self, value: builtins.bool) -> None:
        jsii.set(self, "wrapsSet", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[VpcSecurityGroupIngress]]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[VpcSecurityGroupIngress]]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[VpcSecurityGroupIngress]]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class VpcSecurityGroupIngressOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.VpcSecurityGroupIngressOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
        complex_object_index: jsii.Number,
        complex_object_is_from_set: builtins.bool,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        :param complex_object_index: the index of this item in the list.
        :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute, complex_object_index, complex_object_is_from_set])

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFromPort")
    def reset_from_port(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFromPort", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetPort")
    def reset_port(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPort", []))

    @jsii.member(jsii_name="resetPredefinedTarget")
    def reset_predefined_target(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPredefinedTarget", []))

    @jsii.member(jsii_name="resetSecurityGroupId")
    def reset_security_group_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityGroupId", []))

    @jsii.member(jsii_name="resetToPort")
    def reset_to_port(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetToPort", []))

    @jsii.member(jsii_name="resetV4CidrBlocks")
    def reset_v4_cidr_blocks(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetV4CidrBlocks", []))

    @jsii.member(jsii_name="resetV6CidrBlocks")
    def reset_v6_cidr_blocks(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetV6CidrBlocks", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fromPortInput")
    def from_port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "fromPortInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="portInput")
    def port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "portInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="predefinedTargetInput")
    def predefined_target_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "predefinedTargetInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="protocolInput")
    def protocol_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "protocolInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIdInput")
    def security_group_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "securityGroupIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="toPortInput")
    def to_port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "toPortInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="v4CidrBlocksInput")
    def v4_cidr_blocks_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "v4CidrBlocksInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="v6CidrBlocksInput")
    def v6_cidr_blocks_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "v6CidrBlocksInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fromPort")
    def from_port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "fromPort"))

    @from_port.setter
    def from_port(self, value: jsii.Number) -> None:
        jsii.set(self, "fromPort", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "port"))

    @port.setter
    def port(self, value: jsii.Number) -> None:
        jsii.set(self, "port", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="predefinedTarget")
    def predefined_target(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "predefinedTarget"))

    @predefined_target.setter
    def predefined_target(self, value: builtins.str) -> None:
        jsii.set(self, "predefinedTarget", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "protocol"))

    @protocol.setter
    def protocol(self, value: builtins.str) -> None:
        jsii.set(self, "protocol", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupId")
    def security_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "securityGroupId"))

    @security_group_id.setter
    def security_group_id(self, value: builtins.str) -> None:
        jsii.set(self, "securityGroupId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="toPort")
    def to_port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "toPort"))

    @to_port.setter
    def to_port(self, value: jsii.Number) -> None:
        jsii.set(self, "toPort", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="v4CidrBlocks")
    def v4_cidr_blocks(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "v4CidrBlocks"))

    @v4_cidr_blocks.setter
    def v4_cidr_blocks(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "v4CidrBlocks", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="v6CidrBlocks")
    def v6_cidr_blocks(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "v6CidrBlocks"))

    @v6_cidr_blocks.setter
    def v6_cidr_blocks(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "v6CidrBlocks", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, VpcSecurityGroupIngress]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, VpcSecurityGroupIngress]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, VpcSecurityGroupIngress]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class VpcSecurityGroupRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.VpcSecurityGroupRule",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule yandex_vpc_security_group_rule}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        direction: builtins.str,
        security_group_binding: builtins.str,
        description: typing.Optional[builtins.str] = None,
        from_port: typing.Optional[jsii.Number] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        port: typing.Optional[jsii.Number] = None,
        predefined_target: typing.Optional[builtins.str] = None,
        protocol: typing.Optional[builtins.str] = None,
        security_group_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["VpcSecurityGroupRuleTimeouts"] = None,
        to_port: typing.Optional[jsii.Number] = None,
        v4_cidr_blocks: typing.Optional[typing.Sequence[builtins.str]] = None,
        v6_cidr_blocks: typing.Optional[typing.Sequence[builtins.str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule yandex_vpc_security_group_rule} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param direction: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#direction VpcSecurityGroupRule#direction}.
        :param security_group_binding: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#security_group_binding VpcSecurityGroupRule#security_group_binding}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#description VpcSecurityGroupRule#description}.
        :param from_port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#from_port VpcSecurityGroupRule#from_port}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#id VpcSecurityGroupRule#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#labels VpcSecurityGroupRule#labels}.
        :param port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#port VpcSecurityGroupRule#port}.
        :param predefined_target: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#predefined_target VpcSecurityGroupRule#predefined_target}.
        :param protocol: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#protocol VpcSecurityGroupRule#protocol}.
        :param security_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#security_group_id VpcSecurityGroupRule#security_group_id}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#timeouts VpcSecurityGroupRule#timeouts}
        :param to_port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#to_port VpcSecurityGroupRule#to_port}.
        :param v4_cidr_blocks: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#v4_cidr_blocks VpcSecurityGroupRule#v4_cidr_blocks}.
        :param v6_cidr_blocks: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#v6_cidr_blocks VpcSecurityGroupRule#v6_cidr_blocks}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = VpcSecurityGroupRuleConfig(
            direction=direction,
            security_group_binding=security_group_binding,
            description=description,
            from_port=from_port,
            id=id,
            labels=labels,
            port=port,
            predefined_target=predefined_target,
            protocol=protocol,
            security_group_id=security_group_id,
            timeouts=timeouts,
            to_port=to_port,
            v4_cidr_blocks=v4_cidr_blocks,
            v6_cidr_blocks=v6_cidr_blocks,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#create VpcSecurityGroupRule#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#delete VpcSecurityGroupRule#delete}.
        :param read: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#read VpcSecurityGroupRule#read}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#update VpcSecurityGroupRule#update}.
        '''
        value = VpcSecurityGroupRuleTimeouts(
            create=create, delete=delete, read=read, update=update
        )

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFromPort")
    def reset_from_port(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFromPort", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetPort")
    def reset_port(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPort", []))

    @jsii.member(jsii_name="resetPredefinedTarget")
    def reset_predefined_target(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPredefinedTarget", []))

    @jsii.member(jsii_name="resetProtocol")
    def reset_protocol(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetProtocol", []))

    @jsii.member(jsii_name="resetSecurityGroupId")
    def reset_security_group_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetSecurityGroupId", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="resetToPort")
    def reset_to_port(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetToPort", []))

    @jsii.member(jsii_name="resetV4CidrBlocks")
    def reset_v4_cidr_blocks(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetV4CidrBlocks", []))

    @jsii.member(jsii_name="resetV6CidrBlocks")
    def reset_v6_cidr_blocks(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetV6CidrBlocks", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "VpcSecurityGroupRuleTimeoutsOutputReference":
        return typing.cast("VpcSecurityGroupRuleTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="directionInput")
    def direction_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "directionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fromPortInput")
    def from_port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "fromPortInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="portInput")
    def port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "portInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="predefinedTargetInput")
    def predefined_target_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "predefinedTargetInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="protocolInput")
    def protocol_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "protocolInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupBindingInput")
    def security_group_binding_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "securityGroupBindingInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupIdInput")
    def security_group_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "securityGroupIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "VpcSecurityGroupRuleTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "VpcSecurityGroupRuleTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="toPortInput")
    def to_port_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "toPortInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="v4CidrBlocksInput")
    def v4_cidr_blocks_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "v4CidrBlocksInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="v6CidrBlocksInput")
    def v6_cidr_blocks_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "v6CidrBlocksInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="direction")
    def direction(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "direction"))

    @direction.setter
    def direction(self, value: builtins.str) -> None:
        jsii.set(self, "direction", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fromPort")
    def from_port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "fromPort"))

    @from_port.setter
    def from_port(self, value: jsii.Number) -> None:
        jsii.set(self, "fromPort", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "port"))

    @port.setter
    def port(self, value: jsii.Number) -> None:
        jsii.set(self, "port", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="predefinedTarget")
    def predefined_target(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "predefinedTarget"))

    @predefined_target.setter
    def predefined_target(self, value: builtins.str) -> None:
        jsii.set(self, "predefinedTarget", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "protocol"))

    @protocol.setter
    def protocol(self, value: builtins.str) -> None:
        jsii.set(self, "protocol", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupBinding")
    def security_group_binding(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "securityGroupBinding"))

    @security_group_binding.setter
    def security_group_binding(self, value: builtins.str) -> None:
        jsii.set(self, "securityGroupBinding", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="securityGroupId")
    def security_group_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "securityGroupId"))

    @security_group_id.setter
    def security_group_id(self, value: builtins.str) -> None:
        jsii.set(self, "securityGroupId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="toPort")
    def to_port(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "toPort"))

    @to_port.setter
    def to_port(self, value: jsii.Number) -> None:
        jsii.set(self, "toPort", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="v4CidrBlocks")
    def v4_cidr_blocks(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "v4CidrBlocks"))

    @v4_cidr_blocks.setter
    def v4_cidr_blocks(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "v4CidrBlocks", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="v6CidrBlocks")
    def v6_cidr_blocks(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "v6CidrBlocks"))

    @v6_cidr_blocks.setter
    def v6_cidr_blocks(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "v6CidrBlocks", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.VpcSecurityGroupRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "direction": "direction",
        "security_group_binding": "securityGroupBinding",
        "description": "description",
        "from_port": "fromPort",
        "id": "id",
        "labels": "labels",
        "port": "port",
        "predefined_target": "predefinedTarget",
        "protocol": "protocol",
        "security_group_id": "securityGroupId",
        "timeouts": "timeouts",
        "to_port": "toPort",
        "v4_cidr_blocks": "v4CidrBlocks",
        "v6_cidr_blocks": "v6CidrBlocks",
    },
)
class VpcSecurityGroupRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        direction: builtins.str,
        security_group_binding: builtins.str,
        description: typing.Optional[builtins.str] = None,
        from_port: typing.Optional[jsii.Number] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        port: typing.Optional[jsii.Number] = None,
        predefined_target: typing.Optional[builtins.str] = None,
        protocol: typing.Optional[builtins.str] = None,
        security_group_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["VpcSecurityGroupRuleTimeouts"] = None,
        to_port: typing.Optional[jsii.Number] = None,
        v4_cidr_blocks: typing.Optional[typing.Sequence[builtins.str]] = None,
        v6_cidr_blocks: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param direction: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#direction VpcSecurityGroupRule#direction}.
        :param security_group_binding: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#security_group_binding VpcSecurityGroupRule#security_group_binding}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#description VpcSecurityGroupRule#description}.
        :param from_port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#from_port VpcSecurityGroupRule#from_port}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#id VpcSecurityGroupRule#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#labels VpcSecurityGroupRule#labels}.
        :param port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#port VpcSecurityGroupRule#port}.
        :param predefined_target: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#predefined_target VpcSecurityGroupRule#predefined_target}.
        :param protocol: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#protocol VpcSecurityGroupRule#protocol}.
        :param security_group_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#security_group_id VpcSecurityGroupRule#security_group_id}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#timeouts VpcSecurityGroupRule#timeouts}
        :param to_port: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#to_port VpcSecurityGroupRule#to_port}.
        :param v4_cidr_blocks: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#v4_cidr_blocks VpcSecurityGroupRule#v4_cidr_blocks}.
        :param v6_cidr_blocks: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#v6_cidr_blocks VpcSecurityGroupRule#v6_cidr_blocks}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = VpcSecurityGroupRuleTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "direction": direction,
            "security_group_binding": security_group_binding,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if from_port is not None:
            self._values["from_port"] = from_port
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if port is not None:
            self._values["port"] = port
        if predefined_target is not None:
            self._values["predefined_target"] = predefined_target
        if protocol is not None:
            self._values["protocol"] = protocol
        if security_group_id is not None:
            self._values["security_group_id"] = security_group_id
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if to_port is not None:
            self._values["to_port"] = to_port
        if v4_cidr_blocks is not None:
            self._values["v4_cidr_blocks"] = v4_cidr_blocks
        if v6_cidr_blocks is not None:
            self._values["v6_cidr_blocks"] = v6_cidr_blocks

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def direction(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#direction VpcSecurityGroupRule#direction}.'''
        result = self._values.get("direction")
        assert result is not None, "Required property 'direction' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def security_group_binding(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#security_group_binding VpcSecurityGroupRule#security_group_binding}.'''
        result = self._values.get("security_group_binding")
        assert result is not None, "Required property 'security_group_binding' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#description VpcSecurityGroupRule#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def from_port(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#from_port VpcSecurityGroupRule#from_port}.'''
        result = self._values.get("from_port")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#id VpcSecurityGroupRule#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#labels VpcSecurityGroupRule#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#port VpcSecurityGroupRule#port}.'''
        result = self._values.get("port")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def predefined_target(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#predefined_target VpcSecurityGroupRule#predefined_target}.'''
        result = self._values.get("predefined_target")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def protocol(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#protocol VpcSecurityGroupRule#protocol}.'''
        result = self._values.get("protocol")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def security_group_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#security_group_id VpcSecurityGroupRule#security_group_id}.'''
        result = self._values.get("security_group_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["VpcSecurityGroupRuleTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#timeouts VpcSecurityGroupRule#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["VpcSecurityGroupRuleTimeouts"], result)

    @builtins.property
    def to_port(self) -> typing.Optional[jsii.Number]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#to_port VpcSecurityGroupRule#to_port}.'''
        result = self._values.get("to_port")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def v4_cidr_blocks(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#v4_cidr_blocks VpcSecurityGroupRule#v4_cidr_blocks}.'''
        result = self._values.get("v4_cidr_blocks")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def v6_cidr_blocks(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#v6_cidr_blocks VpcSecurityGroupRule#v6_cidr_blocks}.'''
        result = self._values.get("v6_cidr_blocks")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcSecurityGroupRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.VpcSecurityGroupRuleTimeouts",
    jsii_struct_bases=[],
    name_mapping={
        "create": "create",
        "delete": "delete",
        "read": "read",
        "update": "update",
    },
)
class VpcSecurityGroupRuleTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        read: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#create VpcSecurityGroupRule#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#delete VpcSecurityGroupRule#delete}.
        :param read: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#read VpcSecurityGroupRule#read}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#update VpcSecurityGroupRule#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#create VpcSecurityGroupRule#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#delete VpcSecurityGroupRule#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def read(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#read VpcSecurityGroupRule#read}.'''
        result = self._values.get("read")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group_rule#update VpcSecurityGroupRule#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcSecurityGroupRuleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VpcSecurityGroupRuleTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.VpcSecurityGroupRuleTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetRead")
    def reset_read(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRead", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="readInput")
    def read_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "readInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="read")
    def read(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "read"))

    @read.setter
    def read(self, value: builtins.str) -> None:
        jsii.set(self, "read", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, VpcSecurityGroupRuleTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, VpcSecurityGroupRuleTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, VpcSecurityGroupRuleTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.VpcSecurityGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class VpcSecurityGroupTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#create VpcSecurityGroup#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#delete VpcSecurityGroup#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#update VpcSecurityGroup#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#create VpcSecurityGroup#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#delete VpcSecurityGroup#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_security_group#update VpcSecurityGroup#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcSecurityGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VpcSecurityGroupTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.VpcSecurityGroupTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, VpcSecurityGroupTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, VpcSecurityGroupTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, VpcSecurityGroupTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class VpcSubnet(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.VpcSubnet",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet yandex_vpc_subnet}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        network_id: builtins.str,
        v4_cidr_blocks: typing.Sequence[builtins.str],
        description: typing.Optional[builtins.str] = None,
        dhcp_options: typing.Optional["VpcSubnetDhcpOptions"] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        route_table_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["VpcSubnetTimeouts"] = None,
        zone: typing.Optional[builtins.str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet yandex_vpc_subnet} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#network_id VpcSubnet#network_id}.
        :param v4_cidr_blocks: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#v4_cidr_blocks VpcSubnet#v4_cidr_blocks}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#description VpcSubnet#description}.
        :param dhcp_options: dhcp_options block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#dhcp_options VpcSubnet#dhcp_options}
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#folder_id VpcSubnet#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#id VpcSubnet#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#labels VpcSubnet#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#name VpcSubnet#name}.
        :param route_table_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#route_table_id VpcSubnet#route_table_id}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#timeouts VpcSubnet#timeouts}
        :param zone: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#zone VpcSubnet#zone}.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = VpcSubnetConfig(
            network_id=network_id,
            v4_cidr_blocks=v4_cidr_blocks,
            description=description,
            dhcp_options=dhcp_options,
            folder_id=folder_id,
            id=id,
            labels=labels,
            name=name,
            route_table_id=route_table_id,
            timeouts=timeouts,
            zone=zone,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putDhcpOptions")
    def put_dhcp_options(
        self,
        *,
        domain_name: typing.Optional[builtins.str] = None,
        domain_name_servers: typing.Optional[typing.Sequence[builtins.str]] = None,
        ntp_servers: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param domain_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#domain_name VpcSubnet#domain_name}.
        :param domain_name_servers: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#domain_name_servers VpcSubnet#domain_name_servers}.
        :param ntp_servers: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#ntp_servers VpcSubnet#ntp_servers}.
        '''
        value = VpcSubnetDhcpOptions(
            domain_name=domain_name,
            domain_name_servers=domain_name_servers,
            ntp_servers=ntp_servers,
        )

        return typing.cast(None, jsii.invoke(self, "putDhcpOptions", [value]))

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#create VpcSubnet#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#delete VpcSubnet#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#update VpcSubnet#update}.
        '''
        value = VpcSubnetTimeouts(create=create, delete=delete, update=update)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetDhcpOptions")
    def reset_dhcp_options(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDhcpOptions", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetName")
    def reset_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetName", []))

    @jsii.member(jsii_name="resetRouteTableId")
    def reset_route_table_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRouteTableId", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="resetZone")
    def reset_zone(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetZone", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dhcpOptions")
    def dhcp_options(self) -> "VpcSubnetDhcpOptionsOutputReference":
        return typing.cast("VpcSubnetDhcpOptionsOutputReference", jsii.get(self, "dhcpOptions"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "VpcSubnetTimeoutsOutputReference":
        return typing.cast("VpcSubnetTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="v6CidrBlocks")
    def v6_cidr_blocks(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "v6CidrBlocks"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dhcpOptionsInput")
    def dhcp_options_input(self) -> typing.Optional["VpcSubnetDhcpOptions"]:
        return typing.cast(typing.Optional["VpcSubnetDhcpOptions"], jsii.get(self, "dhcpOptionsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkIdInput")
    def network_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "networkIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="routeTableIdInput")
    def route_table_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "routeTableIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "VpcSubnetTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "VpcSubnetTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="v4CidrBlocksInput")
    def v4_cidr_blocks_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "v4CidrBlocksInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneInput")
    def zone_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "zoneInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @network_id.setter
    def network_id(self, value: builtins.str) -> None:
        jsii.set(self, "networkId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="routeTableId")
    def route_table_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "routeTableId"))

    @route_table_id.setter
    def route_table_id(self, value: builtins.str) -> None:
        jsii.set(self, "routeTableId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="v4CidrBlocks")
    def v4_cidr_blocks(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "v4CidrBlocks"))

    @v4_cidr_blocks.setter
    def v4_cidr_blocks(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "v4CidrBlocks", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zone")
    def zone(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "zone"))

    @zone.setter
    def zone(self, value: builtins.str) -> None:
        jsii.set(self, "zone", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.VpcSubnetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "network_id": "networkId",
        "v4_cidr_blocks": "v4CidrBlocks",
        "description": "description",
        "dhcp_options": "dhcpOptions",
        "folder_id": "folderId",
        "id": "id",
        "labels": "labels",
        "name": "name",
        "route_table_id": "routeTableId",
        "timeouts": "timeouts",
        "zone": "zone",
    },
)
class VpcSubnetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        network_id: builtins.str,
        v4_cidr_blocks: typing.Sequence[builtins.str],
        description: typing.Optional[builtins.str] = None,
        dhcp_options: typing.Optional["VpcSubnetDhcpOptions"] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        route_table_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["VpcSubnetTimeouts"] = None,
        zone: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#network_id VpcSubnet#network_id}.
        :param v4_cidr_blocks: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#v4_cidr_blocks VpcSubnet#v4_cidr_blocks}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#description VpcSubnet#description}.
        :param dhcp_options: dhcp_options block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#dhcp_options VpcSubnet#dhcp_options}
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#folder_id VpcSubnet#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#id VpcSubnet#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#labels VpcSubnet#labels}.
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#name VpcSubnet#name}.
        :param route_table_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#route_table_id VpcSubnet#route_table_id}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#timeouts VpcSubnet#timeouts}
        :param zone: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#zone VpcSubnet#zone}.
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(dhcp_options, dict):
            dhcp_options = VpcSubnetDhcpOptions(**dhcp_options)
        if isinstance(timeouts, dict):
            timeouts = VpcSubnetTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "network_id": network_id,
            "v4_cidr_blocks": v4_cidr_blocks,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if dhcp_options is not None:
            self._values["dhcp_options"] = dhcp_options
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if name is not None:
            self._values["name"] = name
        if route_table_id is not None:
            self._values["route_table_id"] = route_table_id
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if zone is not None:
            self._values["zone"] = zone

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def network_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#network_id VpcSubnet#network_id}.'''
        result = self._values.get("network_id")
        assert result is not None, "Required property 'network_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def v4_cidr_blocks(self) -> typing.List[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#v4_cidr_blocks VpcSubnet#v4_cidr_blocks}.'''
        result = self._values.get("v4_cidr_blocks")
        assert result is not None, "Required property 'v4_cidr_blocks' is missing"
        return typing.cast(typing.List[builtins.str], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#description VpcSubnet#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def dhcp_options(self) -> typing.Optional["VpcSubnetDhcpOptions"]:
        '''dhcp_options block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#dhcp_options VpcSubnet#dhcp_options}
        '''
        result = self._values.get("dhcp_options")
        return typing.cast(typing.Optional["VpcSubnetDhcpOptions"], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#folder_id VpcSubnet#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#id VpcSubnet#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#labels VpcSubnet#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#name VpcSubnet#name}.'''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def route_table_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#route_table_id VpcSubnet#route_table_id}.'''
        result = self._values.get("route_table_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["VpcSubnetTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#timeouts VpcSubnet#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["VpcSubnetTimeouts"], result)

    @builtins.property
    def zone(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#zone VpcSubnet#zone}.'''
        result = self._values.get("zone")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcSubnetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.VpcSubnetDhcpOptions",
    jsii_struct_bases=[],
    name_mapping={
        "domain_name": "domainName",
        "domain_name_servers": "domainNameServers",
        "ntp_servers": "ntpServers",
    },
)
class VpcSubnetDhcpOptions:
    def __init__(
        self,
        *,
        domain_name: typing.Optional[builtins.str] = None,
        domain_name_servers: typing.Optional[typing.Sequence[builtins.str]] = None,
        ntp_servers: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''
        :param domain_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#domain_name VpcSubnet#domain_name}.
        :param domain_name_servers: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#domain_name_servers VpcSubnet#domain_name_servers}.
        :param ntp_servers: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#ntp_servers VpcSubnet#ntp_servers}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if domain_name is not None:
            self._values["domain_name"] = domain_name
        if domain_name_servers is not None:
            self._values["domain_name_servers"] = domain_name_servers
        if ntp_servers is not None:
            self._values["ntp_servers"] = ntp_servers

    @builtins.property
    def domain_name(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#domain_name VpcSubnet#domain_name}.'''
        result = self._values.get("domain_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def domain_name_servers(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#domain_name_servers VpcSubnet#domain_name_servers}.'''
        result = self._values.get("domain_name_servers")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def ntp_servers(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#ntp_servers VpcSubnet#ntp_servers}.'''
        result = self._values.get("ntp_servers")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcSubnetDhcpOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VpcSubnetDhcpOptionsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.VpcSubnetDhcpOptionsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetDomainName")
    def reset_domain_name(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDomainName", []))

    @jsii.member(jsii_name="resetDomainNameServers")
    def reset_domain_name_servers(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDomainNameServers", []))

    @jsii.member(jsii_name="resetNtpServers")
    def reset_ntp_servers(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetNtpServers", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="domainNameInput")
    def domain_name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "domainNameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="domainNameServersInput")
    def domain_name_servers_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "domainNameServersInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ntpServersInput")
    def ntp_servers_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "ntpServersInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="domainName")
    def domain_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "domainName"))

    @domain_name.setter
    def domain_name(self, value: builtins.str) -> None:
        jsii.set(self, "domainName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="domainNameServers")
    def domain_name_servers(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "domainNameServers"))

    @domain_name_servers.setter
    def domain_name_servers(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "domainNameServers", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ntpServers")
    def ntp_servers(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "ntpServers"))

    @ntp_servers.setter
    def ntp_servers(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "ntpServers", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[VpcSubnetDhcpOptions]:
        return typing.cast(typing.Optional[VpcSubnetDhcpOptions], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(self, value: typing.Optional[VpcSubnetDhcpOptions]) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.VpcSubnetTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class VpcSubnetTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[builtins.str] = None,
        delete: typing.Optional[builtins.str] = None,
        update: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param create: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#create VpcSubnet#create}.
        :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#delete VpcSubnet#delete}.
        :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#update VpcSubnet#update}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#create VpcSubnet#create}.'''
        result = self._values.get("create")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def delete(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#delete VpcSubnet#delete}.'''
        result = self._values.get("delete")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/vpc_subnet#update VpcSubnet#update}.'''
        result = self._values.get("update")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcSubnetTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VpcSubnetTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.VpcSubnetTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetCreate")
    def reset_create(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCreate", []))

    @jsii.member(jsii_name="resetDelete")
    def reset_delete(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDelete", []))

    @jsii.member(jsii_name="resetUpdate")
    def reset_update(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetUpdate", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createInput")
    def create_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "createInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteInput")
    def delete_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deleteInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateInput")
    def update_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "updateInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="create")
    def create(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "create"))

    @create.setter
    def create(self, value: builtins.str) -> None:
        jsii.set(self, "create", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="delete")
    def delete(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "delete"))

    @delete.setter
    def delete(self, value: builtins.str) -> None:
        jsii.set(self, "delete", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="update")
    def update(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "update"))

    @update.setter
    def update(self, value: builtins.str) -> None:
        jsii.set(self, "update", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, VpcSubnetTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, VpcSubnetTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, VpcSubnetTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class YandexProvider(
    cdktf.TerraformProvider,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.YandexProvider",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex yandex}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        alias: typing.Optional[builtins.str] = None,
        cloud_id: typing.Optional[builtins.str] = None,
        endpoint: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        insecure: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        max_retries: typing.Optional[jsii.Number] = None,
        organization_id: typing.Optional[builtins.str] = None,
        plaintext: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        service_account_key_file: typing.Optional[builtins.str] = None,
        storage_access_key: typing.Optional[builtins.str] = None,
        storage_endpoint: typing.Optional[builtins.str] = None,
        storage_secret_key: typing.Optional[builtins.str] = None,
        token: typing.Optional[builtins.str] = None,
        ymq_access_key: typing.Optional[builtins.str] = None,
        ymq_endpoint: typing.Optional[builtins.str] = None,
        ymq_secret_key: typing.Optional[builtins.str] = None,
        zone: typing.Optional[builtins.str] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex yandex} Resource.

        :param scope: The scope in which to define this construct.
        :param id: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param alias: Alias name. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#alias YandexProvider#alias}
        :param cloud_id: ID of Yandex.Cloud tenant. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#cloud_id YandexProvider#cloud_id}
        :param endpoint: The API endpoint for Yandex.Cloud SDK client. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#endpoint YandexProvider#endpoint}
        :param folder_id: The default folder ID where resources will be placed. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#folder_id YandexProvider#folder_id}
        :param insecure: Explicitly allow the provider to perform "insecure" SSL requests. If omitted,default value is ``false``. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#insecure YandexProvider#insecure}
        :param max_retries: The maximum number of times an API request is being executed. If the API request still fails, an error is thrown. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#max_retries YandexProvider#max_retries}
        :param organization_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#organization_id YandexProvider#organization_id}.
        :param plaintext: Disable use of TLS. Default value is ``false``. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#plaintext YandexProvider#plaintext}
        :param service_account_key_file: Either the path to or the contents of a Service Account key file in JSON format. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#service_account_key_file YandexProvider#service_account_key_file}
        :param storage_access_key: Yandex.Cloud storage service access key. Used when a storage data/resource doesn't have an access key explicitly specified. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#storage_access_key YandexProvider#storage_access_key}
        :param storage_endpoint: Yandex.Cloud storage service endpoint. Default is storage.yandexcloud.net. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#storage_endpoint YandexProvider#storage_endpoint}
        :param storage_secret_key: Yandex.Cloud storage service secret key. Used when a storage data/resource doesn't have a secret key explicitly specified. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#storage_secret_key YandexProvider#storage_secret_key}
        :param token: The access token for API operations. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#token YandexProvider#token}
        :param ymq_access_key: Yandex.Cloud Message Queue service access key. Used when a message queue resource doesn't have an access key explicitly specified. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#ymq_access_key YandexProvider#ymq_access_key}
        :param ymq_endpoint: Yandex.Cloud Message Queue service endpoint. Default is message-queue.api.cloud.yandex.net. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#ymq_endpoint YandexProvider#ymq_endpoint}
        :param ymq_secret_key: Yandex.Cloud Message Queue service secret key. Used when a message queue resource doesn't have a secret key explicitly specified. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#ymq_secret_key YandexProvider#ymq_secret_key}
        :param zone: The zone where operations will take place. Examples are ru-central1-a, ru-central2-c, etc. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#zone YandexProvider#zone}
        '''
        config = YandexProviderConfig(
            alias=alias,
            cloud_id=cloud_id,
            endpoint=endpoint,
            folder_id=folder_id,
            insecure=insecure,
            max_retries=max_retries,
            organization_id=organization_id,
            plaintext=plaintext,
            service_account_key_file=service_account_key_file,
            storage_access_key=storage_access_key,
            storage_endpoint=storage_endpoint,
            storage_secret_key=storage_secret_key,
            token=token,
            ymq_access_key=ymq_access_key,
            ymq_endpoint=ymq_endpoint,
            ymq_secret_key=ymq_secret_key,
            zone=zone,
        )

        jsii.create(self.__class__, self, [scope, id, config])

    @jsii.member(jsii_name="resetAlias")
    def reset_alias(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAlias", []))

    @jsii.member(jsii_name="resetCloudId")
    def reset_cloud_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetCloudId", []))

    @jsii.member(jsii_name="resetEndpoint")
    def reset_endpoint(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEndpoint", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetInsecure")
    def reset_insecure(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetInsecure", []))

    @jsii.member(jsii_name="resetMaxRetries")
    def reset_max_retries(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetMaxRetries", []))

    @jsii.member(jsii_name="resetOrganizationId")
    def reset_organization_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetOrganizationId", []))

    @jsii.member(jsii_name="resetPlaintext")
    def reset_plaintext(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetPlaintext", []))

    @jsii.member(jsii_name="resetServiceAccountKeyFile")
    def reset_service_account_key_file(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetServiceAccountKeyFile", []))

    @jsii.member(jsii_name="resetStorageAccessKey")
    def reset_storage_access_key(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStorageAccessKey", []))

    @jsii.member(jsii_name="resetStorageEndpoint")
    def reset_storage_endpoint(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStorageEndpoint", []))

    @jsii.member(jsii_name="resetStorageSecretKey")
    def reset_storage_secret_key(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStorageSecretKey", []))

    @jsii.member(jsii_name="resetToken")
    def reset_token(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetToken", []))

    @jsii.member(jsii_name="resetYmqAccessKey")
    def reset_ymq_access_key(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetYmqAccessKey", []))

    @jsii.member(jsii_name="resetYmqEndpoint")
    def reset_ymq_endpoint(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetYmqEndpoint", []))

    @jsii.member(jsii_name="resetYmqSecretKey")
    def reset_ymq_secret_key(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetYmqSecretKey", []))

    @jsii.member(jsii_name="resetZone")
    def reset_zone(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetZone", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="aliasInput")
    def alias_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aliasInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cloudIdInput")
    def cloud_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "cloudIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="endpointInput")
    def endpoint_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "endpointInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="insecureInput")
    def insecure_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "insecureInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxRetriesInput")
    def max_retries_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxRetriesInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="organizationIdInput")
    def organization_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "organizationIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="plaintextInput")
    def plaintext_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "plaintextInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountKeyFileInput")
    def service_account_key_file_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceAccountKeyFileInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="storageAccessKeyInput")
    def storage_access_key_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "storageAccessKeyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="storageEndpointInput")
    def storage_endpoint_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "storageEndpointInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="storageSecretKeyInput")
    def storage_secret_key_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "storageSecretKeyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tokenInput")
    def token_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "tokenInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ymqAccessKeyInput")
    def ymq_access_key_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "ymqAccessKeyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ymqEndpointInput")
    def ymq_endpoint_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "ymqEndpointInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ymqSecretKeyInput")
    def ymq_secret_key_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "ymqSecretKeyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zoneInput")
    def zone_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "zoneInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="alias")
    def alias(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "alias"))

    @alias.setter
    def alias(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "alias", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cloudId")
    def cloud_id(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "cloudId"))

    @cloud_id.setter
    def cloud_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "cloudId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "endpoint"))

    @endpoint.setter
    def endpoint(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "endpoint", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="insecure")
    def insecure(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "insecure"))

    @insecure.setter
    def insecure(
        self,
        value: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]],
    ) -> None:
        jsii.set(self, "insecure", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxRetries")
    def max_retries(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "maxRetries"))

    @max_retries.setter
    def max_retries(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maxRetries", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="organizationId")
    def organization_id(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "organizationId"))

    @organization_id.setter
    def organization_id(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "organizationId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="plaintext")
    def plaintext(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "plaintext"))

    @plaintext.setter
    def plaintext(
        self,
        value: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]],
    ) -> None:
        jsii.set(self, "plaintext", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="serviceAccountKeyFile")
    def service_account_key_file(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "serviceAccountKeyFile"))

    @service_account_key_file.setter
    def service_account_key_file(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "serviceAccountKeyFile", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="storageAccessKey")
    def storage_access_key(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "storageAccessKey"))

    @storage_access_key.setter
    def storage_access_key(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "storageAccessKey", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="storageEndpoint")
    def storage_endpoint(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "storageEndpoint"))

    @storage_endpoint.setter
    def storage_endpoint(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "storageEndpoint", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="storageSecretKey")
    def storage_secret_key(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "storageSecretKey"))

    @storage_secret_key.setter
    def storage_secret_key(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "storageSecretKey", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="token")
    def token(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "token"))

    @token.setter
    def token(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "token", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ymqAccessKey")
    def ymq_access_key(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "ymqAccessKey"))

    @ymq_access_key.setter
    def ymq_access_key(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "ymqAccessKey", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ymqEndpoint")
    def ymq_endpoint(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "ymqEndpoint"))

    @ymq_endpoint.setter
    def ymq_endpoint(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "ymqEndpoint", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ymqSecretKey")
    def ymq_secret_key(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "ymqSecretKey"))

    @ymq_secret_key.setter
    def ymq_secret_key(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "ymqSecretKey", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="zone")
    def zone(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "zone"))

    @zone.setter
    def zone(self, value: typing.Optional[builtins.str]) -> None:
        jsii.set(self, "zone", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.YandexProviderConfig",
    jsii_struct_bases=[],
    name_mapping={
        "alias": "alias",
        "cloud_id": "cloudId",
        "endpoint": "endpoint",
        "folder_id": "folderId",
        "insecure": "insecure",
        "max_retries": "maxRetries",
        "organization_id": "organizationId",
        "plaintext": "plaintext",
        "service_account_key_file": "serviceAccountKeyFile",
        "storage_access_key": "storageAccessKey",
        "storage_endpoint": "storageEndpoint",
        "storage_secret_key": "storageSecretKey",
        "token": "token",
        "ymq_access_key": "ymqAccessKey",
        "ymq_endpoint": "ymqEndpoint",
        "ymq_secret_key": "ymqSecretKey",
        "zone": "zone",
    },
)
class YandexProviderConfig:
    def __init__(
        self,
        *,
        alias: typing.Optional[builtins.str] = None,
        cloud_id: typing.Optional[builtins.str] = None,
        endpoint: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        insecure: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        max_retries: typing.Optional[jsii.Number] = None,
        organization_id: typing.Optional[builtins.str] = None,
        plaintext: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        service_account_key_file: typing.Optional[builtins.str] = None,
        storage_access_key: typing.Optional[builtins.str] = None,
        storage_endpoint: typing.Optional[builtins.str] = None,
        storage_secret_key: typing.Optional[builtins.str] = None,
        token: typing.Optional[builtins.str] = None,
        ymq_access_key: typing.Optional[builtins.str] = None,
        ymq_endpoint: typing.Optional[builtins.str] = None,
        ymq_secret_key: typing.Optional[builtins.str] = None,
        zone: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param alias: Alias name. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#alias YandexProvider#alias}
        :param cloud_id: ID of Yandex.Cloud tenant. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#cloud_id YandexProvider#cloud_id}
        :param endpoint: The API endpoint for Yandex.Cloud SDK client. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#endpoint YandexProvider#endpoint}
        :param folder_id: The default folder ID where resources will be placed. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#folder_id YandexProvider#folder_id}
        :param insecure: Explicitly allow the provider to perform "insecure" SSL requests. If omitted,default value is ``false``. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#insecure YandexProvider#insecure}
        :param max_retries: The maximum number of times an API request is being executed. If the API request still fails, an error is thrown. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#max_retries YandexProvider#max_retries}
        :param organization_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#organization_id YandexProvider#organization_id}.
        :param plaintext: Disable use of TLS. Default value is ``false``. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#plaintext YandexProvider#plaintext}
        :param service_account_key_file: Either the path to or the contents of a Service Account key file in JSON format. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#service_account_key_file YandexProvider#service_account_key_file}
        :param storage_access_key: Yandex.Cloud storage service access key. Used when a storage data/resource doesn't have an access key explicitly specified. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#storage_access_key YandexProvider#storage_access_key}
        :param storage_endpoint: Yandex.Cloud storage service endpoint. Default is storage.yandexcloud.net. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#storage_endpoint YandexProvider#storage_endpoint}
        :param storage_secret_key: Yandex.Cloud storage service secret key. Used when a storage data/resource doesn't have a secret key explicitly specified. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#storage_secret_key YandexProvider#storage_secret_key}
        :param token: The access token for API operations. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#token YandexProvider#token}
        :param ymq_access_key: Yandex.Cloud Message Queue service access key. Used when a message queue resource doesn't have an access key explicitly specified. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#ymq_access_key YandexProvider#ymq_access_key}
        :param ymq_endpoint: Yandex.Cloud Message Queue service endpoint. Default is message-queue.api.cloud.yandex.net. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#ymq_endpoint YandexProvider#ymq_endpoint}
        :param ymq_secret_key: Yandex.Cloud Message Queue service secret key. Used when a message queue resource doesn't have a secret key explicitly specified. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#ymq_secret_key YandexProvider#ymq_secret_key}
        :param zone: The zone where operations will take place. Examples are ru-central1-a, ru-central2-c, etc. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#zone YandexProvider#zone}
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if alias is not None:
            self._values["alias"] = alias
        if cloud_id is not None:
            self._values["cloud_id"] = cloud_id
        if endpoint is not None:
            self._values["endpoint"] = endpoint
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if insecure is not None:
            self._values["insecure"] = insecure
        if max_retries is not None:
            self._values["max_retries"] = max_retries
        if organization_id is not None:
            self._values["organization_id"] = organization_id
        if plaintext is not None:
            self._values["plaintext"] = plaintext
        if service_account_key_file is not None:
            self._values["service_account_key_file"] = service_account_key_file
        if storage_access_key is not None:
            self._values["storage_access_key"] = storage_access_key
        if storage_endpoint is not None:
            self._values["storage_endpoint"] = storage_endpoint
        if storage_secret_key is not None:
            self._values["storage_secret_key"] = storage_secret_key
        if token is not None:
            self._values["token"] = token
        if ymq_access_key is not None:
            self._values["ymq_access_key"] = ymq_access_key
        if ymq_endpoint is not None:
            self._values["ymq_endpoint"] = ymq_endpoint
        if ymq_secret_key is not None:
            self._values["ymq_secret_key"] = ymq_secret_key
        if zone is not None:
            self._values["zone"] = zone

    @builtins.property
    def alias(self) -> typing.Optional[builtins.str]:
        '''Alias name.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#alias YandexProvider#alias}
        '''
        result = self._values.get("alias")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def cloud_id(self) -> typing.Optional[builtins.str]:
        '''ID of Yandex.Cloud tenant.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#cloud_id YandexProvider#cloud_id}
        '''
        result = self._values.get("cloud_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def endpoint(self) -> typing.Optional[builtins.str]:
        '''The API endpoint for Yandex.Cloud SDK client.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#endpoint YandexProvider#endpoint}
        '''
        result = self._values.get("endpoint")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''The default folder ID where resources will be placed.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#folder_id YandexProvider#folder_id}
        '''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def insecure(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Explicitly allow the provider to perform "insecure" SSL requests. If omitted,default value is ``false``.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#insecure YandexProvider#insecure}
        '''
        result = self._values.get("insecure")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def max_retries(self) -> typing.Optional[jsii.Number]:
        '''The maximum number of times an API request is being executed.

        If the API request still fails, an error is thrown.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#max_retries YandexProvider#max_retries}
        '''
        result = self._values.get("max_retries")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def organization_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#organization_id YandexProvider#organization_id}.'''
        result = self._values.get("organization_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def plaintext(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Disable use of TLS. Default value is ``false``.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#plaintext YandexProvider#plaintext}
        '''
        result = self._values.get("plaintext")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def service_account_key_file(self) -> typing.Optional[builtins.str]:
        '''Either the path to or the contents of a Service Account key file in JSON format.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#service_account_key_file YandexProvider#service_account_key_file}
        '''
        result = self._values.get("service_account_key_file")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def storage_access_key(self) -> typing.Optional[builtins.str]:
        '''Yandex.Cloud storage service access key.  Used when a storage data/resource doesn't have an access key explicitly specified.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#storage_access_key YandexProvider#storage_access_key}
        '''
        result = self._values.get("storage_access_key")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def storage_endpoint(self) -> typing.Optional[builtins.str]:
        '''Yandex.Cloud storage service endpoint. Default is  storage.yandexcloud.net.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#storage_endpoint YandexProvider#storage_endpoint}
        '''
        result = self._values.get("storage_endpoint")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def storage_secret_key(self) -> typing.Optional[builtins.str]:
        '''Yandex.Cloud storage service secret key.  Used when a storage data/resource doesn't have a secret key explicitly specified.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#storage_secret_key YandexProvider#storage_secret_key}
        '''
        result = self._values.get("storage_secret_key")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def token(self) -> typing.Optional[builtins.str]:
        '''The access token for API operations.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#token YandexProvider#token}
        '''
        result = self._values.get("token")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def ymq_access_key(self) -> typing.Optional[builtins.str]:
        '''Yandex.Cloud Message Queue service access key.  Used when a message queue resource doesn't have an access key explicitly specified.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#ymq_access_key YandexProvider#ymq_access_key}
        '''
        result = self._values.get("ymq_access_key")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def ymq_endpoint(self) -> typing.Optional[builtins.str]:
        '''Yandex.Cloud Message Queue service endpoint. Default is  message-queue.api.cloud.yandex.net.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#ymq_endpoint YandexProvider#ymq_endpoint}
        '''
        result = self._values.get("ymq_endpoint")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def ymq_secret_key(self) -> typing.Optional[builtins.str]:
        '''Yandex.Cloud Message Queue service secret key.  Used when a message queue resource doesn't have a secret key explicitly specified.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#ymq_secret_key YandexProvider#ymq_secret_key}
        '''
        result = self._values.get("ymq_secret_key")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def zone(self) -> typing.Optional[builtins.str]:
        '''The zone where operations will take place. Examples are ru-central1-a, ru-central2-c, etc.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex#zone YandexProvider#zone}
        '''
        result = self._values.get("zone")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "YandexProviderConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class YdbDatabaseDedicated(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.YdbDatabaseDedicated",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated yandex_ydb_database_dedicated}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        name: builtins.str,
        network_id: builtins.str,
        resource_preset_id: builtins.str,
        scale_policy: "YdbDatabaseDedicatedScalePolicy",
        storage_config: "YdbDatabaseDedicatedStorageConfig",
        subnet_ids: typing.Sequence[builtins.str],
        assign_public_ips: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        location: typing.Optional["YdbDatabaseDedicatedLocation"] = None,
        location_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["YdbDatabaseDedicatedTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated yandex_ydb_database_dedicated} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#name YdbDatabaseDedicated#name}.
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#network_id YdbDatabaseDedicated#network_id}.
        :param resource_preset_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#resource_preset_id YdbDatabaseDedicated#resource_preset_id}.
        :param scale_policy: scale_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#scale_policy YdbDatabaseDedicated#scale_policy}
        :param storage_config: storage_config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#storage_config YdbDatabaseDedicated#storage_config}
        :param subnet_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#subnet_ids YdbDatabaseDedicated#subnet_ids}.
        :param assign_public_ips: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#assign_public_ips YdbDatabaseDedicated#assign_public_ips}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#description YdbDatabaseDedicated#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#folder_id YdbDatabaseDedicated#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#id YdbDatabaseDedicated#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#labels YdbDatabaseDedicated#labels}.
        :param location: location block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#location YdbDatabaseDedicated#location}
        :param location_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#location_id YdbDatabaseDedicated#location_id}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#timeouts YdbDatabaseDedicated#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = YdbDatabaseDedicatedConfig(
            name=name,
            network_id=network_id,
            resource_preset_id=resource_preset_id,
            scale_policy=scale_policy,
            storage_config=storage_config,
            subnet_ids=subnet_ids,
            assign_public_ips=assign_public_ips,
            description=description,
            folder_id=folder_id,
            id=id,
            labels=labels,
            location=location,
            location_id=location_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putLocation")
    def put_location(
        self,
        *,
        region: typing.Optional["YdbDatabaseDedicatedLocationRegion"] = None,
    ) -> None:
        '''
        :param region: region block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#region YdbDatabaseDedicated#region}
        '''
        value = YdbDatabaseDedicatedLocation(region=region)

        return typing.cast(None, jsii.invoke(self, "putLocation", [value]))

    @jsii.member(jsii_name="putScalePolicy")
    def put_scale_policy(
        self,
        *,
        fixed_scale: "YdbDatabaseDedicatedScalePolicyFixedScale",
    ) -> None:
        '''
        :param fixed_scale: fixed_scale block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#fixed_scale YdbDatabaseDedicated#fixed_scale}
        '''
        value = YdbDatabaseDedicatedScalePolicy(fixed_scale=fixed_scale)

        return typing.cast(None, jsii.invoke(self, "putScalePolicy", [value]))

    @jsii.member(jsii_name="putStorageConfig")
    def put_storage_config(
        self,
        *,
        group_count: jsii.Number,
        storage_type_id: builtins.str,
    ) -> None:
        '''
        :param group_count: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#group_count YdbDatabaseDedicated#group_count}.
        :param storage_type_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#storage_type_id YdbDatabaseDedicated#storage_type_id}.
        '''
        value = YdbDatabaseDedicatedStorageConfig(
            group_count=group_count, storage_type_id=storage_type_id
        )

        return typing.cast(None, jsii.invoke(self, "putStorageConfig", [value]))

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(self, *, default: typing.Optional[builtins.str] = None) -> None:
        '''
        :param default: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#default YdbDatabaseDedicated#default}.
        '''
        value = YdbDatabaseDedicatedTimeouts(default=default)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetAssignPublicIps")
    def reset_assign_public_ips(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAssignPublicIps", []))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetLocation")
    def reset_location(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLocation", []))

    @jsii.member(jsii_name="resetLocationId")
    def reset_location_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLocationId", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databasePath")
    def database_path(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "databasePath"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="location")
    def location(self) -> "YdbDatabaseDedicatedLocationOutputReference":
        return typing.cast("YdbDatabaseDedicatedLocationOutputReference", jsii.get(self, "location"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="scalePolicy")
    def scale_policy(self) -> "YdbDatabaseDedicatedScalePolicyOutputReference":
        return typing.cast("YdbDatabaseDedicatedScalePolicyOutputReference", jsii.get(self, "scalePolicy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="storageConfig")
    def storage_config(self) -> "YdbDatabaseDedicatedStorageConfigOutputReference":
        return typing.cast("YdbDatabaseDedicatedStorageConfigOutputReference", jsii.get(self, "storageConfig"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "YdbDatabaseDedicatedTimeoutsOutputReference":
        return typing.cast("YdbDatabaseDedicatedTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tlsEnabled")
    def tls_enabled(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "tlsEnabled"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ydbApiEndpoint")
    def ydb_api_endpoint(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ydbApiEndpoint"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ydbFullEndpoint")
    def ydb_full_endpoint(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ydbFullEndpoint"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIpsInput")
    def assign_public_ips_input(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "assignPublicIpsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="locationIdInput")
    def location_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "locationIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="locationInput")
    def location_input(self) -> typing.Optional["YdbDatabaseDedicatedLocation"]:
        return typing.cast(typing.Optional["YdbDatabaseDedicatedLocation"], jsii.get(self, "locationInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkIdInput")
    def network_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "networkIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetIdInput")
    def resource_preset_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourcePresetIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="scalePolicyInput")
    def scale_policy_input(self) -> typing.Optional["YdbDatabaseDedicatedScalePolicy"]:
        return typing.cast(typing.Optional["YdbDatabaseDedicatedScalePolicy"], jsii.get(self, "scalePolicyInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="storageConfigInput")
    def storage_config_input(
        self,
    ) -> typing.Optional["YdbDatabaseDedicatedStorageConfig"]:
        return typing.cast(typing.Optional["YdbDatabaseDedicatedStorageConfig"], jsii.get(self, "storageConfigInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIdsInput")
    def subnet_ids_input(self) -> typing.Optional[typing.List[builtins.str]]:
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "subnetIdsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "YdbDatabaseDedicatedTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "YdbDatabaseDedicatedTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="assignPublicIps")
    def assign_public_ips(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "assignPublicIps"))

    @assign_public_ips.setter
    def assign_public_ips(
        self,
        value: typing.Union[builtins.bool, cdktf.IResolvable],
    ) -> None:
        jsii.set(self, "assignPublicIps", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="locationId")
    def location_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "locationId"))

    @location_id.setter
    def location_id(self, value: builtins.str) -> None:
        jsii.set(self, "locationId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @network_id.setter
    def network_id(self, value: builtins.str) -> None:
        jsii.set(self, "networkId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="resourcePresetId")
    def resource_preset_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "resourcePresetId"))

    @resource_preset_id.setter
    def resource_preset_id(self, value: builtins.str) -> None:
        jsii.set(self, "resourcePresetId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.List[builtins.str]:
        return typing.cast(typing.List[builtins.str], jsii.get(self, "subnetIds"))

    @subnet_ids.setter
    def subnet_ids(self, value: typing.List[builtins.str]) -> None:
        jsii.set(self, "subnetIds", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.YdbDatabaseDedicatedConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "network_id": "networkId",
        "resource_preset_id": "resourcePresetId",
        "scale_policy": "scalePolicy",
        "storage_config": "storageConfig",
        "subnet_ids": "subnetIds",
        "assign_public_ips": "assignPublicIps",
        "description": "description",
        "folder_id": "folderId",
        "id": "id",
        "labels": "labels",
        "location": "location",
        "location_id": "locationId",
        "timeouts": "timeouts",
    },
)
class YdbDatabaseDedicatedConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        network_id: builtins.str,
        resource_preset_id: builtins.str,
        scale_policy: "YdbDatabaseDedicatedScalePolicy",
        storage_config: "YdbDatabaseDedicatedStorageConfig",
        subnet_ids: typing.Sequence[builtins.str],
        assign_public_ips: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        location: typing.Optional["YdbDatabaseDedicatedLocation"] = None,
        location_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["YdbDatabaseDedicatedTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#name YdbDatabaseDedicated#name}.
        :param network_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#network_id YdbDatabaseDedicated#network_id}.
        :param resource_preset_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#resource_preset_id YdbDatabaseDedicated#resource_preset_id}.
        :param scale_policy: scale_policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#scale_policy YdbDatabaseDedicated#scale_policy}
        :param storage_config: storage_config block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#storage_config YdbDatabaseDedicated#storage_config}
        :param subnet_ids: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#subnet_ids YdbDatabaseDedicated#subnet_ids}.
        :param assign_public_ips: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#assign_public_ips YdbDatabaseDedicated#assign_public_ips}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#description YdbDatabaseDedicated#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#folder_id YdbDatabaseDedicated#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#id YdbDatabaseDedicated#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#labels YdbDatabaseDedicated#labels}.
        :param location: location block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#location YdbDatabaseDedicated#location}
        :param location_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#location_id YdbDatabaseDedicated#location_id}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#timeouts YdbDatabaseDedicated#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(scale_policy, dict):
            scale_policy = YdbDatabaseDedicatedScalePolicy(**scale_policy)
        if isinstance(storage_config, dict):
            storage_config = YdbDatabaseDedicatedStorageConfig(**storage_config)
        if isinstance(location, dict):
            location = YdbDatabaseDedicatedLocation(**location)
        if isinstance(timeouts, dict):
            timeouts = YdbDatabaseDedicatedTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
            "network_id": network_id,
            "resource_preset_id": resource_preset_id,
            "scale_policy": scale_policy,
            "storage_config": storage_config,
            "subnet_ids": subnet_ids,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if assign_public_ips is not None:
            self._values["assign_public_ips"] = assign_public_ips
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if location is not None:
            self._values["location"] = location
        if location_id is not None:
            self._values["location_id"] = location_id
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#name YdbDatabaseDedicated#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def network_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#network_id YdbDatabaseDedicated#network_id}.'''
        result = self._values.get("network_id")
        assert result is not None, "Required property 'network_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def resource_preset_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#resource_preset_id YdbDatabaseDedicated#resource_preset_id}.'''
        result = self._values.get("resource_preset_id")
        assert result is not None, "Required property 'resource_preset_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def scale_policy(self) -> "YdbDatabaseDedicatedScalePolicy":
        '''scale_policy block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#scale_policy YdbDatabaseDedicated#scale_policy}
        '''
        result = self._values.get("scale_policy")
        assert result is not None, "Required property 'scale_policy' is missing"
        return typing.cast("YdbDatabaseDedicatedScalePolicy", result)

    @builtins.property
    def storage_config(self) -> "YdbDatabaseDedicatedStorageConfig":
        '''storage_config block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#storage_config YdbDatabaseDedicated#storage_config}
        '''
        result = self._values.get("storage_config")
        assert result is not None, "Required property 'storage_config' is missing"
        return typing.cast("YdbDatabaseDedicatedStorageConfig", result)

    @builtins.property
    def subnet_ids(self) -> typing.List[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#subnet_ids YdbDatabaseDedicated#subnet_ids}.'''
        result = self._values.get("subnet_ids")
        assert result is not None, "Required property 'subnet_ids' is missing"
        return typing.cast(typing.List[builtins.str], result)

    @builtins.property
    def assign_public_ips(
        self,
    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#assign_public_ips YdbDatabaseDedicated#assign_public_ips}.'''
        result = self._values.get("assign_public_ips")
        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#description YdbDatabaseDedicated#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#folder_id YdbDatabaseDedicated#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#id YdbDatabaseDedicated#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#labels YdbDatabaseDedicated#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def location(self) -> typing.Optional["YdbDatabaseDedicatedLocation"]:
        '''location block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#location YdbDatabaseDedicated#location}
        '''
        result = self._values.get("location")
        return typing.cast(typing.Optional["YdbDatabaseDedicatedLocation"], result)

    @builtins.property
    def location_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#location_id YdbDatabaseDedicated#location_id}.'''
        result = self._values.get("location_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["YdbDatabaseDedicatedTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#timeouts YdbDatabaseDedicated#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["YdbDatabaseDedicatedTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "YdbDatabaseDedicatedConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.YdbDatabaseDedicatedLocation",
    jsii_struct_bases=[],
    name_mapping={"region": "region"},
)
class YdbDatabaseDedicatedLocation:
    def __init__(
        self,
        *,
        region: typing.Optional["YdbDatabaseDedicatedLocationRegion"] = None,
    ) -> None:
        '''
        :param region: region block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#region YdbDatabaseDedicated#region}
        '''
        if isinstance(region, dict):
            region = YdbDatabaseDedicatedLocationRegion(**region)
        self._values: typing.Dict[str, typing.Any] = {}
        if region is not None:
            self._values["region"] = region

    @builtins.property
    def region(self) -> typing.Optional["YdbDatabaseDedicatedLocationRegion"]:
        '''region block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#region YdbDatabaseDedicated#region}
        '''
        result = self._values.get("region")
        return typing.cast(typing.Optional["YdbDatabaseDedicatedLocationRegion"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "YdbDatabaseDedicatedLocation(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class YdbDatabaseDedicatedLocationOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.YdbDatabaseDedicatedLocationOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putRegion")
    def put_region(self, *, id: builtins.str) -> None:
        '''
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#id YdbDatabaseDedicated#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        value = YdbDatabaseDedicatedLocationRegion(id=id)

        return typing.cast(None, jsii.invoke(self, "putRegion", [value]))

    @jsii.member(jsii_name="resetRegion")
    def reset_region(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetRegion", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="region")
    def region(self) -> "YdbDatabaseDedicatedLocationRegionOutputReference":
        return typing.cast("YdbDatabaseDedicatedLocationRegionOutputReference", jsii.get(self, "region"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="regionInput")
    def region_input(self) -> typing.Optional["YdbDatabaseDedicatedLocationRegion"]:
        return typing.cast(typing.Optional["YdbDatabaseDedicatedLocationRegion"], jsii.get(self, "regionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[YdbDatabaseDedicatedLocation]:
        return typing.cast(typing.Optional[YdbDatabaseDedicatedLocation], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[YdbDatabaseDedicatedLocation],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.YdbDatabaseDedicatedLocationRegion",
    jsii_struct_bases=[],
    name_mapping={"id": "id"},
)
class YdbDatabaseDedicatedLocationRegion:
    def __init__(self, *, id: builtins.str) -> None:
        '''
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#id YdbDatabaseDedicated#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "id": id,
        }

    @builtins.property
    def id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#id YdbDatabaseDedicated#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        assert result is not None, "Required property 'id' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "YdbDatabaseDedicatedLocationRegion(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class YdbDatabaseDedicatedLocationRegionOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.YdbDatabaseDedicatedLocationRegionOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[YdbDatabaseDedicatedLocationRegion]:
        return typing.cast(typing.Optional[YdbDatabaseDedicatedLocationRegion], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[YdbDatabaseDedicatedLocationRegion],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.YdbDatabaseDedicatedScalePolicy",
    jsii_struct_bases=[],
    name_mapping={"fixed_scale": "fixedScale"},
)
class YdbDatabaseDedicatedScalePolicy:
    def __init__(
        self,
        *,
        fixed_scale: "YdbDatabaseDedicatedScalePolicyFixedScale",
    ) -> None:
        '''
        :param fixed_scale: fixed_scale block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#fixed_scale YdbDatabaseDedicated#fixed_scale}
        '''
        if isinstance(fixed_scale, dict):
            fixed_scale = YdbDatabaseDedicatedScalePolicyFixedScale(**fixed_scale)
        self._values: typing.Dict[str, typing.Any] = {
            "fixed_scale": fixed_scale,
        }

    @builtins.property
    def fixed_scale(self) -> "YdbDatabaseDedicatedScalePolicyFixedScale":
        '''fixed_scale block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#fixed_scale YdbDatabaseDedicated#fixed_scale}
        '''
        result = self._values.get("fixed_scale")
        assert result is not None, "Required property 'fixed_scale' is missing"
        return typing.cast("YdbDatabaseDedicatedScalePolicyFixedScale", result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "YdbDatabaseDedicatedScalePolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.YdbDatabaseDedicatedScalePolicyFixedScale",
    jsii_struct_bases=[],
    name_mapping={"size": "size"},
)
class YdbDatabaseDedicatedScalePolicyFixedScale:
    def __init__(self, *, size: jsii.Number) -> None:
        '''
        :param size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#size YdbDatabaseDedicated#size}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "size": size,
        }

    @builtins.property
    def size(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#size YdbDatabaseDedicated#size}.'''
        result = self._values.get("size")
        assert result is not None, "Required property 'size' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "YdbDatabaseDedicatedScalePolicyFixedScale(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class YdbDatabaseDedicatedScalePolicyFixedScaleOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.YdbDatabaseDedicatedScalePolicyFixedScaleOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="sizeInput")
    def size_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "sizeInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="size")
    def size(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "size"))

    @size.setter
    def size(self, value: jsii.Number) -> None:
        jsii.set(self, "size", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[YdbDatabaseDedicatedScalePolicyFixedScale]:
        return typing.cast(typing.Optional[YdbDatabaseDedicatedScalePolicyFixedScale], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[YdbDatabaseDedicatedScalePolicyFixedScale],
    ) -> None:
        jsii.set(self, "internalValue", value)


class YdbDatabaseDedicatedScalePolicyOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.YdbDatabaseDedicatedScalePolicyOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="putFixedScale")
    def put_fixed_scale(self, *, size: jsii.Number) -> None:
        '''
        :param size: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#size YdbDatabaseDedicated#size}.
        '''
        value = YdbDatabaseDedicatedScalePolicyFixedScale(size=size)

        return typing.cast(None, jsii.invoke(self, "putFixedScale", [value]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fixedScale")
    def fixed_scale(self) -> YdbDatabaseDedicatedScalePolicyFixedScaleOutputReference:
        return typing.cast(YdbDatabaseDedicatedScalePolicyFixedScaleOutputReference, jsii.get(self, "fixedScale"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fixedScaleInput")
    def fixed_scale_input(
        self,
    ) -> typing.Optional[YdbDatabaseDedicatedScalePolicyFixedScale]:
        return typing.cast(typing.Optional[YdbDatabaseDedicatedScalePolicyFixedScale], jsii.get(self, "fixedScaleInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[YdbDatabaseDedicatedScalePolicy]:
        return typing.cast(typing.Optional[YdbDatabaseDedicatedScalePolicy], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[YdbDatabaseDedicatedScalePolicy],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.YdbDatabaseDedicatedStorageConfig",
    jsii_struct_bases=[],
    name_mapping={"group_count": "groupCount", "storage_type_id": "storageTypeId"},
)
class YdbDatabaseDedicatedStorageConfig:
    def __init__(
        self,
        *,
        group_count: jsii.Number,
        storage_type_id: builtins.str,
    ) -> None:
        '''
        :param group_count: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#group_count YdbDatabaseDedicated#group_count}.
        :param storage_type_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#storage_type_id YdbDatabaseDedicated#storage_type_id}.
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "group_count": group_count,
            "storage_type_id": storage_type_id,
        }

    @builtins.property
    def group_count(self) -> jsii.Number:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#group_count YdbDatabaseDedicated#group_count}.'''
        result = self._values.get("group_count")
        assert result is not None, "Required property 'group_count' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def storage_type_id(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#storage_type_id YdbDatabaseDedicated#storage_type_id}.'''
        result = self._values.get("storage_type_id")
        assert result is not None, "Required property 'storage_type_id' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "YdbDatabaseDedicatedStorageConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class YdbDatabaseDedicatedStorageConfigOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.YdbDatabaseDedicatedStorageConfigOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="groupCountInput")
    def group_count_input(self) -> typing.Optional[jsii.Number]:
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "groupCountInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="storageTypeIdInput")
    def storage_type_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "storageTypeIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="groupCount")
    def group_count(self) -> jsii.Number:
        return typing.cast(jsii.Number, jsii.get(self, "groupCount"))

    @group_count.setter
    def group_count(self, value: jsii.Number) -> None:
        jsii.set(self, "groupCount", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="storageTypeId")
    def storage_type_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "storageTypeId"))

    @storage_type_id.setter
    def storage_type_id(self, value: builtins.str) -> None:
        jsii.set(self, "storageTypeId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(self) -> typing.Optional[YdbDatabaseDedicatedStorageConfig]:
        return typing.cast(typing.Optional[YdbDatabaseDedicatedStorageConfig], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[YdbDatabaseDedicatedStorageConfig],
    ) -> None:
        jsii.set(self, "internalValue", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.YdbDatabaseDedicatedTimeouts",
    jsii_struct_bases=[],
    name_mapping={"default": "default"},
)
class YdbDatabaseDedicatedTimeouts:
    def __init__(self, *, default: typing.Optional[builtins.str] = None) -> None:
        '''
        :param default: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#default YdbDatabaseDedicated#default}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if default is not None:
            self._values["default"] = default

    @builtins.property
    def default(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_dedicated#default YdbDatabaseDedicated#default}.'''
        result = self._values.get("default")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "YdbDatabaseDedicatedTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class YdbDatabaseDedicatedTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.YdbDatabaseDedicatedTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetDefault")
    def reset_default(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDefault", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="defaultInput")
    def default_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "defaultInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="default")
    def default(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "default"))

    @default.setter
    def default(self, value: builtins.str) -> None:
        jsii.set(self, "default", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, YdbDatabaseDedicatedTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, YdbDatabaseDedicatedTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, YdbDatabaseDedicatedTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


class YdbDatabaseServerless(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.YdbDatabaseServerless",
):
    '''Represents a {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_serverless yandex_ydb_database_serverless}.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id_: builtins.str,
        *,
        name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        location_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["YdbDatabaseServerlessTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        '''Create a new {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_serverless yandex_ydb_database_serverless} Resource.

        :param scope: The scope in which to define this construct.
        :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_serverless#name YdbDatabaseServerless#name}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_serverless#description YdbDatabaseServerless#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_serverless#folder_id YdbDatabaseServerless#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_serverless#id YdbDatabaseServerless#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_serverless#labels YdbDatabaseServerless#labels}.
        :param location_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_serverless#location_id YdbDatabaseServerless#location_id}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_serverless#timeouts YdbDatabaseServerless#timeouts}
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        '''
        config = YdbDatabaseServerlessConfig(
            name=name,
            description=description,
            folder_id=folder_id,
            id=id,
            labels=labels,
            location_id=location_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(self.__class__, self, [scope, id_, config])

    @jsii.member(jsii_name="putTimeouts")
    def put_timeouts(self, *, default: typing.Optional[builtins.str] = None) -> None:
        '''
        :param default: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_serverless#default YdbDatabaseServerless#default}.
        '''
        value = YdbDatabaseServerlessTimeouts(default=default)

        return typing.cast(None, jsii.invoke(self, "putTimeouts", [value]))

    @jsii.member(jsii_name="resetDescription")
    def reset_description(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDescription", []))

    @jsii.member(jsii_name="resetFolderId")
    def reset_folder_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetFolderId", []))

    @jsii.member(jsii_name="resetId")
    def reset_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetId", []))

    @jsii.member(jsii_name="resetLabels")
    def reset_labels(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLabels", []))

    @jsii.member(jsii_name="resetLocationId")
    def reset_location_id(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetLocationId", []))

    @jsii.member(jsii_name="resetTimeouts")
    def reset_timeouts(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "createdAt"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="databasePath")
    def database_path(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "databasePath"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="documentApiEndpoint")
    def document_api_endpoint(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "documentApiEndpoint"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> "YdbDatabaseServerlessTimeoutsOutputReference":
        return typing.cast("YdbDatabaseServerlessTimeoutsOutputReference", jsii.get(self, "timeouts"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tlsEnabled")
    def tls_enabled(self) -> cdktf.IResolvable:
        return typing.cast(cdktf.IResolvable, jsii.get(self, "tlsEnabled"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ydbApiEndpoint")
    def ydb_api_endpoint(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ydbApiEndpoint"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ydbFullEndpoint")
    def ydb_full_endpoint(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "ydbFullEndpoint"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionInput")
    def description_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "descriptionInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderIdInput")
    def folder_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "folderIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="idInput")
    def id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labelsInput")
    def labels_input(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "labelsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="locationIdInput")
    def location_id_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "locationIdInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeoutsInput")
    def timeouts_input(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, "YdbDatabaseServerlessTimeouts"]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, "YdbDatabaseServerlessTimeouts"]], jsii.get(self, "timeoutsInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def description(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "description"))

    @description.setter
    def description(self, value: builtins.str) -> None:
        jsii.set(self, "description", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="folderId")
    def folder_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "folderId"))

    @folder_id.setter
    def folder_id(self, value: builtins.str) -> None:
        jsii.set(self, "folderId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @id.setter
    def id(self, value: builtins.str) -> None:
        jsii.set(self, "id", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Mapping[builtins.str, builtins.str]:
        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "labels"))

    @labels.setter
    def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="locationId")
    def location_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "locationId"))

    @location_id.setter
    def location_id(self, value: builtins.str) -> None:
        jsii.set(self, "locationId", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.YdbDatabaseServerlessConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "description": "description",
        "folder_id": "folderId",
        "id": "id",
        "labels": "labels",
        "location_id": "locationId",
        "timeouts": "timeouts",
    },
)
class YdbDatabaseServerlessConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: builtins.str,
        description: typing.Optional[builtins.str] = None,
        folder_id: typing.Optional[builtins.str] = None,
        id: typing.Optional[builtins.str] = None,
        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        location_id: typing.Optional[builtins.str] = None,
        timeouts: typing.Optional["YdbDatabaseServerlessTimeouts"] = None,
    ) -> None:
        '''
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_serverless#name YdbDatabaseServerless#name}.
        :param description: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_serverless#description YdbDatabaseServerless#description}.
        :param folder_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_serverless#folder_id YdbDatabaseServerless#folder_id}.
        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_serverless#id YdbDatabaseServerless#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        :param labels: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_serverless#labels YdbDatabaseServerless#labels}.
        :param location_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_serverless#location_id YdbDatabaseServerless#location_id}.
        :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_serverless#timeouts YdbDatabaseServerless#timeouts}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = YdbDatabaseServerlessTimeouts(**timeouts)
        self._values: typing.Dict[str, typing.Any] = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if folder_id is not None:
            self._values["folder_id"] = folder_id
        if id is not None:
            self._values["id"] = id
        if labels is not None:
            self._values["labels"] = labels
        if location_id is not None:
            self._values["location_id"] = location_id
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)

    @builtins.property
    def name(self) -> builtins.str:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_serverless#name YdbDatabaseServerless#name}.'''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_serverless#description YdbDatabaseServerless#description}.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def folder_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_serverless#folder_id YdbDatabaseServerless#folder_id}.'''
        result = self._values.get("folder_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_serverless#id YdbDatabaseServerless#id}.

        Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
        If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
        '''
        result = self._values.get("id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_serverless#labels YdbDatabaseServerless#labels}.'''
        result = self._values.get("labels")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)

    @builtins.property
    def location_id(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_serverless#location_id YdbDatabaseServerless#location_id}.'''
        result = self._values.get("location_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def timeouts(self) -> typing.Optional["YdbDatabaseServerlessTimeouts"]:
        '''timeouts block.

        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_serverless#timeouts YdbDatabaseServerless#timeouts}
        '''
        result = self._values.get("timeouts")
        return typing.cast(typing.Optional["YdbDatabaseServerlessTimeouts"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "YdbDatabaseServerlessConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdktf/provider-yandex.YdbDatabaseServerlessTimeouts",
    jsii_struct_bases=[],
    name_mapping={"default": "default"},
)
class YdbDatabaseServerlessTimeouts:
    def __init__(self, *, default: typing.Optional[builtins.str] = None) -> None:
        '''
        :param default: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_serverless#default YdbDatabaseServerless#default}.
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if default is not None:
            self._values["default"] = default

    @builtins.property
    def default(self) -> typing.Optional[builtins.str]:
        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/yandex/r/ydb_database_serverless#default YdbDatabaseServerless#default}.'''
        result = self._values.get("default")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "YdbDatabaseServerlessTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class YdbDatabaseServerlessTimeoutsOutputReference(
    cdktf.ComplexObject,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdktf/provider-yandex.YdbDatabaseServerlessTimeoutsOutputReference",
):
    def __init__(
        self,
        terraform_resource: cdktf.IInterpolatingParent,
        terraform_attribute: builtins.str,
    ) -> None:
        '''
        :param terraform_resource: The parent resource.
        :param terraform_attribute: The attribute on the parent resource this class is referencing.
        '''
        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])

    @jsii.member(jsii_name="resetDefault")
    def reset_default(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetDefault", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="defaultInput")
    def default_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "defaultInput"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="default")
    def default(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "default"))

    @default.setter
    def default(self, value: builtins.str) -> None:
        jsii.set(self, "default", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="internalValue")
    def internal_value(
        self,
    ) -> typing.Optional[typing.Union[cdktf.IResolvable, YdbDatabaseServerlessTimeouts]]:
        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, YdbDatabaseServerlessTimeouts]], jsii.get(self, "internalValue"))

    @internal_value.setter
    def internal_value(
        self,
        value: typing.Optional[typing.Union[cdktf.IResolvable, YdbDatabaseServerlessTimeouts]],
    ) -> None:
        jsii.set(self, "internalValue", value)


__all__ = [
    "AlbBackendGroup",
    "AlbBackendGroupConfig",
    "AlbBackendGroupGrpcBackend",
    "AlbBackendGroupGrpcBackendHealthcheck",
    "AlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheck",
    "AlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheckOutputReference",
    "AlbBackendGroupGrpcBackendHealthcheckHttpHealthcheck",
    "AlbBackendGroupGrpcBackendHealthcheckHttpHealthcheckOutputReference",
    "AlbBackendGroupGrpcBackendHealthcheckOutputReference",
    "AlbBackendGroupGrpcBackendHealthcheckStreamHealthcheck",
    "AlbBackendGroupGrpcBackendHealthcheckStreamHealthcheckOutputReference",
    "AlbBackendGroupGrpcBackendList",
    "AlbBackendGroupGrpcBackendLoadBalancingConfig",
    "AlbBackendGroupGrpcBackendLoadBalancingConfigOutputReference",
    "AlbBackendGroupGrpcBackendOutputReference",
    "AlbBackendGroupGrpcBackendTls",
    "AlbBackendGroupGrpcBackendTlsOutputReference",
    "AlbBackendGroupGrpcBackendTlsValidationContext",
    "AlbBackendGroupGrpcBackendTlsValidationContextOutputReference",
    "AlbBackendGroupHttpBackend",
    "AlbBackendGroupHttpBackendHealthcheck",
    "AlbBackendGroupHttpBackendHealthcheckGrpcHealthcheck",
    "AlbBackendGroupHttpBackendHealthcheckGrpcHealthcheckOutputReference",
    "AlbBackendGroupHttpBackendHealthcheckHttpHealthcheck",
    "AlbBackendGroupHttpBackendHealthcheckHttpHealthcheckOutputReference",
    "AlbBackendGroupHttpBackendHealthcheckOutputReference",
    "AlbBackendGroupHttpBackendHealthcheckStreamHealthcheck",
    "AlbBackendGroupHttpBackendHealthcheckStreamHealthcheckOutputReference",
    "AlbBackendGroupHttpBackendList",
    "AlbBackendGroupHttpBackendLoadBalancingConfig",
    "AlbBackendGroupHttpBackendLoadBalancingConfigOutputReference",
    "AlbBackendGroupHttpBackendOutputReference",
    "AlbBackendGroupHttpBackendTls",
    "AlbBackendGroupHttpBackendTlsOutputReference",
    "AlbBackendGroupHttpBackendTlsValidationContext",
    "AlbBackendGroupHttpBackendTlsValidationContextOutputReference",
    "AlbBackendGroupStreamBackend",
    "AlbBackendGroupStreamBackendHealthcheck",
    "AlbBackendGroupStreamBackendHealthcheckGrpcHealthcheck",
    "AlbBackendGroupStreamBackendHealthcheckGrpcHealthcheckOutputReference",
    "AlbBackendGroupStreamBackendHealthcheckHttpHealthcheck",
    "AlbBackendGroupStreamBackendHealthcheckHttpHealthcheckOutputReference",
    "AlbBackendGroupStreamBackendHealthcheckOutputReference",
    "AlbBackendGroupStreamBackendHealthcheckStreamHealthcheck",
    "AlbBackendGroupStreamBackendHealthcheckStreamHealthcheckOutputReference",
    "AlbBackendGroupStreamBackendList",
    "AlbBackendGroupStreamBackendLoadBalancingConfig",
    "AlbBackendGroupStreamBackendLoadBalancingConfigOutputReference",
    "AlbBackendGroupStreamBackendOutputReference",
    "AlbBackendGroupStreamBackendTls",
    "AlbBackendGroupStreamBackendTlsOutputReference",
    "AlbBackendGroupStreamBackendTlsValidationContext",
    "AlbBackendGroupStreamBackendTlsValidationContextOutputReference",
    "AlbBackendGroupTimeouts",
    "AlbBackendGroupTimeoutsOutputReference",
    "AlbHttpRouter",
    "AlbHttpRouterConfig",
    "AlbHttpRouterTimeouts",
    "AlbHttpRouterTimeoutsOutputReference",
    "AlbLoadBalancer",
    "AlbLoadBalancerAllocationPolicy",
    "AlbLoadBalancerAllocationPolicyLocation",
    "AlbLoadBalancerAllocationPolicyLocationList",
    "AlbLoadBalancerAllocationPolicyLocationOutputReference",
    "AlbLoadBalancerAllocationPolicyOutputReference",
    "AlbLoadBalancerConfig",
    "AlbLoadBalancerListener",
    "AlbLoadBalancerListenerEndpoint",
    "AlbLoadBalancerListenerEndpointAddress",
    "AlbLoadBalancerListenerEndpointAddressExternalIpv4Address",
    "AlbLoadBalancerListenerEndpointAddressExternalIpv4AddressOutputReference",
    "AlbLoadBalancerListenerEndpointAddressExternalIpv6Address",
    "AlbLoadBalancerListenerEndpointAddressExternalIpv6AddressOutputReference",
    "AlbLoadBalancerListenerEndpointAddressInternalIpv4Address",
    "AlbLoadBalancerListenerEndpointAddressInternalIpv4AddressOutputReference",
    "AlbLoadBalancerListenerEndpointAddressList",
    "AlbLoadBalancerListenerEndpointAddressOutputReference",
    "AlbLoadBalancerListenerEndpointList",
    "AlbLoadBalancerListenerEndpointOutputReference",
    "AlbLoadBalancerListenerHttp",
    "AlbLoadBalancerListenerHttpHandler",
    "AlbLoadBalancerListenerHttpHandlerHttp2Options",
    "AlbLoadBalancerListenerHttpHandlerHttp2OptionsOutputReference",
    "AlbLoadBalancerListenerHttpHandlerOutputReference",
    "AlbLoadBalancerListenerHttpOutputReference",
    "AlbLoadBalancerListenerHttpRedirects",
    "AlbLoadBalancerListenerHttpRedirectsOutputReference",
    "AlbLoadBalancerListenerList",
    "AlbLoadBalancerListenerOutputReference",
    "AlbLoadBalancerListenerStream",
    "AlbLoadBalancerListenerStreamHandler",
    "AlbLoadBalancerListenerStreamHandlerOutputReference",
    "AlbLoadBalancerListenerStreamOutputReference",
    "AlbLoadBalancerListenerTls",
    "AlbLoadBalancerListenerTlsDefaultHandler",
    "AlbLoadBalancerListenerTlsDefaultHandlerHttpHandler",
    "AlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2Options",
    "AlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2OptionsOutputReference",
    "AlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerOutputReference",
    "AlbLoadBalancerListenerTlsDefaultHandlerOutputReference",
    "AlbLoadBalancerListenerTlsDefaultHandlerStreamHandler",
    "AlbLoadBalancerListenerTlsDefaultHandlerStreamHandlerOutputReference",
    "AlbLoadBalancerListenerTlsOutputReference",
    "AlbLoadBalancerListenerTlsSniHandler",
    "AlbLoadBalancerListenerTlsSniHandlerHandler",
    "AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandler",
    "AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2Options",
    "AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2OptionsOutputReference",
    "AlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerOutputReference",
    "AlbLoadBalancerListenerTlsSniHandlerHandlerOutputReference",
    "AlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandler",
    "AlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandlerOutputReference",
    "AlbLoadBalancerListenerTlsSniHandlerList",
    "AlbLoadBalancerListenerTlsSniHandlerOutputReference",
    "AlbLoadBalancerTimeouts",
    "AlbLoadBalancerTimeoutsOutputReference",
    "AlbTargetGroup",
    "AlbTargetGroupConfig",
    "AlbTargetGroupTarget",
    "AlbTargetGroupTargetList",
    "AlbTargetGroupTargetOutputReference",
    "AlbTargetGroupTimeouts",
    "AlbTargetGroupTimeoutsOutputReference",
    "AlbVirtualHost",
    "AlbVirtualHostConfig",
    "AlbVirtualHostModifyRequestHeaders",
    "AlbVirtualHostModifyRequestHeadersList",
    "AlbVirtualHostModifyRequestHeadersOutputReference",
    "AlbVirtualHostModifyResponseHeaders",
    "AlbVirtualHostModifyResponseHeadersList",
    "AlbVirtualHostModifyResponseHeadersOutputReference",
    "AlbVirtualHostRoute",
    "AlbVirtualHostRouteGrpcRoute",
    "AlbVirtualHostRouteGrpcRouteGrpcMatch",
    "AlbVirtualHostRouteGrpcRouteGrpcMatchFqmn",
    "AlbVirtualHostRouteGrpcRouteGrpcMatchFqmnOutputReference",
    "AlbVirtualHostRouteGrpcRouteGrpcMatchList",
    "AlbVirtualHostRouteGrpcRouteGrpcMatchOutputReference",
    "AlbVirtualHostRouteGrpcRouteGrpcRouteAction",
    "AlbVirtualHostRouteGrpcRouteGrpcRouteActionOutputReference",
    "AlbVirtualHostRouteGrpcRouteGrpcStatusResponseAction",
    "AlbVirtualHostRouteGrpcRouteGrpcStatusResponseActionOutputReference",
    "AlbVirtualHostRouteGrpcRouteOutputReference",
    "AlbVirtualHostRouteHttpRoute",
    "AlbVirtualHostRouteHttpRouteDirectResponseAction",
    "AlbVirtualHostRouteHttpRouteDirectResponseActionOutputReference",
    "AlbVirtualHostRouteHttpRouteHttpMatch",
    "AlbVirtualHostRouteHttpRouteHttpMatchList",
    "AlbVirtualHostRouteHttpRouteHttpMatchOutputReference",
    "AlbVirtualHostRouteHttpRouteHttpMatchPath",
    "AlbVirtualHostRouteHttpRouteHttpMatchPathOutputReference",
    "AlbVirtualHostRouteHttpRouteHttpRouteAction",
    "AlbVirtualHostRouteHttpRouteHttpRouteActionOutputReference",
    "AlbVirtualHostRouteHttpRouteOutputReference",
    "AlbVirtualHostRouteHttpRouteRedirectAction",
    "AlbVirtualHostRouteHttpRouteRedirectActionOutputReference",
    "AlbVirtualHostRouteList",
    "AlbVirtualHostRouteOutputReference",
    "AlbVirtualHostTimeouts",
    "AlbVirtualHostTimeoutsOutputReference",
    "ApiGateway",
    "ApiGatewayConfig",
    "ApiGatewayTimeouts",
    "ApiGatewayTimeoutsOutputReference",
    "CdnOriginGroup",
    "CdnOriginGroupConfig",
    "CdnOriginGroupOrigin",
    "CdnOriginGroupOriginList",
    "CdnOriginGroupOriginOutputReference",
    "CdnOriginGroupTimeouts",
    "CdnOriginGroupTimeoutsOutputReference",
    "CdnResource",
    "CdnResourceConfig",
    "CdnResourceOptions",
    "CdnResourceOptionsOutputReference",
    "CdnResourceSslCertificate",
    "CdnResourceSslCertificateOutputReference",
    "CdnResourceTimeouts",
    "CdnResourceTimeoutsOutputReference",
    "ComputeDisk",
    "ComputeDiskConfig",
    "ComputeDiskDiskPlacementPolicy",
    "ComputeDiskDiskPlacementPolicyOutputReference",
    "ComputeDiskPlacementGroup",
    "ComputeDiskPlacementGroupConfig",
    "ComputeDiskPlacementGroupTimeouts",
    "ComputeDiskPlacementGroupTimeoutsOutputReference",
    "ComputeDiskTimeouts",
    "ComputeDiskTimeoutsOutputReference",
    "ComputeImage",
    "ComputeImageConfig",
    "ComputeImageTimeouts",
    "ComputeImageTimeoutsOutputReference",
    "ComputeInstance",
    "ComputeInstanceBootDisk",
    "ComputeInstanceBootDiskInitializeParams",
    "ComputeInstanceBootDiskInitializeParamsOutputReference",
    "ComputeInstanceBootDiskOutputReference",
    "ComputeInstanceConfig",
    "ComputeInstanceGroup",
    "ComputeInstanceGroupAllocationPolicy",
    "ComputeInstanceGroupAllocationPolicyOutputReference",
    "ComputeInstanceGroupApplicationLoadBalancer",
    "ComputeInstanceGroupApplicationLoadBalancerOutputReference",
    "ComputeInstanceGroupConfig",
    "ComputeInstanceGroupDeployPolicy",
    "ComputeInstanceGroupDeployPolicyOutputReference",
    "ComputeInstanceGroupHealthCheck",
    "ComputeInstanceGroupHealthCheckHttpOptions",
    "ComputeInstanceGroupHealthCheckHttpOptionsList",
    "ComputeInstanceGroupHealthCheckHttpOptionsOutputReference",
    "ComputeInstanceGroupHealthCheckList",
    "ComputeInstanceGroupHealthCheckOutputReference",
    "ComputeInstanceGroupHealthCheckTcpOptions",
    "ComputeInstanceGroupHealthCheckTcpOptionsOutputReference",
    "ComputeInstanceGroupInstanceTemplate",
    "ComputeInstanceGroupInstanceTemplateBootDisk",
    "ComputeInstanceGroupInstanceTemplateBootDiskInitializeParams",
    "ComputeInstanceGroupInstanceTemplateBootDiskInitializeParamsOutputReference",
    "ComputeInstanceGroupInstanceTemplateBootDiskOutputReference",
    "ComputeInstanceGroupInstanceTemplateNetworkInterface",
    "ComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecord",
    "ComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecordList",
    "ComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecordOutputReference",
    "ComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecord",
    "ComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecordList",
    "ComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecordOutputReference",
    "ComputeInstanceGroupInstanceTemplateNetworkInterfaceList",
    "ComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecord",
    "ComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecordList",
    "ComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecordOutputReference",
    "ComputeInstanceGroupInstanceTemplateNetworkInterfaceOutputReference",
    "ComputeInstanceGroupInstanceTemplateNetworkSettings",
    "ComputeInstanceGroupInstanceTemplateNetworkSettingsList",
    "ComputeInstanceGroupInstanceTemplateNetworkSettingsOutputReference",
    "ComputeInstanceGroupInstanceTemplateOutputReference",
    "ComputeInstanceGroupInstanceTemplatePlacementPolicy",
    "ComputeInstanceGroupInstanceTemplatePlacementPolicyOutputReference",
    "ComputeInstanceGroupInstanceTemplateResources",
    "ComputeInstanceGroupInstanceTemplateResourcesOutputReference",
    "ComputeInstanceGroupInstanceTemplateSchedulingPolicy",
    "ComputeInstanceGroupInstanceTemplateSchedulingPolicyOutputReference",
    "ComputeInstanceGroupInstanceTemplateSecondaryDisk",
    "ComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParams",
    "ComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParamsOutputReference",
    "ComputeInstanceGroupInstanceTemplateSecondaryDiskList",
    "ComputeInstanceGroupInstanceTemplateSecondaryDiskOutputReference",
    "ComputeInstanceGroupInstances",
    "ComputeInstanceGroupInstancesList",
    "ComputeInstanceGroupInstancesNetworkInterface",
    "ComputeInstanceGroupInstancesNetworkInterfaceList",
    "ComputeInstanceGroupInstancesNetworkInterfaceOutputReference",
    "ComputeInstanceGroupInstancesOutputReference",
    "ComputeInstanceGroupLoadBalancer",
    "ComputeInstanceGroupLoadBalancerOutputReference",
    "ComputeInstanceGroupScalePolicy",
    "ComputeInstanceGroupScalePolicyAutoScale",
    "ComputeInstanceGroupScalePolicyAutoScaleCustomRule",
    "ComputeInstanceGroupScalePolicyAutoScaleCustomRuleList",
    "ComputeInstanceGroupScalePolicyAutoScaleCustomRuleOutputReference",
    "ComputeInstanceGroupScalePolicyAutoScaleOutputReference",
    "ComputeInstanceGroupScalePolicyFixedScale",
    "ComputeInstanceGroupScalePolicyFixedScaleOutputReference",
    "ComputeInstanceGroupScalePolicyOutputReference",
    "ComputeInstanceGroupScalePolicyTestAutoScale",
    "ComputeInstanceGroupScalePolicyTestAutoScaleCustomRule",
    "ComputeInstanceGroupScalePolicyTestAutoScaleCustomRuleList",
    "ComputeInstanceGroupScalePolicyTestAutoScaleCustomRuleOutputReference",
    "ComputeInstanceGroupScalePolicyTestAutoScaleOutputReference",
    "ComputeInstanceGroupTimeouts",
    "ComputeInstanceGroupTimeoutsOutputReference",
    "ComputeInstanceNetworkInterface",
    "ComputeInstanceNetworkInterfaceDnsRecord",
    "ComputeInstanceNetworkInterfaceDnsRecordList",
    "ComputeInstanceNetworkInterfaceDnsRecordOutputReference",
    "ComputeInstanceNetworkInterfaceIpv6DnsRecord",
    "ComputeInstanceNetworkInterfaceIpv6DnsRecordList",
    "ComputeInstanceNetworkInterfaceIpv6DnsRecordOutputReference",
    "ComputeInstanceNetworkInterfaceList",
    "ComputeInstanceNetworkInterfaceNatDnsRecord",
    "ComputeInstanceNetworkInterfaceNatDnsRecordList",
    "ComputeInstanceNetworkInterfaceNatDnsRecordOutputReference",
    "ComputeInstanceNetworkInterfaceOutputReference",
    "ComputeInstancePlacementPolicy",
    "ComputeInstancePlacementPolicyHostAffinityRules",
    "ComputeInstancePlacementPolicyHostAffinityRulesList",
    "ComputeInstancePlacementPolicyHostAffinityRulesOutputReference",
    "ComputeInstancePlacementPolicyOutputReference",
    "ComputeInstanceResources",
    "ComputeInstanceResourcesOutputReference",
    "ComputeInstanceSchedulingPolicy",
    "ComputeInstanceSchedulingPolicyOutputReference",
    "ComputeInstanceSecondaryDisk",
    "ComputeInstanceSecondaryDiskList",
    "ComputeInstanceSecondaryDiskOutputReference",
    "ComputeInstanceTimeouts",
    "ComputeInstanceTimeoutsOutputReference",
    "ComputePlacementGroup",
    "ComputePlacementGroupConfig",
    "ComputePlacementGroupTimeouts",
    "ComputePlacementGroupTimeoutsOutputReference",
    "ComputeSnapshot",
    "ComputeSnapshotConfig",
    "ComputeSnapshotTimeouts",
    "ComputeSnapshotTimeoutsOutputReference",
    "ContainerRegistry",
    "ContainerRegistryConfig",
    "ContainerRegistryIamBinding",
    "ContainerRegistryIamBindingConfig",
    "ContainerRegistryTimeouts",
    "ContainerRegistryTimeoutsOutputReference",
    "ContainerRepository",
    "ContainerRepositoryConfig",
    "ContainerRepositoryIamBinding",
    "ContainerRepositoryIamBindingConfig",
    "ContainerRepositoryTimeouts",
    "ContainerRepositoryTimeoutsOutputReference",
    "DataYandexAlbBackendGroup",
    "DataYandexAlbBackendGroupConfig",
    "DataYandexAlbBackendGroupGrpcBackend",
    "DataYandexAlbBackendGroupGrpcBackendHealthcheck",
    "DataYandexAlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheck",
    "DataYandexAlbBackendGroupGrpcBackendHealthcheckGrpcHealthcheckOutputReference",
    "DataYandexAlbBackendGroupGrpcBackendHealthcheckHttpHealthcheck",
    "DataYandexAlbBackendGroupGrpcBackendHealthcheckHttpHealthcheckOutputReference",
    "DataYandexAlbBackendGroupGrpcBackendHealthcheckOutputReference",
    "DataYandexAlbBackendGroupGrpcBackendHealthcheckStreamHealthcheck",
    "DataYandexAlbBackendGroupGrpcBackendHealthcheckStreamHealthcheckOutputReference",
    "DataYandexAlbBackendGroupGrpcBackendList",
    "DataYandexAlbBackendGroupGrpcBackendLoadBalancingConfig",
    "DataYandexAlbBackendGroupGrpcBackendLoadBalancingConfigOutputReference",
    "DataYandexAlbBackendGroupGrpcBackendOutputReference",
    "DataYandexAlbBackendGroupGrpcBackendTls",
    "DataYandexAlbBackendGroupGrpcBackendTlsOutputReference",
    "DataYandexAlbBackendGroupGrpcBackendTlsValidationContext",
    "DataYandexAlbBackendGroupGrpcBackendTlsValidationContextOutputReference",
    "DataYandexAlbBackendGroupHttpBackend",
    "DataYandexAlbBackendGroupHttpBackendHealthcheck",
    "DataYandexAlbBackendGroupHttpBackendHealthcheckGrpcHealthcheck",
    "DataYandexAlbBackendGroupHttpBackendHealthcheckGrpcHealthcheckOutputReference",
    "DataYandexAlbBackendGroupHttpBackendHealthcheckHttpHealthcheck",
    "DataYandexAlbBackendGroupHttpBackendHealthcheckHttpHealthcheckOutputReference",
    "DataYandexAlbBackendGroupHttpBackendHealthcheckOutputReference",
    "DataYandexAlbBackendGroupHttpBackendHealthcheckStreamHealthcheck",
    "DataYandexAlbBackendGroupHttpBackendHealthcheckStreamHealthcheckOutputReference",
    "DataYandexAlbBackendGroupHttpBackendList",
    "DataYandexAlbBackendGroupHttpBackendLoadBalancingConfig",
    "DataYandexAlbBackendGroupHttpBackendLoadBalancingConfigOutputReference",
    "DataYandexAlbBackendGroupHttpBackendOutputReference",
    "DataYandexAlbBackendGroupHttpBackendTls",
    "DataYandexAlbBackendGroupHttpBackendTlsOutputReference",
    "DataYandexAlbBackendGroupHttpBackendTlsValidationContext",
    "DataYandexAlbBackendGroupHttpBackendTlsValidationContextOutputReference",
    "DataYandexAlbBackendGroupStreamBackend",
    "DataYandexAlbBackendGroupStreamBackendHealthcheck",
    "DataYandexAlbBackendGroupStreamBackendHealthcheckGrpcHealthcheck",
    "DataYandexAlbBackendGroupStreamBackendHealthcheckGrpcHealthcheckOutputReference",
    "DataYandexAlbBackendGroupStreamBackendHealthcheckHttpHealthcheck",
    "DataYandexAlbBackendGroupStreamBackendHealthcheckHttpHealthcheckOutputReference",
    "DataYandexAlbBackendGroupStreamBackendHealthcheckOutputReference",
    "DataYandexAlbBackendGroupStreamBackendHealthcheckStreamHealthcheck",
    "DataYandexAlbBackendGroupStreamBackendHealthcheckStreamHealthcheckOutputReference",
    "DataYandexAlbBackendGroupStreamBackendList",
    "DataYandexAlbBackendGroupStreamBackendLoadBalancingConfig",
    "DataYandexAlbBackendGroupStreamBackendLoadBalancingConfigOutputReference",
    "DataYandexAlbBackendGroupStreamBackendOutputReference",
    "DataYandexAlbBackendGroupStreamBackendTls",
    "DataYandexAlbBackendGroupStreamBackendTlsOutputReference",
    "DataYandexAlbBackendGroupStreamBackendTlsValidationContext",
    "DataYandexAlbBackendGroupStreamBackendTlsValidationContextOutputReference",
    "DataYandexAlbHttpRouter",
    "DataYandexAlbHttpRouterConfig",
    "DataYandexAlbLoadBalancer",
    "DataYandexAlbLoadBalancerAllocationPolicy",
    "DataYandexAlbLoadBalancerAllocationPolicyList",
    "DataYandexAlbLoadBalancerAllocationPolicyLocation",
    "DataYandexAlbLoadBalancerAllocationPolicyLocationList",
    "DataYandexAlbLoadBalancerAllocationPolicyLocationOutputReference",
    "DataYandexAlbLoadBalancerAllocationPolicyOutputReference",
    "DataYandexAlbLoadBalancerConfig",
    "DataYandexAlbLoadBalancerListener",
    "DataYandexAlbLoadBalancerListenerEndpoint",
    "DataYandexAlbLoadBalancerListenerEndpointAddress",
    "DataYandexAlbLoadBalancerListenerEndpointAddressExternalIpv4Address",
    "DataYandexAlbLoadBalancerListenerEndpointAddressExternalIpv4AddressList",
    "DataYandexAlbLoadBalancerListenerEndpointAddressExternalIpv4AddressOutputReference",
    "DataYandexAlbLoadBalancerListenerEndpointAddressExternalIpv6Address",
    "DataYandexAlbLoadBalancerListenerEndpointAddressExternalIpv6AddressList",
    "DataYandexAlbLoadBalancerListenerEndpointAddressExternalIpv6AddressOutputReference",
    "DataYandexAlbLoadBalancerListenerEndpointAddressInternalIpv4Address",
    "DataYandexAlbLoadBalancerListenerEndpointAddressInternalIpv4AddressList",
    "DataYandexAlbLoadBalancerListenerEndpointAddressInternalIpv4AddressOutputReference",
    "DataYandexAlbLoadBalancerListenerEndpointAddressList",
    "DataYandexAlbLoadBalancerListenerEndpointAddressOutputReference",
    "DataYandexAlbLoadBalancerListenerEndpointList",
    "DataYandexAlbLoadBalancerListenerEndpointOutputReference",
    "DataYandexAlbLoadBalancerListenerHttp",
    "DataYandexAlbLoadBalancerListenerHttpHandler",
    "DataYandexAlbLoadBalancerListenerHttpHandlerHttp2Options",
    "DataYandexAlbLoadBalancerListenerHttpHandlerHttp2OptionsList",
    "DataYandexAlbLoadBalancerListenerHttpHandlerHttp2OptionsOutputReference",
    "DataYandexAlbLoadBalancerListenerHttpHandlerList",
    "DataYandexAlbLoadBalancerListenerHttpHandlerOutputReference",
    "DataYandexAlbLoadBalancerListenerHttpList",
    "DataYandexAlbLoadBalancerListenerHttpOutputReference",
    "DataYandexAlbLoadBalancerListenerHttpRedirects",
    "DataYandexAlbLoadBalancerListenerHttpRedirectsList",
    "DataYandexAlbLoadBalancerListenerHttpRedirectsOutputReference",
    "DataYandexAlbLoadBalancerListenerList",
    "DataYandexAlbLoadBalancerListenerOutputReference",
    "DataYandexAlbLoadBalancerListenerStream",
    "DataYandexAlbLoadBalancerListenerStreamHandler",
    "DataYandexAlbLoadBalancerListenerStreamHandlerList",
    "DataYandexAlbLoadBalancerListenerStreamHandlerOutputReference",
    "DataYandexAlbLoadBalancerListenerStreamList",
    "DataYandexAlbLoadBalancerListenerStreamOutputReference",
    "DataYandexAlbLoadBalancerListenerTls",
    "DataYandexAlbLoadBalancerListenerTlsDefaultHandler",
    "DataYandexAlbLoadBalancerListenerTlsDefaultHandlerHttpHandler",
    "DataYandexAlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2Options",
    "DataYandexAlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2OptionsList",
    "DataYandexAlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerHttp2OptionsOutputReference",
    "DataYandexAlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerList",
    "DataYandexAlbLoadBalancerListenerTlsDefaultHandlerHttpHandlerOutputReference",
    "DataYandexAlbLoadBalancerListenerTlsDefaultHandlerList",
    "DataYandexAlbLoadBalancerListenerTlsDefaultHandlerOutputReference",
    "DataYandexAlbLoadBalancerListenerTlsDefaultHandlerStreamHandler",
    "DataYandexAlbLoadBalancerListenerTlsDefaultHandlerStreamHandlerList",
    "DataYandexAlbLoadBalancerListenerTlsDefaultHandlerStreamHandlerOutputReference",
    "DataYandexAlbLoadBalancerListenerTlsList",
    "DataYandexAlbLoadBalancerListenerTlsOutputReference",
    "DataYandexAlbLoadBalancerListenerTlsSniHandler",
    "DataYandexAlbLoadBalancerListenerTlsSniHandlerHandler",
    "DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandler",
    "DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2Options",
    "DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2OptionsList",
    "DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerHttp2OptionsOutputReference",
    "DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerList",
    "DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerHttpHandlerOutputReference",
    "DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerList",
    "DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerOutputReference",
    "DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandler",
    "DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandlerList",
    "DataYandexAlbLoadBalancerListenerTlsSniHandlerHandlerStreamHandlerOutputReference",
    "DataYandexAlbLoadBalancerListenerTlsSniHandlerList",
    "DataYandexAlbLoadBalancerListenerTlsSniHandlerOutputReference",
    "DataYandexAlbLoadBalancerTimeouts",
    "DataYandexAlbLoadBalancerTimeoutsOutputReference",
    "DataYandexAlbTargetGroup",
    "DataYandexAlbTargetGroupConfig",
    "DataYandexAlbTargetGroupTarget",
    "DataYandexAlbTargetGroupTargetList",
    "DataYandexAlbTargetGroupTargetOutputReference",
    "DataYandexAlbVirtualHost",
    "DataYandexAlbVirtualHostConfig",
    "DataYandexAlbVirtualHostModifyRequestHeaders",
    "DataYandexAlbVirtualHostModifyRequestHeadersList",
    "DataYandexAlbVirtualHostModifyRequestHeadersOutputReference",
    "DataYandexAlbVirtualHostModifyResponseHeaders",
    "DataYandexAlbVirtualHostModifyResponseHeadersList",
    "DataYandexAlbVirtualHostModifyResponseHeadersOutputReference",
    "DataYandexAlbVirtualHostRoute",
    "DataYandexAlbVirtualHostRouteGrpcRoute",
    "DataYandexAlbVirtualHostRouteGrpcRouteGrpcMatch",
    "DataYandexAlbVirtualHostRouteGrpcRouteGrpcMatchFqmn",
    "DataYandexAlbVirtualHostRouteGrpcRouteGrpcMatchFqmnList",
    "DataYandexAlbVirtualHostRouteGrpcRouteGrpcMatchFqmnOutputReference",
    "DataYandexAlbVirtualHostRouteGrpcRouteGrpcMatchList",
    "DataYandexAlbVirtualHostRouteGrpcRouteGrpcMatchOutputReference",
    "DataYandexAlbVirtualHostRouteGrpcRouteGrpcRouteAction",
    "DataYandexAlbVirtualHostRouteGrpcRouteGrpcRouteActionList",
    "DataYandexAlbVirtualHostRouteGrpcRouteGrpcRouteActionOutputReference",
    "DataYandexAlbVirtualHostRouteGrpcRouteGrpcStatusResponseAction",
    "DataYandexAlbVirtualHostRouteGrpcRouteGrpcStatusResponseActionList",
    "DataYandexAlbVirtualHostRouteGrpcRouteGrpcStatusResponseActionOutputReference",
    "DataYandexAlbVirtualHostRouteGrpcRouteList",
    "DataYandexAlbVirtualHostRouteGrpcRouteOutputReference",
    "DataYandexAlbVirtualHostRouteHttpRoute",
    "DataYandexAlbVirtualHostRouteHttpRouteDirectResponseAction",
    "DataYandexAlbVirtualHostRouteHttpRouteDirectResponseActionList",
    "DataYandexAlbVirtualHostRouteHttpRouteDirectResponseActionOutputReference",
    "DataYandexAlbVirtualHostRouteHttpRouteHttpMatch",
    "DataYandexAlbVirtualHostRouteHttpRouteHttpMatchList",
    "DataYandexAlbVirtualHostRouteHttpRouteHttpMatchOutputReference",
    "DataYandexAlbVirtualHostRouteHttpRouteHttpMatchPath",
    "DataYandexAlbVirtualHostRouteHttpRouteHttpMatchPathList",
    "DataYandexAlbVirtualHostRouteHttpRouteHttpMatchPathOutputReference",
    "DataYandexAlbVirtualHostRouteHttpRouteHttpRouteAction",
    "DataYandexAlbVirtualHostRouteHttpRouteHttpRouteActionList",
    "DataYandexAlbVirtualHostRouteHttpRouteHttpRouteActionOutputReference",
    "DataYandexAlbVirtualHostRouteHttpRouteList",
    "DataYandexAlbVirtualHostRouteHttpRouteOutputReference",
    "DataYandexAlbVirtualHostRouteHttpRouteRedirectAction",
    "DataYandexAlbVirtualHostRouteHttpRouteRedirectActionList",
    "DataYandexAlbVirtualHostRouteHttpRouteRedirectActionOutputReference",
    "DataYandexAlbVirtualHostRouteList",
    "DataYandexAlbVirtualHostRouteOutputReference",
    "DataYandexApiGateway",
    "DataYandexApiGatewayConfig",
    "DataYandexCdnOriginGroup",
    "DataYandexCdnOriginGroupConfig",
    "DataYandexCdnOriginGroupOrigin",
    "DataYandexCdnOriginGroupOriginList",
    "DataYandexCdnOriginGroupOriginOutputReference",
    "DataYandexCdnResource",
    "DataYandexCdnResourceConfig",
    "DataYandexCdnResourceOptions",
    "DataYandexCdnResourceOptionsOutputReference",
    "DataYandexCdnResourceSslCertificate",
    "DataYandexCdnResourceSslCertificateOutputReference",
    "DataYandexClientConfig",
    "DataYandexClientConfigConfig",
    "DataYandexComputeDisk",
    "DataYandexComputeDiskConfig",
    "DataYandexComputeDiskDiskPlacementPolicy",
    "DataYandexComputeDiskDiskPlacementPolicyOutputReference",
    "DataYandexComputeDiskPlacementGroup",
    "DataYandexComputeDiskPlacementGroupConfig",
    "DataYandexComputeImage",
    "DataYandexComputeImageConfig",
    "DataYandexComputeInstance",
    "DataYandexComputeInstanceBootDisk",
    "DataYandexComputeInstanceBootDiskInitializeParams",
    "DataYandexComputeInstanceBootDiskInitializeParamsList",
    "DataYandexComputeInstanceBootDiskInitializeParamsOutputReference",
    "DataYandexComputeInstanceBootDiskList",
    "DataYandexComputeInstanceBootDiskOutputReference",
    "DataYandexComputeInstanceConfig",
    "DataYandexComputeInstanceGroup",
    "DataYandexComputeInstanceGroupAllocationPolicy",
    "DataYandexComputeInstanceGroupAllocationPolicyList",
    "DataYandexComputeInstanceGroupAllocationPolicyOutputReference",
    "DataYandexComputeInstanceGroupApplicationBalancerState",
    "DataYandexComputeInstanceGroupApplicationBalancerStateList",
    "DataYandexComputeInstanceGroupApplicationBalancerStateOutputReference",
    "DataYandexComputeInstanceGroupApplicationLoadBalancer",
    "DataYandexComputeInstanceGroupApplicationLoadBalancerList",
    "DataYandexComputeInstanceGroupApplicationLoadBalancerOutputReference",
    "DataYandexComputeInstanceGroupConfig",
    "DataYandexComputeInstanceGroupDeployPolicy",
    "DataYandexComputeInstanceGroupDeployPolicyList",
    "DataYandexComputeInstanceGroupDeployPolicyOutputReference",
    "DataYandexComputeInstanceGroupHealthCheck",
    "DataYandexComputeInstanceGroupHealthCheckHttpOptions",
    "DataYandexComputeInstanceGroupHealthCheckHttpOptionsList",
    "DataYandexComputeInstanceGroupHealthCheckHttpOptionsOutputReference",
    "DataYandexComputeInstanceGroupHealthCheckList",
    "DataYandexComputeInstanceGroupHealthCheckOutputReference",
    "DataYandexComputeInstanceGroupHealthCheckTcpOptions",
    "DataYandexComputeInstanceGroupHealthCheckTcpOptionsList",
    "DataYandexComputeInstanceGroupHealthCheckTcpOptionsOutputReference",
    "DataYandexComputeInstanceGroupInstanceTemplate",
    "DataYandexComputeInstanceGroupInstanceTemplateBootDisk",
    "DataYandexComputeInstanceGroupInstanceTemplateBootDiskInitializeParams",
    "DataYandexComputeInstanceGroupInstanceTemplateBootDiskInitializeParamsList",
    "DataYandexComputeInstanceGroupInstanceTemplateBootDiskInitializeParamsOutputReference",
    "DataYandexComputeInstanceGroupInstanceTemplateBootDiskList",
    "DataYandexComputeInstanceGroupInstanceTemplateBootDiskOutputReference",
    "DataYandexComputeInstanceGroupInstanceTemplateList",
    "DataYandexComputeInstanceGroupInstanceTemplateNetworkInterface",
    "DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecord",
    "DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecordList",
    "DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceDnsRecordOutputReference",
    "DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecord",
    "DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecordList",
    "DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceIpv6DnsRecordOutputReference",
    "DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceList",
    "DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecord",
    "DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecordList",
    "DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceNatDnsRecordOutputReference",
    "DataYandexComputeInstanceGroupInstanceTemplateNetworkInterfaceOutputReference",
    "DataYandexComputeInstanceGroupInstanceTemplateNetworkSettings",
    "DataYandexComputeInstanceGroupInstanceTemplateNetworkSettingsList",
    "DataYandexComputeInstanceGroupInstanceTemplateNetworkSettingsOutputReference",
    "DataYandexComputeInstanceGroupInstanceTemplateOutputReference",
    "DataYandexComputeInstanceGroupInstanceTemplatePlacementPolicy",
    "DataYandexComputeInstanceGroupInstanceTemplatePlacementPolicyList",
    "DataYandexComputeInstanceGroupInstanceTemplatePlacementPolicyOutputReference",
    "DataYandexComputeInstanceGroupInstanceTemplateResources",
    "DataYandexComputeInstanceGroupInstanceTemplateResourcesList",
    "DataYandexComputeInstanceGroupInstanceTemplateResourcesOutputReference",
    "DataYandexComputeInstanceGroupInstanceTemplateSchedulingPolicy",
    "DataYandexComputeInstanceGroupInstanceTemplateSchedulingPolicyList",
    "DataYandexComputeInstanceGroupInstanceTemplateSchedulingPolicyOutputReference",
    "DataYandexComputeInstanceGroupInstanceTemplateSecondaryDisk",
    "DataYandexComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParams",
    "DataYandexComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParamsList",
    "DataYandexComputeInstanceGroupInstanceTemplateSecondaryDiskInitializeParamsOutputReference",
    "DataYandexComputeInstanceGroupInstanceTemplateSecondaryDiskList",
    "DataYandexComputeInstanceGroupInstanceTemplateSecondaryDiskOutputReference",
    "DataYandexComputeInstanceGroupInstances",
    "DataYandexComputeInstanceGroupInstancesList",
    "DataYandexComputeInstanceGroupInstancesNetworkInterface",
    "DataYandexComputeInstanceGroupInstancesNetworkInterfaceList",
    "DataYandexComputeInstanceGroupInstancesNetworkInterfaceOutputReference",
    "DataYandexComputeInstanceGroupInstancesOutputReference",
    "DataYandexComputeInstanceGroupLoadBalancer",
    "DataYandexComputeInstanceGroupLoadBalancerList",
    "DataYandexComputeInstanceGroupLoadBalancerOutputReference",
    "DataYandexComputeInstanceGroupLoadBalancerState",
    "DataYandexComputeInstanceGroupLoadBalancerStateList",
    "DataYandexComputeInstanceGroupLoadBalancerStateOutputReference",
    "DataYandexComputeInstanceGroupScalePolicy",
    "DataYandexComputeInstanceGroupScalePolicyAutoScale",
    "DataYandexComputeInstanceGroupScalePolicyAutoScaleCustomRule",
    "DataYandexComputeInstanceGroupScalePolicyAutoScaleCustomRuleList",
    "DataYandexComputeInstanceGroupScalePolicyAutoScaleCustomRuleOutputReference",
    "DataYandexComputeInstanceGroupScalePolicyAutoScaleList",
    "DataYandexComputeInstanceGroupScalePolicyAutoScaleOutputReference",
    "DataYandexComputeInstanceGroupScalePolicyFixedScale",
    "DataYandexComputeInstanceGroupScalePolicyFixedScaleList",
    "DataYandexComputeInstanceGroupScalePolicyFixedScaleOutputReference",
    "DataYandexComputeInstanceGroupScalePolicyList",
    "DataYandexComputeInstanceGroupScalePolicyOutputReference",
    "DataYandexComputeInstanceGroupScalePolicyTestAutoScale",
    "DataYandexComputeInstanceGroupScalePolicyTestAutoScaleCustomRule",
    "DataYandexComputeInstanceGroupScalePolicyTestAutoScaleCustomRuleList",
    "DataYandexComputeInstanceGroupScalePolicyTestAutoScaleCustomRuleOutputReference",
    "DataYandexComputeInstanceGroupScalePolicyTestAutoScaleList",
    "DataYandexComputeInstanceGroupScalePolicyTestAutoScaleOutputReference",
    "DataYandexComputeInstanceNetworkInterface",
    "DataYandexComputeInstanceNetworkInterfaceDnsRecord",
    "DataYandexComputeInstanceNetworkInterfaceDnsRecordList",
    "DataYandexComputeInstanceNetworkInterfaceDnsRecordOutputReference",
    "DataYandexComputeInstanceNetworkInterfaceIpv6DnsRecord",
    "DataYandexComputeInstanceNetworkInterfaceIpv6DnsRecordList",
    "DataYandexComputeInstanceNetworkInterfaceIpv6DnsRecordOutputReference",
    "DataYandexComputeInstanceNetworkInterfaceList",
    "DataYandexComputeInstanceNetworkInterfaceNatDnsRecord",
    "DataYandexComputeInstanceNetworkInterfaceNatDnsRecordList",
    "DataYandexComputeInstanceNetworkInterfaceNatDnsRecordOutputReference",
    "DataYandexComputeInstanceNetworkInterfaceOutputReference",
    "DataYandexComputeInstancePlacementPolicy",
    "DataYandexComputeInstancePlacementPolicyHostAffinityRules",
    "DataYandexComputeInstancePlacementPolicyHostAffinityRulesList",
    "DataYandexComputeInstancePlacementPolicyHostAffinityRulesOutputReference",
    "DataYandexComputeInstancePlacementPolicyOutputReference",
    "DataYandexComputeInstanceResources",
    "DataYandexComputeInstanceResourcesList",
    "DataYandexComputeInstanceResourcesOutputReference",
    "DataYandexComputeInstanceSchedulingPolicy",
    "DataYandexComputeInstanceSchedulingPolicyList",
    "DataYandexComputeInstanceSchedulingPolicyOutputReference",
    "DataYandexComputeInstanceSecondaryDisk",
    "DataYandexComputeInstanceSecondaryDiskList",
    "DataYandexComputeInstanceSecondaryDiskOutputReference",
    "DataYandexComputePlacementGroup",
    "DataYandexComputePlacementGroupConfig",
    "DataYandexComputeSnapshot",
    "DataYandexComputeSnapshotConfig",
    "DataYandexContainerRegistry",
    "DataYandexContainerRegistryConfig",
    "DataYandexContainerRepository",
    "DataYandexContainerRepositoryConfig",
    "DataYandexDataprocCluster",
    "DataYandexDataprocClusterClusterConfig",
    "DataYandexDataprocClusterClusterConfigHadoop",
    "DataYandexDataprocClusterClusterConfigHadoopList",
    "DataYandexDataprocClusterClusterConfigHadoopOutputReference",
    "DataYandexDataprocClusterClusterConfigList",
    "DataYandexDataprocClusterClusterConfigOutputReference",
    "DataYandexDataprocClusterClusterConfigSubclusterSpec",
    "DataYandexDataprocClusterClusterConfigSubclusterSpecAutoscalingConfig",
    "DataYandexDataprocClusterClusterConfigSubclusterSpecAutoscalingConfigList",
    "DataYandexDataprocClusterClusterConfigSubclusterSpecAutoscalingConfigOutputReference",
    "DataYandexDataprocClusterClusterConfigSubclusterSpecList",
    "DataYandexDataprocClusterClusterConfigSubclusterSpecOutputReference",
    "DataYandexDataprocClusterClusterConfigSubclusterSpecResources",
    "DataYandexDataprocClusterClusterConfigSubclusterSpecResourcesList",
    "DataYandexDataprocClusterClusterConfigSubclusterSpecResourcesOutputReference",
    "DataYandexDataprocClusterConfig",
    "DataYandexDnsZone",
    "DataYandexDnsZoneConfig",
    "DataYandexDnsZoneTimeouts",
    "DataYandexDnsZoneTimeoutsOutputReference",
    "DataYandexFunction",
    "DataYandexFunctionConfig",
    "DataYandexFunctionScalingPolicy",
    "DataYandexFunctionScalingPolicyConfig",
    "DataYandexFunctionScalingPolicyPolicy",
    "DataYandexFunctionScalingPolicyPolicyList",
    "DataYandexFunctionScalingPolicyPolicyOutputReference",
    "DataYandexFunctionTrigger",
    "DataYandexFunctionTriggerConfig",
    "DataYandexFunctionTriggerDlq",
    "DataYandexFunctionTriggerDlqList",
    "DataYandexFunctionTriggerDlqOutputReference",
    "DataYandexFunctionTriggerFunction",
    "DataYandexFunctionTriggerFunctionList",
    "DataYandexFunctionTriggerFunctionOutputReference",
    "DataYandexFunctionTriggerIot",
    "DataYandexFunctionTriggerIotList",
    "DataYandexFunctionTriggerIotOutputReference",
    "DataYandexFunctionTriggerLogGroup",
    "DataYandexFunctionTriggerLogGroupList",
    "DataYandexFunctionTriggerLogGroupOutputReference",
    "DataYandexFunctionTriggerLogging",
    "DataYandexFunctionTriggerLoggingList",
    "DataYandexFunctionTriggerLoggingOutputReference",
    "DataYandexFunctionTriggerMessageQueue",
    "DataYandexFunctionTriggerMessageQueueList",
    "DataYandexFunctionTriggerMessageQueueOutputReference",
    "DataYandexFunctionTriggerObjectStorage",
    "DataYandexFunctionTriggerObjectStorageList",
    "DataYandexFunctionTriggerObjectStorageOutputReference",
    "DataYandexFunctionTriggerTimer",
    "DataYandexFunctionTriggerTimerList",
    "DataYandexFunctionTriggerTimerOutputReference",
    "DataYandexIamPolicy",
    "DataYandexIamPolicyBinding",
    "DataYandexIamPolicyBindingList",
    "DataYandexIamPolicyBindingOutputReference",
    "DataYandexIamPolicyConfig",
    "DataYandexIamRole",
    "DataYandexIamRoleConfig",
    "DataYandexIamServiceAccount",
    "DataYandexIamServiceAccountConfig",
    "DataYandexIamUser",
    "DataYandexIamUserConfig",
    "DataYandexIotCoreDevice",
    "DataYandexIotCoreDeviceConfig",
    "DataYandexIotCoreRegistry",
    "DataYandexIotCoreRegistryConfig",
    "DataYandexKubernetesCluster",
    "DataYandexKubernetesClusterConfig",
    "DataYandexKubernetesClusterKmsProvider",
    "DataYandexKubernetesClusterKmsProviderList",
    "DataYandexKubernetesClusterKmsProviderOutputReference",
    "DataYandexKubernetesClusterMaster",
    "DataYandexKubernetesClusterMasterList",
    "DataYandexKubernetesClusterMasterMaintenancePolicy",
    "DataYandexKubernetesClusterMasterMaintenancePolicyList",
    "DataYandexKubernetesClusterMasterMaintenancePolicyMaintenanceWindow",
    "DataYandexKubernetesClusterMasterMaintenancePolicyMaintenanceWindowList",
    "DataYandexKubernetesClusterMasterMaintenancePolicyMaintenanceWindowOutputReference",
    "DataYandexKubernetesClusterMasterMaintenancePolicyOutputReference",
    "DataYandexKubernetesClusterMasterOutputReference",
    "DataYandexKubernetesClusterMasterRegional",
    "DataYandexKubernetesClusterMasterRegionalList",
    "DataYandexKubernetesClusterMasterRegionalOutputReference",
    "DataYandexKubernetesClusterMasterVersionInfo",
    "DataYandexKubernetesClusterMasterVersionInfoList",
    "DataYandexKubernetesClusterMasterVersionInfoOutputReference",
    "DataYandexKubernetesClusterMasterZonal",
    "DataYandexKubernetesClusterMasterZonalList",
    "DataYandexKubernetesClusterMasterZonalOutputReference",
    "DataYandexKubernetesClusterNetworkImplementation",
    "DataYandexKubernetesClusterNetworkImplementationCilium",
    "DataYandexKubernetesClusterNetworkImplementationCiliumList",
    "DataYandexKubernetesClusterNetworkImplementationCiliumOutputReference",
    "DataYandexKubernetesClusterNetworkImplementationList",
    "DataYandexKubernetesClusterNetworkImplementationOutputReference",
    "DataYandexKubernetesNodeGroup",
    "DataYandexKubernetesNodeGroupAllocationPolicy",
    "DataYandexKubernetesNodeGroupAllocationPolicyList",
    "DataYandexKubernetesNodeGroupAllocationPolicyLocation",
    "DataYandexKubernetesNodeGroupAllocationPolicyLocationList",
    "DataYandexKubernetesNodeGroupAllocationPolicyLocationOutputReference",
    "DataYandexKubernetesNodeGroupAllocationPolicyOutputReference",
    "DataYandexKubernetesNodeGroupConfig",
    "DataYandexKubernetesNodeGroupDeployPolicy",
    "DataYandexKubernetesNodeGroupDeployPolicyList",
    "DataYandexKubernetesNodeGroupDeployPolicyOutputReference",
    "DataYandexKubernetesNodeGroupInstanceTemplate",
    "DataYandexKubernetesNodeGroupInstanceTemplateBootDisk",
    "DataYandexKubernetesNodeGroupInstanceTemplateBootDiskList",
    "DataYandexKubernetesNodeGroupInstanceTemplateBootDiskOutputReference",
    "DataYandexKubernetesNodeGroupInstanceTemplateContainerRuntime",
    "DataYandexKubernetesNodeGroupInstanceTemplateContainerRuntimeList",
    "DataYandexKubernetesNodeGroupInstanceTemplateContainerRuntimeOutputReference",
    "DataYandexKubernetesNodeGroupInstanceTemplateList",
    "DataYandexKubernetesNodeGroupInstanceTemplateNetworkInterface",
    "DataYandexKubernetesNodeGroupInstanceTemplateNetworkInterfaceList",
    "DataYandexKubernetesNodeGroupInstanceTemplateNetworkInterfaceOutputReference",
    "DataYandexKubernetesNodeGroupInstanceTemplateOutputReference",
    "DataYandexKubernetesNodeGroupInstanceTemplatePlacementPolicy",
    "DataYandexKubernetesNodeGroupInstanceTemplatePlacementPolicyList",
    "DataYandexKubernetesNodeGroupInstanceTemplatePlacementPolicyOutputReference",
    "DataYandexKubernetesNodeGroupInstanceTemplateResources",
    "DataYandexKubernetesNodeGroupInstanceTemplateResourcesList",
    "DataYandexKubernetesNodeGroupInstanceTemplateResourcesOutputReference",
    "DataYandexKubernetesNodeGroupInstanceTemplateSchedulingPolicy",
    "DataYandexKubernetesNodeGroupInstanceTemplateSchedulingPolicyList",
    "DataYandexKubernetesNodeGroupInstanceTemplateSchedulingPolicyOutputReference",
    "DataYandexKubernetesNodeGroupMaintenancePolicy",
    "DataYandexKubernetesNodeGroupMaintenancePolicyList",
    "DataYandexKubernetesNodeGroupMaintenancePolicyMaintenanceWindow",
    "DataYandexKubernetesNodeGroupMaintenancePolicyMaintenanceWindowList",
    "DataYandexKubernetesNodeGroupMaintenancePolicyMaintenanceWindowOutputReference",
    "DataYandexKubernetesNodeGroupMaintenancePolicyOutputReference",
    "DataYandexKubernetesNodeGroupScalePolicy",
    "DataYandexKubernetesNodeGroupScalePolicyAutoScale",
    "DataYandexKubernetesNodeGroupScalePolicyAutoScaleList",
    "DataYandexKubernetesNodeGroupScalePolicyAutoScaleOutputReference",
    "DataYandexKubernetesNodeGroupScalePolicyFixedScale",
    "DataYandexKubernetesNodeGroupScalePolicyFixedScaleList",
    "DataYandexKubernetesNodeGroupScalePolicyFixedScaleOutputReference",
    "DataYandexKubernetesNodeGroupScalePolicyList",
    "DataYandexKubernetesNodeGroupScalePolicyOutputReference",
    "DataYandexKubernetesNodeGroupVersionInfo",
    "DataYandexKubernetesNodeGroupVersionInfoList",
    "DataYandexKubernetesNodeGroupVersionInfoOutputReference",
    "DataYandexLbNetworkLoadBalancer",
    "DataYandexLbNetworkLoadBalancerAttachedTargetGroup",
    "DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheck",
    "DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptions",
    "DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptionsList",
    "DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptionsOutputReference",
    "DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckList",
    "DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckOutputReference",
    "DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptions",
    "DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptionsList",
    "DataYandexLbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptionsOutputReference",
    "DataYandexLbNetworkLoadBalancerAttachedTargetGroupList",
    "DataYandexLbNetworkLoadBalancerAttachedTargetGroupOutputReference",
    "DataYandexLbNetworkLoadBalancerConfig",
    "DataYandexLbNetworkLoadBalancerListener",
    "DataYandexLbNetworkLoadBalancerListenerExternalAddressSpec",
    "DataYandexLbNetworkLoadBalancerListenerExternalAddressSpecList",
    "DataYandexLbNetworkLoadBalancerListenerExternalAddressSpecOutputReference",
    "DataYandexLbNetworkLoadBalancerListenerInternalAddressSpec",
    "DataYandexLbNetworkLoadBalancerListenerInternalAddressSpecList",
    "DataYandexLbNetworkLoadBalancerListenerInternalAddressSpecOutputReference",
    "DataYandexLbNetworkLoadBalancerListenerList",
    "DataYandexLbNetworkLoadBalancerListenerOutputReference",
    "DataYandexLbTargetGroup",
    "DataYandexLbTargetGroupConfig",
    "DataYandexLbTargetGroupTarget",
    "DataYandexLbTargetGroupTargetList",
    "DataYandexLbTargetGroupTargetOutputReference",
    "DataYandexLoggingGroup",
    "DataYandexLoggingGroupConfig",
    "DataYandexMdbClickhouseCluster",
    "DataYandexMdbClickhouseClusterAccess",
    "DataYandexMdbClickhouseClusterAccessList",
    "DataYandexMdbClickhouseClusterAccessOutputReference",
    "DataYandexMdbClickhouseClusterBackupWindowStart",
    "DataYandexMdbClickhouseClusterBackupWindowStartList",
    "DataYandexMdbClickhouseClusterBackupWindowStartOutputReference",
    "DataYandexMdbClickhouseClusterClickhouse",
    "DataYandexMdbClickhouseClusterClickhouseConfig",
    "DataYandexMdbClickhouseClusterClickhouseConfigCompression",
    "DataYandexMdbClickhouseClusterClickhouseConfigCompressionList",
    "DataYandexMdbClickhouseClusterClickhouseConfigCompressionOutputReference",
    "DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollup",
    "DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupList",
    "DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupOutputReference",
    "DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupPattern",
    "DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupPatternList",
    "DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupPatternOutputReference",
    "DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetention",
    "DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetentionList",
    "DataYandexMdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetentionOutputReference",
    "DataYandexMdbClickhouseClusterClickhouseConfigKafka",
    "DataYandexMdbClickhouseClusterClickhouseConfigKafkaList",
    "DataYandexMdbClickhouseClusterClickhouseConfigKafkaOutputReference",
    "DataYandexMdbClickhouseClusterClickhouseConfigKafkaTopic",
    "DataYandexMdbClickhouseClusterClickhouseConfigKafkaTopicList",
    "DataYandexMdbClickhouseClusterClickhouseConfigKafkaTopicOutputReference",
    "DataYandexMdbClickhouseClusterClickhouseConfigKafkaTopicSettings",
    "DataYandexMdbClickhouseClusterClickhouseConfigKafkaTopicSettingsList",
    "DataYandexMdbClickhouseClusterClickhouseConfigKafkaTopicSettingsOutputReference",
    "DataYandexMdbClickhouseClusterClickhouseConfigList",
    "DataYandexMdbClickhouseClusterClickhouseConfigMergeTree",
    "DataYandexMdbClickhouseClusterClickhouseConfigMergeTreeList",
    "DataYandexMdbClickhouseClusterClickhouseConfigMergeTreeOutputReference",
    "DataYandexMdbClickhouseClusterClickhouseConfigOutputReference",
    "DataYandexMdbClickhouseClusterClickhouseConfigRabbitmq",
    "DataYandexMdbClickhouseClusterClickhouseConfigRabbitmqList",
    "DataYandexMdbClickhouseClusterClickhouseConfigRabbitmqOutputReference",
    "DataYandexMdbClickhouseClusterClickhouseList",
    "DataYandexMdbClickhouseClusterClickhouseOutputReference",
    "DataYandexMdbClickhouseClusterClickhouseResources",
    "DataYandexMdbClickhouseClusterClickhouseResourcesList",
    "DataYandexMdbClickhouseClusterClickhouseResourcesOutputReference",
    "DataYandexMdbClickhouseClusterCloudStorage",
    "DataYandexMdbClickhouseClusterCloudStorageOutputReference",
    "DataYandexMdbClickhouseClusterConfig",
    "DataYandexMdbClickhouseClusterDatabase",
    "DataYandexMdbClickhouseClusterDatabaseList",
    "DataYandexMdbClickhouseClusterDatabaseOutputReference",
    "DataYandexMdbClickhouseClusterFormatSchema",
    "DataYandexMdbClickhouseClusterFormatSchemaList",
    "DataYandexMdbClickhouseClusterFormatSchemaOutputReference",
    "DataYandexMdbClickhouseClusterHost",
    "DataYandexMdbClickhouseClusterHostList",
    "DataYandexMdbClickhouseClusterHostOutputReference",
    "DataYandexMdbClickhouseClusterMaintenanceWindow",
    "DataYandexMdbClickhouseClusterMaintenanceWindowList",
    "DataYandexMdbClickhouseClusterMaintenanceWindowOutputReference",
    "DataYandexMdbClickhouseClusterMlModel",
    "DataYandexMdbClickhouseClusterMlModelList",
    "DataYandexMdbClickhouseClusterMlModelOutputReference",
    "DataYandexMdbClickhouseClusterShardGroup",
    "DataYandexMdbClickhouseClusterShardGroupList",
    "DataYandexMdbClickhouseClusterShardGroupOutputReference",
    "DataYandexMdbClickhouseClusterUser",
    "DataYandexMdbClickhouseClusterUserList",
    "DataYandexMdbClickhouseClusterUserOutputReference",
    "DataYandexMdbClickhouseClusterUserPermission",
    "DataYandexMdbClickhouseClusterUserPermissionList",
    "DataYandexMdbClickhouseClusterUserPermissionOutputReference",
    "DataYandexMdbClickhouseClusterUserQuota",
    "DataYandexMdbClickhouseClusterUserQuotaList",
    "DataYandexMdbClickhouseClusterUserQuotaOutputReference",
    "DataYandexMdbClickhouseClusterUserSettings",
    "DataYandexMdbClickhouseClusterUserSettingsList",
    "DataYandexMdbClickhouseClusterUserSettingsOutputReference",
    "DataYandexMdbClickhouseClusterZookeeper",
    "DataYandexMdbClickhouseClusterZookeeperList",
    "DataYandexMdbClickhouseClusterZookeeperOutputReference",
    "DataYandexMdbClickhouseClusterZookeeperResources",
    "DataYandexMdbClickhouseClusterZookeeperResourcesList",
    "DataYandexMdbClickhouseClusterZookeeperResourcesOutputReference",
    "DataYandexMdbElasticsearchCluster",
    "DataYandexMdbElasticsearchClusterConfig",
    "DataYandexMdbElasticsearchClusterConfigA",
    "DataYandexMdbElasticsearchClusterConfigAList",
    "DataYandexMdbElasticsearchClusterConfigAOutputReference",
    "DataYandexMdbElasticsearchClusterConfigDataNode",
    "DataYandexMdbElasticsearchClusterConfigDataNodeList",
    "DataYandexMdbElasticsearchClusterConfigDataNodeOutputReference",
    "DataYandexMdbElasticsearchClusterConfigDataNodeResources",
    "DataYandexMdbElasticsearchClusterConfigDataNodeResourcesList",
    "DataYandexMdbElasticsearchClusterConfigDataNodeResourcesOutputReference",
    "DataYandexMdbElasticsearchClusterConfigMasterNode",
    "DataYandexMdbElasticsearchClusterConfigMasterNodeList",
    "DataYandexMdbElasticsearchClusterConfigMasterNodeOutputReference",
    "DataYandexMdbElasticsearchClusterConfigMasterNodeResources",
    "DataYandexMdbElasticsearchClusterConfigMasterNodeResourcesList",
    "DataYandexMdbElasticsearchClusterConfigMasterNodeResourcesOutputReference",
    "DataYandexMdbElasticsearchClusterHost",
    "DataYandexMdbElasticsearchClusterHostList",
    "DataYandexMdbElasticsearchClusterHostOutputReference",
    "DataYandexMdbElasticsearchClusterMaintenanceWindow",
    "DataYandexMdbElasticsearchClusterMaintenanceWindowList",
    "DataYandexMdbElasticsearchClusterMaintenanceWindowOutputReference",
    "DataYandexMdbGreenplumCluster",
    "DataYandexMdbGreenplumClusterAccess",
    "DataYandexMdbGreenplumClusterAccessList",
    "DataYandexMdbGreenplumClusterAccessOutputReference",
    "DataYandexMdbGreenplumClusterBackupWindowStart",
    "DataYandexMdbGreenplumClusterBackupWindowStartList",
    "DataYandexMdbGreenplumClusterBackupWindowStartOutputReference",
    "DataYandexMdbGreenplumClusterConfig",
    "DataYandexMdbGreenplumClusterMasterHosts",
    "DataYandexMdbGreenplumClusterMasterHostsList",
    "DataYandexMdbGreenplumClusterMasterHostsOutputReference",
    "DataYandexMdbGreenplumClusterMasterSubcluster",
    "DataYandexMdbGreenplumClusterMasterSubclusterList",
    "DataYandexMdbGreenplumClusterMasterSubclusterOutputReference",
    "DataYandexMdbGreenplumClusterMasterSubclusterResources",
    "DataYandexMdbGreenplumClusterMasterSubclusterResourcesList",
    "DataYandexMdbGreenplumClusterMasterSubclusterResourcesOutputReference",
    "DataYandexMdbGreenplumClusterSegmentHosts",
    "DataYandexMdbGreenplumClusterSegmentHostsList",
    "DataYandexMdbGreenplumClusterSegmentHostsOutputReference",
    "DataYandexMdbGreenplumClusterSegmentSubcluster",
    "DataYandexMdbGreenplumClusterSegmentSubclusterList",
    "DataYandexMdbGreenplumClusterSegmentSubclusterOutputReference",
    "DataYandexMdbGreenplumClusterSegmentSubclusterResources",
    "DataYandexMdbGreenplumClusterSegmentSubclusterResourcesList",
    "DataYandexMdbGreenplumClusterSegmentSubclusterResourcesOutputReference",
    "DataYandexMdbKafkaCluster",
    "DataYandexMdbKafkaClusterConfig",
    "DataYandexMdbKafkaClusterConfigA",
    "DataYandexMdbKafkaClusterConfigAOutputReference",
    "DataYandexMdbKafkaClusterConfigKafka",
    "DataYandexMdbKafkaClusterConfigKafkaKafkaConfig",
    "DataYandexMdbKafkaClusterConfigKafkaKafkaConfigOutputReference",
    "DataYandexMdbKafkaClusterConfigKafkaOutputReference",
    "DataYandexMdbKafkaClusterConfigKafkaResources",
    "DataYandexMdbKafkaClusterConfigKafkaResourcesOutputReference",
    "DataYandexMdbKafkaClusterConfigZookeeper",
    "DataYandexMdbKafkaClusterConfigZookeeperOutputReference",
    "DataYandexMdbKafkaClusterConfigZookeeperResources",
    "DataYandexMdbKafkaClusterConfigZookeeperResourcesOutputReference",
    "DataYandexMdbKafkaClusterHost",
    "DataYandexMdbKafkaClusterHostList",
    "DataYandexMdbKafkaClusterHostOutputReference",
    "DataYandexMdbKafkaClusterMaintenanceWindow",
    "DataYandexMdbKafkaClusterMaintenanceWindowList",
    "DataYandexMdbKafkaClusterMaintenanceWindowOutputReference",
    "DataYandexMdbKafkaClusterTopic",
    "DataYandexMdbKafkaClusterTopicList",
    "DataYandexMdbKafkaClusterTopicOutputReference",
    "DataYandexMdbKafkaClusterTopicTopicConfig",
    "DataYandexMdbKafkaClusterTopicTopicConfigOutputReference",
    "DataYandexMdbKafkaClusterUser",
    "DataYandexMdbKafkaClusterUserList",
    "DataYandexMdbKafkaClusterUserOutputReference",
    "DataYandexMdbKafkaClusterUserPermission",
    "DataYandexMdbKafkaClusterUserPermissionList",
    "DataYandexMdbKafkaClusterUserPermissionOutputReference",
    "DataYandexMdbKafkaConnector",
    "DataYandexMdbKafkaConnectorConfig",
    "DataYandexMdbKafkaConnectorConnectorConfigMirrormaker",
    "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerList",
    "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerOutputReference",
    "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceCluster",
    "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalCluster",
    "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalClusterList",
    "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalClusterOutputReference",
    "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterList",
    "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterOutputReference",
    "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisCluster",
    "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisClusterList",
    "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisClusterOutputReference",
    "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetCluster",
    "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalCluster",
    "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalClusterList",
    "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalClusterOutputReference",
    "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterList",
    "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterOutputReference",
    "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisCluster",
    "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisClusterList",
    "DataYandexMdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisClusterOutputReference",
    "DataYandexMdbKafkaTopic",
    "DataYandexMdbKafkaTopicConfig",
    "DataYandexMdbKafkaTopicTopicConfig",
    "DataYandexMdbKafkaTopicTopicConfigList",
    "DataYandexMdbKafkaTopicTopicConfigOutputReference",
    "DataYandexMdbMongodbCluster",
    "DataYandexMdbMongodbClusterClusterConfig",
    "DataYandexMdbMongodbClusterClusterConfigAccess",
    "DataYandexMdbMongodbClusterClusterConfigAccessList",
    "DataYandexMdbMongodbClusterClusterConfigAccessOutputReference",
    "DataYandexMdbMongodbClusterClusterConfigBackupWindowStart",
    "DataYandexMdbMongodbClusterClusterConfigBackupWindowStartList",
    "DataYandexMdbMongodbClusterClusterConfigBackupWindowStartOutputReference",
    "DataYandexMdbMongodbClusterClusterConfigList",
    "DataYandexMdbMongodbClusterClusterConfigOutputReference",
    "DataYandexMdbMongodbClusterConfig",
    "DataYandexMdbMongodbClusterDatabase",
    "DataYandexMdbMongodbClusterDatabaseList",
    "DataYandexMdbMongodbClusterDatabaseOutputReference",
    "DataYandexMdbMongodbClusterHost",
    "DataYandexMdbMongodbClusterHostList",
    "DataYandexMdbMongodbClusterHostOutputReference",
    "DataYandexMdbMongodbClusterMaintenanceWindow",
    "DataYandexMdbMongodbClusterMaintenanceWindowList",
    "DataYandexMdbMongodbClusterMaintenanceWindowOutputReference",
    "DataYandexMdbMongodbClusterResources",
    "DataYandexMdbMongodbClusterResourcesList",
    "DataYandexMdbMongodbClusterResourcesOutputReference",
    "DataYandexMdbMongodbClusterUser",
    "DataYandexMdbMongodbClusterUserList",
    "DataYandexMdbMongodbClusterUserOutputReference",
    "DataYandexMdbMongodbClusterUserPermission",
    "DataYandexMdbMongodbClusterUserPermissionList",
    "DataYandexMdbMongodbClusterUserPermissionOutputReference",
    "DataYandexMdbMysqlCluster",
    "DataYandexMdbMysqlClusterAccess",
    "DataYandexMdbMysqlClusterAccessOutputReference",
    "DataYandexMdbMysqlClusterBackupWindowStart",
    "DataYandexMdbMysqlClusterBackupWindowStartList",
    "DataYandexMdbMysqlClusterBackupWindowStartOutputReference",
    "DataYandexMdbMysqlClusterConfig",
    "DataYandexMdbMysqlClusterDatabase",
    "DataYandexMdbMysqlClusterDatabaseList",
    "DataYandexMdbMysqlClusterDatabaseOutputReference",
    "DataYandexMdbMysqlClusterHost",
    "DataYandexMdbMysqlClusterHostList",
    "DataYandexMdbMysqlClusterHostOutputReference",
    "DataYandexMdbMysqlClusterMaintenanceWindow",
    "DataYandexMdbMysqlClusterMaintenanceWindowList",
    "DataYandexMdbMysqlClusterMaintenanceWindowOutputReference",
    "DataYandexMdbMysqlClusterResources",
    "DataYandexMdbMysqlClusterResourcesList",
    "DataYandexMdbMysqlClusterResourcesOutputReference",
    "DataYandexMdbMysqlClusterUser",
    "DataYandexMdbMysqlClusterUserConnectionLimits",
    "DataYandexMdbMysqlClusterUserConnectionLimitsList",
    "DataYandexMdbMysqlClusterUserConnectionLimitsOutputReference",
    "DataYandexMdbMysqlClusterUserList",
    "DataYandexMdbMysqlClusterUserOutputReference",
    "DataYandexMdbMysqlClusterUserPermission",
    "DataYandexMdbMysqlClusterUserPermissionList",
    "DataYandexMdbMysqlClusterUserPermissionOutputReference",
    "DataYandexMdbPostgresqlCluster",
    "DataYandexMdbPostgresqlClusterConfig",
    "DataYandexMdbPostgresqlClusterConfigA",
    "DataYandexMdbPostgresqlClusterConfigAList",
    "DataYandexMdbPostgresqlClusterConfigAOutputReference",
    "DataYandexMdbPostgresqlClusterConfigAccess",
    "DataYandexMdbPostgresqlClusterConfigAccessList",
    "DataYandexMdbPostgresqlClusterConfigAccessOutputReference",
    "DataYandexMdbPostgresqlClusterConfigBackupWindowStart",
    "DataYandexMdbPostgresqlClusterConfigBackupWindowStartList",
    "DataYandexMdbPostgresqlClusterConfigBackupWindowStartOutputReference",
    "DataYandexMdbPostgresqlClusterConfigPerformanceDiagnostics",
    "DataYandexMdbPostgresqlClusterConfigPerformanceDiagnosticsList",
    "DataYandexMdbPostgresqlClusterConfigPerformanceDiagnosticsOutputReference",
    "DataYandexMdbPostgresqlClusterConfigPoolerConfig",
    "DataYandexMdbPostgresqlClusterConfigPoolerConfigList",
    "DataYandexMdbPostgresqlClusterConfigPoolerConfigOutputReference",
    "DataYandexMdbPostgresqlClusterConfigResources",
    "DataYandexMdbPostgresqlClusterConfigResourcesList",
    "DataYandexMdbPostgresqlClusterConfigResourcesOutputReference",
    "DataYandexMdbPostgresqlClusterDatabase",
    "DataYandexMdbPostgresqlClusterDatabaseExtension",
    "DataYandexMdbPostgresqlClusterDatabaseExtensionList",
    "DataYandexMdbPostgresqlClusterDatabaseExtensionOutputReference",
    "DataYandexMdbPostgresqlClusterDatabaseList",
    "DataYandexMdbPostgresqlClusterDatabaseOutputReference",
    "DataYandexMdbPostgresqlClusterHost",
    "DataYandexMdbPostgresqlClusterHostList",
    "DataYandexMdbPostgresqlClusterHostOutputReference",
    "DataYandexMdbPostgresqlClusterMaintenanceWindow",
    "DataYandexMdbPostgresqlClusterMaintenanceWindowList",
    "DataYandexMdbPostgresqlClusterMaintenanceWindowOutputReference",
    "DataYandexMdbPostgresqlClusterUser",
    "DataYandexMdbPostgresqlClusterUserList",
    "DataYandexMdbPostgresqlClusterUserOutputReference",
    "DataYandexMdbPostgresqlClusterUserPermission",
    "DataYandexMdbPostgresqlClusterUserPermissionList",
    "DataYandexMdbPostgresqlClusterUserPermissionOutputReference",
    "DataYandexMdbRedisCluster",
    "DataYandexMdbRedisClusterConfig",
    "DataYandexMdbRedisClusterConfigA",
    "DataYandexMdbRedisClusterConfigAList",
    "DataYandexMdbRedisClusterConfigAOutputReference",
    "DataYandexMdbRedisClusterHost",
    "DataYandexMdbRedisClusterHostList",
    "DataYandexMdbRedisClusterHostOutputReference",
    "DataYandexMdbRedisClusterMaintenanceWindow",
    "DataYandexMdbRedisClusterMaintenanceWindowList",
    "DataYandexMdbRedisClusterMaintenanceWindowOutputReference",
    "DataYandexMdbRedisClusterResources",
    "DataYandexMdbRedisClusterResourcesList",
    "DataYandexMdbRedisClusterResourcesOutputReference",
    "DataYandexMdbSqlserverCluster",
    "DataYandexMdbSqlserverClusterBackupWindowStart",
    "DataYandexMdbSqlserverClusterBackupWindowStartList",
    "DataYandexMdbSqlserverClusterBackupWindowStartOutputReference",
    "DataYandexMdbSqlserverClusterConfig",
    "DataYandexMdbSqlserverClusterDatabase",
    "DataYandexMdbSqlserverClusterDatabaseList",
    "DataYandexMdbSqlserverClusterDatabaseOutputReference",
    "DataYandexMdbSqlserverClusterHost",
    "DataYandexMdbSqlserverClusterHostList",
    "DataYandexMdbSqlserverClusterHostOutputReference",
    "DataYandexMdbSqlserverClusterResources",
    "DataYandexMdbSqlserverClusterResourcesList",
    "DataYandexMdbSqlserverClusterResourcesOutputReference",
    "DataYandexMdbSqlserverClusterUser",
    "DataYandexMdbSqlserverClusterUserList",
    "DataYandexMdbSqlserverClusterUserOutputReference",
    "DataYandexMdbSqlserverClusterUserPermission",
    "DataYandexMdbSqlserverClusterUserPermissionList",
    "DataYandexMdbSqlserverClusterUserPermissionOutputReference",
    "DataYandexMessageQueue",
    "DataYandexMessageQueueConfig",
    "DataYandexOrganizationmanagerSamlFederation",
    "DataYandexOrganizationmanagerSamlFederationConfig",
    "DataYandexOrganizationmanagerSamlFederationSecuritySettings",
    "DataYandexOrganizationmanagerSamlFederationSecuritySettingsList",
    "DataYandexOrganizationmanagerSamlFederationSecuritySettingsOutputReference",
    "DataYandexOrganizationmanagerSamlFederationUserAccount",
    "DataYandexOrganizationmanagerSamlFederationUserAccountConfig",
    "DataYandexResourcemanagerCloud",
    "DataYandexResourcemanagerCloudConfig",
    "DataYandexResourcemanagerFolder",
    "DataYandexResourcemanagerFolderConfig",
    "DataYandexServerlessContainer",
    "DataYandexServerlessContainerConfig",
    "DataYandexServerlessContainerImage",
    "DataYandexServerlessContainerImageList",
    "DataYandexServerlessContainerImageOutputReference",
    "DataYandexVpcAddress",
    "DataYandexVpcAddressConfig",
    "DataYandexVpcAddressExternalIpv4Address",
    "DataYandexVpcAddressExternalIpv4AddressList",
    "DataYandexVpcAddressExternalIpv4AddressOutputReference",
    "DataYandexVpcNetwork",
    "DataYandexVpcNetworkConfig",
    "DataYandexVpcRouteTable",
    "DataYandexVpcRouteTableConfig",
    "DataYandexVpcRouteTableStaticRoute",
    "DataYandexVpcRouteTableStaticRouteList",
    "DataYandexVpcRouteTableStaticRouteOutputReference",
    "DataYandexVpcSecurityGroup",
    "DataYandexVpcSecurityGroupConfig",
    "DataYandexVpcSecurityGroupEgress",
    "DataYandexVpcSecurityGroupEgressList",
    "DataYandexVpcSecurityGroupEgressOutputReference",
    "DataYandexVpcSecurityGroupIngress",
    "DataYandexVpcSecurityGroupIngressList",
    "DataYandexVpcSecurityGroupIngressOutputReference",
    "DataYandexVpcSecurityGroupRule",
    "DataYandexVpcSecurityGroupRuleConfig",
    "DataYandexVpcSubnet",
    "DataYandexVpcSubnetConfig",
    "DataYandexVpcSubnetDhcpOptions",
    "DataYandexVpcSubnetDhcpOptionsList",
    "DataYandexVpcSubnetDhcpOptionsOutputReference",
    "DataYandexYdbDatabaseDedicated",
    "DataYandexYdbDatabaseDedicatedConfig",
    "DataYandexYdbDatabaseDedicatedLocation",
    "DataYandexYdbDatabaseDedicatedLocationList",
    "DataYandexYdbDatabaseDedicatedLocationOutputReference",
    "DataYandexYdbDatabaseDedicatedLocationRegion",
    "DataYandexYdbDatabaseDedicatedLocationRegionList",
    "DataYandexYdbDatabaseDedicatedLocationRegionOutputReference",
    "DataYandexYdbDatabaseDedicatedLocationZone",
    "DataYandexYdbDatabaseDedicatedLocationZoneList",
    "DataYandexYdbDatabaseDedicatedLocationZoneOutputReference",
    "DataYandexYdbDatabaseDedicatedScalePolicy",
    "DataYandexYdbDatabaseDedicatedScalePolicyFixedScale",
    "DataYandexYdbDatabaseDedicatedScalePolicyFixedScaleList",
    "DataYandexYdbDatabaseDedicatedScalePolicyFixedScaleOutputReference",
    "DataYandexYdbDatabaseDedicatedScalePolicyList",
    "DataYandexYdbDatabaseDedicatedScalePolicyOutputReference",
    "DataYandexYdbDatabaseDedicatedStorageConfig",
    "DataYandexYdbDatabaseDedicatedStorageConfigList",
    "DataYandexYdbDatabaseDedicatedStorageConfigOutputReference",
    "DataYandexYdbDatabaseServerless",
    "DataYandexYdbDatabaseServerlessConfig",
    "DataprocCluster",
    "DataprocClusterClusterConfig",
    "DataprocClusterClusterConfigHadoop",
    "DataprocClusterClusterConfigHadoopOutputReference",
    "DataprocClusterClusterConfigOutputReference",
    "DataprocClusterClusterConfigSubclusterSpec",
    "DataprocClusterClusterConfigSubclusterSpecAutoscalingConfig",
    "DataprocClusterClusterConfigSubclusterSpecAutoscalingConfigOutputReference",
    "DataprocClusterClusterConfigSubclusterSpecList",
    "DataprocClusterClusterConfigSubclusterSpecOutputReference",
    "DataprocClusterClusterConfigSubclusterSpecResources",
    "DataprocClusterClusterConfigSubclusterSpecResourcesOutputReference",
    "DataprocClusterConfig",
    "DataprocClusterTimeouts",
    "DataprocClusterTimeoutsOutputReference",
    "DatatransferEndpoint",
    "DatatransferEndpointConfig",
    "DatatransferEndpointSettings",
    "DatatransferEndpointSettingsMysqlSource",
    "DatatransferEndpointSettingsMysqlSourceConnection",
    "DatatransferEndpointSettingsMysqlSourceConnectionOnPremise",
    "DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseOutputReference",
    "DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsMode",
    "DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeDisabled",
    "DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeDisabledOutputReference",
    "DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeEnabled",
    "DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeEnabledOutputReference",
    "DatatransferEndpointSettingsMysqlSourceConnectionOnPremiseTlsModeOutputReference",
    "DatatransferEndpointSettingsMysqlSourceConnectionOutputReference",
    "DatatransferEndpointSettingsMysqlSourceObjectTransferSettings",
    "DatatransferEndpointSettingsMysqlSourceObjectTransferSettingsOutputReference",
    "DatatransferEndpointSettingsMysqlSourceOutputReference",
    "DatatransferEndpointSettingsMysqlSourcePassword",
    "DatatransferEndpointSettingsMysqlSourcePasswordOutputReference",
    "DatatransferEndpointSettingsMysqlTarget",
    "DatatransferEndpointSettingsMysqlTargetConnection",
    "DatatransferEndpointSettingsMysqlTargetConnectionOnPremise",
    "DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseOutputReference",
    "DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsMode",
    "DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeDisabled",
    "DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeDisabledOutputReference",
    "DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeEnabled",
    "DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeEnabledOutputReference",
    "DatatransferEndpointSettingsMysqlTargetConnectionOnPremiseTlsModeOutputReference",
    "DatatransferEndpointSettingsMysqlTargetConnectionOutputReference",
    "DatatransferEndpointSettingsMysqlTargetOutputReference",
    "DatatransferEndpointSettingsMysqlTargetPassword",
    "DatatransferEndpointSettingsMysqlTargetPasswordOutputReference",
    "DatatransferEndpointSettingsOutputReference",
    "DatatransferEndpointSettingsPostgresSource",
    "DatatransferEndpointSettingsPostgresSourceConnection",
    "DatatransferEndpointSettingsPostgresSourceConnectionOnPremise",
    "DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseOutputReference",
    "DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsMode",
    "DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeDisabled",
    "DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeDisabledOutputReference",
    "DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeEnabled",
    "DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeEnabledOutputReference",
    "DatatransferEndpointSettingsPostgresSourceConnectionOnPremiseTlsModeOutputReference",
    "DatatransferEndpointSettingsPostgresSourceConnectionOutputReference",
    "DatatransferEndpointSettingsPostgresSourceObjectTransferSettings",
    "DatatransferEndpointSettingsPostgresSourceObjectTransferSettingsOutputReference",
    "DatatransferEndpointSettingsPostgresSourceOutputReference",
    "DatatransferEndpointSettingsPostgresSourcePassword",
    "DatatransferEndpointSettingsPostgresSourcePasswordOutputReference",
    "DatatransferEndpointSettingsPostgresTarget",
    "DatatransferEndpointSettingsPostgresTargetConnection",
    "DatatransferEndpointSettingsPostgresTargetConnectionOnPremise",
    "DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseOutputReference",
    "DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsMode",
    "DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeDisabled",
    "DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeDisabledOutputReference",
    "DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeEnabled",
    "DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeEnabledOutputReference",
    "DatatransferEndpointSettingsPostgresTargetConnectionOnPremiseTlsModeOutputReference",
    "DatatransferEndpointSettingsPostgresTargetConnectionOutputReference",
    "DatatransferEndpointSettingsPostgresTargetOutputReference",
    "DatatransferEndpointSettingsPostgresTargetPassword",
    "DatatransferEndpointSettingsPostgresTargetPasswordOutputReference",
    "DatatransferTransfer",
    "DatatransferTransferConfig",
    "DnsRecordset",
    "DnsRecordsetConfig",
    "DnsRecordsetTimeouts",
    "DnsRecordsetTimeoutsOutputReference",
    "DnsZone",
    "DnsZoneConfig",
    "DnsZoneTimeouts",
    "DnsZoneTimeoutsOutputReference",
    "Function",
    "FunctionConfig",
    "FunctionContent",
    "FunctionContentOutputReference",
    "FunctionIamBinding",
    "FunctionIamBindingConfig",
    "FunctionPackage",
    "FunctionPackageOutputReference",
    "FunctionScalingPolicy",
    "FunctionScalingPolicyConfig",
    "FunctionScalingPolicyPolicy",
    "FunctionScalingPolicyPolicyList",
    "FunctionScalingPolicyPolicyOutputReference",
    "FunctionTimeouts",
    "FunctionTimeoutsOutputReference",
    "FunctionTrigger",
    "FunctionTriggerConfig",
    "FunctionTriggerDlq",
    "FunctionTriggerDlqOutputReference",
    "FunctionTriggerFunction",
    "FunctionTriggerFunctionOutputReference",
    "FunctionTriggerIot",
    "FunctionTriggerIotOutputReference",
    "FunctionTriggerLogGroup",
    "FunctionTriggerLogGroupOutputReference",
    "FunctionTriggerLogging",
    "FunctionTriggerLoggingOutputReference",
    "FunctionTriggerMessageQueue",
    "FunctionTriggerMessageQueueOutputReference",
    "FunctionTriggerObjectStorage",
    "FunctionTriggerObjectStorageOutputReference",
    "FunctionTriggerTimeouts",
    "FunctionTriggerTimeoutsOutputReference",
    "FunctionTriggerTimer",
    "FunctionTriggerTimerOutputReference",
    "IamServiceAccount",
    "IamServiceAccountApiKey",
    "IamServiceAccountApiKeyConfig",
    "IamServiceAccountConfig",
    "IamServiceAccountIamBinding",
    "IamServiceAccountIamBindingConfig",
    "IamServiceAccountIamMember",
    "IamServiceAccountIamMemberConfig",
    "IamServiceAccountIamPolicy",
    "IamServiceAccountIamPolicyConfig",
    "IamServiceAccountKey",
    "IamServiceAccountKeyConfig",
    "IamServiceAccountStaticAccessKey",
    "IamServiceAccountStaticAccessKeyConfig",
    "IamServiceAccountTimeouts",
    "IamServiceAccountTimeoutsOutputReference",
    "IotCoreDevice",
    "IotCoreDeviceConfig",
    "IotCoreDeviceTimeouts",
    "IotCoreDeviceTimeoutsOutputReference",
    "IotCoreRegistry",
    "IotCoreRegistryConfig",
    "IotCoreRegistryTimeouts",
    "IotCoreRegistryTimeoutsOutputReference",
    "KmsSecretCiphertext",
    "KmsSecretCiphertextConfig",
    "KmsSecretCiphertextTimeouts",
    "KmsSecretCiphertextTimeoutsOutputReference",
    "KmsSymmetricKey",
    "KmsSymmetricKeyConfig",
    "KmsSymmetricKeyIamBinding",
    "KmsSymmetricKeyIamBindingConfig",
    "KmsSymmetricKeyTimeouts",
    "KmsSymmetricKeyTimeoutsOutputReference",
    "KubernetesCluster",
    "KubernetesClusterConfig",
    "KubernetesClusterKmsProvider",
    "KubernetesClusterKmsProviderOutputReference",
    "KubernetesClusterMaster",
    "KubernetesClusterMasterMaintenancePolicy",
    "KubernetesClusterMasterMaintenancePolicyMaintenanceWindow",
    "KubernetesClusterMasterMaintenancePolicyMaintenanceWindowList",
    "KubernetesClusterMasterMaintenancePolicyMaintenanceWindowOutputReference",
    "KubernetesClusterMasterMaintenancePolicyOutputReference",
    "KubernetesClusterMasterOutputReference",
    "KubernetesClusterMasterRegional",
    "KubernetesClusterMasterRegionalLocation",
    "KubernetesClusterMasterRegionalLocationList",
    "KubernetesClusterMasterRegionalLocationOutputReference",
    "KubernetesClusterMasterRegionalOutputReference",
    "KubernetesClusterMasterVersionInfo",
    "KubernetesClusterMasterVersionInfoList",
    "KubernetesClusterMasterVersionInfoOutputReference",
    "KubernetesClusterMasterZonal",
    "KubernetesClusterMasterZonalOutputReference",
    "KubernetesClusterNetworkImplementation",
    "KubernetesClusterNetworkImplementationCilium",
    "KubernetesClusterNetworkImplementationCiliumOutputReference",
    "KubernetesClusterNetworkImplementationOutputReference",
    "KubernetesClusterTimeouts",
    "KubernetesClusterTimeoutsOutputReference",
    "KubernetesNodeGroup",
    "KubernetesNodeGroupAllocationPolicy",
    "KubernetesNodeGroupAllocationPolicyLocation",
    "KubernetesNodeGroupAllocationPolicyLocationList",
    "KubernetesNodeGroupAllocationPolicyLocationOutputReference",
    "KubernetesNodeGroupAllocationPolicyOutputReference",
    "KubernetesNodeGroupConfig",
    "KubernetesNodeGroupDeployPolicy",
    "KubernetesNodeGroupDeployPolicyOutputReference",
    "KubernetesNodeGroupInstanceTemplate",
    "KubernetesNodeGroupInstanceTemplateBootDisk",
    "KubernetesNodeGroupInstanceTemplateBootDiskOutputReference",
    "KubernetesNodeGroupInstanceTemplateContainerRuntime",
    "KubernetesNodeGroupInstanceTemplateContainerRuntimeOutputReference",
    "KubernetesNodeGroupInstanceTemplateNetworkInterface",
    "KubernetesNodeGroupInstanceTemplateNetworkInterfaceList",
    "KubernetesNodeGroupInstanceTemplateNetworkInterfaceOutputReference",
    "KubernetesNodeGroupInstanceTemplateOutputReference",
    "KubernetesNodeGroupInstanceTemplatePlacementPolicy",
    "KubernetesNodeGroupInstanceTemplatePlacementPolicyOutputReference",
    "KubernetesNodeGroupInstanceTemplateResources",
    "KubernetesNodeGroupInstanceTemplateResourcesOutputReference",
    "KubernetesNodeGroupInstanceTemplateSchedulingPolicy",
    "KubernetesNodeGroupInstanceTemplateSchedulingPolicyOutputReference",
    "KubernetesNodeGroupMaintenancePolicy",
    "KubernetesNodeGroupMaintenancePolicyMaintenanceWindow",
    "KubernetesNodeGroupMaintenancePolicyMaintenanceWindowList",
    "KubernetesNodeGroupMaintenancePolicyMaintenanceWindowOutputReference",
    "KubernetesNodeGroupMaintenancePolicyOutputReference",
    "KubernetesNodeGroupScalePolicy",
    "KubernetesNodeGroupScalePolicyAutoScale",
    "KubernetesNodeGroupScalePolicyAutoScaleOutputReference",
    "KubernetesNodeGroupScalePolicyFixedScale",
    "KubernetesNodeGroupScalePolicyFixedScaleOutputReference",
    "KubernetesNodeGroupScalePolicyOutputReference",
    "KubernetesNodeGroupTimeouts",
    "KubernetesNodeGroupTimeoutsOutputReference",
    "KubernetesNodeGroupVersionInfo",
    "KubernetesNodeGroupVersionInfoList",
    "KubernetesNodeGroupVersionInfoOutputReference",
    "LbNetworkLoadBalancer",
    "LbNetworkLoadBalancerAttachedTargetGroup",
    "LbNetworkLoadBalancerAttachedTargetGroupHealthcheck",
    "LbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptions",
    "LbNetworkLoadBalancerAttachedTargetGroupHealthcheckHttpOptionsOutputReference",
    "LbNetworkLoadBalancerAttachedTargetGroupHealthcheckList",
    "LbNetworkLoadBalancerAttachedTargetGroupHealthcheckOutputReference",
    "LbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptions",
    "LbNetworkLoadBalancerAttachedTargetGroupHealthcheckTcpOptionsOutputReference",
    "LbNetworkLoadBalancerAttachedTargetGroupList",
    "LbNetworkLoadBalancerAttachedTargetGroupOutputReference",
    "LbNetworkLoadBalancerConfig",
    "LbNetworkLoadBalancerListener",
    "LbNetworkLoadBalancerListenerExternalAddressSpec",
    "LbNetworkLoadBalancerListenerExternalAddressSpecOutputReference",
    "LbNetworkLoadBalancerListenerInternalAddressSpec",
    "LbNetworkLoadBalancerListenerInternalAddressSpecOutputReference",
    "LbNetworkLoadBalancerListenerList",
    "LbNetworkLoadBalancerListenerOutputReference",
    "LbNetworkLoadBalancerTimeouts",
    "LbNetworkLoadBalancerTimeoutsOutputReference",
    "LbTargetGroup",
    "LbTargetGroupConfig",
    "LbTargetGroupTarget",
    "LbTargetGroupTargetList",
    "LbTargetGroupTargetOutputReference",
    "LbTargetGroupTimeouts",
    "LbTargetGroupTimeoutsOutputReference",
    "LoggingGroup",
    "LoggingGroupConfig",
    "LoggingGroupTimeouts",
    "LoggingGroupTimeoutsOutputReference",
    "MdbClickhouseCluster",
    "MdbClickhouseClusterAccess",
    "MdbClickhouseClusterAccessOutputReference",
    "MdbClickhouseClusterBackupWindowStart",
    "MdbClickhouseClusterBackupWindowStartOutputReference",
    "MdbClickhouseClusterClickhouse",
    "MdbClickhouseClusterClickhouseConfig",
    "MdbClickhouseClusterClickhouseConfigCompression",
    "MdbClickhouseClusterClickhouseConfigCompressionList",
    "MdbClickhouseClusterClickhouseConfigCompressionOutputReference",
    "MdbClickhouseClusterClickhouseConfigGraphiteRollup",
    "MdbClickhouseClusterClickhouseConfigGraphiteRollupList",
    "MdbClickhouseClusterClickhouseConfigGraphiteRollupOutputReference",
    "MdbClickhouseClusterClickhouseConfigGraphiteRollupPattern",
    "MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternList",
    "MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternOutputReference",
    "MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetention",
    "MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetentionList",
    "MdbClickhouseClusterClickhouseConfigGraphiteRollupPatternRetentionOutputReference",
    "MdbClickhouseClusterClickhouseConfigKafka",
    "MdbClickhouseClusterClickhouseConfigKafkaOutputReference",
    "MdbClickhouseClusterClickhouseConfigKafkaTopic",
    "MdbClickhouseClusterClickhouseConfigKafkaTopicList",
    "MdbClickhouseClusterClickhouseConfigKafkaTopicOutputReference",
    "MdbClickhouseClusterClickhouseConfigKafkaTopicSettings",
    "MdbClickhouseClusterClickhouseConfigKafkaTopicSettingsOutputReference",
    "MdbClickhouseClusterClickhouseConfigMergeTree",
    "MdbClickhouseClusterClickhouseConfigMergeTreeOutputReference",
    "MdbClickhouseClusterClickhouseConfigOutputReference",
    "MdbClickhouseClusterClickhouseConfigRabbitmq",
    "MdbClickhouseClusterClickhouseConfigRabbitmqOutputReference",
    "MdbClickhouseClusterClickhouseOutputReference",
    "MdbClickhouseClusterClickhouseResources",
    "MdbClickhouseClusterClickhouseResourcesOutputReference",
    "MdbClickhouseClusterCloudStorage",
    "MdbClickhouseClusterCloudStorageOutputReference",
    "MdbClickhouseClusterConfig",
    "MdbClickhouseClusterDatabase",
    "MdbClickhouseClusterDatabaseList",
    "MdbClickhouseClusterDatabaseOutputReference",
    "MdbClickhouseClusterFormatSchema",
    "MdbClickhouseClusterFormatSchemaList",
    "MdbClickhouseClusterFormatSchemaOutputReference",
    "MdbClickhouseClusterHost",
    "MdbClickhouseClusterHostList",
    "MdbClickhouseClusterHostOutputReference",
    "MdbClickhouseClusterMaintenanceWindow",
    "MdbClickhouseClusterMaintenanceWindowOutputReference",
    "MdbClickhouseClusterMlModel",
    "MdbClickhouseClusterMlModelList",
    "MdbClickhouseClusterMlModelOutputReference",
    "MdbClickhouseClusterShardGroup",
    "MdbClickhouseClusterShardGroupList",
    "MdbClickhouseClusterShardGroupOutputReference",
    "MdbClickhouseClusterTimeouts",
    "MdbClickhouseClusterTimeoutsOutputReference",
    "MdbClickhouseClusterUser",
    "MdbClickhouseClusterUserList",
    "MdbClickhouseClusterUserOutputReference",
    "MdbClickhouseClusterUserPermission",
    "MdbClickhouseClusterUserPermissionList",
    "MdbClickhouseClusterUserPermissionOutputReference",
    "MdbClickhouseClusterUserQuota",
    "MdbClickhouseClusterUserQuotaList",
    "MdbClickhouseClusterUserQuotaOutputReference",
    "MdbClickhouseClusterUserSettings",
    "MdbClickhouseClusterUserSettingsOutputReference",
    "MdbClickhouseClusterZookeeper",
    "MdbClickhouseClusterZookeeperOutputReference",
    "MdbClickhouseClusterZookeeperResources",
    "MdbClickhouseClusterZookeeperResourcesOutputReference",
    "MdbElasticsearchCluster",
    "MdbElasticsearchClusterConfig",
    "MdbElasticsearchClusterConfigA",
    "MdbElasticsearchClusterConfigAOutputReference",
    "MdbElasticsearchClusterConfigDataNode",
    "MdbElasticsearchClusterConfigDataNodeOutputReference",
    "MdbElasticsearchClusterConfigDataNodeResources",
    "MdbElasticsearchClusterConfigDataNodeResourcesOutputReference",
    "MdbElasticsearchClusterConfigMasterNode",
    "MdbElasticsearchClusterConfigMasterNodeOutputReference",
    "MdbElasticsearchClusterConfigMasterNodeResources",
    "MdbElasticsearchClusterConfigMasterNodeResourcesOutputReference",
    "MdbElasticsearchClusterHost",
    "MdbElasticsearchClusterHostList",
    "MdbElasticsearchClusterHostOutputReference",
    "MdbElasticsearchClusterMaintenanceWindow",
    "MdbElasticsearchClusterMaintenanceWindowOutputReference",
    "MdbElasticsearchClusterTimeouts",
    "MdbElasticsearchClusterTimeoutsOutputReference",
    "MdbGreenplumCluster",
    "MdbGreenplumClusterAccess",
    "MdbGreenplumClusterAccessOutputReference",
    "MdbGreenplumClusterBackupWindowStart",
    "MdbGreenplumClusterBackupWindowStartOutputReference",
    "MdbGreenplumClusterConfig",
    "MdbGreenplumClusterMasterHosts",
    "MdbGreenplumClusterMasterHostsList",
    "MdbGreenplumClusterMasterHostsOutputReference",
    "MdbGreenplumClusterMasterSubcluster",
    "MdbGreenplumClusterMasterSubclusterOutputReference",
    "MdbGreenplumClusterMasterSubclusterResources",
    "MdbGreenplumClusterMasterSubclusterResourcesOutputReference",
    "MdbGreenplumClusterSegmentHosts",
    "MdbGreenplumClusterSegmentHostsList",
    "MdbGreenplumClusterSegmentHostsOutputReference",
    "MdbGreenplumClusterSegmentSubcluster",
    "MdbGreenplumClusterSegmentSubclusterOutputReference",
    "MdbGreenplumClusterSegmentSubclusterResources",
    "MdbGreenplumClusterSegmentSubclusterResourcesOutputReference",
    "MdbGreenplumClusterTimeouts",
    "MdbGreenplumClusterTimeoutsOutputReference",
    "MdbKafkaCluster",
    "MdbKafkaClusterConfig",
    "MdbKafkaClusterConfigA",
    "MdbKafkaClusterConfigAOutputReference",
    "MdbKafkaClusterConfigKafka",
    "MdbKafkaClusterConfigKafkaKafkaConfig",
    "MdbKafkaClusterConfigKafkaKafkaConfigOutputReference",
    "MdbKafkaClusterConfigKafkaOutputReference",
    "MdbKafkaClusterConfigKafkaResources",
    "MdbKafkaClusterConfigKafkaResourcesOutputReference",
    "MdbKafkaClusterConfigZookeeper",
    "MdbKafkaClusterConfigZookeeperOutputReference",
    "MdbKafkaClusterConfigZookeeperResources",
    "MdbKafkaClusterConfigZookeeperResourcesOutputReference",
    "MdbKafkaClusterHost",
    "MdbKafkaClusterHostList",
    "MdbKafkaClusterHostOutputReference",
    "MdbKafkaClusterMaintenanceWindow",
    "MdbKafkaClusterMaintenanceWindowOutputReference",
    "MdbKafkaClusterTimeouts",
    "MdbKafkaClusterTimeoutsOutputReference",
    "MdbKafkaClusterTopic",
    "MdbKafkaClusterTopicList",
    "MdbKafkaClusterTopicOutputReference",
    "MdbKafkaClusterTopicTopicConfig",
    "MdbKafkaClusterTopicTopicConfigOutputReference",
    "MdbKafkaClusterUser",
    "MdbKafkaClusterUserList",
    "MdbKafkaClusterUserOutputReference",
    "MdbKafkaClusterUserPermission",
    "MdbKafkaClusterUserPermissionList",
    "MdbKafkaClusterUserPermissionOutputReference",
    "MdbKafkaConnector",
    "MdbKafkaConnectorConfig",
    "MdbKafkaConnectorConnectorConfigMirrormaker",
    "MdbKafkaConnectorConnectorConfigMirrormakerList",
    "MdbKafkaConnectorConnectorConfigMirrormakerOutputReference",
    "MdbKafkaConnectorConnectorConfigMirrormakerSourceCluster",
    "MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalCluster",
    "MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalClusterList",
    "MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterExternalClusterOutputReference",
    "MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterOutputReference",
    "MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisCluster",
    "MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisClusterList",
    "MdbKafkaConnectorConnectorConfigMirrormakerSourceClusterThisClusterOutputReference",
    "MdbKafkaConnectorConnectorConfigMirrormakerTargetCluster",
    "MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalCluster",
    "MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalClusterList",
    "MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterExternalClusterOutputReference",
    "MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterOutputReference",
    "MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisCluster",
    "MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisClusterList",
    "MdbKafkaConnectorConnectorConfigMirrormakerTargetClusterThisClusterOutputReference",
    "MdbKafkaTopic",
    "MdbKafkaTopicConfig",
    "MdbKafkaTopicTimeouts",
    "MdbKafkaTopicTimeoutsOutputReference",
    "MdbKafkaTopicTopicConfig",
    "MdbKafkaTopicTopicConfigOutputReference",
    "MdbMongodbCluster",
    "MdbMongodbClusterClusterConfig",
    "MdbMongodbClusterClusterConfigAccess",
    "MdbMongodbClusterClusterConfigAccessOutputReference",
    "MdbMongodbClusterClusterConfigBackupWindowStart",
    "MdbMongodbClusterClusterConfigBackupWindowStartOutputReference",
    "MdbMongodbClusterClusterConfigOutputReference",
    "MdbMongodbClusterConfig",
    "MdbMongodbClusterDatabase",
    "MdbMongodbClusterDatabaseList",
    "MdbMongodbClusterDatabaseOutputReference",
    "MdbMongodbClusterHost",
    "MdbMongodbClusterHostList",
    "MdbMongodbClusterHostOutputReference",
    "MdbMongodbClusterMaintenanceWindow",
    "MdbMongodbClusterMaintenanceWindowOutputReference",
    "MdbMongodbClusterResources",
    "MdbMongodbClusterResourcesOutputReference",
    "MdbMongodbClusterTimeouts",
    "MdbMongodbClusterTimeoutsOutputReference",
    "MdbMongodbClusterUser",
    "MdbMongodbClusterUserList",
    "MdbMongodbClusterUserOutputReference",
    "MdbMongodbClusterUserPermission",
    "MdbMongodbClusterUserPermissionList",
    "MdbMongodbClusterUserPermissionOutputReference",
    "MdbMysqlCluster",
    "MdbMysqlClusterAccess",
    "MdbMysqlClusterAccessOutputReference",
    "MdbMysqlClusterBackupWindowStart",
    "MdbMysqlClusterBackupWindowStartOutputReference",
    "MdbMysqlClusterConfig",
    "MdbMysqlClusterDatabase",
    "MdbMysqlClusterDatabaseList",
    "MdbMysqlClusterDatabaseOutputReference",
    "MdbMysqlClusterHost",
    "MdbMysqlClusterHostList",
    "MdbMysqlClusterHostOutputReference",
    "MdbMysqlClusterMaintenanceWindow",
    "MdbMysqlClusterMaintenanceWindowOutputReference",
    "MdbMysqlClusterResources",
    "MdbMysqlClusterResourcesOutputReference",
    "MdbMysqlClusterRestore",
    "MdbMysqlClusterRestoreOutputReference",
    "MdbMysqlClusterTimeouts",
    "MdbMysqlClusterTimeoutsOutputReference",
    "MdbMysqlClusterUser",
    "MdbMysqlClusterUserConnectionLimits",
    "MdbMysqlClusterUserConnectionLimitsOutputReference",
    "MdbMysqlClusterUserList",
    "MdbMysqlClusterUserOutputReference",
    "MdbMysqlClusterUserPermission",
    "MdbMysqlClusterUserPermissionList",
    "MdbMysqlClusterUserPermissionOutputReference",
    "MdbPostgresqlCluster",
    "MdbPostgresqlClusterConfig",
    "MdbPostgresqlClusterConfigA",
    "MdbPostgresqlClusterConfigAOutputReference",
    "MdbPostgresqlClusterConfigAccess",
    "MdbPostgresqlClusterConfigAccessOutputReference",
    "MdbPostgresqlClusterConfigBackupWindowStart",
    "MdbPostgresqlClusterConfigBackupWindowStartOutputReference",
    "MdbPostgresqlClusterConfigPerformanceDiagnostics",
    "MdbPostgresqlClusterConfigPerformanceDiagnosticsOutputReference",
    "MdbPostgresqlClusterConfigPoolerConfig",
    "MdbPostgresqlClusterConfigPoolerConfigOutputReference",
    "MdbPostgresqlClusterConfigResources",
    "MdbPostgresqlClusterConfigResourcesOutputReference",
    "MdbPostgresqlClusterDatabase",
    "MdbPostgresqlClusterDatabaseExtension",
    "MdbPostgresqlClusterDatabaseExtensionList",
    "MdbPostgresqlClusterDatabaseExtensionOutputReference",
    "MdbPostgresqlClusterDatabaseList",
    "MdbPostgresqlClusterDatabaseOutputReference",
    "MdbPostgresqlClusterHost",
    "MdbPostgresqlClusterHostList",
    "MdbPostgresqlClusterHostOutputReference",
    "MdbPostgresqlClusterMaintenanceWindow",
    "MdbPostgresqlClusterMaintenanceWindowOutputReference",
    "MdbPostgresqlClusterRestore",
    "MdbPostgresqlClusterRestoreOutputReference",
    "MdbPostgresqlClusterTimeouts",
    "MdbPostgresqlClusterTimeoutsOutputReference",
    "MdbPostgresqlClusterUser",
    "MdbPostgresqlClusterUserList",
    "MdbPostgresqlClusterUserOutputReference",
    "MdbPostgresqlClusterUserPermission",
    "MdbPostgresqlClusterUserPermissionList",
    "MdbPostgresqlClusterUserPermissionOutputReference",
    "MdbRedisCluster",
    "MdbRedisClusterConfig",
    "MdbRedisClusterConfigA",
    "MdbRedisClusterConfigAOutputReference",
    "MdbRedisClusterHost",
    "MdbRedisClusterHostList",
    "MdbRedisClusterHostOutputReference",
    "MdbRedisClusterMaintenanceWindow",
    "MdbRedisClusterMaintenanceWindowOutputReference",
    "MdbRedisClusterResources",
    "MdbRedisClusterResourcesOutputReference",
    "MdbRedisClusterTimeouts",
    "MdbRedisClusterTimeoutsOutputReference",
    "MdbSqlserverCluster",
    "MdbSqlserverClusterBackupWindowStart",
    "MdbSqlserverClusterBackupWindowStartOutputReference",
    "MdbSqlserverClusterConfig",
    "MdbSqlserverClusterDatabase",
    "MdbSqlserverClusterDatabaseList",
    "MdbSqlserverClusterDatabaseOutputReference",
    "MdbSqlserverClusterHost",
    "MdbSqlserverClusterHostList",
    "MdbSqlserverClusterHostOutputReference",
    "MdbSqlserverClusterResources",
    "MdbSqlserverClusterResourcesOutputReference",
    "MdbSqlserverClusterTimeouts",
    "MdbSqlserverClusterTimeoutsOutputReference",
    "MdbSqlserverClusterUser",
    "MdbSqlserverClusterUserList",
    "MdbSqlserverClusterUserOutputReference",
    "MdbSqlserverClusterUserPermission",
    "MdbSqlserverClusterUserPermissionList",
    "MdbSqlserverClusterUserPermissionOutputReference",
    "MessageQueue",
    "MessageQueueConfig",
    "OrganizationmanagerOrganizationIamBinding",
    "OrganizationmanagerOrganizationIamBindingConfig",
    "OrganizationmanagerOrganizationIamMember",
    "OrganizationmanagerOrganizationIamMemberConfig",
    "OrganizationmanagerSamlFederation",
    "OrganizationmanagerSamlFederationConfig",
    "OrganizationmanagerSamlFederationSecuritySettings",
    "OrganizationmanagerSamlFederationSecuritySettingsOutputReference",
    "OrganizationmanagerSamlFederationTimeouts",
    "OrganizationmanagerSamlFederationTimeoutsOutputReference",
    "ResourcemanagerCloud",
    "ResourcemanagerCloudConfig",
    "ResourcemanagerCloudIamBinding",
    "ResourcemanagerCloudIamBindingConfig",
    "ResourcemanagerCloudIamMember",
    "ResourcemanagerCloudIamMemberConfig",
    "ResourcemanagerCloudTimeouts",
    "ResourcemanagerCloudTimeoutsOutputReference",
    "ResourcemanagerFolder",
    "ResourcemanagerFolderConfig",
    "ResourcemanagerFolderIamBinding",
    "ResourcemanagerFolderIamBindingConfig",
    "ResourcemanagerFolderIamMember",
    "ResourcemanagerFolderIamMemberConfig",
    "ResourcemanagerFolderIamPolicy",
    "ResourcemanagerFolderIamPolicyConfig",
    "ResourcemanagerFolderTimeouts",
    "ResourcemanagerFolderTimeoutsOutputReference",
    "ServerlessContainer",
    "ServerlessContainerConfig",
    "ServerlessContainerImage",
    "ServerlessContainerImageOutputReference",
    "ServerlessContainerTimeouts",
    "ServerlessContainerTimeoutsOutputReference",
    "StorageBucket",
    "StorageBucketConfig",
    "StorageBucketCorsRule",
    "StorageBucketCorsRuleList",
    "StorageBucketCorsRuleOutputReference",
    "StorageBucketGrant",
    "StorageBucketGrantList",
    "StorageBucketGrantOutputReference",
    "StorageBucketLifecycleRule",
    "StorageBucketLifecycleRuleExpiration",
    "StorageBucketLifecycleRuleExpirationOutputReference",
    "StorageBucketLifecycleRuleList",
    "StorageBucketLifecycleRuleNoncurrentVersionExpiration",
    "StorageBucketLifecycleRuleNoncurrentVersionExpirationOutputReference",
    "StorageBucketLifecycleRuleNoncurrentVersionTransition",
    "StorageBucketLifecycleRuleNoncurrentVersionTransitionList",
    "StorageBucketLifecycleRuleNoncurrentVersionTransitionOutputReference",
    "StorageBucketLifecycleRuleOutputReference",
    "StorageBucketLifecycleRuleTransition",
    "StorageBucketLifecycleRuleTransitionList",
    "StorageBucketLifecycleRuleTransitionOutputReference",
    "StorageBucketLogging",
    "StorageBucketLoggingList",
    "StorageBucketLoggingOutputReference",
    "StorageBucketServerSideEncryptionConfiguration",
    "StorageBucketServerSideEncryptionConfigurationOutputReference",
    "StorageBucketServerSideEncryptionConfigurationRule",
    "StorageBucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefault",
    "StorageBucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefaultOutputReference",
    "StorageBucketServerSideEncryptionConfigurationRuleOutputReference",
    "StorageBucketVersioning",
    "StorageBucketVersioningOutputReference",
    "StorageBucketWebsite",
    "StorageBucketWebsiteOutputReference",
    "StorageObject",
    "StorageObjectConfig",
    "VpcAddress",
    "VpcAddressConfig",
    "VpcAddressExternalIpv4Address",
    "VpcAddressExternalIpv4AddressOutputReference",
    "VpcAddressTimeouts",
    "VpcAddressTimeoutsOutputReference",
    "VpcDefaultSecurityGroup",
    "VpcDefaultSecurityGroupConfig",
    "VpcDefaultSecurityGroupEgress",
    "VpcDefaultSecurityGroupEgressList",
    "VpcDefaultSecurityGroupEgressOutputReference",
    "VpcDefaultSecurityGroupIngress",
    "VpcDefaultSecurityGroupIngressList",
    "VpcDefaultSecurityGroupIngressOutputReference",
    "VpcDefaultSecurityGroupTimeouts",
    "VpcDefaultSecurityGroupTimeoutsOutputReference",
    "VpcNetwork",
    "VpcNetworkConfig",
    "VpcNetworkTimeouts",
    "VpcNetworkTimeoutsOutputReference",
    "VpcRouteTable",
    "VpcRouteTableConfig",
    "VpcRouteTableStaticRoute",
    "VpcRouteTableStaticRouteList",
    "VpcRouteTableStaticRouteOutputReference",
    "VpcRouteTableTimeouts",
    "VpcRouteTableTimeoutsOutputReference",
    "VpcSecurityGroup",
    "VpcSecurityGroupConfig",
    "VpcSecurityGroupEgress",
    "VpcSecurityGroupEgressList",
    "VpcSecurityGroupEgressOutputReference",
    "VpcSecurityGroupIngress",
    "VpcSecurityGroupIngressList",
    "VpcSecurityGroupIngressOutputReference",
    "VpcSecurityGroupRule",
    "VpcSecurityGroupRuleConfig",
    "VpcSecurityGroupRuleTimeouts",
    "VpcSecurityGroupRuleTimeoutsOutputReference",
    "VpcSecurityGroupTimeouts",
    "VpcSecurityGroupTimeoutsOutputReference",
    "VpcSubnet",
    "VpcSubnetConfig",
    "VpcSubnetDhcpOptions",
    "VpcSubnetDhcpOptionsOutputReference",
    "VpcSubnetTimeouts",
    "VpcSubnetTimeoutsOutputReference",
    "YandexProvider",
    "YandexProviderConfig",
    "YdbDatabaseDedicated",
    "YdbDatabaseDedicatedConfig",
    "YdbDatabaseDedicatedLocation",
    "YdbDatabaseDedicatedLocationOutputReference",
    "YdbDatabaseDedicatedLocationRegion",
    "YdbDatabaseDedicatedLocationRegionOutputReference",
    "YdbDatabaseDedicatedScalePolicy",
    "YdbDatabaseDedicatedScalePolicyFixedScale",
    "YdbDatabaseDedicatedScalePolicyFixedScaleOutputReference",
    "YdbDatabaseDedicatedScalePolicyOutputReference",
    "YdbDatabaseDedicatedStorageConfig",
    "YdbDatabaseDedicatedStorageConfigOutputReference",
    "YdbDatabaseDedicatedTimeouts",
    "YdbDatabaseDedicatedTimeoutsOutputReference",
    "YdbDatabaseServerless",
    "YdbDatabaseServerlessConfig",
    "YdbDatabaseServerlessTimeouts",
    "YdbDatabaseServerlessTimeoutsOutputReference",
]

publication.publish()
